@@ -67,6 +67,7 @@ typedef struct _ValaCCodeStatementPrivate ValaCCodeStatementPrivate;
 typedef struct _ValaCCodeBlock ValaCCodeBlock;
 typedef struct _ValaCCodeBlockClass ValaCCodeBlockClass;
 typedef struct _ValaCCodeBlockPrivate ValaCCodeBlockPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LABEL (vala_ccode_label_get_type ())
 #define VALA_CCODE_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LABEL, ValaCCodeLabel))
@@ -87,6 +88,7 @@ typedef struct _ValaCCodeLabelClass ValaCCodeLabelClass;
 
 typedef struct _ValaCCodeCaseStatement ValaCCodeCaseStatement;
 typedef struct _ValaCCodeCaseStatementClass ValaCCodeCaseStatementClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_RETURN_STATEMENT (vala_ccode_return_statement_get_type ())
 #define VALA_CCODE_RETURN_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_RETURN_STATEMENT, ValaCCodeReturnStatement))
@@ -128,9 +130,6 @@ typedef struct _ValaCCodeContinueStatementClass ValaCCodeContinueStatementClass;
 typedef struct _ValaCCodeBreakStatement ValaCCodeBreakStatement;
 typedef struct _ValaCCodeBreakStatementClass ValaCCodeBreakStatementClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -145,9 +144,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -157,9 +153,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a C code block.
- */
 struct _ValaCCodeBlock {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeBlockPrivate * priv;
@@ -210,17 +203,14 @@ void vala_ccode_writer_write_end_block (ValaCCodeWriter* self);
 gboolean vala_ccode_block_get_suppress_newline (ValaCCodeBlock* self);
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 ValaCCodeBlock* vala_ccode_block_new (void);
 ValaCCodeBlock* vala_ccode_block_construct (GType object_type);
-ValaCCodeBlock* vala_ccode_block_new (void);
 void vala_ccode_block_set_suppress_newline (ValaCCodeBlock* self, gboolean value);
 static void vala_ccode_block_finalize (ValaCCodeNode* obj);
 
 
 
-/**
- * Prepend the specified statement to the list of statements.
- */
 void vala_ccode_block_prepend_statement (ValaCCodeBlock* self, ValaCCodeNode* statement) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (statement != NULL);
@@ -228,23 +218,23 @@ void vala_ccode_block_prepend_statement (ValaCCodeBlock* self, ValaCCodeNode* st
 }
 
 
-/**
- * Append the specified statement to the list of statements.
- */
 void vala_ccode_block_add_statement (ValaCCodeBlock* self, ValaCCodeNode* statement) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (statement != NULL);
-	/* allow generic nodes to include comments */
 	gee_collection_add ((GeeCollection*) self->priv->statements, statement);
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeBlock * self;
 	ValaCCodeNode* last_statement;
 	self = (ValaCCodeBlock*) base;
 	g_return_if_fail (writer != NULL);
-	/* the last reachable statement*/
 	last_statement = NULL;
 	vala_ccode_writer_write_begin_block (writer);
 	{
@@ -264,11 +254,9 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 			} else {
 				_tmp0_ = VALA_IS_CCODE_CASE_STATEMENT (statement);
 			}
-			/* determine last reachable statement*/
 			if (_tmp0_) {
 				ValaCCodeNode* _tmp1_;
-				_tmp1_ = NULL;
-				last_statement = (_tmp1_ = NULL, (last_statement == NULL) ? NULL : (last_statement = (vala_ccode_node_unref (last_statement), NULL)), _tmp1_);
+				last_statement = (_tmp1_ = NULL, _vala_ccode_node_unref0 (last_statement), _tmp1_);
 			} else {
 				gboolean _tmp2_;
 				gboolean _tmp3_;
@@ -292,16 +280,13 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 					_tmp2_ = VALA_IS_CCODE_BREAK_STATEMENT (statement);
 				}
 				if (_tmp2_) {
-					ValaCCodeNode* _tmp6_;
 					ValaCCodeNode* _tmp5_;
-					_tmp6_ = NULL;
-					_tmp5_ = NULL;
-					last_statement = (_tmp6_ = (_tmp5_ = statement, (_tmp5_ == NULL) ? NULL : vala_ccode_node_ref (_tmp5_)), (last_statement == NULL) ? NULL : (last_statement = (vala_ccode_node_unref (last_statement), NULL)), _tmp6_);
+					last_statement = (_tmp5_ = _vala_ccode_node_ref0 (statement), _vala_ccode_node_unref0 (last_statement), _tmp5_);
 				}
 			}
-			(statement == NULL) ? NULL : (statement = (vala_ccode_node_unref (statement), NULL));
+			_vala_ccode_node_unref0 (statement);
 		}
-		(_statement_it == NULL) ? NULL : (_statement_it = (gee_collection_object_unref (_statement_it), NULL));
+		_gee_collection_object_unref0 (_statement_it);
 	}
 	{
 		GeeIterator* _statement_it;
@@ -313,29 +298,25 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 			}
 			statement = (ValaCCodeNode*) gee_iterator_get (_statement_it);
 			vala_ccode_node_write (statement, writer);
-			/* only output reachable code*/
 			if (statement == last_statement) {
-				(statement == NULL) ? NULL : (statement = (vala_ccode_node_unref (statement), NULL));
+				_vala_ccode_node_unref0 (statement);
 				break;
 			}
-			(statement == NULL) ? NULL : (statement = (vala_ccode_node_unref (statement), NULL));
+			_vala_ccode_node_unref0 (statement);
 		}
-		(_statement_it == NULL) ? NULL : (_statement_it = (gee_collection_object_unref (_statement_it), NULL));
+		_gee_collection_object_unref0 (_statement_it);
 	}
 	vala_ccode_writer_write_end_block (writer);
 	if (!self->priv->_suppress_newline) {
 		vala_ccode_writer_write_newline (writer);
 	}
-	(last_statement == NULL) ? NULL : (last_statement = (vala_ccode_node_unref (last_statement), NULL));
+	_vala_ccode_node_unref0 (last_statement);
 }
 
 
-/**
- * Represents a C code block.
- */
 ValaCCodeBlock* vala_ccode_block_construct (GType object_type) {
 	ValaCCodeBlock* self;
-	self = (ValaCCodeBlock*) g_type_create_instance (object_type);
+	self = (ValaCCodeBlock*) vala_ccode_statement_construct (object_type);
 	return self;
 }
 
@@ -376,7 +357,7 @@ static void vala_ccode_block_instance_init (ValaCCodeBlock * self) {
 static void vala_ccode_block_finalize (ValaCCodeNode* obj) {
 	ValaCCodeBlock * self;
 	self = VALA_CCODE_BLOCK (obj);
-	(self->priv->statements == NULL) ? NULL : (self->priv->statements = (gee_collection_object_unref (self->priv->statements), NULL));
+	_gee_collection_object_unref0 (self->priv->statements);
 	VALA_CCODE_NODE_CLASS (vala_ccode_block_parent_class)->finalize (obj);
 }
 
