@@ -68,10 +68,9 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
 typedef struct _ValaCCodeCastExpression ValaCCodeCastExpression;
 typedef struct _ValaCCodeCastExpressionClass ValaCCodeCastExpressionClass;
 typedef struct _ValaCCodeCastExpressionPrivate ValaCCodeCastExpressionPrivate;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -86,9 +85,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an expression node in the C code tree.
- */
 struct _ValaCCodeExpression {
 	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
@@ -99,9 +95,6 @@ struct _ValaCCodeExpressionClass {
 	void (*write_inner) (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a type cast in the generated C code.
- */
 struct _ValaCCodeCastExpression {
 	ValaCCodeExpression parent_instance;
 	ValaCCodeCastExpressionPrivate * priv;
@@ -117,6 +110,7 @@ struct _ValaCCodeCastExpressionPrivate {
 };
 
 
+static gpointer vala_ccode_cast_expression_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -136,11 +130,11 @@ GType vala_ccode_cast_expression_get_type (void);
 enum  {
 	VALA_CCODE_CAST_EXPRESSION_DUMMY_PROPERTY
 };
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type);
 void vala_ccode_cast_expression_set_inner (ValaCCodeCastExpression* self, ValaCCodeExpression* value);
 void vala_ccode_cast_expression_set_type_name (ValaCCodeCastExpression* self, const char* value);
 ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* expr, const char* type);
 ValaCCodeCastExpression* vala_ccode_cast_expression_construct (GType object_type, ValaCCodeExpression* expr, const char* type);
-ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* expr, const char* type);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 const char* vala_ccode_cast_expression_get_type_name (ValaCCodeCastExpression* self);
 ValaCCodeExpression* vala_ccode_cast_expression_get_inner (ValaCCodeCastExpression* self);
@@ -148,7 +142,6 @@ void vala_ccode_expression_write_inner (ValaCCodeExpression* self, ValaCCodeWrit
 static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 static void vala_ccode_cast_expression_real_write_inner (ValaCCodeExpression* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_cast_expression_parent_class = NULL;
 static void vala_ccode_cast_expression_finalize (ValaCCodeNode* obj);
 
 
@@ -157,7 +150,7 @@ ValaCCodeCastExpression* vala_ccode_cast_expression_construct (GType object_type
 	ValaCCodeCastExpression* self;
 	g_return_val_if_fail (expr != NULL, NULL);
 	g_return_val_if_fail (type != NULL, NULL);
-	self = (ValaCCodeCastExpression*) g_type_create_instance (object_type);
+	self = (ValaCCodeCastExpression*) vala_ccode_expression_construct (object_type);
 	vala_ccode_cast_expression_set_inner (self, expr);
 	vala_ccode_cast_expression_set_type_name (self, type);
 	return self;
@@ -191,34 +184,37 @@ static void vala_ccode_cast_expression_real_write_inner (ValaCCodeExpression* ba
 
 
 ValaCCodeExpression* vala_ccode_cast_expression_get_inner (ValaCCodeCastExpression* self) {
+	ValaCCodeExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_inner;
+	result = self->priv->_inner;
+	return result;
+}
+
+
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
 }
 
 
 void vala_ccode_cast_expression_set_inner (ValaCCodeCastExpression* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2_;
-	ValaCCodeExpression* _tmp1_;
+	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_inner = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)), _tmp2_);
+	self->priv->_inner = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_inner), _tmp0_);
 }
 
 
 const char* vala_ccode_cast_expression_get_type_name (ValaCCodeCastExpression* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_type_name;
+	result = self->priv->_type_name;
+	return result;
 }
 
 
 void vala_ccode_cast_expression_set_type_name (ValaCCodeCastExpression* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_type_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_type_name = (g_free (self->priv->_type_name), NULL), _tmp2_);
+	self->priv->_type_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_type_name), _tmp0_);
 }
 
 
@@ -239,8 +235,8 @@ static void vala_ccode_cast_expression_instance_init (ValaCCodeCastExpression *
 static void vala_ccode_cast_expression_finalize (ValaCCodeNode* obj) {
 	ValaCCodeCastExpression * self;
 	self = VALA_CCODE_CAST_EXPRESSION (obj);
-	(self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL));
-	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
+	_vala_ccode_node_unref0 (self->priv->_inner);
+	_g_free0 (self->priv->_type_name);
 	VALA_CCODE_NODE_CLASS (vala_ccode_cast_expression_parent_class)->finalize (obj);
 }
 
