@@ -68,10 +68,8 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
 typedef struct _ValaCCodeConstant ValaCCodeConstant;
 typedef struct _ValaCCodeConstantClass ValaCCodeConstantClass;
 typedef struct _ValaCCodeConstantPrivate ValaCCodeConstantPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -86,9 +84,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an expression node in the C code tree.
- */
 struct _ValaCCodeExpression {
 	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
@@ -99,9 +94,6 @@ struct _ValaCCodeExpressionClass {
 	void (*write_inner) (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 };
 
-/**
- * A constant C expression.
- */
 struct _ValaCCodeConstant {
 	ValaCCodeExpression parent_instance;
 	ValaCCodeConstantPrivate * priv;
@@ -116,6 +108,7 @@ struct _ValaCCodeConstantPrivate {
 };
 
 
+static gpointer vala_ccode_constant_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -135,14 +128,13 @@ GType vala_ccode_constant_get_type (void);
 enum  {
 	VALA_CCODE_CONSTANT_DUMMY_PROPERTY
 };
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type);
 void vala_ccode_constant_set_name (ValaCCodeConstant* self, const char* value);
 ValaCCodeConstant* vala_ccode_constant_new (const char* _name);
 ValaCCodeConstant* vala_ccode_constant_construct (GType object_type, const char* _name);
-ValaCCodeConstant* vala_ccode_constant_new (const char* _name);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 const char* vala_ccode_constant_get_name (ValaCCodeConstant* self);
 static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_constant_parent_class = NULL;
 static void vala_ccode_constant_finalize (ValaCCodeNode* obj);
 
 
@@ -150,7 +142,7 @@ static void vala_ccode_constant_finalize (ValaCCodeNode* obj);
 ValaCCodeConstant* vala_ccode_constant_construct (GType object_type, const char* _name) {
 	ValaCCodeConstant* self;
 	g_return_val_if_fail (_name != NULL, NULL);
-	self = (ValaCCodeConstant*) g_type_create_instance (object_type);
+	self = (ValaCCodeConstant*) vala_ccode_expression_construct (object_type);
 	vala_ccode_constant_set_name (self, _name);
 	return self;
 }
@@ -170,18 +162,17 @@ static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter
 
 
 const char* vala_ccode_constant_get_name (ValaCCodeConstant* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_name;
+	result = self->priv->_name;
+	return result;
 }
 
 
 void vala_ccode_constant_set_name (ValaCCodeConstant* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -201,7 +192,7 @@ static void vala_ccode_constant_instance_init (ValaCCodeConstant * self) {
 static void vala_ccode_constant_finalize (ValaCCodeNode* obj) {
 	ValaCCodeConstant * self;
 	self = VALA_CCODE_CONSTANT (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
+	_g_free0 (self->priv->_name);
 	VALA_CCODE_NODE_CLASS (vala_ccode_constant_parent_class)->finalize (obj);
 }
 
