@@ -68,6 +68,8 @@ typedef struct _ValaCCodeEnumPrivate ValaCCodeEnumPrivate;
 
 typedef struct _ValaCCodeEnumValue ValaCCodeEnumValue;
 typedef struct _ValaCCodeEnumValueClass ValaCCodeEnumValueClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -78,10 +80,8 @@ typedef struct _ValaCCodeEnumValueClass ValaCCodeEnumValueClass;
 
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -96,9 +96,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an enum in the C code.
- */
 struct _ValaCCodeEnum {
 	ValaCCodeNode parent_instance;
 	ValaCCodeEnumPrivate * priv;
@@ -114,6 +111,7 @@ struct _ValaCCodeEnumPrivate {
 };
 
 
+static gpointer vala_ccode_enum_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -133,10 +131,10 @@ GType vala_ccode_enum_value_get_type (void);
 enum  {
 	VALA_CCODE_ENUM_DUMMY_PROPERTY
 };
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
 void vala_ccode_enum_set_name (ValaCCodeEnum* self, const char* value);
 ValaCCodeEnum* vala_ccode_enum_new (const char* name);
 ValaCCodeEnum* vala_ccode_enum_construct (GType object_type, const char* name);
-ValaCCodeEnum* vala_ccode_enum_new (const char* name);
 void vala_ccode_enum_add_value (ValaCCodeEnum* self, ValaCCodeEnumValue* value);
 const char* vala_ccode_enum_get_name (ValaCCodeEnum* self);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
@@ -147,14 +145,13 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirecti
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 void vala_ccode_writer_write_end_block (ValaCCodeWriter* self);
 static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_enum_parent_class = NULL;
 static void vala_ccode_enum_finalize (ValaCCodeNode* obj);
 
 
 
 ValaCCodeEnum* vala_ccode_enum_construct (GType object_type, const char* name) {
 	ValaCCodeEnum* self;
-	self = (ValaCCodeEnum*) g_type_create_instance (object_type);
+	self = (ValaCCodeEnum*) vala_ccode_node_construct (object_type);
 	vala_ccode_enum_set_name (self, name);
 	return self;
 }
@@ -165,12 +162,6 @@ ValaCCodeEnum* vala_ccode_enum_new (const char* name) {
 }
 
 
-/**
- * Adds the specified value to this enum.
- *
- * @param name  enum value name
- * @param value optional numerical value
- */
 void vala_ccode_enum_add_value (ValaCCodeEnum* self, ValaCCodeEnumValue* value) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (value != NULL);
@@ -192,8 +183,11 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 	{
 		GeeIterator* _value_it;
 		_value_it = gee_iterable_iterator ((GeeIterable*) self->priv->values);
-		while (gee_iterator_next (_value_it)) {
+		while (TRUE) {
 			ValaCCodeEnumValue* value;
+			if (!gee_iterator_next (_value_it)) {
+				break;
+			}
 			value = (ValaCCodeEnumValue*) gee_iterator_get (_value_it);
 			if (!first) {
 				vala_ccode_writer_write_string (writer, ",");
@@ -202,9 +196,9 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 			vala_ccode_writer_write_indent (writer, NULL);
 			vala_ccode_node_write ((ValaCCodeNode*) value, writer);
 			first = FALSE;
-			(value == NULL) ? NULL : (value = (vala_ccode_node_unref (value), NULL));
+			_vala_ccode_node_unref0 (value);
 		}
-		(_value_it == NULL) ? NULL : (_value_it = (gee_collection_object_unref (_value_it), NULL));
+		_gee_collection_object_unref0 (_value_it);
 	}
 	if (!first) {
 		vala_ccode_writer_write_newline (writer);
@@ -220,18 +214,17 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 
 
 const char* vala_ccode_enum_get_name (ValaCCodeEnum* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_name;
+	result = self->priv->_name;
+	return result;
 }
 
 
 void vala_ccode_enum_set_name (ValaCCodeEnum* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -252,8 +245,8 @@ static void vala_ccode_enum_instance_init (ValaCCodeEnum * self) {
 static void vala_ccode_enum_finalize (ValaCCodeNode* obj) {
 	ValaCCodeEnum * self;
 	self = VALA_CCODE_ENUM (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->values == NULL) ? NULL : (self->priv->values = (gee_collection_object_unref (self->priv->values), NULL));
+	_g_free0 (self->priv->_name);
+	_gee_collection_object_unref0 (self->priv->values);
 	VALA_CCODE_NODE_CLASS (vala_ccode_enum_parent_class)->finalize (obj);
 }
 
