@@ -56,9 +56,6 @@ typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
 typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -73,9 +70,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an expression node in the C code tree.
- */
 struct _ValaCCodeExpression {
 	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
@@ -87,6 +81,7 @@ struct _ValaCCodeExpressionClass {
 };
 
 
+static gpointer vala_ccode_expression_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -107,7 +102,8 @@ enum  {
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 void vala_ccode_expression_write_inner (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 static void vala_ccode_expression_real_write_inner (ValaCCodeExpression* self, ValaCCodeWriter* writer);
-static gpointer vala_ccode_expression_parent_class = NULL;
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type);
 
 
 
@@ -123,6 +119,13 @@ void vala_ccode_expression_write_inner (ValaCCodeExpression* self, ValaCCodeWrit
 }
 
 
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type) {
+	ValaCCodeExpression* self;
+	self = (ValaCCodeExpression*) vala_ccode_node_construct (object_type);
+	return self;
+}
+
+
 static void vala_ccode_expression_class_init (ValaCCodeExpressionClass * klass) {
 	vala_ccode_expression_parent_class = g_type_class_peek_parent (klass);
 	VALA_CCODE_EXPRESSION_CLASS (klass)->write_inner = vala_ccode_expression_real_write_inner;
