@@ -79,6 +79,7 @@ typedef struct _ValaCCodeExpressionStatementPrivate ValaCCodeExpressionStatement
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_COMMA_EXPRESSION (vala_ccode_comma_expression_get_type ())
 #define VALA_CCODE_COMMA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_COMMA_EXPRESSION, ValaCCodeCommaExpression))
@@ -89,6 +90,7 @@ typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
 
 typedef struct _ValaCCodeCommaExpression ValaCCodeCommaExpression;
 typedef struct _ValaCCodeCommaExpressionClass ValaCCodeCommaExpressionClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_PARENTHESIZED_EXPRESSION (vala_ccode_parenthesized_expression_get_type ())
 #define VALA_CCODE_PARENTHESIZED_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_PARENTHESIZED_EXPRESSION, ValaCCodeParenthesizedExpression))
@@ -110,9 +112,6 @@ typedef struct _ValaCCodeParenthesizedExpressionClass ValaCCodeParenthesizedExpr
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -127,9 +126,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -139,9 +135,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a C code statement that evaluates a given expression.
- */
 struct _ValaCCodeExpressionStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeExpressionStatementPrivate * priv;
@@ -156,6 +149,7 @@ struct _ValaCCodeExpressionStatementPrivate {
 };
 
 
+static gpointer vala_ccode_expression_statement_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -176,10 +170,10 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_EXPRESSION_STATEMENT_DUMMY_PROPERTY
 };
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 void vala_ccode_expression_statement_set_expression (ValaCCodeExpressionStatement* self, ValaCCodeExpression* value);
 ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpression* expr);
 ValaCCodeExpressionStatement* vala_ccode_expression_statement_construct (GType object_type, ValaCCodeExpression* expr);
-ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpression* expr);
 ValaCCodeExpression* vala_ccode_expression_statement_get_expression (ValaCCodeExpressionStatement* self);
 GType vala_ccode_comma_expression_get_type (void);
 GeeList* vala_ccode_comma_expression_get_inner (ValaCCodeCommaExpression* self);
@@ -193,7 +187,6 @@ ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
-static gpointer vala_ccode_expression_statement_parent_class = NULL;
 static void vala_ccode_expression_statement_finalize (ValaCCodeNode* obj);
 
 
@@ -201,7 +194,7 @@ static void vala_ccode_expression_statement_finalize (ValaCCodeNode* obj);
 ValaCCodeExpressionStatement* vala_ccode_expression_statement_construct (GType object_type, ValaCCodeExpression* expr) {
 	ValaCCodeExpressionStatement* self;
 	g_return_val_if_fail (expr != NULL, NULL);
-	self = (ValaCCodeExpressionStatement*) g_type_create_instance (object_type);
+	self = (ValaCCodeExpressionStatement*) vala_ccode_statement_construct (object_type);
 	vala_ccode_expression_statement_set_expression (self, expr);
 	return self;
 }
@@ -212,45 +205,43 @@ ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpr
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeExpressionStatement * self;
 	self = (ValaCCodeExpressionStatement*) base;
 	g_return_if_fail (writer != NULL);
 	if (VALA_IS_CCODE_COMMA_EXPRESSION (self->priv->_expression)) {
-		ValaCCodeCommaExpression* _tmp1_;
 		ValaCCodeExpression* _tmp0_;
 		ValaCCodeCommaExpression* ccomma;
-		/* expand comma expression into multiple statements
-		 to improve code readability*/
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		ccomma = (_tmp1_ = (_tmp0_ = self->priv->_expression, VALA_IS_CCODE_COMMA_EXPRESSION (_tmp0_) ? ((ValaCCodeCommaExpression*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_));
+		ccomma = _vala_ccode_node_ref0 ((_tmp0_ = self->priv->_expression, VALA_IS_CCODE_COMMA_EXPRESSION (_tmp0_) ? ((ValaCCodeCommaExpression*) _tmp0_) : NULL));
 		{
-			GeeList* _tmp2_;
-			GeeIterator* _tmp3_;
+			GeeList* _tmp1_;
+			GeeIterator* _tmp2_;
 			GeeIterator* _expr_it;
-			_tmp2_ = NULL;
-			_tmp3_ = NULL;
-			_expr_it = (_tmp3_ = gee_iterable_iterator ((GeeIterable*) (_tmp2_ = vala_ccode_comma_expression_get_inner (ccomma))), (_tmp2_ == NULL) ? NULL : (_tmp2_ = (gee_collection_object_unref (_tmp2_), NULL)), _tmp3_);
-			while (gee_iterator_next (_expr_it)) {
+			_expr_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_ccode_comma_expression_get_inner (ccomma))), _gee_collection_object_unref0 (_tmp1_), _tmp2_);
+			while (TRUE) {
 				ValaCCodeExpression* expr;
+				if (!gee_iterator_next (_expr_it)) {
+					break;
+				}
 				expr = (ValaCCodeExpression*) gee_iterator_get (_expr_it);
 				vala_ccode_expression_statement_write_expression (self, writer, expr);
-				(expr == NULL) ? NULL : (expr = (vala_ccode_node_unref (expr), NULL));
+				_vala_ccode_node_unref0 (expr);
 			}
-			(_expr_it == NULL) ? NULL : (_expr_it = (gee_collection_object_unref (_expr_it), NULL));
+			_gee_collection_object_unref0 (_expr_it);
 		}
-		(ccomma == NULL) ? NULL : (ccomma = (vala_ccode_node_unref (ccomma), NULL));
+		_vala_ccode_node_unref0 (ccomma);
 	} else {
 		if (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (self->priv->_expression)) {
-			ValaCCodeParenthesizedExpression* _tmp5_;
-			ValaCCodeExpression* _tmp4_;
+			ValaCCodeExpression* _tmp3_;
 			ValaCCodeParenthesizedExpression* cpar;
-			_tmp5_ = NULL;
-			_tmp4_ = NULL;
-			cpar = (_tmp5_ = (_tmp4_ = self->priv->_expression, VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (_tmp4_) ? ((ValaCCodeParenthesizedExpression*) _tmp4_) : NULL), (_tmp5_ == NULL) ? NULL : vala_ccode_node_ref (_tmp5_));
+			cpar = _vala_ccode_node_ref0 ((_tmp3_ = self->priv->_expression, VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (_tmp3_) ? ((ValaCCodeParenthesizedExpression*) _tmp3_) : NULL));
 			vala_ccode_expression_statement_write_expression (self, writer, vala_ccode_parenthesized_expression_get_inner (cpar));
-			(cpar == NULL) ? NULL : (cpar = (vala_ccode_node_unref (cpar), NULL));
+			_vala_ccode_node_unref0 (cpar);
 		} else {
 			vala_ccode_expression_statement_write_expression (self, writer, self->priv->_expression);
 		}
@@ -271,18 +262,17 @@ static void vala_ccode_expression_statement_write_expression (ValaCCodeExpressio
 
 
 ValaCCodeExpression* vala_ccode_expression_statement_get_expression (ValaCCodeExpressionStatement* self) {
+	ValaCCodeExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_expression;
+	result = self->priv->_expression;
+	return result;
 }
 
 
 void vala_ccode_expression_statement_set_expression (ValaCCodeExpressionStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2_;
-	ValaCCodeExpression* _tmp1_;
+	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL)), _tmp2_);
+	self->priv->_expression = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_expression), _tmp0_);
 }
 
 
@@ -302,7 +292,7 @@ static void vala_ccode_expression_statement_instance_init (ValaCCodeExpressionSt
 static void vala_ccode_expression_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeExpressionStatement * self;
 	self = VALA_CCODE_EXPRESSION_STATEMENT (obj);
-	(self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL));
+	_vala_ccode_node_unref0 (self->priv->_expression);
 	VALA_CCODE_NODE_CLASS (vala_ccode_expression_statement_parent_class)->finalize (obj);
 }
 
