@@ -57,10 +57,8 @@ typedef struct _ValaCCodeWriterClass ValaCCodeWriterClass;
 typedef struct _ValaCCodeFormalParameter ValaCCodeFormalParameter;
 typedef struct _ValaCCodeFormalParameterClass ValaCCodeFormalParameterClass;
 typedef struct _ValaCCodeFormalParameterPrivate ValaCCodeFormalParameterPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -75,9 +73,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a formal parameter in a C method signature.
- */
 struct _ValaCCodeFormalParameter {
 	ValaCCodeNode parent_instance;
 	ValaCCodeFormalParameterPrivate * priv;
@@ -113,6 +108,7 @@ GType vala_ccode_formal_parameter_get_type (void);
 enum  {
 	VALA_CCODE_FORMAL_PARAMETER_DUMMY_PROPERTY
 };
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
 void vala_ccode_formal_parameter_set_name (ValaCCodeFormalParameter* self, const char* value);
 void vala_ccode_formal_parameter_set_type_name (ValaCCodeFormalParameter* self, const char* value);
 ValaCCodeFormalParameter* vala_ccode_formal_parameter_new (const char* n, const char* type);
@@ -133,7 +129,7 @@ ValaCCodeFormalParameter* vala_ccode_formal_parameter_construct (GType object_ty
 	ValaCCodeFormalParameter* self;
 	g_return_val_if_fail (n != NULL, NULL);
 	g_return_val_if_fail (type != NULL, NULL);
-	self = (ValaCCodeFormalParameter*) g_type_create_instance (object_type);
+	self = (ValaCCodeFormalParameter*) vala_ccode_node_construct (object_type);
 	vala_ccode_formal_parameter_set_name (self, n);
 	vala_ccode_formal_parameter_set_type_name (self, type);
 	return self;
@@ -147,7 +143,7 @@ ValaCCodeFormalParameter* vala_ccode_formal_parameter_new (const char* n, const
 
 ValaCCodeFormalParameter* vala_ccode_formal_parameter_construct_with_ellipsis (GType object_type) {
 	ValaCCodeFormalParameter* self;
-	self = (ValaCCodeFormalParameter*) g_type_create_instance (object_type);
+	self = (ValaCCodeFormalParameter*) vala_ccode_node_construct (object_type);
 	vala_ccode_formal_parameter_set_ellipsis (self, TRUE);
 	return self;
 }
@@ -181,12 +177,9 @@ const char* vala_ccode_formal_parameter_get_name (ValaCCodeFormalParameter* self
 
 
 void vala_ccode_formal_parameter_set_name (ValaCCodeFormalParameter* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -199,12 +192,9 @@ const char* vala_ccode_formal_parameter_get_type_name (ValaCCodeFormalParameter*
 
 
 void vala_ccode_formal_parameter_set_type_name (ValaCCodeFormalParameter* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_type_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_type_name = (g_free (self->priv->_type_name), NULL), _tmp1_);
+	self->priv->_type_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_type_name), _tmp0_);
 }
 
 
@@ -238,8 +228,8 @@ static void vala_ccode_formal_parameter_instance_init (ValaCCodeFormalParameter
 static void vala_ccode_formal_parameter_finalize (ValaCCodeNode* obj) {
 	ValaCCodeFormalParameter * self;
 	self = VALA_CCODE_FORMAL_PARAMETER (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
+	_g_free0 (self->priv->_name);
+	_g_free0 (self->priv->_type_name);
 	VALA_CCODE_NODE_CLASS (vala_ccode_formal_parameter_parent_class)->finalize (obj);
 }
 
