@@ -79,6 +79,8 @@ typedef struct _ValaCCodeForStatementPrivate ValaCCodeForStatementPrivate;
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -90,9 +92,6 @@ typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -107,9 +106,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -119,9 +115,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a for iteration statement in the C code.
- */
 struct _ValaCCodeForStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeForStatementPrivate * priv;
@@ -160,6 +153,7 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_FOR_STATEMENT_DUMMY_PROPERTY
 };
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 void vala_ccode_for_statement_set_condition (ValaCCodeForStatement* self, ValaCCodeExpression* value);
 void vala_ccode_for_statement_set_body (ValaCCodeForStatement* self, ValaCCodeStatement* value);
 ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body);
@@ -180,7 +174,7 @@ static void vala_ccode_for_statement_finalize (ValaCCodeNode* obj);
 
 ValaCCodeForStatement* vala_ccode_for_statement_construct (GType object_type, ValaCCodeExpression* condition, ValaCCodeStatement* body) {
 	ValaCCodeForStatement* self;
-	self = (ValaCCodeForStatement*) g_type_create_instance (object_type);
+	self = (ValaCCodeForStatement*) vala_ccode_statement_construct (object_type);
 	vala_ccode_for_statement_set_condition (self, condition);
 	vala_ccode_for_statement_set_body (self, body);
 	return self;
@@ -192,11 +186,6 @@ ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condit
 }
 
 
-/**
- * Appends the specified expression to the list of initializers.
- *
- * @param expr an initializer expression
- */
 void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (expr != NULL);
@@ -204,11 +193,6 @@ void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, Vala
 }
 
 
-/**
- * Appends the specified expression to the iterator.
- *
- * @param expr an iterator expression
- */
 void vala_ccode_for_statement_add_iterator (ValaCCodeForStatement* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (expr != NULL);
@@ -242,9 +226,9 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 			if (init_expr != NULL) {
 				vala_ccode_node_write ((ValaCCodeNode*) init_expr, writer);
 			}
-			(init_expr == NULL) ? NULL : (init_expr = (vala_ccode_node_unref (init_expr), NULL));
+			_vala_ccode_node_unref0 (init_expr);
 		}
-		(_init_expr_it == NULL) ? NULL : (_init_expr_it = (gee_collection_object_unref (_init_expr_it), NULL));
+		_gee_collection_object_unref0 (_init_expr_it);
 	}
 	vala_ccode_writer_write_string (writer, "; ");
 	if (self->priv->_condition != NULL) {
@@ -269,9 +253,9 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 			if (it_expr != NULL) {
 				vala_ccode_node_write ((ValaCCodeNode*) it_expr, writer);
 			}
-			(it_expr == NULL) ? NULL : (it_expr = (vala_ccode_node_unref (it_expr), NULL));
+			_vala_ccode_node_unref0 (it_expr);
 		}
-		(_it_expr_it == NULL) ? NULL : (_it_expr_it = (gee_collection_object_unref (_it_expr_it), NULL));
+		_gee_collection_object_unref0 (_it_expr_it);
 	}
 	vala_ccode_writer_write_string (writer, ")");
 	vala_ccode_node_write ((ValaCCodeNode*) self->priv->_body, writer);
@@ -286,13 +270,15 @@ ValaCCodeExpression* vala_ccode_for_statement_get_condition (ValaCCodeForStateme
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 void vala_ccode_for_statement_set_condition (ValaCCodeForStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_condition = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp1_);
+	self->priv->_condition = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_condition), _tmp0_);
 }
 
 
@@ -305,12 +291,9 @@ ValaCCodeStatement* vala_ccode_for_statement_get_body (ValaCCodeForStatement* se
 
 
 void vala_ccode_for_statement_set_body (ValaCCodeForStatement* self, ValaCCodeStatement* value) {
-	ValaCCodeStatement* _tmp1_;
 	ValaCCodeStatement* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_body = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)), _tmp1_);
+	self->priv->_body = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_body), _tmp0_);
 }
 
 
@@ -332,10 +315,10 @@ static void vala_ccode_for_statement_instance_init (ValaCCodeForStatement * self
 static void vala_ccode_for_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeForStatement * self;
 	self = VALA_CCODE_FOR_STATEMENT (obj);
-	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL));
-	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL));
-	(self->priv->initializer == NULL) ? NULL : (self->priv->initializer = (gee_collection_object_unref (self->priv->initializer), NULL));
-	(self->priv->iterator == NULL) ? NULL : (self->priv->iterator = (gee_collection_object_unref (self->priv->iterator), NULL));
+	_vala_ccode_node_unref0 (self->priv->_condition);
+	_vala_ccode_node_unref0 (self->priv->_body);
+	_gee_collection_object_unref0 (self->priv->initializer);
+	_gee_collection_object_unref0 (self->priv->iterator);
 	VALA_CCODE_NODE_CLASS (vala_ccode_for_statement_parent_class)->finalize (obj);
 }
 
