@@ -57,6 +57,7 @@ typedef struct _ValaCCodeWriterClass ValaCCodeWriterClass;
 typedef struct _ValaCCodeIncludeDirective ValaCCodeIncludeDirective;
 typedef struct _ValaCCodeIncludeDirectiveClass ValaCCodeIncludeDirectiveClass;
 typedef struct _ValaCCodeIncludeDirectivePrivate ValaCCodeIncludeDirectivePrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -68,9 +69,6 @@ typedef struct _ValaCCodeIncludeDirectivePrivate ValaCCodeIncludeDirectivePrivat
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -85,9 +83,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an include preprocessor directive in the C code.
- */
 struct _ValaCCodeIncludeDirective {
 	ValaCCodeNode parent_instance;
 	ValaCCodeIncludeDirectivePrivate * priv;
@@ -103,6 +98,7 @@ struct _ValaCCodeIncludeDirectivePrivate {
 };
 
 
+static gpointer vala_ccode_include_directive_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -121,11 +117,11 @@ GType vala_ccode_include_directive_get_type (void);
 enum  {
 	VALA_CCODE_INCLUDE_DIRECTIVE_DUMMY_PROPERTY
 };
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
 void vala_ccode_include_directive_set_filename (ValaCCodeIncludeDirective* self, const char* value);
 void vala_ccode_include_directive_set_local (ValaCCodeIncludeDirective* self, gboolean value);
 ValaCCodeIncludeDirective* vala_ccode_include_directive_new (const char* _filename, gboolean _local);
 ValaCCodeIncludeDirective* vala_ccode_include_directive_construct (GType object_type, const char* _filename, gboolean _local);
-ValaCCodeIncludeDirective* vala_ccode_include_directive_new (const char* _filename, gboolean _local);
 GType vala_ccode_line_directive_get_type (void);
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
@@ -133,7 +129,6 @@ gboolean vala_ccode_include_directive_get_local (ValaCCodeIncludeDirective* self
 const char* vala_ccode_include_directive_get_filename (ValaCCodeIncludeDirective* self);
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 static void vala_ccode_include_directive_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_include_directive_parent_class = NULL;
 static void vala_ccode_include_directive_finalize (ValaCCodeNode* obj);
 
 
@@ -141,7 +136,7 @@ static void vala_ccode_include_directive_finalize (ValaCCodeNode* obj);
 ValaCCodeIncludeDirective* vala_ccode_include_directive_construct (GType object_type, const char* _filename, gboolean _local) {
 	ValaCCodeIncludeDirective* self;
 	g_return_val_if_fail (_filename != NULL, NULL);
-	self = (ValaCCodeIncludeDirective*) g_type_create_instance (object_type);
+	self = (ValaCCodeIncludeDirective*) vala_ccode_node_construct (object_type);
 	vala_ccode_include_directive_set_filename (self, _filename);
 	vala_ccode_include_directive_set_local (self, _local);
 	return self;
@@ -173,24 +168,25 @@ static void vala_ccode_include_directive_real_write (ValaCCodeNode* base, ValaCC
 
 
 const char* vala_ccode_include_directive_get_filename (ValaCCodeIncludeDirective* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_filename;
+	result = self->priv->_filename;
+	return result;
 }
 
 
 void vala_ccode_include_directive_set_filename (ValaCCodeIncludeDirective* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_filename = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2_);
+	self->priv->_filename = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_filename), _tmp0_);
 }
 
 
 gboolean vala_ccode_include_directive_get_local (ValaCCodeIncludeDirective* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_local;
+	result = self->priv->_local;
+	return result;
 }
 
 
@@ -216,7 +212,7 @@ static void vala_ccode_include_directive_instance_init (ValaCCodeIncludeDirectiv
 static void vala_ccode_include_directive_finalize (ValaCCodeNode* obj) {
 	ValaCCodeIncludeDirective * self;
 	self = VALA_CCODE_INCLUDE_DIRECTIVE (obj);
-	self->priv->_filename = (g_free (self->priv->_filename), NULL);
+	_g_free0 (self->priv->_filename);
 	VALA_CCODE_NODE_CLASS (vala_ccode_include_directive_parent_class)->finalize (obj);
 }
 
