@@ -68,10 +68,9 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
 typedef struct _ValaCCodeMemberAccess ValaCCodeMemberAccess;
 typedef struct _ValaCCodeMemberAccessClass ValaCCodeMemberAccessClass;
 typedef struct _ValaCCodeMemberAccessPrivate ValaCCodeMemberAccessPrivate;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -86,9 +85,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an expression node in the C code tree.
- */
 struct _ValaCCodeExpression {
 	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
@@ -99,9 +95,6 @@ struct _ValaCCodeExpressionClass {
 	void (*write_inner) (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an access to a struct member in the C code.
- */
 struct _ValaCCodeMemberAccess {
 	ValaCCodeExpression parent_instance;
 	ValaCCodeMemberAccessPrivate * priv;
@@ -138,6 +131,7 @@ GType vala_ccode_member_access_get_type (void);
 enum  {
 	VALA_CCODE_MEMBER_ACCESS_DUMMY_PROPERTY
 };
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type);
 void vala_ccode_member_access_set_inner (ValaCCodeMemberAccess* self, ValaCCodeExpression* value);
 void vala_ccode_member_access_set_member_name (ValaCCodeMemberAccess* self, const char* value);
 void vala_ccode_member_access_set_is_pointer (ValaCCodeMemberAccess* self, gboolean value);
@@ -159,7 +153,7 @@ ValaCCodeMemberAccess* vala_ccode_member_access_construct (GType object_type, Va
 	ValaCCodeMemberAccess* self;
 	g_return_val_if_fail (container != NULL, NULL);
 	g_return_val_if_fail (member != NULL, NULL);
-	self = (ValaCCodeMemberAccess*) g_type_create_instance (object_type);
+	self = (ValaCCodeMemberAccess*) vala_ccode_expression_construct (object_type);
 	vala_ccode_member_access_set_inner (self, container);
 	vala_ccode_member_access_set_member_name (self, member);
 	vala_ccode_member_access_set_is_pointer (self, pointer);
@@ -176,7 +170,7 @@ ValaCCodeMemberAccess* vala_ccode_member_access_construct_pointer (GType object_
 	ValaCCodeMemberAccess* self;
 	g_return_val_if_fail (container != NULL, NULL);
 	g_return_val_if_fail (member != NULL, NULL);
-	self = (ValaCCodeMemberAccess*) g_type_create_instance (object_type);
+	self = (ValaCCodeMemberAccess*) vala_ccode_expression_construct (object_type);
 	vala_ccode_member_access_set_inner (self, container);
 	vala_ccode_member_access_set_member_name (self, member);
 	vala_ccode_member_access_set_is_pointer (self, TRUE);
@@ -211,13 +205,15 @@ ValaCCodeExpression* vala_ccode_member_access_get_inner (ValaCCodeMemberAccess*
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 void vala_ccode_member_access_set_inner (ValaCCodeMemberAccess* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_inner = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)), _tmp1_);
+	self->priv->_inner = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_inner), _tmp0_);
 }
 
 
@@ -230,12 +226,9 @@ const char* vala_ccode_member_access_get_member_name (ValaCCodeMemberAccess* sel
 
 
 void vala_ccode_member_access_set_member_name (ValaCCodeMemberAccess* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_member_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_member_name = (g_free (self->priv->_member_name), NULL), _tmp1_);
+	self->priv->_member_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_member_name), _tmp0_);
 }
 
 
@@ -269,8 +262,8 @@ static void vala_ccode_member_access_instance_init (ValaCCodeMemberAccess * self
 static void vala_ccode_member_access_finalize (ValaCCodeNode* obj) {
 	ValaCCodeMemberAccess * self;
 	self = VALA_CCODE_MEMBER_ACCESS (obj);
-	(self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL));
-	self->priv->_member_name = (g_free (self->priv->_member_name), NULL);
+	_vala_ccode_node_unref0 (self->priv->_inner);
+	_g_free0 (self->priv->_member_name);
 	VALA_CCODE_NODE_CLASS (vala_ccode_member_access_parent_class)->finalize (obj);
 }
 
