@@ -69,6 +69,7 @@ typedef struct _ValaCCodeFragmentPrivate ValaCCodeFragmentPrivate;
 typedef struct _ValaCCodeOnceSection ValaCCodeOnceSection;
 typedef struct _ValaCCodeOnceSectionClass ValaCCodeOnceSectionClass;
 typedef struct _ValaCCodeOnceSectionPrivate ValaCCodeOnceSectionPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -79,10 +80,9 @@ typedef struct _ValaCCodeOnceSectionPrivate ValaCCodeOnceSectionPrivate;
 
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -97,9 +97,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a container for C code nodes.
- */
 struct _ValaCCodeFragment {
 	ValaCCodeNode parent_instance;
 	ValaCCodeFragmentPrivate * priv;
@@ -109,9 +106,6 @@ struct _ValaCCodeFragmentClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a section that should only to processed once.
- */
 struct _ValaCCodeOnceSection {
 	ValaCCodeFragment parent_instance;
 	ValaCCodeOnceSectionPrivate * priv;
@@ -126,6 +120,7 @@ struct _ValaCCodeOnceSectionPrivate {
 };
 
 
+static gpointer vala_ccode_once_section_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -145,10 +140,11 @@ GType vala_ccode_once_section_get_type (void);
 enum  {
 	VALA_CCODE_ONCE_SECTION_DUMMY_PROPERTY
 };
+ValaCCodeFragment* vala_ccode_fragment_new (void);
+ValaCCodeFragment* vala_ccode_fragment_construct (GType object_type);
 void vala_ccode_once_section_set_define (ValaCCodeOnceSection* self, const char* value);
 ValaCCodeOnceSection* vala_ccode_once_section_new (const char* def);
 ValaCCodeOnceSection* vala_ccode_once_section_construct (GType object_type, const char* def);
-ValaCCodeOnceSection* vala_ccode_once_section_new (const char* def);
 GType vala_ccode_line_directive_get_type (void);
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
@@ -158,7 +154,6 @@ GeeList* vala_ccode_fragment_get_children (ValaCCodeFragment* self);
 void vala_ccode_node_write_combined (ValaCCodeNode* self, ValaCCodeWriter* writer);
 static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_once_section_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_once_section_parent_class = NULL;
 static void vala_ccode_once_section_finalize (ValaCCodeNode* obj);
 
 
@@ -166,7 +161,7 @@ static void vala_ccode_once_section_finalize (ValaCCodeNode* obj);
 ValaCCodeOnceSection* vala_ccode_once_section_construct (GType object_type, const char* def) {
 	ValaCCodeOnceSection* self;
 	g_return_val_if_fail (def != NULL, NULL);
-	self = (ValaCCodeOnceSection*) g_type_create_instance (object_type);
+	self = (ValaCCodeOnceSection*) vala_ccode_fragment_construct (object_type);
 	vala_ccode_once_section_set_define (self, def);
 	return self;
 }
@@ -192,16 +187,17 @@ static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWr
 		GeeList* _tmp0_;
 		GeeIterator* _tmp1_;
 		GeeIterator* _node_it;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		_node_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_ccode_fragment_get_children ((ValaCCodeFragment*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
-		while (gee_iterator_next (_node_it)) {
+		_node_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_ccode_fragment_get_children ((ValaCCodeFragment*) self))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
+		while (TRUE) {
 			ValaCCodeNode* node;
+			if (!gee_iterator_next (_node_it)) {
+				break;
+			}
 			node = (ValaCCodeNode*) gee_iterator_get (_node_it);
 			vala_ccode_node_write_combined (node, writer);
-			(node == NULL) ? NULL : (node = (vala_ccode_node_unref (node), NULL));
+			_vala_ccode_node_unref0 (node);
 		}
-		(_node_it == NULL) ? NULL : (_node_it = (gee_collection_object_unref (_node_it), NULL));
+		_gee_collection_object_unref0 (_node_it);
 	}
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#endif");
@@ -217,18 +213,17 @@ static void vala_ccode_once_section_real_write_declaration (ValaCCodeNode* base,
 
 
 const char* vala_ccode_once_section_get_define (ValaCCodeOnceSection* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_define;
+	result = self->priv->_define;
+	return result;
 }
 
 
 void vala_ccode_once_section_set_define (ValaCCodeOnceSection* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_define = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_define = (g_free (self->priv->_define), NULL), _tmp2_);
+	self->priv->_define = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_define), _tmp0_);
 }
 
 
@@ -249,7 +244,7 @@ static void vala_ccode_once_section_instance_init (ValaCCodeOnceSection * self)
 static void vala_ccode_once_section_finalize (ValaCCodeNode* obj) {
 	ValaCCodeOnceSection * self;
 	self = VALA_CCODE_ONCE_SECTION (obj);
-	self->priv->_define = (g_free (self->priv->_define), NULL);
+	_g_free0 (self->priv->_define);
 	VALA_CCODE_NODE_CLASS (vala_ccode_once_section_parent_class)->finalize (obj);
 }
 
