@@ -78,6 +78,8 @@ typedef struct _ValaCCodeStatementClass ValaCCodeStatementClass;
 
 typedef struct _ValaCCodeDeclaration ValaCCodeDeclaration;
 typedef struct _ValaCCodeDeclarationClass ValaCCodeDeclarationClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_DECLARATOR (vala_ccode_declarator_get_type ())
 #define VALA_CCODE_DECLARATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_DECLARATOR, ValaCCodeDeclarator))
@@ -108,10 +110,8 @@ typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
 
 typedef struct _ValaCCodeVariableDeclarator ValaCCodeVariableDeclarator;
 typedef struct _ValaCCodeVariableDeclaratorClass ValaCCodeVariableDeclaratorClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -126,9 +126,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a struct declaration in the C code.
- */
 struct _ValaCCodeStruct {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStructPrivate * priv;
@@ -144,6 +141,7 @@ struct _ValaCCodeStructPrivate {
 };
 
 
+static gpointer vala_ccode_struct_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -164,10 +162,10 @@ GType vala_ccode_declaration_get_type (void);
 enum  {
 	VALA_CCODE_STRUCT_DUMMY_PROPERTY
 };
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
 void vala_ccode_struct_set_name (ValaCCodeStruct* self, const char* value);
 ValaCCodeStruct* vala_ccode_struct_new (const char* name);
 ValaCCodeStruct* vala_ccode_struct_construct (GType object_type, const char* name);
-ValaCCodeStruct* vala_ccode_struct_new (const char* name);
 void vala_ccode_struct_add_declaration (ValaCCodeStruct* self, ValaCCodeDeclaration* decl);
 ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name);
 ValaCCodeDeclaration* vala_ccode_declaration_construct (GType object_type, const char* type_name);
@@ -185,7 +183,6 @@ void vala_ccode_node_write_declaration (ValaCCodeNode* self, ValaCCodeWriter* wr
 void vala_ccode_writer_write_end_block (ValaCCodeWriter* self);
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 static void vala_ccode_struct_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_struct_parent_class = NULL;
 static void vala_ccode_struct_finalize (ValaCCodeNode* obj);
 
 
@@ -193,7 +190,7 @@ static void vala_ccode_struct_finalize (ValaCCodeNode* obj);
 ValaCCodeStruct* vala_ccode_struct_construct (GType object_type, const char* name) {
 	ValaCCodeStruct* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaCCodeStruct*) g_type_create_instance (object_type);
+	self = (ValaCCodeStruct*) vala_ccode_node_construct (object_type);
 	vala_ccode_struct_set_name (self, name);
 	return self;
 }
@@ -204,11 +201,6 @@ ValaCCodeStruct* vala_ccode_struct_new (const char* name) {
 }
 
 
-/**
- * Adds the specified declaration as member to this struct.
- *
- * @param decl a variable declaration
- */
 void vala_ccode_struct_add_declaration (ValaCCodeStruct* self, ValaCCodeDeclaration* decl) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (decl != NULL);
@@ -216,12 +208,6 @@ void vala_ccode_struct_add_declaration (ValaCCodeStruct* self, ValaCCodeDeclarat
 }
 
 
-/**
- * Adds a variable with the specified type and name to this struct.
- *
- * @param type_name field type
- * @param name      member name
- */
 void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name, const char* name) {
 	ValaCCodeDeclaration* decl;
 	ValaCCodeVariableDeclarator* _tmp0_;
@@ -229,11 +215,10 @@ void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name,
 	g_return_if_fail (type_name != NULL);
 	g_return_if_fail (name != NULL);
 	decl = vala_ccode_declaration_new (type_name);
-	_tmp0_ = NULL;
 	vala_ccode_declaration_add_declarator (decl, (ValaCCodeDeclarator*) (_tmp0_ = vala_ccode_variable_declarator_new (name, NULL, NULL)));
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_ccode_node_unref (_tmp0_), NULL));
+	_vala_ccode_node_unref0 (_tmp0_);
 	vala_ccode_struct_add_declaration (self, decl);
-	(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
+	_vala_ccode_node_unref0 (decl);
 }
 
 
@@ -247,13 +232,16 @@ static void vala_ccode_struct_real_write (ValaCCodeNode* base, ValaCCodeWriter*
 	{
 		GeeIterator* _decl_it;
 		_decl_it = gee_iterable_iterator ((GeeIterable*) self->priv->declarations);
-		while (gee_iterator_next (_decl_it)) {
+		while (TRUE) {
 			ValaCCodeDeclaration* decl;
+			if (!gee_iterator_next (_decl_it)) {
+				break;
+			}
 			decl = (ValaCCodeDeclaration*) gee_iterator_get (_decl_it);
 			vala_ccode_node_write_declaration ((ValaCCodeNode*) decl, writer);
-			(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
+			_vala_ccode_node_unref0 (decl);
 		}
-		(_decl_it == NULL) ? NULL : (_decl_it = (gee_collection_object_unref (_decl_it), NULL));
+		_gee_collection_object_unref0 (_decl_it);
 	}
 	vala_ccode_writer_write_end_block (writer);
 	vala_ccode_writer_write_string (writer, ";");
@@ -263,18 +251,17 @@ static void vala_ccode_struct_real_write (ValaCCodeNode* base, ValaCCodeWriter*
 
 
 const char* vala_ccode_struct_get_name (ValaCCodeStruct* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_name;
+	result = self->priv->_name;
+	return result;
 }
 
 
 void vala_ccode_struct_set_name (ValaCCodeStruct* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -295,8 +282,8 @@ static void vala_ccode_struct_instance_init (ValaCCodeStruct * self) {
 static void vala_ccode_struct_finalize (ValaCCodeNode* obj) {
 	ValaCCodeStruct * self;
 	self = VALA_CCODE_STRUCT (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->declarations == NULL) ? NULL : (self->priv->declarations = (gee_collection_object_unref (self->priv->declarations), NULL));
+	_g_free0 (self->priv->_name);
+	_gee_collection_object_unref0 (self->priv->declarations);
 	VALA_CCODE_NODE_CLASS (vala_ccode_struct_parent_class)->finalize (obj);
 }
 
