@@ -78,6 +78,8 @@ typedef struct _ValaCCodeVariableDeclaratorPrivate ValaCCodeVariableDeclaratorPr
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_INITIALIZER_LIST (vala_ccode_initializer_list_get_type ())
 #define VALA_CCODE_INITIALIZER_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_INITIALIZER_LIST, ValaCCodeInitializerList))
@@ -99,9 +101,6 @@ typedef struct _ValaCCodeInitializerListClass ValaCCodeInitializerListClass;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -116,9 +115,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a variable or function pointer declarator in the C code.
- */
 struct _ValaCCodeDeclarator {
 	ValaCCodeNode parent_instance;
 	ValaCCodeDeclaratorPrivate * priv;
@@ -129,9 +125,6 @@ struct _ValaCCodeDeclaratorClass {
 	void (*write_initialization) (ValaCCodeDeclarator* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a variable declarator in the C code.
- */
 struct _ValaCCodeVariableDeclarator {
 	ValaCCodeDeclarator parent_instance;
 	ValaCCodeVariableDeclaratorPrivate * priv;
@@ -144,9 +137,11 @@ struct _ValaCCodeVariableDeclaratorClass {
 struct _ValaCCodeVariableDeclaratorPrivate {
 	char* _name;
 	ValaCCodeExpression* _initializer;
+	char* _declarator_suffix;
 };
 
 
+static gpointer vala_ccode_variable_declarator_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -167,13 +162,15 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_VARIABLE_DECLARATOR_DUMMY_PROPERTY
 };
+ValaCCodeDeclarator* vala_ccode_declarator_construct (GType object_type);
 void vala_ccode_variable_declarator_set_name (ValaCCodeVariableDeclarator* self, const char* value);
 void vala_ccode_variable_declarator_set_initializer (ValaCCodeVariableDeclarator* self, ValaCCodeExpression* value);
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name, ValaCCodeExpression* initializer);
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_construct (GType object_type, const char* name, ValaCCodeExpression* initializer);
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name, ValaCCodeExpression* initializer);
+void vala_ccode_variable_declarator_set_declarator_suffix (ValaCCodeVariableDeclarator* self, const char* value);
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name, ValaCCodeExpression* initializer, const char* declarator_suffix);
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_construct (GType object_type, const char* name, ValaCCodeExpression* initializer, const char* declarator_suffix);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 const char* vala_ccode_variable_declarator_get_name (ValaCCodeVariableDeclarator* self);
+const char* vala_ccode_variable_declarator_get_declarator_suffix (ValaCCodeVariableDeclarator* self);
 ValaCCodeExpression* vala_ccode_variable_declarator_get_initializer (ValaCCodeVariableDeclarator* self);
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 static void vala_ccode_variable_declarator_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
@@ -184,23 +181,23 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirecti
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 static void vala_ccode_variable_declarator_real_write_initialization (ValaCCodeDeclarator* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_variable_declarator_parent_class = NULL;
 static void vala_ccode_variable_declarator_finalize (ValaCCodeNode* obj);
 
 
 
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_construct (GType object_type, const char* name, ValaCCodeExpression* initializer) {
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_construct (GType object_type, const char* name, ValaCCodeExpression* initializer, const char* declarator_suffix) {
 	ValaCCodeVariableDeclarator* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaCCodeVariableDeclarator*) g_type_create_instance (object_type);
+	self = (ValaCCodeVariableDeclarator*) vala_ccode_declarator_construct (object_type);
 	vala_ccode_variable_declarator_set_name (self, name);
 	vala_ccode_variable_declarator_set_initializer (self, initializer);
+	vala_ccode_variable_declarator_set_declarator_suffix (self, declarator_suffix);
 	return self;
 }
 
 
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name, ValaCCodeExpression* initializer) {
-	return vala_ccode_variable_declarator_construct (VALA_TYPE_CCODE_VARIABLE_DECLARATOR, name, initializer);
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name, ValaCCodeExpression* initializer, const char* declarator_suffix) {
+	return vala_ccode_variable_declarator_construct (VALA_TYPE_CCODE_VARIABLE_DECLARATOR, name, initializer, declarator_suffix);
 }
 
 
@@ -209,6 +206,9 @@ static void vala_ccode_variable_declarator_real_write (ValaCCodeNode* base, Vala
 	self = (ValaCCodeVariableDeclarator*) base;
 	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_string (writer, self->priv->_name);
+	if (self->priv->_declarator_suffix != NULL) {
+		vala_ccode_writer_write_string (writer, self->priv->_declarator_suffix);
+	}
 	if (self->priv->_initializer != NULL) {
 		vala_ccode_writer_write_string (writer, " = ");
 		vala_ccode_node_write ((ValaCCodeNode*) self->priv->_initializer, writer);
@@ -221,7 +221,9 @@ static void vala_ccode_variable_declarator_real_write_declaration (ValaCCodeNode
 	self = (ValaCCodeVariableDeclarator*) base;
 	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_string (writer, self->priv->_name);
-	/* initializer lists can't be moved to a separate statement*/
+	if (self->priv->_declarator_suffix != NULL) {
+		vala_ccode_writer_write_string (writer, self->priv->_declarator_suffix);
+	}
 	if (VALA_IS_CCODE_INITIALIZER_LIST (self->priv->_initializer)) {
 		vala_ccode_writer_write_string (writer, " = ");
 		vala_ccode_node_write ((ValaCCodeNode*) self->priv->_initializer, writer);
@@ -231,16 +233,16 @@ static void vala_ccode_variable_declarator_real_write_declaration (ValaCCodeNode
 
 static void vala_ccode_variable_declarator_real_write_initialization (ValaCCodeDeclarator* base, ValaCCodeWriter* writer) {
 	ValaCCodeVariableDeclarator * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	self = (ValaCCodeVariableDeclarator*) base;
 	g_return_if_fail (writer != NULL);
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (self->priv->_initializer != NULL) {
-		_tmp0 = !VALA_IS_CCODE_INITIALIZER_LIST (self->priv->_initializer);
+		_tmp0_ = !VALA_IS_CCODE_INITIALIZER_LIST (self->priv->_initializer);
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	if (_tmp0) {
+	if (_tmp0_) {
 		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line ((ValaCCodeNode*) self));
 		vala_ccode_writer_write_string (writer, self->priv->_name);
 		vala_ccode_writer_write_string (writer, " = ");
@@ -252,34 +254,52 @@ static void vala_ccode_variable_declarator_real_write_initialization (ValaCCodeD
 
 
 const char* vala_ccode_variable_declarator_get_name (ValaCCodeVariableDeclarator* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_name;
+	result = self->priv->_name;
+	return result;
 }
 
 
 void vala_ccode_variable_declarator_set_name (ValaCCodeVariableDeclarator* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
 ValaCCodeExpression* vala_ccode_variable_declarator_get_initializer (ValaCCodeVariableDeclarator* self) {
+	ValaCCodeExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_initializer;
+	result = self->priv->_initializer;
+	return result;
+}
+
+
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
 }
 
 
 void vala_ccode_variable_declarator_set_initializer (ValaCCodeVariableDeclarator* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2;
-	ValaCCodeExpression* _tmp1;
+	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_ccode_node_unref (self->priv->_initializer), NULL)), _tmp2);
+	self->priv->_initializer = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_initializer), _tmp0_);
+}
+
+
+const char* vala_ccode_variable_declarator_get_declarator_suffix (ValaCCodeVariableDeclarator* self) {
+	const char* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = self->priv->_declarator_suffix;
+	return result;
+}
+
+
+void vala_ccode_variable_declarator_set_declarator_suffix (ValaCCodeVariableDeclarator* self, const char* value) {
+	char* _tmp0_;
+	g_return_if_fail (self != NULL);
+	self->priv->_declarator_suffix = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_declarator_suffix), _tmp0_);
 }
 
 
@@ -301,8 +321,9 @@ static void vala_ccode_variable_declarator_instance_init (ValaCCodeVariableDecla
 static void vala_ccode_variable_declarator_finalize (ValaCCodeNode* obj) {
 	ValaCCodeVariableDeclarator * self;
 	self = VALA_CCODE_VARIABLE_DECLARATOR (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_ccode_node_unref (self->priv->_initializer), NULL));
+	_g_free0 (self->priv->_name);
+	_vala_ccode_node_unref0 (self->priv->_initializer);
+	_g_free0 (self->priv->_declarator_suffix);
 	VALA_CCODE_NODE_CLASS (vala_ccode_variable_declarator_parent_class)->finalize (obj);
 }
 
