@@ -78,6 +78,7 @@ typedef struct _ValaCCodeWhileStatementPrivate ValaCCodeWhileStatementPrivate;
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -89,9 +90,6 @@ typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -106,9 +104,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -118,9 +113,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a while iteration statement in the C code.
- */
 struct _ValaCCodeWhileStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeWhileStatementPrivate * priv;
@@ -136,6 +128,7 @@ struct _ValaCCodeWhileStatementPrivate {
 };
 
 
+static gpointer vala_ccode_while_statement_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -156,11 +149,11 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_WHILE_STATEMENT_DUMMY_PROPERTY
 };
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 void vala_ccode_while_statement_set_condition (ValaCCodeWhileStatement* self, ValaCCodeExpression* value);
 void vala_ccode_while_statement_set_body (ValaCCodeWhileStatement* self, ValaCCodeStatement* value);
 ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* stmt);
 ValaCCodeWhileStatement* vala_ccode_while_statement_construct (GType object_type, ValaCCodeExpression* cond, ValaCCodeStatement* stmt);
-ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* stmt);
 GType vala_ccode_line_directive_get_type (void);
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
@@ -169,7 +162,6 @@ ValaCCodeExpression* vala_ccode_while_statement_get_condition (ValaCCodeWhileSta
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 ValaCCodeStatement* vala_ccode_while_statement_get_body (ValaCCodeWhileStatement* self);
 static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_while_statement_parent_class = NULL;
 static void vala_ccode_while_statement_finalize (ValaCCodeNode* obj);
 
 
@@ -177,7 +169,7 @@ static void vala_ccode_while_statement_finalize (ValaCCodeNode* obj);
 ValaCCodeWhileStatement* vala_ccode_while_statement_construct (GType object_type, ValaCCodeExpression* cond, ValaCCodeStatement* stmt) {
 	ValaCCodeWhileStatement* self;
 	g_return_val_if_fail (cond != NULL, NULL);
-	self = (ValaCCodeWhileStatement*) g_type_create_instance (object_type);
+	self = (ValaCCodeWhileStatement*) vala_ccode_statement_construct (object_type);
 	vala_ccode_while_statement_set_condition (self, cond);
 	vala_ccode_while_statement_set_body (self, stmt);
 	return self;
@@ -202,34 +194,37 @@ static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCod
 
 
 ValaCCodeExpression* vala_ccode_while_statement_get_condition (ValaCCodeWhileStatement* self) {
+	ValaCCodeExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_condition;
+	result = self->priv->_condition;
+	return result;
+}
+
+
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
 }
 
 
 void vala_ccode_while_statement_set_condition (ValaCCodeWhileStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2;
-	ValaCCodeExpression* _tmp1;
+	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp2);
+	self->priv->_condition = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_condition), _tmp0_);
 }
 
 
 ValaCCodeStatement* vala_ccode_while_statement_get_body (ValaCCodeWhileStatement* self) {
+	ValaCCodeStatement* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_body;
+	result = self->priv->_body;
+	return result;
 }
 
 
 void vala_ccode_while_statement_set_body (ValaCCodeWhileStatement* self, ValaCCodeStatement* value) {
-	ValaCCodeStatement* _tmp2;
-	ValaCCodeStatement* _tmp1;
+	ValaCCodeStatement* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)), _tmp2);
+	self->priv->_body = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_body), _tmp0_);
 }
 
 
@@ -249,8 +244,8 @@ static void vala_ccode_while_statement_instance_init (ValaCCodeWhileStatement *
 static void vala_ccode_while_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeWhileStatement * self;
 	self = VALA_CCODE_WHILE_STATEMENT (obj);
-	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL));
-	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL));
+	_vala_ccode_node_unref0 (self->priv->_condition);
+	_vala_ccode_node_unref0 (self->priv->_body);
 	VALA_CCODE_NODE_CLASS (vala_ccode_while_statement_parent_class)->finalize (obj);
 }
 
