@@ -68,6 +68,17 @@ typedef struct _ValaClassRegisterFunction ValaClassRegisterFunction;
 typedef struct _ValaClassRegisterFunctionClass ValaClassRegisterFunctionClass;
 typedef struct _ValaClassRegisterFunctionPrivate ValaClassRegisterFunctionPrivate;
 
+#define VALA_TYPE_CTYPE (vala_ctype_get_type ())
+#define VALA_CTYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CTYPE, ValaCType))
+#define VALA_CTYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CTYPE, ValaCTypeClass))
+#define VALA_IS_CTYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CTYPE))
+#define VALA_IS_CTYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CTYPE))
+#define VALA_CTYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CTYPE, ValaCTypeClass))
+
+typedef struct _ValaCType ValaCType;
+typedef struct _ValaCTypeClass ValaCTypeClass;
+typedef struct _ValaCTypePrivate ValaCTypePrivate;
+
 #define VALA_TYPE_INTERFACE_REGISTER_FUNCTION (vala_interface_register_function_get_type ())
 #define VALA_INTERFACE_REGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_INTERFACE_REGISTER_FUNCTION, ValaInterfaceRegisterFunction))
 #define VALA_INTERFACE_REGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_INTERFACE_REGISTER_FUNCTION, ValaInterfaceRegisterFunctionClass))
@@ -112,9 +123,6 @@ typedef struct _ValaStructRegisterFunction ValaStructRegisterFunction;
 typedef struct _ValaStructRegisterFunctionClass ValaStructRegisterFunctionClass;
 typedef struct _ValaStructRegisterFunctionPrivate ValaStructRegisterFunctionPrivate;
 
-/**
- * Interface to the C compiler.
- */
 struct _ValaCCodeCompiler {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -126,9 +134,6 @@ struct _ValaCCodeCompilerClass {
 	void (*finalize) (ValaCCodeCompiler *self);
 };
 
-/**
- * Code visitor generating C Code.
- */
 struct _ValaCCodeGenerator {
 	ValaCodeGenerator parent_instance;
 	ValaCCodeGeneratorPrivate * priv;
@@ -139,9 +144,6 @@ struct _ValaCCodeGeneratorClass {
 	ValaCodeGeneratorClass parent_class;
 };
 
-/**
- * Code visitor generating C Code.
- */
 struct _ValaCCodeModule {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -239,9 +241,6 @@ struct _ValaCCodeModuleClass {
 	void (*add_simple_check) (ValaCCodeModule* self, ValaCodeNode* node, ValaCCodeFragment* cfrag);
 };
 
-/**
- * C function to register a type at runtime.
- */
 struct _ValaTypeRegisterFunction {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -272,9 +271,6 @@ struct _ValaTypeRegisterFunctionClass {
 	ValaSymbolAccessibility (*get_accessibility) (ValaTypeRegisterFunction* self);
 };
 
-/**
- * C function to register a class at runtime.
- */
 struct _ValaClassRegisterFunction {
 	ValaTypeRegisterFunction parent_instance;
 	ValaClassRegisterFunctionPrivate * priv;
@@ -284,9 +280,15 @@ struct _ValaClassRegisterFunctionClass {
 	ValaTypeRegisterFunctionClass parent_class;
 };
 
-/**
- * C function to register an interface at runtime.
- */
+struct _ValaCType {
+	ValaDataType parent_instance;
+	ValaCTypePrivate * priv;
+};
+
+struct _ValaCTypeClass {
+	ValaDataTypeClass parent_class;
+};
+
 struct _ValaInterfaceRegisterFunction {
 	ValaTypeRegisterFunction parent_instance;
 	ValaInterfaceRegisterFunctionPrivate * priv;
@@ -296,9 +298,6 @@ struct _ValaInterfaceRegisterFunctionClass {
 	ValaTypeRegisterFunctionClass parent_class;
 };
 
-/**
- * C function to register an interface at runtime.
- */
 struct _ValaDBusInterfaceRegisterFunction {
 	ValaInterfaceRegisterFunction parent_instance;
 	ValaDBusInterfaceRegisterFunctionPrivate * priv;
@@ -308,9 +307,6 @@ struct _ValaDBusInterfaceRegisterFunctionClass {
 	ValaInterfaceRegisterFunctionClass parent_class;
 };
 
-/**
- * Code visitor generating .gir file for the public interface.
- */
 struct _ValaGIRWriter {
 	ValaCodeVisitor parent_instance;
 	ValaGIRWriterPrivate * priv;
@@ -320,9 +316,6 @@ struct _ValaGIRWriterClass {
 	ValaCodeVisitorClass parent_class;
 };
 
-/**
- * C function to register a class at runtime.
- */
 struct _ValaStructRegisterFunction {
 	ValaTypeRegisterFunction parent_instance;
 	ValaStructRegisterFunctionPrivate * priv;
@@ -351,7 +344,6 @@ gpointer vala_value_get_ccode_module (const GValue* value);
 GType vala_ccode_module_get_type (void);
 ValaCCodeGenerator* vala_ccode_generator_new (void);
 ValaCCodeGenerator* vala_ccode_generator_construct (GType object_type);
-ValaCCodeModule* vala_ccode_module_new (ValaCCodeGenerator* codegen, ValaCCodeModule* next);
 ValaCCodeModule* vala_ccode_module_construct (GType object_type, ValaCCodeGenerator* codegen, ValaCCodeModule* next);
 void vala_ccode_module_emit (ValaCCodeModule* self, ValaCodeContext* context);
 void vala_ccode_module_visit_source_file (ValaCCodeModule* self, ValaSourceFile* source_file);
@@ -452,6 +444,11 @@ ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl, Vala
 ValaClassRegisterFunction* vala_class_register_function_construct (GType object_type, ValaClass* cl, ValaCodeContext* context);
 ValaClass* vala_class_register_function_get_class_reference (ValaClassRegisterFunction* self);
 void vala_class_register_function_set_class_reference (ValaClassRegisterFunction* self, ValaClass* value);
+GType vala_ctype_get_type (void);
+ValaCType* vala_ctype_new (const char* ctype_name);
+ValaCType* vala_ctype_construct (GType object_type, const char* ctype_name);
+const char* vala_ctype_get_ctype_name (ValaCType* self);
+void vala_ctype_set_ctype_name (ValaCType* self, const char* value);
 GType vala_interface_register_function_get_type (void);
 GType vala_dbus_interface_register_function_get_type (void);
 ValaDBusInterfaceRegisterFunction* vala_dbus_interface_register_function_new (ValaInterface* iface, ValaCodeContext* context);
@@ -492,6 +489,7 @@ ValaCCodeFragment* vala_typeregister_function_get_source_declaration (ValaTypeRe
 ValaCCodeFragment* vala_typeregister_function_get_declaration (ValaTypeRegisterFunction* self);
 ValaCCodeFragment* vala_typeregister_function_get_definition (ValaTypeRegisterFunction* self);
 ValaSymbolAccessibility vala_typeregister_function_get_accessibility (ValaTypeRegisterFunction* self);
+ValaTypeRegisterFunction* vala_typeregister_function_construct (GType object_type);
 ValaCodeContext* vala_typeregister_function_get_context (ValaTypeRegisterFunction* self);
 void vala_typeregister_function_set_context (ValaTypeRegisterFunction* self, ValaCodeContext* value);
 
