@@ -90,11 +90,10 @@ typedef struct _GeeHashSetNode GeeHashSetNode;
 
 typedef struct _GeeHashSetIterator GeeHashSetIterator;
 typedef struct _GeeHashSetIteratorClass GeeHashSetIteratorClass;
+#define _gee_hash_set_node_free0(var) ((var == NULL) ? NULL : (var = (gee_hash_set_node_free (var), NULL)))
 typedef struct _GeeHashSetIteratorPrivate GeeHashSetIteratorPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
-/**
- * Base class for all collections.
- */
 struct _GeeCollectionObject {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -106,30 +105,18 @@ struct _GeeCollectionObjectClass {
 	void (*finalize) (GeeCollectionObject *self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIteratorIface {
 	GTypeInterface parent_iface;
 	gboolean (*next) (GeeIterator* self);
 	gpointer (*get) (GeeIterator* self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIterableIface {
 	GTypeInterface parent_iface;
 	GType (*get_element_type) (GeeIterable* self);
 	GeeIterator* (*iterator) (GeeIterable* self);
 };
 
-/**
- * Serves as the base interface for implementing collection classes. Defines
- * size, iteration, and modification methods.
- */
 struct _GeeCollectionIface {
 	GTypeInterface parent_iface;
 	gboolean (*contains) (GeeCollection* self, gconstpointer item);
@@ -139,16 +126,10 @@ struct _GeeCollectionIface {
 	gint (*get_size) (GeeCollection* self);
 };
 
-/**
- * A set is a collection without duplicates.
- */
 struct _GeeSetIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Hashtable implementation of the Set interface.
- */
 struct _GeeHashSet {
 	GeeCollectionObject parent_instance;
 	GeeHashSetPrivate * priv;
@@ -198,6 +179,12 @@ struct _GeeHashSetIteratorPrivate {
 };
 
 
+static gpointer gee_hash_set_iterator_parent_class = NULL;
+static GeeIteratorIface* gee_hash_set_iterator_gee_iterator_parent_iface = NULL;
+static gpointer gee_hash_set_parent_class = NULL;
+static GeeIterableIface* gee_hash_set_gee_iterable_parent_iface = NULL;
+static GeeCollectionIface* gee_hash_set_gee_collection_parent_iface = NULL;
+static GeeSetIface* gee_hash_set_gee_set_parent_iface = NULL;
 
 gpointer gee_collection_object_ref (gpointer instance);
 void gee_collection_object_unref (gpointer instance);
@@ -216,11 +203,12 @@ enum  {
 };
 #define GEE_HASH_SET_MIN_SIZE 11
 #define GEE_HASH_SET_MAX_SIZE 13845163
+GeeCollectionObject* gee_collection_object_new (void);
+GeeCollectionObject* gee_collection_object_construct (GType object_type);
 void gee_hash_set_set_hash_func (GeeHashSet* self, GHashFunc value);
 void gee_hash_set_set_equal_func (GeeHashSet* self, GEqualFunc value);
 GeeHashSet* gee_hash_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func);
 GeeHashSet* gee_hash_set_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func);
-GeeHashSet* gee_hash_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func);
 static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointer key);
 static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer key);
 static GType gee_hash_set_real_get_element_type (GeeIterable* base);
@@ -242,16 +230,9 @@ enum  {
 	GEE_HASH_SET_ITERATOR_DUMMY_PROPERTY
 };
 static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet* value);
-static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set);
 static gboolean gee_hash_set_iterator_real_next (GeeIterator* base);
 static gpointer gee_hash_set_iterator_real_get (GeeIterator* base);
-static gpointer gee_hash_set_iterator_parent_class = NULL;
-static GeeIteratorIface* gee_hash_set_iterator_gee_iterator_parent_iface = NULL;
 static void gee_hash_set_iterator_finalize (GeeCollectionObject* obj);
-static gpointer gee_hash_set_parent_class = NULL;
-static GeeIterableIface* gee_hash_set_gee_iterable_parent_iface = NULL;
-static GeeCollectionIface* gee_hash_set_gee_collection_parent_iface = NULL;
-static GeeSetIface* gee_hash_set_gee_set_parent_iface = NULL;
 static void gee_hash_set_finalize (GeeCollectionObject* obj);
 static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -261,14 +242,13 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 GeeHashSet* gee_hash_set_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func) {
 	GeeHashSet* self;
 	GeeHashSetNode** _tmp0_;
-	self = (GeeHashSet*) g_type_create_instance (object_type);
+	self = (GeeHashSet*) gee_collection_object_construct (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
 	gee_hash_set_set_hash_func (self, hash_func);
 	gee_hash_set_set_equal_func (self, equal_func);
 	self->priv->_array_size = GEE_HASH_SET_MIN_SIZE;
-	_tmp0_ = NULL;
 	self->priv->_nodes = (_tmp0_ = g_new0 (GeeHashSetNode*, self->priv->_array_size + 1), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_set_node_free), NULL), self->priv->_nodes_length1 = self->priv->_array_size, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp0_);
 	return self;
 }
@@ -280,6 +260,7 @@ GeeHashSet* gee_hash_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyN
 
 
 static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointer key) {
+	GeeHashSetNode** result;
 	guint hash_value;
 	GeeHashSetNode** node;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -305,70 +286,87 @@ static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointe
 		}
 		node = &(*node)->next;
 	}
-	return node;
+	result = node;
+	return result;
 }
 
 
 static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer key) {
 	GeeHashSet * self;
+	gboolean result;
 	GeeHashSetNode** node;
 	self = (GeeHashSet*) base;
 	node = gee_hash_set_lookup_node (self, key);
-	return (*node) != NULL;
+	result = (*node) != NULL;
+	return result;
 }
 
 
 static GType gee_hash_set_real_get_element_type (GeeIterable* base) {
 	GeeHashSet * self;
+	GType result;
 	self = (GeeHashSet*) base;
-	return self->priv->g_type;
+	result = self->priv->g_type;
+	return result;
 }
 
 
 static GeeIterator* gee_hash_set_real_iterator (GeeIterable* base) {
 	GeeHashSet * self;
+	GeeIterator* result;
 	self = (GeeHashSet*) base;
-	return (GeeIterator*) gee_hash_set_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func, self);
+	result = (GeeIterator*) gee_hash_set_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func, self);
+	return result;
 }
 
 
 static gboolean gee_hash_set_real_add (GeeCollection* base, gconstpointer key) {
 	GeeHashSet * self;
+	gboolean result;
 	GeeHashSetNode** node;
 	self = (GeeHashSet*) base;
 	node = gee_hash_set_lookup_node (self, key);
 	if ((*node) != NULL) {
-		return FALSE;
+		result = FALSE;
+		return result;
 	} else {
 		guint hash_value;
-		gconstpointer _tmp1_;
+		gconstpointer _tmp0_;
 		hash_value = self->priv->_hash_func (key);
-		_tmp1_ = NULL;
-		*node = gee_hash_set_node_new ((_tmp1_ = key, ((_tmp1_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1_) : self->priv->g_dup_func ((gpointer) _tmp1_)), hash_value);
+		*node = gee_hash_set_node_new ((_tmp0_ = key, ((_tmp0_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->g_dup_func ((gpointer) _tmp0_)), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_set_resize (self);
 		self->priv->_stamp++;
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
 }
 
 
 static gboolean gee_hash_set_real_remove (GeeCollection* base, gconstpointer key) {
 	GeeHashSet * self;
+	gboolean result;
 	GeeHashSetNode** node;
 	self = (GeeHashSet*) base;
 	node = gee_hash_set_lookup_node (self, key);
 	if ((*node) != NULL) {
-		gpointer _tmp0_;
-		_tmp0_ = NULL;
-		(*node)->key = (_tmp0_ = NULL, (((*node)->key == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : ((*node)->key = (self->priv->g_destroy_func ((*node)->key), NULL)), _tmp0_);
-		*node = (*node)->next;
+		GeeHashSetNode* _tmp0_;
+		GeeHashSetNode* next;
+		gpointer _tmp1_;
+		GeeHashSetNode* _tmp2_;
+		next = (_tmp0_ = (*node)->next, (*node)->next = NULL, _tmp0_);
+		(*node)->key = (_tmp1_ = NULL, (((*node)->key == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : ((*node)->key = (self->priv->g_destroy_func ((*node)->key), NULL)), _tmp1_);
+		gee_hash_set_node_free (*node);
+		*node = (_tmp2_ = next, next = NULL, _tmp2_);
 		self->priv->_nnodes--;
 		gee_hash_set_resize (self);
 		self->priv->_stamp++;
-		return TRUE;
+		result = TRUE;
+		_gee_hash_set_node_free0 (next);
+		return result;
 	}
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
@@ -378,27 +376,36 @@ static void gee_hash_set_real_clear (GeeCollection* base) {
 	{
 		gint i;
 		i = 0;
-		for (; i < self->priv->_array_size; i++) {
-			GeeHashSetNode* _tmp0_;
-			GeeHashSetNode* node;
-			_tmp0_ = NULL;
-			node = (_tmp0_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp0_);
-			while (node != NULL) {
+		{
+			gboolean _tmp0_;
+			_tmp0_ = TRUE;
+			while (TRUE) {
 				GeeHashSetNode* _tmp1_;
-				GeeHashSetNode* next;
-				gpointer _tmp2_;
-				GeeHashSetNode* _tmp4_;
-				GeeHashSetNode* _tmp3_;
-				_tmp1_ = NULL;
-				next = (_tmp1_ = node->next, node->next = NULL, _tmp1_);
-				_tmp2_ = NULL;
-				node->key = (_tmp2_ = NULL, ((node->key == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (node->key = (self->priv->g_destroy_func (node->key), NULL)), _tmp2_);
-				_tmp4_ = NULL;
-				_tmp3_ = NULL;
-				node = (_tmp4_ = (_tmp3_ = next, next = NULL, _tmp3_), (node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL)), _tmp4_);
-				(next == NULL) ? NULL : (next = (gee_hash_set_node_free (next), NULL));
+				GeeHashSetNode* node;
+				if (!_tmp0_) {
+					i++;
+				}
+				_tmp0_ = FALSE;
+				if (!(i < self->priv->_array_size)) {
+					break;
+				}
+				node = (_tmp1_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp1_);
+				while (TRUE) {
+					GeeHashSetNode* _tmp2_;
+					GeeHashSetNode* next;
+					gpointer _tmp3_;
+					GeeHashSetNode* _tmp5_;
+					GeeHashSetNode* _tmp4_;
+					if (!(node != NULL)) {
+						break;
+					}
+					next = (_tmp2_ = node->next, node->next = NULL, _tmp2_);
+					node->key = (_tmp3_ = NULL, ((node->key == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (node->key = (self->priv->g_destroy_func (node->key), NULL)), _tmp3_);
+					node = (_tmp5_ = (_tmp4_ = next, next = NULL, _tmp4_), _gee_hash_set_node_free0 (node), _tmp5_);
+					_gee_hash_set_node_free0 (next);
+				}
+				_gee_hash_set_node_free0 (node);
 			}
-			(node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL));
 		}
 	}
 	self->priv->_nnodes = 0;
@@ -435,54 +442,64 @@ static void gee_hash_set_resize (GeeHashSet* self) {
 		gint new_nodes_size;
 		gint new_nodes_length1;
 		GeeHashSetNode** new_nodes;
-		GeeHashSetNode** _tmp15_;
-		GeeHashSetNode** _tmp14_;
+		GeeHashSetNode** _tmp17_;
+		GeeHashSetNode** _tmp16_;
 		new_array_size = (gint) g_spaced_primes_closest ((guint) self->priv->_nnodes);
 		new_array_size = CLAMP (new_array_size, GEE_HASH_SET_MIN_SIZE, GEE_HASH_SET_MAX_SIZE);
-		_tmp3_ = NULL;
 		new_nodes = (_tmp3_ = g_new0 (GeeHashSetNode*, new_array_size + 1), new_nodes_length1 = new_array_size, new_nodes_size = new_nodes_length1, _tmp3_);
 		{
 			gint i;
 			i = 0;
-			for (; i < self->priv->_array_size; i++) {
-				GeeHashSetNode* node;
-				GeeHashSetNode* next;
-				GeeHashSetNode* _tmp7_;
-				GeeHashSetNode* _tmp6_;
-				GeeHashSetNode* _tmp5_;
-				GeeHashSetNode* _tmp4_;
-				node = NULL;
-				next = NULL;
-				_tmp7_ = NULL;
-				_tmp6_ = NULL;
-				_tmp5_ = NULL;
-				_tmp4_ = NULL;
-				for (node = (_tmp5_ = (_tmp4_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp4_), (node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL)), _tmp5_); node != NULL; node = (_tmp7_ = (_tmp6_ = next, next = NULL, _tmp6_), (node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL)), _tmp7_)) {
-					GeeHashSetNode* _tmp9_;
-					GeeHashSetNode* _tmp8_;
-					guint hash_val;
-					GeeHashSetNode* _tmp11_;
-					GeeHashSetNode* _tmp10_;
-					GeeHashSetNode* _tmp13_;
-					GeeHashSetNode* _tmp12_;
-					_tmp9_ = NULL;
-					_tmp8_ = NULL;
-					next = (_tmp9_ = (_tmp8_ = node->next, node->next = NULL, _tmp8_), (next == NULL) ? NULL : (next = (gee_hash_set_node_free (next), NULL)), _tmp9_);
-					hash_val = node->key_hash % new_array_size;
-					_tmp11_ = NULL;
-					_tmp10_ = NULL;
-					node->next = (_tmp11_ = (_tmp10_ = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp10_), (node->next == NULL) ? NULL : (node->next = (gee_hash_set_node_free (node->next), NULL)), _tmp11_);
-					_tmp13_ = NULL;
-					_tmp12_ = NULL;
-					new_nodes[hash_val] = (_tmp13_ = (_tmp12_ = node, node = NULL, _tmp12_), (new_nodes[hash_val] == NULL) ? NULL : (new_nodes[hash_val] = (gee_hash_set_node_free (new_nodes[hash_val]), NULL)), _tmp13_);
+			{
+				gboolean _tmp4_;
+				_tmp4_ = TRUE;
+				while (TRUE) {
+					GeeHashSetNode* node;
+					GeeHashSetNode* next;
+					if (!_tmp4_) {
+						i++;
+					}
+					_tmp4_ = FALSE;
+					if (!(i < self->priv->_array_size)) {
+						break;
+					}
+					node = NULL;
+					next = NULL;
+					{
+						GeeHashSetNode* _tmp6_;
+						GeeHashSetNode* _tmp5_;
+						gboolean _tmp7_;
+						node = (_tmp6_ = (_tmp5_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp5_), _gee_hash_set_node_free0 (node), _tmp6_);
+						_tmp7_ = TRUE;
+						while (TRUE) {
+							GeeHashSetNode* _tmp11_;
+							GeeHashSetNode* _tmp10_;
+							guint hash_val;
+							GeeHashSetNode* _tmp13_;
+							GeeHashSetNode* _tmp12_;
+							GeeHashSetNode* _tmp15_;
+							GeeHashSetNode* _tmp14_;
+							if (!_tmp7_) {
+								GeeHashSetNode* _tmp9_;
+								GeeHashSetNode* _tmp8_;
+								node = (_tmp9_ = (_tmp8_ = next, next = NULL, _tmp8_), _gee_hash_set_node_free0 (node), _tmp9_);
+							}
+							_tmp7_ = FALSE;
+							if (!(node != NULL)) {
+								break;
+							}
+							next = (_tmp11_ = (_tmp10_ = node->next, node->next = NULL, _tmp10_), _gee_hash_set_node_free0 (next), _tmp11_);
+							hash_val = node->key_hash % new_array_size;
+							node->next = (_tmp13_ = (_tmp12_ = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp12_), _gee_hash_set_node_free0 (node->next), _tmp13_);
+							new_nodes[hash_val] = (_tmp15_ = (_tmp14_ = node, node = NULL, _tmp14_), _gee_hash_set_node_free0 (new_nodes[hash_val]), _tmp15_);
+						}
+					}
+					_gee_hash_set_node_free0 (node);
+					_gee_hash_set_node_free0 (next);
 				}
-				(node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL));
-				(next == NULL) ? NULL : (next = (gee_hash_set_node_free (next), NULL));
 			}
 		}
-		_tmp15_ = NULL;
-		_tmp14_ = NULL;
-		self->priv->_nodes = (_tmp15_ = (_tmp14_ = new_nodes, new_nodes = NULL, _tmp14_), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_set_node_free), NULL), self->priv->_nodes_length1 = new_nodes_length1, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp15_);
+		self->priv->_nodes = (_tmp17_ = (_tmp16_ = new_nodes, new_nodes = NULL, _tmp16_), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_set_node_free), NULL), self->priv->_nodes_length1 = new_nodes_length1, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp17_);
 		self->priv->_array_size = new_array_size;
 		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, (GDestroyNotify) gee_hash_set_node_free), NULL);
 	}
@@ -490,9 +507,11 @@ static void gee_hash_set_resize (GeeHashSet* self) {
 
 
 static gint gee_hash_set_real_get_size (GeeCollection* base) {
+	gint result;
 	GeeHashSet* self;
 	self = (GeeHashSet*) base;
-	return self->priv->_nnodes;
+	result = self->priv->_nnodes;
+	return result;
 }
 
 
@@ -513,7 +532,6 @@ static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash) {
 	gpointer _tmp0_;
 	self = g_slice_new0 (GeeHashSetNode);
 	gee_hash_set_node_instance_init (self);
-	_tmp0_ = NULL;
 	self->key = (_tmp0_ = k, k = NULL, _tmp0_);
 	self->key_hash = hash;
 	return self;
@@ -525,7 +543,7 @@ static void gee_hash_set_node_instance_init (GeeHashSetNode * self) {
 
 
 static void gee_hash_set_node_free (GeeHashSetNode* self) {
-	(self->next == NULL) ? NULL : (self->next = (gee_hash_set_node_free (self->next), NULL));
+	_gee_hash_set_node_free0 (self->next);
 	g_slice_free (GeeHashSetNode, self);
 }
 
@@ -533,7 +551,7 @@ static void gee_hash_set_node_free (GeeHashSetNode* self) {
 static GeeHashSetIterator* gee_hash_set_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set) {
 	GeeHashSetIterator* self;
 	g_return_val_if_fail (set != NULL, NULL);
-	self = (GeeHashSetIterator*) g_type_create_instance (object_type);
+	self = (GeeHashSetIterator*) gee_collection_object_construct (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -549,6 +567,7 @@ static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFu
 
 static gboolean gee_hash_set_iterator_real_next (GeeIterator* base) {
 	GeeHashSetIterator * self;
+	gboolean result;
 	self = (GeeHashSetIterator*) base;
 	if (self->priv->_node != NULL) {
 		self->priv->_node = self->priv->_node->next;
@@ -567,28 +586,32 @@ static gboolean gee_hash_set_iterator_real_next (GeeIterator* base) {
 		self->priv->_index++;
 		self->priv->_node = self->priv->_set->priv->_nodes[self->priv->_index];
 	}
-	return self->priv->_node != NULL;
+	result = self->priv->_node != NULL;
+	return result;
 }
 
 
 static gpointer gee_hash_set_iterator_real_get (GeeIterator* base) {
 	GeeHashSetIterator * self;
+	gpointer result;
 	gconstpointer _tmp0_;
 	self = (GeeHashSetIterator*) base;
 	g_assert (self->priv->_stamp == self->priv->_set->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
-	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->_node->key, ((_tmp0_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->g_dup_func ((gpointer) _tmp0_));
+	result = (_tmp0_ = self->priv->_node->key, ((_tmp0_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->g_dup_func ((gpointer) _tmp0_));
+	return result;
+}
+
+
+static gpointer _gee_collection_object_ref0 (gpointer self) {
+	return self ? gee_collection_object_ref (self) : NULL;
 }
 
 
 static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet* value) {
-	GeeHashSet* _tmp1_;
 	GeeHashSet* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_set = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_set == NULL) ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL)), _tmp1_);
+	self->priv->_set = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_set), _tmp0_);
 	self->priv->_stamp = self->priv->_set->priv->_stamp;
 }
 
@@ -617,7 +640,7 @@ static void gee_hash_set_iterator_instance_init (GeeHashSetIterator * self) {
 static void gee_hash_set_iterator_finalize (GeeCollectionObject* obj) {
 	GeeHashSetIterator * self;
 	self = GEE_HASH_SET_ITERATOR (obj);
-	(self->priv->_set == NULL) ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL));
+	_gee_collection_object_unref0 (self->priv->_set);
 	GEE_COLLECTION_OBJECT_CLASS (gee_hash_set_iterator_parent_class)->finalize (obj);
 }
 
