@@ -69,6 +69,7 @@ typedef struct _GeeCollectionIface GeeCollectionIface;
 typedef struct _GeeReadOnlyCollection GeeReadOnlyCollection;
 typedef struct _GeeReadOnlyCollectionClass GeeReadOnlyCollectionClass;
 typedef struct _GeeReadOnlyCollectionPrivate GeeReadOnlyCollectionPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR (gee_read_only_collection_iterator_get_type ())
 #define GEE_READ_ONLY_COLLECTION_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, GeeReadOnlyCollectionIterator))
@@ -81,9 +82,6 @@ typedef struct _GeeReadOnlyCollectionIterator GeeReadOnlyCollectionIterator;
 typedef struct _GeeReadOnlyCollectionIteratorClass GeeReadOnlyCollectionIteratorClass;
 typedef struct _GeeReadOnlyCollectionIteratorPrivate GeeReadOnlyCollectionIteratorPrivate;
 
-/**
- * Base class for all collections.
- */
 struct _GeeCollectionObject {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -95,30 +93,18 @@ struct _GeeCollectionObjectClass {
 	void (*finalize) (GeeCollectionObject *self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIteratorIface {
 	GTypeInterface parent_iface;
 	gboolean (*next) (GeeIterator* self);
 	gpointer (*get) (GeeIterator* self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIterableIface {
 	GTypeInterface parent_iface;
 	GType (*get_element_type) (GeeIterable* self);
 	GeeIterator* (*iterator) (GeeIterable* self);
 };
 
-/**
- * Serves as the base interface for implementing collection classes. Defines
- * size, iteration, and modification methods.
- */
 struct _GeeCollectionIface {
 	GTypeInterface parent_iface;
 	gboolean (*contains) (GeeCollection* self, gconstpointer item);
@@ -128,9 +114,6 @@ struct _GeeCollectionIface {
 	gint (*get_size) (GeeCollection* self);
 };
 
-/**
- * Represents a read-only collection of items.
- */
 struct _GeeReadOnlyCollection {
 	GeeCollectionObject parent_instance;
 	GeeReadOnlyCollectionPrivate * priv;
@@ -183,6 +166,8 @@ GType gee_read_only_collection_get_type (void);
 enum  {
 	GEE_READ_ONLY_COLLECTION_DUMMY_PROPERTY
 };
+GeeCollectionObject* gee_collection_object_new (void);
+GeeCollectionObject* gee_collection_object_construct (GType object_type);
 void gee_read_only_collection_set_collection (GeeReadOnlyCollection* self, GeeCollection* value);
 GeeReadOnlyCollection* gee_read_only_collection_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection);
 GeeReadOnlyCollection* gee_read_only_collection_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection);
@@ -210,7 +195,7 @@ static void gee_read_only_collection_finalize (GeeCollectionObject* obj);
 
 GeeReadOnlyCollection* gee_read_only_collection_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection) {
 	GeeReadOnlyCollection* self;
-	self = (GeeReadOnlyCollection*) g_type_create_instance (object_type);
+	self = (GeeReadOnlyCollection*) gee_collection_object_construct (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -261,7 +246,6 @@ static gboolean gee_read_only_collection_real_contains (GeeCollection* base, gco
 
 static gboolean gee_read_only_collection_real_add (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyCollection * self;
-	gboolean result;
 	self = (GeeReadOnlyCollection*) base;
 	g_assert_not_reached ();
 }
@@ -269,7 +253,6 @@ static gboolean gee_read_only_collection_real_add (GeeCollection* base, gconstpo
 
 static gboolean gee_read_only_collection_real_remove (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyCollection * self;
-	gboolean result;
 	self = (GeeReadOnlyCollection*) base;
 	g_assert_not_reached ();
 }
@@ -291,13 +274,15 @@ static gint gee_read_only_collection_real_get_size (GeeCollection* base) {
 }
 
 
+static gpointer _gee_collection_object_ref0 (gpointer self) {
+	return self ? gee_collection_object_ref (self) : NULL;
+}
+
+
 void gee_read_only_collection_set_collection (GeeReadOnlyCollection* self, GeeCollection* value) {
-	GeeCollection* _tmp1_;
 	GeeCollection* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_collection = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_collection == NULL) ? NULL : (self->priv->_collection = (gee_collection_object_unref (self->priv->_collection), NULL)), _tmp1_);
+	self->priv->_collection = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_collection), _tmp0_);
 }
 
 
@@ -321,7 +306,7 @@ static gpointer gee_read_only_collection_iterator_real_get (GeeIterator* base) {
 
 static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
 	GeeReadOnlyCollectionIterator* self;
-	self = (GeeReadOnlyCollectionIterator*) g_type_create_instance (object_type);
+	self = (GeeReadOnlyCollectionIterator*) gee_collection_object_construct (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -396,7 +381,7 @@ static void gee_read_only_collection_instance_init (GeeReadOnlyCollection * self
 static void gee_read_only_collection_finalize (GeeCollectionObject* obj) {
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (obj);
-	(self->priv->_collection == NULL) ? NULL : (self->priv->_collection = (gee_collection_object_unref (self->priv->_collection), NULL));
+	_gee_collection_object_unref0 (self->priv->_collection);
 	GEE_COLLECTION_OBJECT_CLASS (gee_read_only_collection_parent_class)->finalize (obj);
 }
 
