@@ -85,6 +85,7 @@ typedef struct _GeeSetIface GeeSetIface;
 typedef struct _GeeReadOnlyMap GeeReadOnlyMap;
 typedef struct _GeeReadOnlyMapClass GeeReadOnlyMapClass;
 typedef struct _GeeReadOnlyMapPrivate GeeReadOnlyMapPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define GEE_TYPE_READ_ONLY_SET (gee_read_only_set_get_type ())
 #define GEE_READ_ONLY_SET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_READ_ONLY_SET, GeeReadOnlySet))
@@ -106,9 +107,6 @@ typedef struct _GeeReadOnlySetClass GeeReadOnlySetClass;
 typedef struct _GeeReadOnlyCollection GeeReadOnlyCollection;
 typedef struct _GeeReadOnlyCollectionClass GeeReadOnlyCollectionClass;
 
-/**
- * Base class for all collections.
- */
 struct _GeeCollectionObject {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -120,30 +118,18 @@ struct _GeeCollectionObjectClass {
 	void (*finalize) (GeeCollectionObject *self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIteratorIface {
 	GTypeInterface parent_iface;
 	gboolean (*next) (GeeIterator* self);
 	gpointer (*get) (GeeIterator* self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIterableIface {
 	GTypeInterface parent_iface;
 	GType (*get_element_type) (GeeIterable* self);
 	GeeIterator* (*iterator) (GeeIterable* self);
 };
 
-/**
- * Serves as the base interface for implementing collection classes. Defines
- * size, iteration, and modification methods.
- */
 struct _GeeCollectionIface {
 	GTypeInterface parent_iface;
 	gboolean (*contains) (GeeCollection* self, gconstpointer item);
@@ -153,16 +139,10 @@ struct _GeeCollectionIface {
 	gint (*get_size) (GeeCollection* self);
 };
 
-/**
- * A set is a collection without duplicates.
- */
 struct _GeeSetIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * A map is a generic collection of key/value pairs.
- */
 struct _GeeMapIface {
 	GTypeInterface parent_iface;
 	GeeSet* (*get_keys) (GeeMap* self);
@@ -175,9 +155,6 @@ struct _GeeMapIface {
 	gint (*get_size) (GeeMap* self);
 };
 
-/**
- * Represents a read-only collection of key/value pairs.
- */
 struct _GeeReadOnlyMap {
 	GeeCollectionObject parent_instance;
 	GeeReadOnlyMapPrivate * priv;
@@ -217,6 +194,8 @@ GType gee_read_only_map_get_type (void);
 enum  {
 	GEE_READ_ONLY_MAP_DUMMY_PROPERTY
 };
+GeeCollectionObject* gee_collection_object_new (void);
+GeeCollectionObject* gee_collection_object_construct (GType object_type);
 void gee_read_only_map_set_map (GeeReadOnlyMap* self, GeeMap* value);
 GeeReadOnlyMap* gee_read_only_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map);
 GeeReadOnlyMap* gee_read_only_map_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map);
@@ -244,7 +223,7 @@ static void gee_read_only_map_finalize (GeeCollectionObject* obj);
 
 GeeReadOnlyMap* gee_read_only_map_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map) {
 	GeeReadOnlyMap* self;
-	self = (GeeReadOnlyMap*) g_type_create_instance (object_type);
+	self = (GeeReadOnlyMap*) gee_collection_object_construct (object_type);
 	self->priv->k_type = k_type;
 	self->priv->k_dup_func = k_dup_func;
 	self->priv->k_destroy_func = k_destroy_func;
@@ -322,7 +301,6 @@ static void gee_read_only_map_real_set (GeeMap* base, gconstpointer key, gconstp
 
 static gboolean gee_read_only_map_real_remove (GeeMap* base, gconstpointer key) {
 	GeeReadOnlyMap * self;
-	gboolean result;
 	self = (GeeReadOnlyMap*) base;
 	g_assert_not_reached ();
 }
@@ -344,13 +322,15 @@ static gint gee_read_only_map_real_get_size (GeeMap* base) {
 }
 
 
+static gpointer _gee_collection_object_ref0 (gpointer self) {
+	return self ? gee_collection_object_ref (self) : NULL;
+}
+
+
 void gee_read_only_map_set_map (GeeReadOnlyMap* self, GeeMap* value) {
-	GeeMap* _tmp1_;
 	GeeMap* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_map = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL)), _tmp1_);
+	self->priv->_map = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_map), _tmp0_);
 }
 
 
@@ -382,7 +362,7 @@ static void gee_read_only_map_instance_init (GeeReadOnlyMap * self) {
 static void gee_read_only_map_finalize (GeeCollectionObject* obj) {
 	GeeReadOnlyMap * self;
 	self = GEE_READ_ONLY_MAP (obj);
-	(self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL));
+	_gee_collection_object_unref0 (self->priv->_map);
 	GEE_COLLECTION_OBJECT_CLASS (gee_read_only_map_parent_class)->finalize (obj);
 }
 
