@@ -119,6 +119,7 @@ typedef struct _ValaExpressionPrivate ValaExpressionPrivate;
 typedef struct _ValaAddressofExpression ValaAddressofExpression;
 typedef struct _ValaAddressofExpressionClass ValaAddressofExpressionClass;
 typedef struct _ValaAddressofExpressionPrivate ValaAddressofExpressionPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -170,12 +171,16 @@ typedef struct _ValaObjectTypeClass ValaObjectTypeClass;
 typedef struct _ValaPointerType ValaPointerType;
 typedef struct _ValaPointerTypeClass ValaPointerTypeClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
+#define VALA_TYPE_GENERIC_TYPE (vala_generic_type_get_type ())
+#define VALA_GENERIC_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_GENERIC_TYPE, ValaGenericType))
+#define VALA_GENERIC_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_GENERIC_TYPE, ValaGenericTypeClass))
+#define VALA_IS_GENERIC_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_GENERIC_TYPE))
+#define VALA_IS_GENERIC_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_GENERIC_TYPE))
+#define VALA_GENERIC_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_GENERIC_TYPE, ValaGenericTypeClass))
+
+typedef struct _ValaGenericType ValaGenericType;
+typedef struct _ValaGenericTypeClass ValaGenericTypeClass;
+
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -196,9 +201,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -212,9 +214,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Represents an address-of expression in the source code, e.g. `&foo'.
- */
 struct _ValaAddressofExpression {
 	ValaExpression parent_instance;
 	ValaAddressofExpressionPrivate * priv;
@@ -229,6 +228,7 @@ struct _ValaAddressofExpressionPrivate {
 };
 
 
+static gpointer vala_addressof_expression_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -253,6 +253,7 @@ GType vala_addressof_expression_get_type (void);
 enum  {
 	VALA_ADDRESSOF_EXPRESSION_DUMMY_PROPERTY
 };
+ValaExpression* vala_expression_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -263,7 +264,6 @@ void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReferenc
 void vala_addressof_expression_set_inner (ValaAddressofExpression* self, ValaExpression* value);
 ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, ValaSourceReference* source_reference);
 ValaAddressofExpression* vala_addressof_expression_construct (GType object_type, ValaExpression* inner, ValaSourceReference* source_reference);
-ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, ValaSourceReference* source_reference);
 ValaExpression* vala_addressof_expression_get_inner (ValaAddressofExpression* self);
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_visitor_visit_addressof_expression (ValaCodeVisitor* self, ValaAddressofExpression* expr);
@@ -282,6 +282,7 @@ GType vala_value_type_get_type (void);
 GType vala_reference_type_get_type (void);
 GType vala_object_type_get_type (void);
 GType vala_pointer_type_get_type (void);
+GType vala_generic_type_get_type (void);
 void vala_report_error (ValaSourceReference* source, const char* message);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
 gboolean vala_data_type_is_reference_type_or_type_parameter (ValaDataType* self);
@@ -290,21 +291,14 @@ ValaPointerType* vala_pointer_type_construct (GType object_type, ValaDataType* b
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_addressof_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-static gpointer vala_addressof_expression_parent_class = NULL;
 static void vala_addressof_expression_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new address-of expression.
- *
- * @param inner variable whose address is to be computed
- * @return      newly created address-of expression
- */
 ValaAddressofExpression* vala_addressof_expression_construct (GType object_type, ValaExpression* inner, ValaSourceReference* source_reference) {
 	ValaAddressofExpression* self;
 	g_return_val_if_fail (inner != NULL, NULL);
-	self = (ValaAddressofExpression*) g_type_create_instance (object_type);
+	self = (ValaAddressofExpression*) vala_expression_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	vala_addressof_expression_set_inner (self, inner);
 	return self;
@@ -339,73 +333,88 @@ static void vala_addressof_expression_real_replace_expression (ValaCodeNode* bas
 
 static gboolean vala_addressof_expression_real_is_pure (ValaExpression* base) {
 	ValaAddressofExpression * self;
+	gboolean result;
 	self = (ValaAddressofExpression*) base;
-	return vala_expression_is_pure (vala_addressof_expression_get_inner (self));
+	result = vala_expression_is_pure (vala_addressof_expression_get_inner (self));
+	return result;
 }
 
 
 static gboolean vala_addressof_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaAddressofExpression * self;
-	gboolean _tmp2;
-	gboolean _tmp3;
+	gboolean result;
+	gboolean _tmp0_;
+	gboolean _tmp1_;
+	gboolean _tmp2_;
 	self = (ValaAddressofExpression*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (!vala_code_node_check ((ValaCodeNode*) vala_addressof_expression_get_inner (self), analyzer)) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
-	_tmp2 = FALSE;
-	_tmp3 = FALSE;
+	_tmp0_ = FALSE;
+	_tmp1_ = FALSE;
+	_tmp2_ = FALSE;
 	if (VALA_IS_VALUE_TYPE (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)))) {
-		_tmp3 = TRUE;
+		_tmp2_ = TRUE;
 	} else {
-		_tmp3 = VALA_IS_OBJECT_TYPE (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)));
+		_tmp2_ = VALA_IS_OBJECT_TYPE (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)));
 	}
-	if (_tmp3) {
-		_tmp2 = TRUE;
+	if (_tmp2_) {
+		_tmp1_ = TRUE;
 	} else {
-		_tmp2 = VALA_IS_POINTER_TYPE (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)));
+		_tmp1_ = VALA_IS_POINTER_TYPE (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)));
 	}
-	if (!_tmp2) {
+	if (_tmp1_) {
+		_tmp0_ = TRUE;
+	} else {
+		_tmp0_ = VALA_IS_GENERIC_TYPE (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)));
+	}
+	if (!_tmp0_) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Address-of operator not supported for this expression");
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	if (vala_data_type_is_reference_type_or_type_parameter (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)))) {
-		ValaPointerType* _tmp6;
-		ValaPointerType* _tmp5;
-		_tmp6 = NULL;
-		_tmp5 = NULL;
-		vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp6 = vala_pointer_type_new ((ValaDataType*) (_tmp5 = vala_pointer_type_new (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)), NULL)), NULL)));
-		(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
-		(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL));
+		ValaPointerType* _tmp4_;
+		ValaPointerType* _tmp3_;
+		vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp4_ = vala_pointer_type_new ((ValaDataType*) (_tmp3_ = vala_pointer_type_new (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)), NULL)), NULL)));
+		_vala_code_node_unref0 (_tmp4_);
+		_vala_code_node_unref0 (_tmp3_);
 	} else {
-		ValaPointerType* _tmp7;
-		_tmp7 = NULL;
-		vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp7 = vala_pointer_type_new (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)), NULL)));
-		(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_code_node_unref (_tmp7), NULL));
+		ValaPointerType* _tmp5_;
+		vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp5_ = vala_pointer_type_new (vala_expression_get_value_type (vala_addressof_expression_get_inner (self)), NULL)));
+		_vala_code_node_unref0 (_tmp5_);
 	}
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 ValaExpression* vala_addressof_expression_get_inner (ValaAddressofExpression* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_inner;
+	result = self->priv->_inner;
+	return result;
+}
+
+
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
 }
 
 
 void vala_addressof_expression_set_inner (ValaAddressofExpression* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp2);
+	self->priv->_inner = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_inner), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_inner, (ValaCodeNode*) self);
 }
 
@@ -429,7 +438,7 @@ static void vala_addressof_expression_instance_init (ValaAddressofExpression * s
 static void vala_addressof_expression_finalize (ValaCodeNode* obj) {
 	ValaAddressofExpression * self;
 	self = VALA_ADDRESSOF_EXPRESSION (obj);
-	(self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL));
+	_vala_code_node_unref0 (self->priv->_inner);
 	VALA_CODE_NODE_CLASS (vala_addressof_expression_parent_class)->finalize (obj);
 }
 
