@@ -56,12 +56,10 @@ typedef struct _ValaCodeNodeClass ValaCodeNodeClass;
 
 typedef struct _ValaPhiFunction ValaPhiFunction;
 typedef struct _ValaPhiFunctionClass ValaPhiFunctionClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_basic_block_unref0(var) ((var == NULL) ? NULL : (var = (vala_basic_block_unref (var), NULL)))
 typedef struct _ValaParamSpecBasicBlock ValaParamSpecBasicBlock;
 
-/**
- * Represents a basic block, i.e. a straight-line piece of code without any
- * jumps or jump targets.
- */
 struct _ValaBasicBlock {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -178,12 +176,15 @@ void vala_basic_block_add_node (ValaBasicBlock* self, ValaCodeNode* node) {
 }
 
 
+static gpointer _gee_collection_object_ref0 (gpointer self) {
+	return self ? gee_collection_object_ref (self) : NULL;
+}
+
+
 GeeList* vala_basic_block_get_nodes (ValaBasicBlock* self) {
 	GeeList* result;
-	GeeList* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0_ = NULL;
-	result = (_tmp0_ = self->priv->nodes, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	result = _gee_collection_object_ref0 (self->priv->nodes);
 	return result;
 }
 
@@ -226,10 +227,8 @@ void vala_basic_block_add_child (ValaBasicBlock* self, ValaBasicBlock* block) {
 
 GeeList* vala_basic_block_get_children (ValaBasicBlock* self) {
 	GeeList* result;
-	GeeList* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0_ = NULL;
-	result = (_tmp0_ = self->priv->children, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	result = _gee_collection_object_ref0 (self->priv->children);
 	return result;
 }
 
@@ -243,10 +242,8 @@ void vala_basic_block_add_dominator_frontier (ValaBasicBlock* self, ValaBasicBlo
 
 GeeSet* vala_basic_block_get_dominator_frontier (ValaBasicBlock* self) {
 	GeeSet* result;
-	GeeSet* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0_ = NULL;
-	result = (_tmp0_ = self->priv->df, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	result = _gee_collection_object_ref0 (self->priv->df);
 	return result;
 }
 
@@ -260,10 +257,8 @@ void vala_basic_block_add_phi_function (ValaBasicBlock* self, ValaPhiFunction* p
 
 GeeSet* vala_basic_block_get_phi_functions (ValaBasicBlock* self) {
 	GeeSet* result;
-	GeeSet* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0_ = NULL;
-	result = (_tmp0_ = self->priv->phi_functions, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+	result = _gee_collection_object_ref0 (self->priv->phi_functions);
 	return result;
 }
 
@@ -276,13 +271,15 @@ ValaBasicBlock* vala_basic_block_get_parent (ValaBasicBlock* self) {
 }
 
 
+static gpointer _vala_basic_block_ref0 (gpointer self) {
+	return self ? vala_basic_block_ref (self) : NULL;
+}
+
+
 static void vala_basic_block_set_parent (ValaBasicBlock* self, ValaBasicBlock* value) {
-	ValaBasicBlock* _tmp1_;
 	ValaBasicBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_parent = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_basic_block_ref (_tmp0_)), (self->priv->_parent == NULL) ? NULL : (self->priv->_parent = (vala_basic_block_unref (self->priv->_parent), NULL)), _tmp1_);
+	self->priv->_parent = (_tmp0_ = _vala_basic_block_ref0 (value), _vala_basic_block_unref0 (self->priv->_parent), _tmp0_);
 }
 
 
@@ -401,13 +398,13 @@ static void vala_basic_block_instance_init (ValaBasicBlock * self) {
 static void vala_basic_block_finalize (ValaBasicBlock* obj) {
 	ValaBasicBlock * self;
 	self = VALA_BASIC_BLOCK (obj);
-	(self->priv->nodes == NULL) ? NULL : (self->priv->nodes = (gee_collection_object_unref (self->priv->nodes), NULL));
-	(self->priv->predecessors == NULL) ? NULL : (self->priv->predecessors = (gee_collection_object_unref (self->priv->predecessors), NULL));
-	(self->priv->successors == NULL) ? NULL : (self->priv->successors = (gee_collection_object_unref (self->priv->successors), NULL));
-	(self->priv->_parent == NULL) ? NULL : (self->priv->_parent = (vala_basic_block_unref (self->priv->_parent), NULL));
-	(self->priv->children == NULL) ? NULL : (self->priv->children = (gee_collection_object_unref (self->priv->children), NULL));
-	(self->priv->df == NULL) ? NULL : (self->priv->df = (gee_collection_object_unref (self->priv->df), NULL));
-	(self->priv->phi_functions == NULL) ? NULL : (self->priv->phi_functions = (gee_collection_object_unref (self->priv->phi_functions), NULL));
+	_gee_collection_object_unref0 (self->priv->nodes);
+	_gee_collection_object_unref0 (self->priv->predecessors);
+	_gee_collection_object_unref0 (self->priv->successors);
+	_vala_basic_block_unref0 (self->priv->_parent);
+	_gee_collection_object_unref0 (self->priv->children);
+	_gee_collection_object_unref0 (self->priv->df);
+	_gee_collection_object_unref0 (self->priv->phi_functions);
 }
 
 
