@@ -128,6 +128,8 @@ typedef struct _ValaCatchClausePrivate ValaCatchClausePrivate;
 
 typedef struct _ValaBlock ValaBlock;
 typedef struct _ValaBlockClass ValaBlockClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -199,12 +201,6 @@ typedef struct _ValaReferenceTypeClass ValaReferenceTypeClass;
 typedef struct _ValaErrorType ValaErrorType;
 typedef struct _ValaErrorTypeClass ValaErrorTypeClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -225,9 +221,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a catch clause in a try statement in the source code.
- */
 struct _ValaCatchClause {
 	ValaCodeNode parent_instance;
 	ValaCatchClausePrivate * priv;
@@ -239,13 +232,14 @@ struct _ValaCatchClauseClass {
 
 struct _ValaCatchClausePrivate {
 	char* _variable_name;
-	ValaBlock* _body;
-	ValaLocalVariable* _error_variable;
 	char* _clabel_name;
 	ValaDataType* _data_type;
+	ValaBlock* _body;
+	ValaLocalVariable* _error_variable;
 };
 
 
+static gpointer vala_catch_clause_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -271,6 +265,7 @@ GType vala_block_get_type (void);
 enum  {
 	VALA_CATCH_CLAUSE_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_catch_clause_set_error_type (ValaCatchClause* self, ValaDataType* value);
 void vala_catch_clause_set_variable_name (ValaCatchClause* self, const char* value);
 void vala_catch_clause_set_body (ValaCatchClause* self, ValaBlock* value);
@@ -283,7 +278,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaCatchClause* vala_catch_clause_new (ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference);
 ValaCatchClause* vala_catch_clause_construct (GType object_type, ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference);
-ValaCatchClause* vala_catch_clause_new (ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
 static void vala_catch_clause_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaDataType* vala_catch_clause_get_error_type (ValaCatchClause* self);
@@ -323,24 +317,14 @@ static void vala_catch_clause_real_get_defined_variables (ValaCodeNode* base, Ge
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 const char* vala_catch_clause_get_clabel_name (ValaCatchClause* self);
 void vala_catch_clause_set_clabel_name (ValaCatchClause* self, const char* value);
-static gpointer vala_catch_clause_parent_class = NULL;
 static void vala_catch_clause_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new catch 
- *
- * @param type_reference   error type
- * @param variable_name    error variable name
- * @param body             error handler body
- * @param source_reference reference to source code
- * @return                 newly created catch clause
- */
 ValaCatchClause* vala_catch_clause_construct (GType object_type, ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference) {
 	ValaCatchClause* self;
 	g_return_val_if_fail (body != NULL, NULL);
-	self = (ValaCatchClause*) g_type_create_instance (object_type);
+	self = (ValaCatchClause*) vala_code_node_construct (object_type);
 	vala_catch_clause_set_error_type (self, error_type);
 	vala_catch_clause_set_variable_name (self, variable_name);
 	vala_catch_clause_set_body (self, body);
@@ -369,7 +353,7 @@ static void vala_catch_clause_real_accept_children (ValaCodeNode* base, ValaCode
 	if (vala_catch_clause_get_error_type (self) != NULL) {
 		vala_code_node_accept ((ValaCodeNode*) vala_catch_clause_get_error_type (self), visitor);
 	}
-	vala_code_node_accept ((ValaCodeNode*) self->priv->_body, visitor);
+	vala_code_node_accept ((ValaCodeNode*) vala_catch_clause_get_body (self), visitor);
 }
 
 
@@ -386,32 +370,32 @@ static void vala_catch_clause_real_replace_type (ValaCodeNode* base, ValaDataTyp
 
 static gboolean vala_catch_clause_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaCatchClause * self;
+	gboolean result;
 	self = (ValaCatchClause*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (vala_catch_clause_get_error_type (self) != NULL) {
-		ValaLocalVariable* _tmp2_;
-		ValaDataType* _tmp1_;
-		_tmp2_ = NULL;
-		_tmp1_ = NULL;
-		vala_catch_clause_set_error_variable (self, _tmp2_ = vala_local_variable_new (_tmp1_ = vala_data_type_copy (vala_catch_clause_get_error_type (self)), self->priv->_variable_name, NULL, NULL));
-		(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
-		(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL));
-		vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self->priv->_body), self->priv->_variable_name, (ValaSymbol*) self->priv->_error_variable);
-		vala_block_add_local_variable (self->priv->_body, self->priv->_error_variable);
-		vala_code_node_set_checked ((ValaCodeNode*) self->priv->_error_variable, TRUE);
+		ValaLocalVariable* _tmp1_;
+		ValaDataType* _tmp0_;
+		vala_catch_clause_set_error_variable (self, _tmp1_ = vala_local_variable_new (_tmp0_ = vala_data_type_copy (vala_catch_clause_get_error_type (self)), self->priv->_variable_name, NULL, NULL));
+		_vala_code_node_unref0 (_tmp1_);
+		_vala_code_node_unref0 (_tmp0_);
+		vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) vala_catch_clause_get_body (self)), self->priv->_variable_name, (ValaSymbol*) vala_catch_clause_get_error_variable (self));
+		vala_block_add_local_variable (vala_catch_clause_get_body (self), vala_catch_clause_get_error_variable (self));
+		vala_code_node_set_checked ((ValaCodeNode*) vala_catch_clause_get_error_variable (self), TRUE);
 	} else {
-		ValaErrorType* _tmp3_;
-		_tmp3_ = NULL;
-		vala_catch_clause_set_error_type (self, (ValaDataType*) (_tmp3_ = vala_error_type_new (NULL, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-		(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_node_unref (_tmp3_), NULL));
+		ValaErrorType* _tmp2_;
+		vala_catch_clause_set_error_type (self, (ValaDataType*) (_tmp2_ = vala_error_type_new (NULL, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+		_vala_code_node_unref0 (_tmp2_);
 	}
 	vala_code_node_check ((ValaCodeNode*) vala_catch_clause_get_error_type (self), analyzer);
-	vala_code_node_check ((ValaCodeNode*) self->priv->_body, analyzer);
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	vala_code_node_check ((ValaCodeNode*) vala_catch_clause_get_body (self), analyzer);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
@@ -419,25 +403,29 @@ static void vala_catch_clause_real_get_defined_variables (ValaCodeNode* base, Ge
 	ValaCatchClause * self;
 	self = (ValaCatchClause*) base;
 	g_return_if_fail (collection != NULL);
-	if (self->priv->_error_variable != NULL) {
-		gee_collection_add (collection, self->priv->_error_variable);
+	if (vala_catch_clause_get_error_variable (self) != NULL) {
+		gee_collection_add (collection, vala_catch_clause_get_error_variable (self));
 	}
 }
 
 
 ValaDataType* vala_catch_clause_get_error_type (ValaCatchClause* self) {
+	ValaDataType* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_data_type;
+	result = self->priv->_data_type;
+	return result;
+}
+
+
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
 }
 
 
 void vala_catch_clause_set_error_type (ValaCatchClause* self, ValaDataType* value) {
-	ValaDataType* _tmp2_;
-	ValaDataType* _tmp1_;
+	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_data_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2_);
+	self->priv->_data_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_data_type), _tmp0_);
 	if (self->priv->_data_type != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 	}
@@ -445,66 +433,64 @@ void vala_catch_clause_set_error_type (ValaCatchClause* self, ValaDataType* valu
 
 
 const char* vala_catch_clause_get_variable_name (ValaCatchClause* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_variable_name;
+	result = self->priv->_variable_name;
+	return result;
 }
 
 
 void vala_catch_clause_set_variable_name (ValaCatchClause* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_variable_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL), _tmp2_);
+	self->priv->_variable_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_variable_name), _tmp0_);
 }
 
 
 ValaBlock* vala_catch_clause_get_body (ValaCatchClause* self) {
+	ValaBlock* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_body;
+	result = self->priv->_body;
+	return result;
 }
 
 
 void vala_catch_clause_set_body (ValaCatchClause* self, ValaBlock* value) {
-	ValaBlock* _tmp2_;
-	ValaBlock* _tmp1_;
+	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_body = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp2_);
+	self->priv->_body = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_body), _tmp0_);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_body, (ValaCodeNode*) self);
 }
 
 
 ValaLocalVariable* vala_catch_clause_get_error_variable (ValaCatchClause* self) {
+	ValaLocalVariable* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_error_variable;
+	result = self->priv->_error_variable;
+	return result;
 }
 
 
 void vala_catch_clause_set_error_variable (ValaCatchClause* self, ValaLocalVariable* value) {
-	ValaLocalVariable* _tmp2_;
-	ValaLocalVariable* _tmp1_;
+	ValaLocalVariable* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_error_variable = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_error_variable == NULL) ? NULL : (self->priv->_error_variable = (vala_code_node_unref (self->priv->_error_variable), NULL)), _tmp2_);
+	self->priv->_error_variable = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_error_variable), _tmp0_);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_error_variable, (ValaCodeNode*) self);
 }
 
 
 const char* vala_catch_clause_get_clabel_name (ValaCatchClause* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_clabel_name;
+	result = self->priv->_clabel_name;
+	return result;
 }
 
 
 void vala_catch_clause_set_clabel_name (ValaCatchClause* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_clabel_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_clabel_name = (g_free (self->priv->_clabel_name), NULL), _tmp2_);
+	self->priv->_clabel_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_clabel_name), _tmp0_);
 }
 
 
@@ -528,11 +514,11 @@ static void vala_catch_clause_instance_init (ValaCatchClause * self) {
 static void vala_catch_clause_finalize (ValaCodeNode* obj) {
 	ValaCatchClause * self;
 	self = VALA_CATCH_CLAUSE (obj);
-	self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL);
-	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL));
-	(self->priv->_error_variable == NULL) ? NULL : (self->priv->_error_variable = (vala_code_node_unref (self->priv->_error_variable), NULL));
-	self->priv->_clabel_name = (g_free (self->priv->_clabel_name), NULL);
-	(self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL));
+	_g_free0 (self->priv->_variable_name);
+	_g_free0 (self->priv->_clabel_name);
+	_vala_code_node_unref0 (self->priv->_data_type);
+	_vala_code_node_unref0 (self->priv->_body);
+	_vala_code_node_unref0 (self->priv->_error_variable);
 	VALA_CODE_NODE_CLASS (vala_catch_clause_parent_class)->finalize (obj);
 }
 
