@@ -132,6 +132,10 @@ typedef struct _ValaCodeVisitorClass ValaCodeVisitorClass;
 
 typedef struct _ValaCodeGenerator ValaCodeGenerator;
 typedef struct _ValaCodeGeneratorClass ValaCodeGeneratorClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -142,11 +146,10 @@ typedef struct _ValaCodeGeneratorClass ValaCodeGeneratorClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _vala_code_visitor_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_visitor_unref (var), NULL)))
+#define _vala_source_file_unref0(var) ((var == NULL) ? NULL : (var = (vala_source_file_unref (var), NULL)))
 typedef struct _ValaParamSpecCodeContext ValaParamSpecCodeContext;
 
-/**
- * The root of the code tree.
- */
 struct _ValaCodeContext {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -173,6 +176,7 @@ struct _ValaCodeContextPrivate {
 	gboolean _ccode_only;
 	char* _header_filename;
 	char* _internal_header_filename;
+	char* _includedir;
 	gboolean _compile_only;
 	char* _output;
 	char* _basedir;
@@ -187,6 +191,7 @@ struct _ValaCodeContextPrivate {
 	gint _target_glib_minor;
 	gboolean _verbose_mode;
 	ValaReport* _report;
+	ValaMethod* _entry_point;
 	GeeList* source_files;
 	GeeList* c_source_files;
 	ValaNamespace* _root;
@@ -291,6 +296,8 @@ const char* vala_code_context_get_header_filename (ValaCodeContext* self);
 void vala_code_context_set_header_filename (ValaCodeContext* self, const char* value);
 const char* vala_code_context_get_internal_header_filename (ValaCodeContext* self);
 void vala_code_context_set_internal_header_filename (ValaCodeContext* self, const char* value);
+const char* vala_code_context_get_includedir (ValaCodeContext* self);
+void vala_code_context_set_includedir (ValaCodeContext* self, const char* value);
 gboolean vala_code_context_get_compile_only (ValaCodeContext* self);
 void vala_code_context_set_compile_only (ValaCodeContext* self, gboolean value);
 const char* vala_code_context_get_output (ValaCodeContext* self);
@@ -318,6 +325,8 @@ void vala_code_context_set_verbose_mode (ValaCodeContext* self, gboolean value);
 gboolean vala_code_context_get_save_csources (ValaCodeContext* self);
 ValaReport* vala_code_context_get_report (ValaCodeContext* self);
 void vala_code_context_set_report (ValaCodeContext* self, ValaReport* value);
+ValaMethod* vala_code_context_get_entry_point (ValaCodeContext* self);
+void vala_code_context_set_entry_point (ValaCodeContext* self, ValaMethod* value);
 ValaCodeGenerator* vala_code_context_get_codegen (ValaCodeContext* self);
 void vala_code_context_set_codegen (ValaCodeContext* self, ValaCodeGenerator* value);
 static void vala_code_context_finalize (ValaCodeContext* obj);
@@ -325,10 +334,6 @@ static gint _vala_array_length (gpointer array);
 
 
 
-/**
- * Returns true if the target version of glib is greater than or 
- * equal to the specified version.
- */
 gboolean vala_code_context_require_glib_version (ValaCodeContext* self, gint major, gint minor) {
 	gboolean result;
 	gboolean _tmp0_;
@@ -363,9 +368,6 @@ ValaCodeContext* vala_code_context_new (void) {
 }
 
 
-/**
- * Return the topmost context from the context stack.
- */
 ValaCodeContext* vala_code_context_get (void) {
 	ValaCodeContext* result;
 	GeeList* context_stack;
@@ -375,9 +377,6 @@ ValaCodeContext* vala_code_context_get (void) {
 }
 
 
-/**
- * Push the specified context to the context stack.
- */
 void vala_code_context_push (ValaCodeContext* context) {
 	GeeList* context_stack;
 	g_return_if_fail (context != NULL);
@@ -390,9 +389,6 @@ void vala_code_context_push (ValaCodeContext* context) {
 }
 
 
-/**
- * Remove the topmost context from the context stack.
- */
 void vala_code_context_pop (void) {
 	GeeList* context_stack;
 	context_stack = g_static_private_get (&vala_code_context_context_stack_key);
@@ -400,11 +396,6 @@ void vala_code_context_pop (void) {
 }
 
 
-/**
- * Returns a copy of the list of source files.
- *
- * @return list of source files
- */
 GeeList* vala_code_context_get_source_files (ValaCodeContext* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -413,11 +404,6 @@ GeeList* vala_code_context_get_source_files (ValaCodeContext* self) {
 }
 
 
-/**
- * Returns a copy of the list of C source files.
- *
- * @return list of C source files
- */
 GeeList* vala_code_context_get_c_source_files (ValaCodeContext* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -426,11 +412,6 @@ GeeList* vala_code_context_get_c_source_files (ValaCodeContext* self) {
 }
 
 
-/**
- * Adds the specified file to the list of source files.
- *
- * @param file a source file
- */
 void vala_code_context_add_source_file (ValaCodeContext* self, ValaSourceFile* file) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (file != NULL);
@@ -438,11 +419,6 @@ void vala_code_context_add_source_file (ValaCodeContext* self, ValaSourceFile* f
 }
 
 
-/**
- * Adds the specified file to the list of C source files.
- *
- * @param file a C source file
- */
 void vala_code_context_add_c_source_file (ValaCodeContext* self, const char* file) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (file != NULL);
@@ -450,11 +426,6 @@ void vala_code_context_add_c_source_file (ValaCodeContext* self, const char* fil
 }
 
 
-/**
- * Returns a copy of the list of used packages.
- *
- * @return list of used packages
- */
 GeeList* vala_code_context_get_packages (ValaCodeContext* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -463,12 +434,6 @@ GeeList* vala_code_context_get_packages (ValaCodeContext* self) {
 }
 
 
-/**
- * Returns whether the specified package is being used.
- *
- * @param pkg a package name
- * @return    true if the specified package is being used
- */
 gboolean vala_code_context_has_package (ValaCodeContext* self, const char* pkg) {
 	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
@@ -478,11 +443,6 @@ gboolean vala_code_context_has_package (ValaCodeContext* self, const char* pkg)
 }
 
 
-/**
- * Adds the specified package to the list of used packages.
- *
- * @param pkg a package name
- */
 void vala_code_context_add_package (ValaCodeContext* self, const char* pkg) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (pkg != NULL);
@@ -490,11 +450,6 @@ void vala_code_context_add_package (ValaCodeContext* self, const char* pkg) {
 }
 
 
-/**
- * Visits the complete code tree file by file.
- *
- * @param visitor the visitor to be called when traversing
- */
 void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (visitor != NULL);
@@ -509,9 +464,9 @@ void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor)
 			}
 			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			vala_source_file_accept (file, visitor);
-			(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
+			_vala_source_file_unref0 (file);
 		}
-		(_file_it == NULL) ? NULL : (_file_it = (gee_collection_object_unref (_file_it), NULL));
+		_gee_collection_object_unref0 (_file_it);
 	}
 }
 
@@ -536,7 +491,7 @@ char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg
 	char* result;
 	char* basename;
 	char* filename;
-	char* _tmp2_;
+	char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (pkg != NULL, NULL);
 	basename = g_strdup_printf ("%s.vapi", pkg);
@@ -549,62 +504,54 @@ char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg
 			vapidir_collection = vapi_directories;
 			vapidir_collection_length1 = vapi_directories_length1;
 			for (vapidir_it = 0; vapidir_it < vapi_directories_length1; vapidir_it = vapidir_it + 1) {
-				const char* _tmp1_;
 				char* vapidir;
-				_tmp1_ = NULL;
-				vapidir = (_tmp1_ = vapidir_collection[vapidir_it], (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+				vapidir = g_strdup (vapidir_collection[vapidir_it]);
 				{
 					char* _tmp0_;
-					_tmp0_ = NULL;
-					filename = (_tmp0_ = g_build_filename (vapidir, basename, NULL), filename = (g_free (filename), NULL), _tmp0_);
+					filename = (_tmp0_ = g_build_filename (vapidir, basename, NULL), _g_free0 (filename), _tmp0_);
 					if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
 						result = filename;
-						vapidir = (g_free (vapidir), NULL);
-						basename = (g_free (basename), NULL);
+						_g_free0 (vapidir);
+						_g_free0 (basename);
 						return result;
 					}
-					vapidir = (g_free (vapidir), NULL);
+					_g_free0 (vapidir);
 				}
 			}
 		}
 	}
-	_tmp2_ = NULL;
-	filename = (_tmp2_ = g_build_filename (PACKAGE_DATADIR, "vapi", basename, NULL), filename = (g_free (filename), NULL), _tmp2_);
+	filename = (_tmp1_ = g_build_filename (PACKAGE_DATADIR, "vapi", basename, NULL), _g_free0 (filename), _tmp1_);
 	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
 		result = filename;
-		basename = (g_free (basename), NULL);
+		_g_free0 (basename);
 		return result;
 	}
 	{
-		char** _tmp3_;
+		char** _tmp2_;
 		char** vapidir_collection;
 		int vapidir_collection_length1;
 		int vapidir_it;
-		_tmp3_ = NULL;
-		vapidir_collection = _tmp3_ = g_get_system_data_dirs ();
-		vapidir_collection_length1 = _vala_array_length (_tmp3_);
-		for (vapidir_it = 0; vapidir_it < _vala_array_length (_tmp3_); vapidir_it = vapidir_it + 1) {
-			const char* _tmp5_;
+		vapidir_collection = _tmp2_ = g_get_system_data_dirs ();
+		vapidir_collection_length1 = _vala_array_length (_tmp2_);
+		for (vapidir_it = 0; vapidir_it < _vala_array_length (_tmp2_); vapidir_it = vapidir_it + 1) {
 			char* vapidir;
-			_tmp5_ = NULL;
-			vapidir = (_tmp5_ = vapidir_collection[vapidir_it], (_tmp5_ == NULL) ? NULL : g_strdup (_tmp5_));
+			vapidir = g_strdup (vapidir_collection[vapidir_it]);
 			{
-				char* _tmp4_;
-				_tmp4_ = NULL;
-				filename = (_tmp4_ = g_build_filename (vapidir, "vala/vapi", basename, NULL), filename = (g_free (filename), NULL), _tmp4_);
+				char* _tmp3_;
+				filename = (_tmp3_ = g_build_filename (vapidir, "vala/vapi", basename, NULL), _g_free0 (filename), _tmp3_);
 				if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
 					result = filename;
-					vapidir = (g_free (vapidir), NULL);
-					basename = (g_free (basename), NULL);
+					_g_free0 (vapidir);
+					_g_free0 (basename);
 					return result;
 				}
-				vapidir = (g_free (vapidir), NULL);
+				_g_free0 (vapidir);
 			}
 		}
 	}
 	result = NULL;
-	basename = (g_free (basename), NULL);
-	filename = (g_free (filename), NULL);
+	_g_free0 (basename);
+	_g_free0 (filename);
 	return result;
 }
 
@@ -716,12 +663,9 @@ const char* vala_code_context_get_header_filename (ValaCodeContext* self) {
 
 
 void vala_code_context_set_header_filename (ValaCodeContext* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_header_filename = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_header_filename = (g_free (self->priv->_header_filename), NULL), _tmp1_);
+	self->priv->_header_filename = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_header_filename), _tmp0_);
 }
 
 
@@ -734,12 +678,24 @@ const char* vala_code_context_get_internal_header_filename (ValaCodeContext* sel
 
 
 void vala_code_context_set_internal_header_filename (ValaCodeContext* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_internal_header_filename = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_internal_header_filename = (g_free (self->priv->_internal_header_filename), NULL), _tmp1_);
+	self->priv->_internal_header_filename = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_internal_header_filename), _tmp0_);
+}
+
+
+const char* vala_code_context_get_includedir (ValaCodeContext* self) {
+	const char* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = self->priv->_includedir;
+	return result;
+}
+
+
+void vala_code_context_set_includedir (ValaCodeContext* self, const char* value) {
+	char* _tmp0_;
+	g_return_if_fail (self != NULL);
+	self->priv->_includedir = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_includedir), _tmp0_);
 }
 
 
@@ -766,12 +722,9 @@ const char* vala_code_context_get_output (ValaCodeContext* self) {
 
 
 void vala_code_context_set_output (ValaCodeContext* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_output = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_output = (g_free (self->priv->_output), NULL), _tmp1_);
+	self->priv->_output = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_output), _tmp0_);
 }
 
 
@@ -784,12 +737,9 @@ const char* vala_code_context_get_basedir (ValaCodeContext* self) {
 
 
 void vala_code_context_set_basedir (ValaCodeContext* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_basedir = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_basedir = (g_free (self->priv->_basedir), NULL), _tmp1_);
+	self->priv->_basedir = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_basedir), _tmp0_);
 }
 
 
@@ -802,12 +752,9 @@ const char* vala_code_context_get_directory (ValaCodeContext* self) {
 
 
 void vala_code_context_set_directory (ValaCodeContext* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_directory = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_directory = (g_free (self->priv->_directory), NULL), _tmp1_);
+	self->priv->_directory = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_directory), _tmp0_);
 }
 
 
@@ -861,13 +808,15 @@ ValaMethod* vala_code_context_get_module_init_method (ValaCodeContext* self) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_code_context_set_module_init_method (ValaCodeContext* self, ValaMethod* value) {
-	ValaMethod* _tmp1_;
 	ValaMethod* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_module_init_method = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_module_init_method == NULL) ? NULL : (self->priv->_module_init_method = (vala_code_node_unref (self->priv->_module_init_method), NULL)), _tmp1_);
+	self->priv->_module_init_method = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_module_init_method), _tmp0_);
 }
 
 
@@ -957,13 +906,30 @@ ValaReport* vala_code_context_get_report (ValaCodeContext* self) {
 }
 
 
+static gpointer _g_object_ref0 (gpointer self) {
+	return self ? g_object_ref (self) : NULL;
+}
+
+
 void vala_code_context_set_report (ValaCodeContext* self, ValaReport* value) {
-	ValaReport* _tmp1_;
 	ValaReport* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_report = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_report == NULL) ? NULL : (self->priv->_report = (g_object_unref (self->priv->_report), NULL)), _tmp1_);
+	self->priv->_report = (_tmp0_ = _g_object_ref0 (value), _g_object_unref0 (self->priv->_report), _tmp0_);
+}
+
+
+ValaMethod* vala_code_context_get_entry_point (ValaCodeContext* self) {
+	ValaMethod* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = self->priv->_entry_point;
+	return result;
+}
+
+
+void vala_code_context_set_entry_point (ValaCodeContext* self, ValaMethod* value) {
+	ValaMethod* _tmp0_;
+	g_return_if_fail (self != NULL);
+	self->priv->_entry_point = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_entry_point), _tmp0_);
 }
 
 
@@ -983,13 +949,15 @@ ValaCodeGenerator* vala_code_context_get_codegen (ValaCodeContext* self) {
 }
 
 
+static gpointer _vala_code_visitor_ref0 (gpointer self) {
+	return self ? vala_code_visitor_ref (self) : NULL;
+}
+
+
 void vala_code_context_set_codegen (ValaCodeContext* self, ValaCodeGenerator* value) {
-	ValaCodeGenerator* _tmp1_;
 	ValaCodeGenerator* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_codegen = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_visitor_ref (_tmp0_)), (self->priv->_codegen == NULL) ? NULL : (self->priv->_codegen = (vala_code_visitor_unref (self->priv->_codegen), NULL)), _tmp1_);
+	self->priv->_codegen = (_tmp0_ = _vala_code_visitor_ref0 (value), _vala_code_visitor_unref0 (self->priv->_codegen), _tmp0_);
 }
 
 
@@ -1111,19 +1079,21 @@ static void vala_code_context_instance_init (ValaCodeContext * self) {
 static void vala_code_context_finalize (ValaCodeContext* obj) {
 	ValaCodeContext * self;
 	self = VALA_CODE_CONTEXT (obj);
-	self->priv->_header_filename = (g_free (self->priv->_header_filename), NULL);
-	self->priv->_internal_header_filename = (g_free (self->priv->_internal_header_filename), NULL);
-	self->priv->_output = (g_free (self->priv->_output), NULL);
-	self->priv->_basedir = (g_free (self->priv->_basedir), NULL);
-	self->priv->_directory = (g_free (self->priv->_directory), NULL);
-	(self->priv->_module_init_method == NULL) ? NULL : (self->priv->_module_init_method = (vala_code_node_unref (self->priv->_module_init_method), NULL));
-	(self->priv->_report == NULL) ? NULL : (self->priv->_report = (g_object_unref (self->priv->_report), NULL));
-	(self->priv->source_files == NULL) ? NULL : (self->priv->source_files = (gee_collection_object_unref (self->priv->source_files), NULL));
-	(self->priv->c_source_files == NULL) ? NULL : (self->priv->c_source_files = (gee_collection_object_unref (self->priv->c_source_files), NULL));
-	(self->priv->_root == NULL) ? NULL : (self->priv->_root = (vala_code_node_unref (self->priv->_root), NULL));
-	(self->priv->packages == NULL) ? NULL : (self->priv->packages = (gee_collection_object_unref (self->priv->packages), NULL));
-	(self->priv->defines == NULL) ? NULL : (self->priv->defines = (gee_collection_object_unref (self->priv->defines), NULL));
-	(self->priv->_codegen == NULL) ? NULL : (self->priv->_codegen = (vala_code_visitor_unref (self->priv->_codegen), NULL));
+	_g_free0 (self->priv->_header_filename);
+	_g_free0 (self->priv->_internal_header_filename);
+	_g_free0 (self->priv->_includedir);
+	_g_free0 (self->priv->_output);
+	_g_free0 (self->priv->_basedir);
+	_g_free0 (self->priv->_directory);
+	_vala_code_node_unref0 (self->priv->_module_init_method);
+	_g_object_unref0 (self->priv->_report);
+	_vala_code_node_unref0 (self->priv->_entry_point);
+	_gee_collection_object_unref0 (self->priv->source_files);
+	_gee_collection_object_unref0 (self->priv->c_source_files);
+	_vala_code_node_unref0 (self->priv->_root);
+	_gee_collection_object_unref0 (self->priv->packages);
+	_gee_collection_object_unref0 (self->priv->defines);
+	_vala_code_visitor_unref0 (self->priv->_codegen);
 }
 
 
