@@ -119,6 +119,13 @@ typedef struct _ValaAttributeClass ValaAttributeClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _vala_source_reference_unref0(var) ((var == NULL) ? NULL : (var = (vala_source_reference_unref (var), NULL)))
+#define __g_list_free_vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (_g_list_free_vala_code_node_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
 
 #define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
 #define VALA_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFile))
@@ -131,12 +138,6 @@ typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
 typedef struct _ValaParamSpecCodeNode ValaParamSpecCodeNode;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -171,6 +172,11 @@ struct _ValaParamSpecCodeNode {
 };
 
 
+static GeeList* vala_code_node__empty_type_list;
+static GeeList* vala_code_node__empty_type_list = NULL;
+static gint vala_code_node_last_temp_nr;
+static gint vala_code_node_last_temp_nr = 0;
+static gpointer vala_code_node_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -201,10 +207,6 @@ enum  {
 	VALA_CODE_NODE_DUMMY_PROPERTY
 };
 static void _g_list_free_vala_code_node_unref (GList* self);
-static GeeList* vala_code_node__empty_type_list;
-static GeeList* vala_code_node__empty_type_list = NULL;
-static gint vala_code_node_last_temp_nr;
-static gint vala_code_node_last_temp_nr = 0;
 GeeList* vala_code_node_get_error_types (ValaCodeNode* self);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type);
@@ -230,6 +232,7 @@ static void vala_code_node_real_get_defined_variables (ValaCodeNode* self, GeeCo
 void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
 static void vala_code_node_real_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
 char* vala_code_node_get_temp_name (ValaCodeNode* self);
+ValaCodeNode* vala_code_node_construct (GType object_type);
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 const char* vala_code_node_get_type_name (ValaCodeNode* self);
@@ -249,7 +252,6 @@ void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self);
-static gpointer vala_code_node_parent_class = NULL;
 static void vala_code_node_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -261,73 +263,61 @@ static void _g_list_free_vala_code_node_unref (GList* self) {
 }
 
 
-/**
- * Specifies the exceptions that can be thrown by this node or a child node
- */
+static gpointer _gee_collection_object_ref0 (gpointer self) {
+	return self ? gee_collection_object_ref (self) : NULL;
+}
+
+
 GeeList* vala_code_node_get_error_types (ValaCodeNode* self) {
-	GeeList* _tmp4_;
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_error_types != NULL) {
-		GeeList* _tmp0_;
-		_tmp0_ = NULL;
-		return (_tmp0_ = self->priv->_error_types, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
+		result = _gee_collection_object_ref0 (self->priv->_error_types);
+		return result;
 	}
 	if (vala_code_node__empty_type_list == NULL) {
-		GeeList* _tmp3_;
-		GeeArrayList* _tmp2_;
-		_tmp3_ = NULL;
-		_tmp2_ = NULL;
-		vala_code_node__empty_type_list = (_tmp3_ = (GeeList*) gee_read_only_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, (GeeList*) (_tmp2_ = gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal))), (vala_code_node__empty_type_list == NULL) ? NULL : (vala_code_node__empty_type_list = (gee_collection_object_unref (vala_code_node__empty_type_list), NULL)), _tmp3_);
-		(_tmp2_ == NULL) ? NULL : (_tmp2_ = (gee_collection_object_unref (_tmp2_), NULL));
+		GeeList* _tmp1_;
+		GeeArrayList* _tmp0_;
+		vala_code_node__empty_type_list = (_tmp1_ = (GeeList*) gee_read_only_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, (GeeList*) (_tmp0_ = gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal))), _gee_collection_object_unref0 (vala_code_node__empty_type_list), _tmp1_);
+		_gee_collection_object_unref0 (_tmp0_);
 	}
-	_tmp4_ = NULL;
-	return (_tmp4_ = vala_code_node__empty_type_list, (_tmp4_ == NULL) ? NULL : gee_collection_object_ref (_tmp4_));
+	result = _gee_collection_object_ref0 (vala_code_node__empty_type_list);
+	return result;
 }
 
 
-/**
- * Adds an error type to the exceptions that can be thrown by this node
- * or a child node 
- */
 void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (error_type != NULL);
 	if (self->priv->_error_types == NULL) {
 		GeeList* _tmp0_;
-		_tmp0_ = NULL;
-		self->priv->_error_types = (_tmp0_ = (GeeList*) gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal), (self->priv->_error_types == NULL) ? NULL : (self->priv->_error_types = (gee_collection_object_unref (self->priv->_error_types), NULL)), _tmp0_);
+		self->priv->_error_types = (_tmp0_ = (GeeList*) gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal), _gee_collection_object_unref0 (self->priv->_error_types), _tmp0_);
 	}
 	gee_collection_add ((GeeCollection*) self->priv->_error_types, error_type);
 	vala_code_node_set_parent_node ((ValaCodeNode*) error_type, self);
 }
 
 
-/**
- * Adds a collection of error types to the exceptions that can be thrown by this node
- * or a child node 
- */
 void vala_code_node_add_error_types (ValaCodeNode* self, GeeList* error_types) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (error_types != NULL);
 	{
 		GeeIterator* _error_type_it;
 		_error_type_it = gee_iterable_iterator ((GeeIterable*) error_types);
-		while (gee_iterator_next (_error_type_it)) {
+		while (TRUE) {
 			ValaDataType* error_type;
+			if (!gee_iterator_next (_error_type_it)) {
+				break;
+			}
 			error_type = (ValaDataType*) gee_iterator_get (_error_type_it);
 			vala_code_node_add_error_type (self, error_type);
-			(error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL));
+			_vala_code_node_unref0 (error_type);
 		}
-		(_error_type_it == NULL) ? NULL : (_error_type_it = (gee_collection_object_unref (_error_type_it), NULL));
+		_gee_collection_object_unref0 (_error_type_it);
 	}
 }
 
 
-/**
- * Visits this code node with the specified CodeVisitor.
- *
- * @param visitor the visitor to be called while traversing
- */
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (visitor != NULL);
@@ -339,11 +329,6 @@ void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
 }
 
 
-/**
- * Visits all children of this code node with the specified CodeVisitor.
- *
- * @param visitor the visitor to be called while traversing
- */
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (visitor != NULL);
@@ -356,9 +341,11 @@ void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visito
 
 
 static gboolean vala_code_node_real_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (analyzer != NULL, FALSE);
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
@@ -391,58 +378,50 @@ void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_
 }
 
 
-/**
- * Returns the specified attribute.
- *
- * @param name attribute name
- * @return     attribute
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* name) {
+	ValaAttribute* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
-	/* FIXME: use hash table*/
 	{
 		GList* a_collection;
 		GList* a_it;
 		a_collection = self->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp1_;
 			ValaAttribute* a;
-			_tmp1_ = NULL;
-			a = (_tmp1_ = (ValaAttribute*) a_it->data, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+			a = _vala_code_node_ref0 ((ValaAttribute*) a_it->data);
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), name) == 0) {
-					return a;
+					result = a;
+					return result;
 				}
-				(a == NULL) ? NULL : (a = (vala_code_node_unref (a), NULL));
+				_vala_code_node_unref0 (a);
 			}
 		}
 	}
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
-/**
- * Returns a string that represents this code node.
- *
- * @return a string representation
- */
 static char* vala_code_node_real_to_string (ValaCodeNode* self) {
+	char* result;
 	GString* str;
-	const char* _tmp1_;
-	char* _tmp2_;
 	g_return_val_if_fail (self != NULL, NULL);
 	str = g_string_new ("");
 	g_string_append (str, "/* ");
 	if (self->priv->_source_reference != NULL) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
 		g_string_append (g_string_append (str, "@"), _tmp0_ = vala_source_reference_to_string (self->priv->_source_reference));
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		_g_free0 (_tmp0_);
 	}
-	_tmp1_ = NULL;
-	_tmp2_ = NULL;
-	return (_tmp2_ = (_tmp1_ = g_string_append (str, " */")->str, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), _tmp2_);
+	result = g_strdup (g_string_append (str, " */")->str);
+	_g_string_free0 (str);
+	return result;
 }
 
 
@@ -474,18 +453,27 @@ void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* colle
 
 
 char* vala_code_node_get_temp_name (ValaCodeNode* self) {
+	char* result;
 	char* _tmp0_;
 	char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	return (_tmp1_ = g_strconcat (".", _tmp0_ = g_strdup_printf ("%i", vala_code_node_last_temp_nr = vala_code_node_last_temp_nr + 1), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strconcat (".", _tmp0_ = g_strdup_printf ("%i", vala_code_node_last_temp_nr = vala_code_node_last_temp_nr + 1), NULL), _g_free0 (_tmp0_), _tmp1_);
+	return result;
+}
+
+
+ValaCodeNode* vala_code_node_construct (GType object_type) {
+	ValaCodeNode* self;
+	self = (ValaCodeNode*) g_type_create_instance (object_type);
+	return self;
 }
 
 
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self) {
+	ValaCodeNode* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_parent_node;
+	result = self->priv->_parent_node;
+	return result;
 }
 
 
@@ -496,62 +484,72 @@ void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value) {
 
 
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self) {
+	ValaSourceReference* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_source_reference;
+	result = self->priv->_source_reference;
+	return result;
+}
+
+
+static gpointer _vala_source_reference_ref0 (gpointer self) {
+	return self ? vala_source_reference_ref (self) : NULL;
 }
 
 
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value) {
-	ValaSourceReference* _tmp2_;
-	ValaSourceReference* _tmp1_;
+	ValaSourceReference* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_source_reference = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_source_reference_ref (_tmp1_)), (self->priv->_source_reference == NULL) ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL)), _tmp2_);
+	self->priv->_source_reference = (_tmp0_ = _vala_source_reference_ref0 (value), _vala_source_reference_unref0 (self->priv->_source_reference), _tmp0_);
 }
 
 
 const char* vala_code_node_get_type_name (ValaCodeNode* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return g_type_name (G_TYPE_FROM_INSTANCE (self));
+	result = g_type_name (G_TYPE_FROM_INSTANCE (self));
+	return result;
 }
 
 
 ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self) {
+	ValaCCodeNode* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_ccodenode;
+	result = self->priv->_ccodenode;
+	return result;
+}
+
+
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
 }
 
 
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
-	gboolean _tmp1_;
-	ValaCCodeNode* _tmp5_;
-	ValaCCodeNode* _tmp4_;
+	gboolean _tmp0_;
+	ValaCCodeNode* _tmp3_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = FALSE;
+	_tmp0_ = FALSE;
 	if (value != NULL) {
-		_tmp1_ = self->priv->_source_reference != NULL;
+		_tmp0_ = self->priv->_source_reference != NULL;
 	} else {
-		_tmp1_ = FALSE;
+		_tmp0_ = FALSE;
 	}
-	if (_tmp1_) {
-		ValaCCodeLineDirective* _tmp3_;
-		char* _tmp2_;
-		_tmp3_ = NULL;
-		_tmp2_ = NULL;
-		vala_ccode_node_set_line (value, _tmp3_ = vala_ccode_line_directive_new (_tmp2_ = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (self->priv->_source_reference))), vala_source_reference_get_first_line (self->priv->_source_reference)));
-		(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_ccode_node_unref (_tmp3_), NULL));
-		_tmp2_ = (g_free (_tmp2_), NULL);
+	if (_tmp0_) {
+		ValaCCodeLineDirective* _tmp2_;
+		char* _tmp1_;
+		vala_ccode_node_set_line (value, _tmp2_ = vala_ccode_line_directive_new (_tmp1_ = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (self->priv->_source_reference))), vala_source_reference_get_first_line (self->priv->_source_reference)));
+		_vala_ccode_node_unref0 (_tmp2_);
+		_g_free0 (_tmp1_);
 	}
-	_tmp5_ = NULL;
-	_tmp4_ = NULL;
-	self->priv->_ccodenode = (_tmp5_ = (_tmp4_ = value, (_tmp4_ == NULL) ? NULL : vala_ccode_node_ref (_tmp4_)), (self->priv->_ccodenode == NULL) ? NULL : (self->priv->_ccodenode = (vala_ccode_node_unref (self->priv->_ccodenode), NULL)), _tmp5_);
+	self->priv->_ccodenode = (_tmp3_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_ccodenode), _tmp3_);
 }
 
 
 gboolean vala_code_node_get_checked (ValaCodeNode* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_checked;
+	result = self->priv->_checked;
+	return result;
 }
 
 
@@ -562,8 +560,10 @@ void vala_code_node_set_checked (ValaCodeNode* self, gboolean value) {
 
 
 gboolean vala_code_node_get_error (ValaCodeNode* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_error;
+	result = self->priv->_error;
+	return result;
 }
 
 
@@ -574,6 +574,7 @@ void vala_code_node_set_error (ValaCodeNode* self, gboolean value) {
 
 
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self) {
+	gboolean result;
 	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	_tmp0_ = FALSE;
@@ -582,7 +583,8 @@ gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self) {
 	} else {
 		_tmp0_ = FALSE;
 	}
-	return _tmp0_;
+	result = _tmp0_;
+	return result;
 }
 
 
@@ -703,10 +705,10 @@ static void vala_code_node_instance_init (ValaCodeNode * self) {
 static void vala_code_node_finalize (ValaCodeNode* obj) {
 	ValaCodeNode * self;
 	self = VALA_CODE_NODE (obj);
-	(self->priv->_source_reference == NULL) ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL));
-	(self->attributes == NULL) ? NULL : (self->attributes = (_g_list_free_vala_code_node_unref (self->attributes), NULL));
-	(self->priv->_error_types == NULL) ? NULL : (self->priv->_error_types = (gee_collection_object_unref (self->priv->_error_types), NULL));
-	(self->priv->_ccodenode == NULL) ? NULL : (self->priv->_ccodenode = (vala_ccode_node_unref (self->priv->_ccodenode), NULL));
+	_vala_source_reference_unref0 (self->priv->_source_reference);
+	__g_list_free_vala_code_node_unref0 (self->attributes);
+	_gee_collection_object_unref0 (self->priv->_error_types);
+	_vala_ccode_node_unref0 (self->priv->_ccodenode);
 }
 
 
