@@ -159,13 +159,10 @@ typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
 
 typedef struct _ValaDelegate ValaDelegate;
 typedef struct _ValaDelegateClass ValaDelegateClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -186,10 +183,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -219,9 +212,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * The type of an instance of a delegate.
- */
 struct _ValaDelegateType {
 	ValaDataType parent_instance;
 	ValaDelegateTypePrivate * priv;
@@ -270,10 +260,10 @@ GType vala_delegate_get_type (void);
 enum  {
 	VALA_DELEGATE_TYPE_DUMMY_PROPERTY
 };
+ValaDataType* vala_data_type_construct (GType object_type);
 void vala_delegate_type_set_delegate_symbol (ValaDelegateType* self, ValaDelegate* value);
 ValaDelegateType* vala_delegate_type_new (ValaDelegate* delegate_symbol);
 ValaDelegateType* vala_delegate_type_construct (GType object_type, ValaDelegate* delegate_symbol);
-ValaDelegateType* vala_delegate_type_new (ValaDelegate* delegate_symbol);
 static gboolean vala_delegate_type_real_is_invokable (ValaDataType* base);
 ValaDelegate* vala_delegate_type_get_delegate_symbol (ValaDelegateType* self);
 ValaDataType* vala_delegate_get_return_type (ValaDelegate* self);
@@ -297,7 +287,7 @@ static void vala_delegate_type_finalize (ValaCodeNode* obj);
 ValaDelegateType* vala_delegate_type_construct (GType object_type, ValaDelegate* delegate_symbol) {
 	ValaDelegateType* self;
 	g_return_val_if_fail (delegate_symbol != NULL, NULL);
-	self = (ValaDelegateType*) g_type_create_instance (object_type);
+	self = (ValaDelegateType*) vala_data_type_construct (object_type);
 	vala_delegate_type_set_delegate_symbol (self, delegate_symbol);
 	return self;
 }
@@ -317,13 +307,16 @@ static gboolean vala_delegate_type_real_is_invokable (ValaDataType* base) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static ValaDataType* vala_delegate_type_real_get_return_type (ValaDataType* base) {
 	ValaDelegateType * self;
 	ValaDataType* result;
-	ValaDataType* _tmp0_;
 	self = (ValaDelegateType*) base;
-	_tmp0_ = NULL;
-	result = (_tmp0_ = vala_delegate_get_return_type (self->priv->_delegate_symbol), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	result = _vala_code_node_ref0 (vala_delegate_get_return_type (self->priv->_delegate_symbol));
 	return result;
 }
 
@@ -345,8 +338,7 @@ static char* vala_delegate_type_real_to_qualified_string (ValaDataType* base, Va
 	s = vala_symbol_get_full_name ((ValaSymbol*) self->priv->_delegate_symbol);
 	if (vala_data_type_get_nullable ((ValaDataType*) self)) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
-		s = (_tmp0_ = g_strconcat (s, "?", NULL), s = (g_free (s), NULL), _tmp0_);
+		s = (_tmp0_ = g_strconcat (s, "?", NULL), _g_free0 (s), _tmp0_);
 	}
 	result = s;
 	return result;
@@ -411,12 +403,9 @@ ValaDelegate* vala_delegate_type_get_delegate_symbol (ValaDelegateType* self) {
 
 
 void vala_delegate_type_set_delegate_symbol (ValaDelegateType* self, ValaDelegate* value) {
-	ValaDelegate* _tmp1_;
 	ValaDelegate* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_delegate_symbol = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_delegate_symbol == NULL) ? NULL : (self->priv->_delegate_symbol = (vala_code_node_unref (self->priv->_delegate_symbol), NULL)), _tmp1_);
+	self->priv->_delegate_symbol = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_delegate_symbol), _tmp0_);
 }
 
 
@@ -444,7 +433,7 @@ static void vala_delegate_type_instance_init (ValaDelegateType * self) {
 static void vala_delegate_type_finalize (ValaCodeNode* obj) {
 	ValaDelegateType * self;
 	self = VALA_DELEGATE_TYPE (obj);
-	(self->priv->_delegate_symbol == NULL) ? NULL : (self->priv->_delegate_symbol = (vala_code_node_unref (self->priv->_delegate_symbol), NULL));
+	_vala_code_node_unref0 (self->priv->_delegate_symbol);
 	VALA_CODE_NODE_CLASS (vala_delegate_type_parent_class)->finalize (obj);
 }
 
