@@ -141,6 +141,7 @@ typedef struct _ValaFormalParameter ValaFormalParameter;
 typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
 
 #define TYPE_MEMBER_BINDING (member_binding_get_type ())
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -162,12 +163,6 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaScope ValaScope;
 typedef struct _ValaScopeClass ValaScopeClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -188,9 +183,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -202,11 +194,10 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a class or instance destructor.
- */
 struct _ValaDestructor {
 	ValaSymbol parent_instance;
 	ValaDestructorPrivate * priv;
@@ -229,6 +220,7 @@ struct _ValaDestructorPrivate {
 };
 
 
+static gpointer vala_destructor_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -262,11 +254,9 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
 ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference);
 ValaDestructor* vala_destructor_construct (GType object_type, ValaSourceReference* source_reference);
-ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference);
 void vala_code_visitor_visit_destructor (ValaCodeVisitor* self, ValaDestructor* d);
 static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaBlock* vala_destructor_get_body (ValaDestructor* self);
@@ -293,17 +283,10 @@ ValaFormalParameter* vala_destructor_get_this_parameter (ValaDestructor* self);
 void vala_destructor_set_this_parameter (ValaDestructor* self, ValaFormalParameter* value);
 MemberBinding vala_destructor_get_binding (ValaDestructor* self);
 void vala_destructor_set_binding (ValaDestructor* self, MemberBinding value);
-static gpointer vala_destructor_parent_class = NULL;
 static void vala_destructor_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new destructor.
- *
- * @param source_reference reference to source code
- * @return                 newly created destructor
- */
 ValaDestructor* vala_destructor_construct (GType object_type, ValaSourceReference* source_reference) {
 	ValaDestructor* self;
 	self = (ValaDestructor*) vala_symbol_construct (object_type, NULL, source_reference);
@@ -336,10 +319,12 @@ static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVi
 
 static gboolean vala_destructor_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaDestructor * self;
+	gboolean result;
 	self = (ValaDestructor*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_symbol_set_owner ((ValaSymbol*) self, vala_symbol_get_scope (vala_semantic_analyzer_get_current_symbol (analyzer)));
@@ -348,45 +333,51 @@ static gboolean vala_destructor_real_check (ValaCodeNode* base, ValaSemanticAnal
 		vala_code_node_check ((ValaCodeNode*) self->priv->_body, analyzer);
 	}
 	vala_semantic_analyzer_set_current_symbol (analyzer, vala_symbol_get_parent_symbol (vala_semantic_analyzer_get_current_symbol (analyzer)));
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 ValaBlock* vala_destructor_get_body (ValaDestructor* self) {
+	ValaBlock* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_body;
+	result = self->priv->_body;
+	return result;
+}
+
+
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
 }
 
 
 void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value) {
-	ValaBlock* _tmp2;
-	ValaBlock* _tmp1;
+	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp2);
+	self->priv->_body = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_body), _tmp0_);
 }
 
 
 ValaFormalParameter* vala_destructor_get_this_parameter (ValaDestructor* self) {
+	ValaFormalParameter* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_this_parameter;
+	result = self->priv->_this_parameter;
+	return result;
 }
 
 
 void vala_destructor_set_this_parameter (ValaDestructor* self, ValaFormalParameter* value) {
-	ValaFormalParameter* _tmp2;
-	ValaFormalParameter* _tmp1;
+	ValaFormalParameter* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_this_parameter == NULL) ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL)), _tmp2);
+	self->priv->_this_parameter = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_this_parameter), _tmp0_);
 }
 
 
 MemberBinding vala_destructor_get_binding (ValaDestructor* self) {
+	MemberBinding result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_binding;
+	result = self->priv->_binding;
+	return result;
 }
 
 
@@ -415,8 +406,8 @@ static void vala_destructor_instance_init (ValaDestructor * self) {
 static void vala_destructor_finalize (ValaCodeNode* obj) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (obj);
-	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL));
-	(self->priv->_this_parameter == NULL) ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL));
+	_vala_code_node_unref0 (self->priv->_body);
+	_vala_code_node_unref0 (self->priv->_this_parameter);
 	VALA_CODE_NODE_CLASS (vala_destructor_parent_class)->finalize (obj);
 }
 
