@@ -151,6 +151,8 @@ typedef struct _ValaDynamicMethodPrivate ValaDynamicMethodPrivate;
 
 typedef struct _ValaMethodCall ValaMethodCall;
 typedef struct _ValaMethodCallClass ValaMethodCallClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -162,12 +164,16 @@ typedef struct _ValaMethodCallClass ValaMethodCallClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -188,9 +194,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -206,9 +209,6 @@ struct _ValaSymbolClass {
 	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a general class member.
- */
 struct _ValaMember {
 	ValaSymbol parent_instance;
 	ValaMemberPrivate * priv;
@@ -218,9 +218,6 @@ struct _ValaMemberClass {
 	ValaSymbolClass parent_class;
 };
 
-/**
- * Represents a type or namespace method.
- */
 struct _ValaMethod {
 	ValaMember parent_instance;
 	ValaMethodPrivate * priv;
@@ -232,9 +229,6 @@ struct _ValaMethodClass {
 	char* (*get_real_cname) (ValaMethod* self);
 };
 
-/**
- * Represents a late bound method.
- */
 struct _ValaDynamicMethod {
 	ValaMethod parent_instance;
 	ValaDynamicMethodPrivate * priv;
@@ -287,11 +281,17 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
+ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
+ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
 void vala_dynamic_method_set_dynamic_type (ValaDynamicMethod* self, ValaDataType* value);
-ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaDynamicMethod* vala_dynamic_method_construct (GType object_type, ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
+ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
+ValaDynamicMethod* vala_dynamic_method_construct (GType object_type, ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
 static GeeList* vala_dynamic_method_real_get_cheader_filenames (ValaSymbol* base);
 const char* vala_symbol_get_name (ValaSymbol* self);
 static char* vala_dynamic_method_real_get_default_cname (ValaMethod* base);
@@ -303,19 +303,19 @@ static void vala_dynamic_method_finalize (ValaCodeNode* obj);
 
 
 
-ValaDynamicMethod* vala_dynamic_method_construct (GType object_type, ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
+ValaDynamicMethod* vala_dynamic_method_construct (GType object_type, ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment) {
 	ValaDynamicMethod* self;
 	g_return_val_if_fail (dynamic_type != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (return_type != NULL, NULL);
-	self = (ValaDynamicMethod*) vala_method_construct (object_type, name, return_type, source_reference);
+	self = (ValaDynamicMethod*) vala_method_construct (object_type, name, return_type, source_reference, comment);
 	vala_dynamic_method_set_dynamic_type (self, dynamic_type);
 	return self;
 }
 
 
-ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
-	return vala_dynamic_method_construct (VALA_TYPE_DYNAMIC_METHOD, dynamic_type, name, return_type, source_reference);
+ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment) {
+	return vala_dynamic_method_construct (VALA_TYPE_DYNAMIC_METHOD, dynamic_type, name, return_type, source_reference, comment);
 }
 
 
@@ -331,16 +331,12 @@ static GeeList* vala_dynamic_method_real_get_cheader_filenames (ValaSymbol* base
 static char* vala_dynamic_method_real_get_default_cname (ValaMethod* base) {
 	ValaDynamicMethod * self;
 	char* result;
-	const char* _tmp1_;
 	self = (ValaDynamicMethod*) base;
-	/* return cname of wrapper method*/
 	if (self->priv->cname == NULL) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
-		self->priv->cname = (_tmp0_ = g_strdup_printf ("_dynamic_%s%d", vala_symbol_get_name ((ValaSymbol*) self), vala_dynamic_method_dynamic_method_id++), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
+		self->priv->cname = (_tmp0_ = g_strdup_printf ("_dynamic_%s%d", vala_symbol_get_name ((ValaSymbol*) self), vala_dynamic_method_dynamic_method_id++), _g_free0 (self->priv->cname), _tmp0_);
 	}
-	_tmp1_ = NULL;
-	result = (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	result = g_strdup (self->priv->cname);
 	return result;
 }
 
@@ -363,13 +359,15 @@ ValaDataType* vala_dynamic_method_get_dynamic_type (ValaDynamicMethod* self) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_dynamic_method_set_dynamic_type (ValaDynamicMethod* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_dynamic_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_dynamic_type == NULL) ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL)), _tmp1_);
+	self->priv->_dynamic_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_dynamic_type), _tmp0_);
 }
 
 
@@ -382,12 +380,9 @@ ValaMethodCall* vala_dynamic_method_get_invocation (ValaDynamicMethod* self) {
 
 
 void vala_dynamic_method_set_invocation (ValaDynamicMethod* self, ValaMethodCall* value) {
-	ValaMethodCall* _tmp1_;
 	ValaMethodCall* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_invocation = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_invocation == NULL) ? NULL : (self->priv->_invocation = (vala_code_node_unref (self->priv->_invocation), NULL)), _tmp1_);
+	self->priv->_invocation = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_invocation), _tmp0_);
 }
 
 
@@ -409,9 +404,9 @@ static void vala_dynamic_method_instance_init (ValaDynamicMethod * self) {
 static void vala_dynamic_method_finalize (ValaCodeNode* obj) {
 	ValaDynamicMethod * self;
 	self = VALA_DYNAMIC_METHOD (obj);
-	(self->priv->_dynamic_type == NULL) ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL));
-	(self->priv->_invocation == NULL) ? NULL : (self->priv->_invocation = (vala_code_node_unref (self->priv->_invocation), NULL));
-	self->priv->cname = (g_free (self->priv->cname), NULL);
+	_vala_code_node_unref0 (self->priv->_dynamic_type);
+	_vala_code_node_unref0 (self->priv->_invocation);
+	_g_free0 (self->priv->cname);
 	VALA_CODE_NODE_CLASS (vala_dynamic_method_parent_class)->finalize (obj);
 }
 
