@@ -137,12 +137,6 @@ typedef struct _ValaEmptyStatementPrivate ValaEmptyStatementPrivate;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -163,16 +157,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * An empty statement.
- */
 struct _ValaEmptyStatement {
 	ValaCodeNode parent_instance;
 	ValaEmptyStatementPrivate * priv;
@@ -183,6 +171,8 @@ struct _ValaEmptyStatementClass {
 };
 
 
+static gpointer vala_empty_statement_parent_class = NULL;
+static ValaStatementIface* vala_empty_statement_vala_statement_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -207,6 +197,7 @@ GType vala_empty_statement_get_type (void);
 enum  {
 	VALA_EMPTY_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -216,24 +207,15 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaEmptyStatement* vala_empty_statement_new (ValaSourceReference* source);
 ValaEmptyStatement* vala_empty_statement_construct (GType object_type, ValaSourceReference* source);
-ValaEmptyStatement* vala_empty_statement_new (ValaSourceReference* source);
 void vala_code_visitor_visit_empty_statement (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
 static void vala_empty_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static gpointer vala_empty_statement_parent_class = NULL;
-static ValaStatementIface* vala_empty_statement_vala_statement_parent_iface = NULL;
 
 
 
-/**
- * Creates a new empty statement.
- *
- * @param source reference to source code
- * @return       newly created empty statement
- */
 ValaEmptyStatement* vala_empty_statement_construct (GType object_type, ValaSourceReference* source) {
 	ValaEmptyStatement* self;
 	g_return_val_if_fail (source != NULL, NULL);
-	self = (ValaEmptyStatement*) g_type_create_instance (object_type);
+	self = (ValaEmptyStatement*) vala_code_node_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
