@@ -160,6 +160,8 @@ typedef struct _ValaMemberClass ValaMemberClass;
 
 typedef struct _ValaMethod ValaMethod;
 typedef struct _ValaMethodClass ValaMethodClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -171,6 +173,16 @@ typedef struct _ValaMethodClass ValaMethodClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+
 #define VALA_TYPE_SCOPE (vala_scope_get_type ())
 #define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
 #define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
@@ -222,13 +234,8 @@ typedef struct _ValaErrorTypeClass ValaErrorTypeClass;
 
 typedef struct _ValaFormalParameter ValaFormalParameter;
 typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -249,9 +256,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -263,12 +267,10 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a runtime data type. This data type may be defined in Vala source
- * code or imported from an external library with a Vala API file.
- */
 struct _ValaTypeSymbol {
 	ValaSymbol parent_instance;
 	ValaTypeSymbolPrivate * priv;
@@ -298,9 +300,6 @@ struct _ValaTypeSymbolClass {
 	char* (*get_type_signature) (ValaTypeSymbol* self);
 };
 
-/**
- * Represents an error domain declaration in the source code.
- */
 struct _ValaErrorDomain {
 	ValaTypeSymbol parent_instance;
 	ValaErrorDomainPrivate * priv;
@@ -326,6 +325,7 @@ typedef enum  {
 } MemberBinding;
 
 
+static gpointer vala_error_domain_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -360,11 +360,15 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaTypeSymbol* vala_typesymbol_new (const char* name, ValaSourceReference* source_reference);
-ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference);
-ValaErrorDomain* vala_error_domain_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
+ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
+ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference, ValaComment* comment);
+ValaErrorDomain* vala_error_domain_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
 gpointer vala_scope_ref (gpointer instance);
 void vala_scope_unref (gpointer instance);
 GParamSpec* vala_param_spec_scope (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -427,7 +431,6 @@ gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 static gboolean vala_error_domain_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
-static gpointer vala_error_domain_parent_class = NULL;
 static void vala_error_domain_finalize (ValaCodeNode* obj);
 static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -436,31 +439,19 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-/**
- * Creates a new error domain.
- *
- * @param name             type name
- * @param source_reference reference to source code
- * @return                 newly created error domain
- */
-ValaErrorDomain* vala_error_domain_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+ValaErrorDomain* vala_error_domain_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment) {
 	ValaErrorDomain* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaErrorDomain*) vala_typesymbol_construct (object_type, name, source_reference);
+	self = (ValaErrorDomain*) vala_typesymbol_construct (object_type, name, source_reference, comment);
 	return self;
 }
 
 
-ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference) {
-	return vala_error_domain_construct (VALA_TYPE_ERROR_DOMAIN, name, source_reference);
+ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference, ValaComment* comment) {
+	return vala_error_domain_construct (VALA_TYPE_ERROR_DOMAIN, name, source_reference, comment);
 }
 
 
-/**
- * Appends the specified code to the list of error codes.
- *
- * @param ecode an error code
- */
 void vala_error_domain_add_code (ValaErrorDomain* self, ValaErrorCode* ecode) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (ecode != NULL);
@@ -469,11 +460,6 @@ void vala_error_domain_add_code (ValaErrorDomain* self, ValaErrorCode* ecode) {
 }
 
 
-/**
- * Adds the specified method as a member to this error domain.
- *
- * @param m a method
- */
 void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (m != NULL);
@@ -485,11 +471,9 @@ void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
 	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
 		ValaFormalParameter* _tmp1_;
 		ValaErrorType* _tmp0_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
 		vala_method_set_this_parameter (m, _tmp1_ = vala_formal_parameter_new ("this", (ValaDataType*) (_tmp0_ = vala_error_type_new (self, NULL, NULL)), NULL));
-		(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL));
-		(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+		_vala_code_node_unref0 (_tmp1_);
+		_vala_code_node_unref0 (_tmp0_);
 		vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) m), vala_symbol_get_name ((ValaSymbol*) vala_method_get_this_parameter (m)), (ValaSymbol*) vala_method_get_this_parameter (m));
 	}
 	gee_collection_add ((GeeCollection*) self->priv->methods, m);
@@ -497,25 +481,19 @@ void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
 }
 
 
-/**
- * Returns a copy of the list of error codes.
- *
- * @return list of error codes
- */
 GeeList* vala_error_domain_get_codes (ValaErrorDomain* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_ERROR_CODE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->codes);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_ERROR_CODE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->codes);
+	return result;
 }
 
 
-/**
- * Returns a copy of the list of methods.
- *
- * @return list of methods
- */
 GeeList* vala_error_domain_get_methods (ValaErrorDomain* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_METHOD, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->methods);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_METHOD, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->methods);
+	return result;
 }
 
 
@@ -534,77 +512,79 @@ static void vala_error_domain_real_accept_children (ValaCodeNode* base, ValaCode
 	{
 		GeeIterator* _ecode_it;
 		_ecode_it = gee_iterable_iterator ((GeeIterable*) self->priv->codes);
-		while (gee_iterator_next (_ecode_it)) {
+		while (TRUE) {
 			ValaErrorCode* ecode;
+			if (!gee_iterator_next (_ecode_it)) {
+				break;
+			}
 			ecode = (ValaErrorCode*) gee_iterator_get (_ecode_it);
 			vala_code_node_accept ((ValaCodeNode*) ecode, visitor);
-			(ecode == NULL) ? NULL : (ecode = (vala_code_node_unref (ecode), NULL));
+			_vala_code_node_unref0 (ecode);
 		}
-		(_ecode_it == NULL) ? NULL : (_ecode_it = (gee_collection_object_unref (_ecode_it), NULL));
+		_gee_collection_object_unref0 (_ecode_it);
 	}
 	{
 		GeeIterator* _m_it;
 		_m_it = gee_iterable_iterator ((GeeIterable*) self->priv->methods);
-		while (gee_iterator_next (_m_it)) {
+		while (TRUE) {
 			ValaMethod* m;
+			if (!gee_iterator_next (_m_it)) {
+				break;
+			}
 			m = (ValaMethod*) gee_iterator_get (_m_it);
 			vala_code_node_accept ((ValaCodeNode*) m, visitor);
-			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
+			_vala_code_node_unref0 (m);
 		}
-		(_m_it == NULL) ? NULL : (_m_it = (gee_collection_object_unref (_m_it), NULL));
+		_gee_collection_object_unref0 (_m_it);
 	}
 }
 
 
 static char* vala_error_domain_real_get_cname (ValaTypeSymbol* base, gboolean const_type) {
 	ValaErrorDomain * self;
-	const char* _tmp2_;
+	char* result;
 	self = (ValaErrorDomain*) base;
 	if (self->priv->cname == NULL) {
 		char* _tmp1_;
 		char* _tmp0_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		self->priv->cname = (_tmp1_ = g_strdup_printf ("%s%s", _tmp0_ = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), vala_symbol_get_name ((ValaSymbol*) self)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1_);
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		self->priv->cname = (_tmp1_ = g_strdup_printf ("%s%s", _tmp0_ = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), vala_symbol_get_name ((ValaSymbol*) self)), _g_free0 (self->priv->cname), _tmp1_);
+		_g_free0 (_tmp0_);
 	}
-	_tmp2_ = NULL;
-	return (_tmp2_ = self->priv->cname, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+	result = g_strdup (self->priv->cname);
+	return result;
 }
 
 
 static char* vala_error_domain_real_get_lower_case_cprefix (ValaSymbol* base) {
 	ValaErrorDomain * self;
-	const char* _tmp2_;
+	char* result;
 	self = (ValaErrorDomain*) base;
 	if (self->priv->lower_case_cprefix == NULL) {
 		char* _tmp1_;
 		char* _tmp0_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		self->priv->lower_case_cprefix = (_tmp1_ = g_strdup_printf ("%s_", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self, NULL)), self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL), _tmp1_);
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		self->priv->lower_case_cprefix = (_tmp1_ = g_strdup_printf ("%s_", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self, NULL)), _g_free0 (self->priv->lower_case_cprefix), _tmp1_);
+		_g_free0 (_tmp0_);
 	}
-	_tmp2_ = NULL;
-	return (_tmp2_ = self->priv->lower_case_cprefix, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+	result = g_strdup (self->priv->lower_case_cprefix);
+	return result;
 }
 
 
 static char* vala_error_domain_get_lower_case_csuffix (ValaErrorDomain* self) {
-	const char* _tmp1_;
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
-		self->priv->lower_case_csuffix = (_tmp0_ = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self)), self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL), _tmp0_);
+		self->priv->lower_case_csuffix = (_tmp0_ = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self)), _g_free0 (self->priv->lower_case_csuffix), _tmp0_);
 	}
-	_tmp1_ = NULL;
-	return (_tmp1_ = self->priv->lower_case_csuffix, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	result = g_strdup (self->priv->lower_case_csuffix);
+	return result;
 }
 
 
 static char* vala_error_domain_real_get_lower_case_cname (ValaSymbol* base, const char* infix) {
 	ValaErrorDomain * self;
+	char* result;
 	char* _tmp1_;
 	char* _tmp0_;
 	char* _tmp2_;
@@ -612,73 +592,59 @@ static char* vala_error_domain_real_get_lower_case_cname (ValaSymbol* base, cons
 	if (infix == NULL) {
 		infix = "";
 	}
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	_tmp2_ = NULL;
-	return (_tmp2_ = g_strdup_printf ("%s%s%s", _tmp0_ = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), infix, _tmp1_ = vala_error_domain_get_lower_case_csuffix (self)), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp2_);
+	result = (_tmp2_ = g_strdup_printf ("%s%s%s", _tmp0_ = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), infix, _tmp1_ = vala_error_domain_get_lower_case_csuffix (self)), _g_free0 (_tmp1_), _g_free0 (_tmp0_), _tmp2_);
+	return result;
 }
 
 
 static char* vala_error_domain_real_get_upper_case_cname (ValaTypeSymbol* base, const char* infix) {
 	ValaErrorDomain * self;
+	char* result;
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaErrorDomain*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	return (_tmp1_ = g_utf8_strup (_tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self, infix), -1), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_utf8_strup (_tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self, infix), -1), _g_free0 (_tmp0_), _tmp1_);
+	return result;
 }
 
 
 static gboolean vala_error_domain_real_is_reference_type (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
+	gboolean result;
 	self = (ValaErrorDomain*) base;
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
 static void vala_error_domain_set_cname (ValaErrorDomain* self, const char* cname) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (cname != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->cname = (_tmp1_ = (_tmp0_ = cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1_);
+	self->priv->cname = (_tmp0_ = g_strdup (cname), _g_free0 (self->priv->cname), _tmp0_);
 }
 
 
 static char* vala_error_domain_real_get_cprefix (ValaSymbol* base) {
 	ValaErrorDomain * self;
-	const char* _tmp2_;
+	char* result;
 	self = (ValaErrorDomain*) base;
 	if (self->priv->cprefix == NULL) {
 		char* _tmp1_;
 		char* _tmp0_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		self->priv->cprefix = (_tmp1_ = g_strdup_printf ("%s_", _tmp0_ = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) self, NULL)), self->priv->cprefix = (g_free (self->priv->cprefix), NULL), _tmp1_);
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		self->priv->cprefix = (_tmp1_ = g_strdup_printf ("%s_", _tmp0_ = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) self, NULL)), _g_free0 (self->priv->cprefix), _tmp1_);
+		_g_free0 (_tmp0_);
 	}
-	_tmp2_ = NULL;
-	return (_tmp2_ = self->priv->cprefix, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+	result = g_strdup (self->priv->cprefix);
+	return result;
 }
 
 
-/**
- * Sets the string to be prepended to the name of members of this error
- * domain when used in C code.
- *
- * @param cprefix the prefix to be used in C code
- */
 void vala_error_domain_set_cprefix (ValaErrorDomain* self, const char* cprefix) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (cprefix != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->cprefix = (_tmp1_ = (_tmp0_ = cprefix, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->cprefix = (g_free (self->priv->cprefix), NULL), _tmp1_);
+	self->priv->cprefix = (_tmp0_ = g_strdup (cprefix), _g_free0 (self->priv->cprefix), _tmp0_);
 }
 
 
@@ -687,20 +653,17 @@ static void vala_error_domain_process_ccode_attribute (ValaErrorDomain* self, Va
 	g_return_if_fail (a != NULL);
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
 		vala_error_domain_set_cname (self, _tmp0_ = vala_attribute_get_string (a, "cname"));
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		_g_free0 (_tmp0_);
 	}
 	if (vala_attribute_has_argument (a, "cprefix")) {
 		char* _tmp1_;
-		_tmp1_ = NULL;
 		vala_error_domain_set_cprefix (self, _tmp1_ = vala_attribute_get_string (a, "cprefix"));
-		_tmp1_ = (g_free (_tmp1_), NULL);
+		_g_free0 (_tmp1_);
 	}
 	if (vala_attribute_has_argument (a, "lower_case_csuffix")) {
 		char* _tmp2_;
-		_tmp2_ = NULL;
-		self->priv->lower_case_csuffix = (_tmp2_ = vala_attribute_get_string (a, "lower_case_csuffix"), self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL), _tmp2_);
+		self->priv->lower_case_csuffix = (_tmp2_ = vala_attribute_get_string (a, "lower_case_csuffix"), _g_free0 (self->priv->lower_case_csuffix), _tmp2_);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -710,29 +673,28 @@ static void vala_error_domain_process_ccode_attribute (ValaErrorDomain* self, Va
 			char** filename_collection;
 			int filename_collection_length1;
 			int filename_it;
-			_tmp3_ = NULL;
 			filename_collection = _tmp3_ = g_strsplit (val, ",", 0);
 			filename_collection_length1 = _vala_array_length (_tmp3_);
 			for (filename_it = 0; filename_it < _vala_array_length (_tmp3_); filename_it = filename_it + 1) {
-				const char* _tmp4_;
 				char* filename;
-				_tmp4_ = NULL;
-				filename = (_tmp4_ = filename_collection[filename_it], (_tmp4_ == NULL) ? NULL : g_strdup (_tmp4_));
+				filename = g_strdup (filename_collection[filename_it]);
 				{
 					vala_typesymbol_add_cheader_filename ((ValaTypeSymbol*) self, filename);
-					filename = (g_free (filename), NULL);
+					_g_free0 (filename);
 				}
 			}
 			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, (GDestroyNotify) g_free), NULL);
 		}
-		val = (g_free (val), NULL);
+		_g_free0 (val);
 	}
 }
 
 
-/**
- * Process all associated attributes.
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_error_domain_process_attributes (ValaErrorDomain* self) {
 	g_return_if_fail (self != NULL);
 	{
@@ -740,15 +702,13 @@ void vala_error_domain_process_attributes (ValaErrorDomain* self) {
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp0_;
 			ValaAttribute* a;
-			_tmp0_ = NULL;
-			a = (_tmp0_ = (ValaAttribute*) a_it->data, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+			a = _vala_code_node_ref0 ((ValaAttribute*) a_it->data);
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_error_domain_process_ccode_attribute (self, a);
 				}
-				(a == NULL) ? NULL : (a = (vala_code_node_unref (a), NULL));
+				_vala_code_node_unref0 (a);
 			}
 		}
 	}
@@ -757,64 +717,81 @@ void vala_error_domain_process_attributes (ValaErrorDomain* self) {
 
 static char* vala_error_domain_real_get_type_id (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
+	char* result;
 	self = (ValaErrorDomain*) base;
-	return g_strdup ("G_TYPE_POINTER");
+	result = g_strdup ("G_TYPE_POINTER");
+	return result;
 }
 
 
 static char* vala_error_domain_real_get_marshaller_type_name (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
+	char* result;
 	self = (ValaErrorDomain*) base;
-	return g_strdup ("POINTER");
+	result = g_strdup ("POINTER");
+	return result;
 }
 
 
 static char* vala_error_domain_real_get_get_value_function (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
+	char* result;
 	self = (ValaErrorDomain*) base;
-	return g_strdup ("g_value_get_pointer");
+	result = g_strdup ("g_value_get_pointer");
+	return result;
 }
 
 
 static char* vala_error_domain_real_get_set_value_function (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
+	char* result;
 	self = (ValaErrorDomain*) base;
-	return g_strdup ("g_value_set_pointer");
+	result = g_strdup ("g_value_set_pointer");
+	return result;
 }
 
 
 static gboolean vala_error_domain_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaErrorDomain * self;
+	gboolean result;
 	self = (ValaErrorDomain*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_error_domain_process_attributes (self);
 	{
 		GeeIterator* _ecode_it;
 		_ecode_it = gee_iterable_iterator ((GeeIterable*) self->priv->codes);
-		while (gee_iterator_next (_ecode_it)) {
+		while (TRUE) {
 			ValaErrorCode* ecode;
+			if (!gee_iterator_next (_ecode_it)) {
+				break;
+			}
 			ecode = (ValaErrorCode*) gee_iterator_get (_ecode_it);
 			vala_code_node_check ((ValaCodeNode*) ecode, analyzer);
-			(ecode == NULL) ? NULL : (ecode = (vala_code_node_unref (ecode), NULL));
+			_vala_code_node_unref0 (ecode);
 		}
-		(_ecode_it == NULL) ? NULL : (_ecode_it = (gee_collection_object_unref (_ecode_it), NULL));
+		_gee_collection_object_unref0 (_ecode_it);
 	}
 	{
 		GeeIterator* _m_it;
 		_m_it = gee_iterable_iterator ((GeeIterable*) self->priv->methods);
-		while (gee_iterator_next (_m_it)) {
+		while (TRUE) {
 			ValaMethod* m;
+			if (!gee_iterator_next (_m_it)) {
+				break;
+			}
 			m = (ValaMethod*) gee_iterator_get (_m_it);
 			vala_code_node_check ((ValaCodeNode*) m, analyzer);
-			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
+			_vala_code_node_unref0 (m);
 		}
-		(_m_it == NULL) ? NULL : (_m_it = (gee_collection_object_unref (_m_it), NULL));
+		_gee_collection_object_unref0 (_m_it);
 	}
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
@@ -848,12 +825,12 @@ static void vala_error_domain_instance_init (ValaErrorDomain * self) {
 static void vala_error_domain_finalize (ValaCodeNode* obj) {
 	ValaErrorDomain * self;
 	self = VALA_ERROR_DOMAIN (obj);
-	(self->priv->codes == NULL) ? NULL : (self->priv->codes = (gee_collection_object_unref (self->priv->codes), NULL));
-	(self->priv->methods == NULL) ? NULL : (self->priv->methods = (gee_collection_object_unref (self->priv->methods), NULL));
-	self->priv->cname = (g_free (self->priv->cname), NULL);
-	self->priv->cprefix = (g_free (self->priv->cprefix), NULL);
-	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
-	self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL);
+	_gee_collection_object_unref0 (self->priv->codes);
+	_gee_collection_object_unref0 (self->priv->methods);
+	_g_free0 (self->priv->cname);
+	_g_free0 (self->priv->cprefix);
+	_g_free0 (self->priv->lower_case_cprefix);
+	_g_free0 (self->priv->lower_case_csuffix);
 	VALA_CODE_NODE_CLASS (vala_error_domain_parent_class)->finalize (obj);
 }
 
