@@ -140,6 +140,8 @@ typedef struct _ValaFieldClass ValaFieldClass;
 typedef struct _ValaFieldPrivate ValaFieldPrivate;
 
 #define TYPE_MEMBER_BINDING (member_binding_get_type ())
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -151,6 +153,16 @@ typedef struct _ValaFieldPrivate ValaFieldPrivate;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+
 #define VALA_TYPE_LITERAL (vala_literal_get_type ())
 #define VALA_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LITERAL, ValaLiteral))
 #define VALA_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LITERAL, ValaLiteralClass))
@@ -180,6 +192,7 @@ typedef struct _ValaStringLiteralClass ValaStringLiteralClass;
 
 typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
+#define _vala_source_file_unref0(var) ((var == NULL) ? NULL : (var = (vala_source_file_unref (var), NULL)))
 
 #define VALA_TYPE_TYPESYMBOL (vala_typesymbol_get_type ())
 #define VALA_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))
@@ -221,12 +234,6 @@ typedef struct _ValaInterfaceClass ValaInterfaceClass;
 typedef struct _ValaClass ValaClass;
 typedef struct _ValaClassClass ValaClassClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -247,9 +254,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -265,9 +269,6 @@ struct _ValaSymbolClass {
 	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a general class member.
- */
 struct _ValaMember {
 	ValaSymbol parent_instance;
 	ValaMemberPrivate * priv;
@@ -277,18 +278,12 @@ struct _ValaMemberClass {
 	ValaSymbolClass parent_class;
 };
 
-/**
- * Represents a lockable object.
- */
 struct _ValaLockableIface {
 	GTypeInterface parent_iface;
 	gboolean (*get_lock_used) (ValaLockable* self);
 	void (*set_lock_used) (ValaLockable* self, gboolean used);
 };
 
-/**
- * Represents a type or namespace field.
- */
 struct _ValaField {
 	ValaMember parent_instance;
 	ValaFieldPrivate * priv;
@@ -354,12 +349,17 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaMember* vala_member_new (const char* name, ValaSourceReference* source_reference);
-ValaMember* vala_member_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
+ValaMember* vala_member_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
 void vala_field_set_field_type (ValaField* self, ValaDataType* value);
 void vala_field_set_initializer (ValaField* self, ValaExpression* value);
-ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
-ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
+ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference, ValaComment* comment);
+ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference, ValaComment* comment);
 void vala_code_visitor_visit_member (ValaCodeVisitor* self, ValaMember* m);
 void vala_code_visitor_visit_field (ValaCodeVisitor* self, ValaField* f);
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -455,28 +455,19 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-/**
- * Creates a new field.
- *
- * @param name   field name
- * @param type   field type
- * @param init   initializer expression
- * @param source reference to source code
- * @return       newly created field
- */
-ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference) {
+ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference, ValaComment* comment) {
 	ValaField* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (field_type != NULL, NULL);
-	self = (ValaField*) vala_member_construct (object_type, name, source_reference);
+	self = (ValaField*) vala_member_construct (object_type, name, source_reference, comment);
 	vala_field_set_field_type (self, field_type);
 	vala_field_set_initializer (self, initializer);
 	return self;
 }
 
 
-ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference) {
-	return vala_field_construct (VALA_TYPE_FIELD, name, field_type, initializer, source_reference);
+ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference, ValaComment* comment) {
+	return vala_field_construct (VALA_TYPE_FIELD, name, field_type, initializer, source_reference, comment);
 }
 
 
@@ -500,125 +491,68 @@ static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor
 }
 
 
-/**
- * Returns the name of this field as it is used in C code.
- *
- * @return the name to be used in C code
- */
 char* vala_field_get_cname (ValaField* self) {
 	char* result;
-	const char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->cname == NULL) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
-		self->priv->cname = (_tmp0_ = vala_field_get_default_cname (self), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
+		self->priv->cname = (_tmp0_ = vala_field_get_default_cname (self), _g_free0 (self->priv->cname), _tmp0_);
 	}
-	_tmp1_ = NULL;
-	result = (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	result = g_strdup (self->priv->cname);
 	return result;
 }
 
 
-/**
- * Sets the name of this field as it is used in C code.
- *
- * @param cname the name to be used in C code
- */
 void vala_field_set_cname (ValaField* self, const char* cname) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (cname != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->cname = (_tmp1_ = (_tmp0_ = cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1_);
+	self->priv->cname = (_tmp0_ = g_strdup (cname), _g_free0 (self->priv->cname), _tmp0_);
 }
 
 
-/**
- * Returns the default name of this field as it is used in C code.
- *
- * @return the name to be used in C code by default
- */
 char* vala_field_get_default_cname (ValaField* self) {
 	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_binding == MEMBER_BINDING_STATIC) {
 		char* _tmp0_;
 		char* _tmp1_;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		result = (_tmp1_ = g_strconcat (_tmp0_ = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), vala_symbol_get_name ((ValaSymbol*) self), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+		result = (_tmp1_ = g_strconcat (_tmp0_ = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), vala_symbol_get_name ((ValaSymbol*) self), NULL), _g_free0 (_tmp0_), _tmp1_);
 		return result;
 	} else {
-		const char* _tmp2_;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = vala_symbol_get_name ((ValaSymbol*) self), (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+		result = g_strdup (vala_symbol_get_name ((ValaSymbol*) self));
 		return result;
 	}
 }
 
 
-/**
- * Returns the name of the array length field as it is used in C code
- *
- * @return the name of the array length field to be used in C code
- */
 char* vala_field_get_array_length_cname (ValaField* self) {
 	char* result;
-	const char* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0_ = NULL;
-	result = (_tmp0_ = self->priv->array_length_cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = g_strdup (self->priv->array_length_cname);
 	return result;
 }
 
 
-/**
- * Sets the name of the array length field as it is used in C code
- *
- * @param array_length_cname the name of the array length field to be
- * used in C code
- */
 void vala_field_set_array_length_cname (ValaField* self, const char* array_length_cname) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->array_length_cname = (_tmp1_ = (_tmp0_ = array_length_cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->array_length_cname = (g_free (self->priv->array_length_cname), NULL), _tmp1_);
+	self->priv->array_length_cname = (_tmp0_ = g_strdup (array_length_cname), _g_free0 (self->priv->array_length_cname), _tmp0_);
 }
 
 
-/**
- * Returns the array length expression as it is used in C code
- *
- * @return the array length expression to be used in C code
- */
 char* vala_field_get_array_length_cexpr (ValaField* self) {
 	char* result;
-	const char* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0_ = NULL;
-	result = (_tmp0_ = self->priv->array_length_cexpr, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = g_strdup (self->priv->array_length_cexpr);
 	return result;
 }
 
 
-/**
- * Sets the array length expression as it is used in C code
- *
- * @param array_length_cexpr the array length expression to be used in C
- * code
- */
 void vala_field_set_array_length_cexpr (ValaField* self, const char* array_length_cexpr) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->array_length_cexpr = (_tmp1_ = (_tmp0_ = array_length_cexpr, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->array_length_cexpr = (g_free (self->priv->array_length_cexpr), NULL), _tmp1_);
+	self->priv->array_length_cexpr = (_tmp0_ = g_strdup (array_length_cexpr), _g_free0 (self->priv->array_length_cexpr), _tmp0_);
 }
 
 
@@ -627,9 +561,8 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 	g_return_if_fail (a != NULL);
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
 		vala_field_set_cname (self, _tmp0_ = vala_attribute_get_string (a, "cname"));
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		_g_free0 (_tmp0_);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -639,22 +572,19 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 			char** filename_collection;
 			int filename_collection_length1;
 			int filename_it;
-			_tmp1_ = NULL;
 			filename_collection = _tmp1_ = g_strsplit (val, ",", 0);
 			filename_collection_length1 = _vala_array_length (_tmp1_);
 			for (filename_it = 0; filename_it < _vala_array_length (_tmp1_); filename_it = filename_it + 1) {
-				const char* _tmp2_;
 				char* filename;
-				_tmp2_ = NULL;
-				filename = (_tmp2_ = filename_collection[filename_it], (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+				filename = g_strdup (filename_collection[filename_it]);
 				{
 					vala_member_add_cheader_filename ((ValaMember*) self, filename);
-					filename = (g_free (filename), NULL);
+					_g_free0 (filename);
 				}
 			}
 			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, (GDestroyNotify) g_free), NULL);
 		}
-		val = (g_free (val), NULL);
+		_g_free0 (val);
 	}
 	if (vala_attribute_has_argument (a, "array_length")) {
 		vala_field_set_no_array_length (self, !vala_attribute_get_bool (a, "array_length"));
@@ -663,16 +593,14 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 		vala_field_set_array_null_terminated (self, vala_attribute_get_bool (a, "array_null_terminated"));
 	}
 	if (vala_attribute_has_argument (a, "array_length_cname")) {
-		char* _tmp3_;
-		_tmp3_ = NULL;
-		vala_field_set_array_length_cname (self, _tmp3_ = vala_attribute_get_string (a, "array_length_cname"));
-		_tmp3_ = (g_free (_tmp3_), NULL);
+		char* _tmp2_;
+		vala_field_set_array_length_cname (self, _tmp2_ = vala_attribute_get_string (a, "array_length_cname"));
+		_g_free0 (_tmp2_);
 	}
 	if (vala_attribute_has_argument (a, "array_length_cexpr")) {
-		char* _tmp4_;
-		_tmp4_ = NULL;
-		vala_field_set_array_length_cexpr (self, _tmp4_ = vala_attribute_get_string (a, "array_length_cexpr"));
-		_tmp4_ = (g_free (_tmp4_), NULL);
+		char* _tmp3_;
+		vala_field_set_array_length_cexpr (self, _tmp3_ = vala_attribute_get_string (a, "array_length_cexpr"));
+		_g_free0 (_tmp3_);
 	}
 	if (vala_attribute_has_argument (a, "delegate_target")) {
 		vala_field_set_no_delegate_target (self, !vala_attribute_get_bool (a, "delegate_target"));
@@ -680,9 +608,11 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 }
 
 
-/**
- * Process all associated attributes.
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_field_process_attributes (ValaField* self) {
 	g_return_if_fail (self != NULL);
 	{
@@ -690,15 +620,13 @@ void vala_field_process_attributes (ValaField* self) {
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp0_;
 			ValaAttribute* a;
-			_tmp0_ = NULL;
-			a = (_tmp0_ = (ValaAttribute*) a_it->data, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+			a = _vala_code_node_ref0 ((ValaAttribute*) a_it->data);
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_field_process_ccode_attribute (self, a);
 				}
-				(a == NULL) ? NULL : (a = (vala_code_node_unref (a), NULL));
+				_vala_code_node_unref0 (a);
 			}
 		}
 	}
@@ -750,50 +678,48 @@ char* vala_field_get_ctype (ValaField* self) {
 	attr = vala_code_node_get_attribute ((ValaCodeNode*) self, "CCode");
 	if (attr == NULL) {
 		result = NULL;
-		(attr == NULL) ? NULL : (attr = (vala_code_node_unref (attr), NULL));
+		_vala_code_node_unref0 (attr);
 		return result;
 	}
 	result = vala_attribute_get_string (attr, "type");
-	(attr == NULL) ? NULL : (attr = (vala_code_node_unref (attr), NULL));
+	_vala_code_node_unref0 (attr);
 	return result;
 }
 
 
 void vala_field_set_ctype (ValaField* self, const char* ctype) {
 	ValaAttribute* attr;
-	ValaStringLiteral* _tmp3_;
-	char* _tmp2_;
+	ValaStringLiteral* _tmp2_;
+	char* _tmp1_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (ctype != NULL);
 	attr = vala_code_node_get_attribute ((ValaCodeNode*) self, "CCode");
 	if (attr == NULL) {
 		ValaAttribute* _tmp0_;
-		ValaAttribute* _tmp1_;
-		_tmp0_ = NULL;
-		attr = (_tmp0_ = vala_attribute_new ("CCode", NULL), (attr == NULL) ? NULL : (attr = (vala_code_node_unref (attr), NULL)), _tmp0_);
-		_tmp1_ = NULL;
-		((ValaCodeNode*) self)->attributes = g_list_append (((ValaCodeNode*) self)->attributes, (_tmp1_ = attr, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)));
+		attr = (_tmp0_ = vala_attribute_new ("CCode", NULL), _vala_code_node_unref0 (attr), _tmp0_);
+		((ValaCodeNode*) self)->attributes = g_list_append (((ValaCodeNode*) self)->attributes, _vala_code_node_ref0 (attr));
 	}
-	_tmp3_ = NULL;
-	_tmp2_ = NULL;
-	vala_attribute_add_argument (attr, "type", (ValaExpression*) (_tmp3_ = vala_string_literal_new (_tmp2_ = g_strdup_printf ("\"%s\"", ctype), NULL)));
-	(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_node_unref (_tmp3_), NULL));
-	_tmp2_ = (g_free (_tmp2_), NULL);
-	(attr == NULL) ? NULL : (attr = (vala_code_node_unref (attr), NULL));
+	vala_attribute_add_argument (attr, "type", (ValaExpression*) (_tmp2_ = vala_string_literal_new (_tmp1_ = g_strdup_printf ("\"%s\"", ctype), NULL)));
+	_vala_code_node_unref0 (_tmp2_);
+	_g_free0 (_tmp1_);
+	_vala_code_node_unref0 (attr);
+}
+
+
+static gpointer _vala_source_file_ref0 (gpointer self) {
+	return self ? vala_source_file_ref (self) : NULL;
 }
 
 
 static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaField * self;
 	gboolean result;
-	ValaSourceFile* _tmp0_;
 	ValaSourceFile* old_source_file;
-	ValaSymbol* _tmp1_;
 	ValaSymbol* old_symbol;
-	gboolean _tmp8_;
+	gboolean _tmp6_;
 	gboolean field_in_header;
-	gboolean _tmp11_;
-	gboolean _tmp12_;
+	gboolean _tmp8_;
+	gboolean _tmp9_;
 	self = (ValaField*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -801,31 +727,25 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	_tmp0_ = NULL;
-	old_source_file = (_tmp0_ = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp0_ == NULL) ? NULL : vala_source_file_ref (_tmp0_));
-	_tmp1_ = NULL;
-	old_symbol = (_tmp1_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+	old_source_file = _vala_source_file_ref0 (vala_semantic_analyzer_get_current_source_file (analyzer));
+	old_symbol = _vala_code_node_ref0 (vala_semantic_analyzer_get_current_symbol (analyzer));
 	if (vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL) {
 		vala_semantic_analyzer_set_current_source_file (analyzer, vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self)));
 	}
 	vala_semantic_analyzer_set_current_symbol (analyzer, (ValaSymbol*) self);
 	vala_code_node_check ((ValaCodeNode*) vala_field_get_field_type (self), analyzer);
-	/* check whether field type is at least as accessible as the field*/
 	if (!vala_semantic_analyzer_is_type_accessible (analyzer, (ValaSymbol*) self, vala_field_get_field_type (self))) {
-		char* _tmp4_;
-		char* _tmp3_;
 		char* _tmp2_;
+		char* _tmp1_;
+		char* _tmp0_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		_tmp4_ = NULL;
-		_tmp3_ = NULL;
-		_tmp2_ = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp4_ = g_strdup_printf ("field type `%s` is less accessible than field `%s`", _tmp2_ = vala_code_node_to_string ((ValaCodeNode*) vala_field_get_field_type (self)), _tmp3_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
-		_tmp4_ = (g_free (_tmp4_), NULL);
-		_tmp3_ = (g_free (_tmp3_), NULL);
-		_tmp2_ = (g_free (_tmp2_), NULL);
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp2_ = g_strdup_printf ("field type `%s` is less accessible than field `%s`", _tmp0_ = vala_code_node_to_string ((ValaCodeNode*) vala_field_get_field_type (self)), _tmp1_ = vala_symbol_get_full_name ((ValaSymbol*) self)));
+		_g_free0 (_tmp2_);
+		_g_free0 (_tmp1_);
+		_g_free0 (_tmp0_);
 		result = FALSE;
-		(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
-		(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+		_vala_source_file_unref0 (old_source_file);
+		_vala_code_node_unref0 (old_symbol);
 		return result;
 	}
 	vala_field_process_attributes (self);
@@ -833,20 +753,17 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 		vala_expression_set_target_type (vala_field_get_initializer (self), vala_field_get_field_type (self));
 		vala_code_node_check ((ValaCodeNode*) vala_field_get_initializer (self), analyzer);
 		if (!vala_data_type_compatible (vala_expression_get_value_type (vala_field_get_initializer (self)), vala_field_get_field_type (self))) {
-			char* _tmp7_;
-			char* _tmp6_;
 			char* _tmp5_;
+			char* _tmp4_;
+			char* _tmp3_;
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			_tmp7_ = NULL;
-			_tmp6_ = NULL;
-			_tmp5_ = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp7_ = g_strdup_printf ("Cannot convert from `%s' to `%s'", _tmp5_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_field_get_initializer (self))), _tmp6_ = vala_code_node_to_string ((ValaCodeNode*) vala_field_get_field_type (self))));
-			_tmp7_ = (g_free (_tmp7_), NULL);
-			_tmp6_ = (g_free (_tmp6_), NULL);
-			_tmp5_ = (g_free (_tmp5_), NULL);
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp5_ = g_strdup_printf ("Cannot convert from `%s' to `%s'", _tmp3_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_field_get_initializer (self))), _tmp4_ = vala_code_node_to_string ((ValaCodeNode*) vala_field_get_field_type (self))));
+			_g_free0 (_tmp5_);
+			_g_free0 (_tmp4_);
+			_g_free0 (_tmp3_);
 			result = FALSE;
-			(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
-			(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+			_vala_source_file_unref0 (old_source_file);
+			_vala_code_node_unref0 (old_symbol);
 			return result;
 		}
 		if (vala_symbol_get_external ((ValaSymbol*) self)) {
@@ -854,74 +771,66 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "External fields cannot use initializers");
 		}
 	}
-	_tmp8_ = FALSE;
+	_tmp6_ = FALSE;
 	if (self->priv->_binding == MEMBER_BINDING_INSTANCE) {
-		_tmp8_ = VALA_IS_INTERFACE (vala_symbol_get_parent_symbol ((ValaSymbol*) self));
+		_tmp6_ = VALA_IS_INTERFACE (vala_symbol_get_parent_symbol ((ValaSymbol*) self));
 	} else {
-		_tmp8_ = FALSE;
+		_tmp6_ = FALSE;
 	}
-	if (_tmp8_) {
+	if (_tmp6_) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Interfaces may not have instance fields");
 		result = FALSE;
-		(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
-		(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+		_vala_source_file_unref0 (old_source_file);
+		_vala_code_node_unref0 (old_symbol);
 		return result;
 	}
 	field_in_header = !vala_symbol_is_internal_symbol ((ValaSymbol*) self);
 	if (VALA_IS_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
-		ValaClass* _tmp9_;
 		ValaClass* cl;
-		gboolean _tmp10_;
-		_tmp9_ = NULL;
-		cl = (_tmp9_ = VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), (_tmp9_ == NULL) ? NULL : vala_code_node_ref (_tmp9_));
-		_tmp10_ = FALSE;
+		gboolean _tmp7_;
+		cl = _vala_code_node_ref0 (VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self)));
+		_tmp7_ = FALSE;
 		if (vala_class_get_is_compact (cl)) {
-			_tmp10_ = !vala_symbol_is_internal_symbol ((ValaSymbol*) cl);
+			_tmp7_ = !vala_symbol_is_internal_symbol ((ValaSymbol*) cl);
 		} else {
-			_tmp10_ = FALSE;
+			_tmp7_ = FALSE;
 		}
-		if (_tmp10_) {
-			/* compact classes don't have priv structs*/
+		if (_tmp7_) {
 			field_in_header = TRUE;
 		}
-		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+		_vala_code_node_unref0 (cl);
 	}
-	_tmp11_ = FALSE;
-	_tmp12_ = FALSE;
+	_tmp8_ = FALSE;
+	_tmp9_ = FALSE;
 	if (!vala_symbol_get_external_package ((ValaSymbol*) self)) {
-		_tmp12_ = !vala_member_get_hides ((ValaMember*) self);
+		_tmp9_ = !vala_member_get_hides ((ValaMember*) self);
 	} else {
-		_tmp12_ = FALSE;
+		_tmp9_ = FALSE;
 	}
-	if (_tmp12_) {
-		ValaSymbol* _tmp13_;
-		_tmp13_ = NULL;
-		_tmp11_ = (_tmp13_ = vala_member_get_hidden_member ((ValaMember*) self)) != NULL;
-		(_tmp13_ == NULL) ? NULL : (_tmp13_ = (vala_code_node_unref (_tmp13_), NULL));
+	if (_tmp9_) {
+		ValaSymbol* _tmp10_;
+		_tmp8_ = (_tmp10_ = vala_member_get_hidden_member ((ValaMember*) self)) != NULL;
+		_vala_code_node_unref0 (_tmp10_);
 	} else {
-		_tmp11_ = FALSE;
+		_tmp8_ = FALSE;
 	}
-	if (_tmp11_) {
-		char* _tmp17_;
-		char* _tmp16_;
-		ValaSymbol* _tmp15_;
+	if (_tmp8_) {
 		char* _tmp14_;
-		_tmp17_ = NULL;
-		_tmp16_ = NULL;
-		_tmp15_ = NULL;
-		_tmp14_ = NULL;
-		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp17_ = g_strdup_printf ("%s hides inherited field `%s'. Use the `new' keyword if hiding was intentional", _tmp14_ = vala_symbol_get_full_name ((ValaSymbol*) self), _tmp16_ = vala_symbol_get_full_name (_tmp15_ = vala_member_get_hidden_member ((ValaMember*) self))));
-		_tmp17_ = (g_free (_tmp17_), NULL);
-		_tmp16_ = (g_free (_tmp16_), NULL);
-		(_tmp15_ == NULL) ? NULL : (_tmp15_ = (vala_code_node_unref (_tmp15_), NULL));
-		_tmp14_ = (g_free (_tmp14_), NULL);
+		char* _tmp13_;
+		ValaSymbol* _tmp12_;
+		char* _tmp11_;
+		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp14_ = g_strdup_printf ("%s hides inherited field `%s'. Use the `new' keyword if hiding was intentional", _tmp11_ = vala_symbol_get_full_name ((ValaSymbol*) self), _tmp13_ = vala_symbol_get_full_name (_tmp12_ = vala_member_get_hidden_member ((ValaMember*) self))));
+		_g_free0 (_tmp14_);
+		_g_free0 (_tmp13_);
+		_vala_code_node_unref0 (_tmp12_);
+		_g_free0 (_tmp11_);
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
-	(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
-	(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+	_vala_source_file_unref0 (old_source_file);
+	_vala_code_node_unref0 (old_symbol);
 	return result;
 }
 
@@ -935,12 +844,9 @@ ValaDataType* vala_field_get_field_type (ValaField* self) {
 
 
 void vala_field_set_field_type (ValaField* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_data_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp1_);
+	self->priv->_data_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_data_type), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
@@ -954,12 +860,9 @@ ValaExpression* vala_field_get_initializer (ValaField* self) {
 
 
 void vala_field_set_initializer (ValaField* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_initializer = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)), _tmp1_);
+	self->priv->_initializer = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_initializer), _tmp0_);
 	if (self->priv->_initializer != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_initializer, (ValaCodeNode*) self);
 	}
@@ -1081,11 +984,11 @@ static void vala_field_instance_init (ValaField * self) {
 static void vala_field_finalize (ValaCodeNode* obj) {
 	ValaField * self;
 	self = VALA_FIELD (obj);
-	self->priv->array_length_cname = (g_free (self->priv->array_length_cname), NULL);
-	self->priv->array_length_cexpr = (g_free (self->priv->array_length_cexpr), NULL);
-	self->priv->cname = (g_free (self->priv->cname), NULL);
-	(self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL));
-	(self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL));
+	_g_free0 (self->priv->array_length_cname);
+	_g_free0 (self->priv->array_length_cexpr);
+	_g_free0 (self->priv->cname);
+	_vala_code_node_unref0 (self->priv->_initializer);
+	_vala_code_node_unref0 (self->priv->_data_type);
 	VALA_CODE_NODE_CLASS (vala_field_parent_class)->finalize (obj);
 }
 
