@@ -136,6 +136,7 @@ typedef struct _ValaIfStatementPrivate ValaIfStatementPrivate;
 
 typedef struct _ValaBlock ValaBlock;
 typedef struct _ValaBlockClass ValaBlockClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -888,13 +889,8 @@ typedef struct _ValaValueTypeClass ValaValueTypeClass;
 
 typedef struct _ValaStructValueType ValaStructValueType;
 typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -915,16 +911,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents an if selection statement in the source code.
- */
 struct _ValaIfStatement {
 	ValaCodeNode parent_instance;
 	ValaIfStatementPrivate * priv;
@@ -940,9 +930,6 @@ struct _ValaIfStatementPrivate {
 	ValaBlock* _false_statement;
 };
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -1029,17 +1016,12 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Code visitor analyzing and checking code.
- */
 struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 	ValaSymbol* root_symbol;
-	ValaDataType* current_return_type;
-	ValaClass* current_class;
-	ValaStruct* current_struct;
 	ValaBlock* insert_block;
+	ValaDataType* void_type;
 	ValaDataType* bool_type;
 	ValaDataType* string_type;
 	ValaDataType* uchar_type;
@@ -1099,6 +1081,7 @@ GType vala_block_get_type (void);
 enum  {
 	VALA_IF_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* value);
 void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* value);
 void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* value);
@@ -1216,19 +1199,11 @@ static void vala_if_statement_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new if statement.
- *
- * @param cond       a boolean condition
- * @param true_stmt  statement to be evaluated if condition is true
- * @param false_stmt statement to be evaluated if condition is false
- * @return           newly created if statement
- */
 ValaIfStatement* vala_if_statement_construct (GType object_type, ValaExpression* cond, ValaBlock* true_stmt, ValaBlock* false_stmt, ValaSourceReference* source) {
 	ValaIfStatement* self;
 	g_return_val_if_fail (cond != NULL, NULL);
 	g_return_val_if_fail (true_stmt != NULL, NULL);
-	self = (ValaIfStatement*) g_type_create_instance (object_type);
+	self = (ValaIfStatement*) vala_code_node_construct (object_type);
 	vala_if_statement_set_condition (self, cond);
 	vala_if_statement_set_true_statement (self, true_stmt);
 	vala_if_statement_set_false_statement (self, false_stmt);
@@ -1292,7 +1267,6 @@ static gboolean vala_if_statement_real_check (ValaCodeNode* base, ValaSemanticAn
 		vala_code_node_check ((ValaCodeNode*) vala_if_statement_get_false_statement (self), analyzer);
 	}
 	if (vala_code_node_get_error ((ValaCodeNode*) vala_if_statement_get_condition (self))) {
-		/* if there was an error in the condition, skip this check */
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		result = FALSE;
 		return result;
@@ -1303,17 +1277,14 @@ static gboolean vala_if_statement_real_check (ValaCodeNode* base, ValaSemanticAn
 		result = FALSE;
 		return result;
 	}
-	_tmp0_ = NULL;
 	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp0_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_condition (self)));
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL));
-	_tmp1_ = NULL;
+	_gee_collection_object_unref0 (_tmp0_);
 	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp1_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_true_statement (self)));
-	(_tmp1_ == NULL) ? NULL : (_tmp1_ = (gee_collection_object_unref (_tmp1_), NULL));
+	_gee_collection_object_unref0 (_tmp1_);
 	if (vala_if_statement_get_false_statement (self) != NULL) {
 		GeeList* _tmp2_;
-		_tmp2_ = NULL;
 		vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp2_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_false_statement (self)));
-		(_tmp2_ == NULL) ? NULL : (_tmp2_ = (gee_collection_object_unref (_tmp2_), NULL));
+		_gee_collection_object_unref0 (_tmp2_);
 	}
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
 	return result;
@@ -1328,13 +1299,15 @@ ValaExpression* vala_if_statement_get_condition (ValaIfStatement* self) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_condition = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp1_);
+	self->priv->_condition = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_condition), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_condition, (ValaCodeNode*) self);
 }
 
@@ -1348,12 +1321,9 @@ ValaBlock* vala_if_statement_get_true_statement (ValaIfStatement* self) {
 
 
 void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp1_;
 	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_true_statement = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL)), _tmp1_);
+	self->priv->_true_statement = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_true_statement), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_true_statement, (ValaCodeNode*) self);
 }
 
@@ -1367,12 +1337,9 @@ ValaBlock* vala_if_statement_get_false_statement (ValaIfStatement* self) {
 
 
 void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp1_;
 	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_false_statement = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL)), _tmp1_);
+	self->priv->_false_statement = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_false_statement), _tmp0_);
 	if (self->priv->_false_statement != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_false_statement, (ValaCodeNode*) self);
 	}
@@ -1403,9 +1370,9 @@ static void vala_if_statement_instance_init (ValaIfStatement * self) {
 static void vala_if_statement_finalize (ValaCodeNode* obj) {
 	ValaIfStatement * self;
 	self = VALA_IF_STATEMENT (obj);
-	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL));
-	(self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL));
-	(self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL));
+	_vala_code_node_unref0 (self->priv->_condition);
+	_vala_code_node_unref0 (self->priv->_true_statement);
+	_vala_code_node_unref0 (self->priv->_false_statement);
 	VALA_CODE_NODE_CLASS (vala_if_statement_parent_class)->finalize (obj);
 }
 
