@@ -130,6 +130,7 @@ typedef struct _ValaLiteralPrivate ValaLiteralPrivate;
 typedef struct _ValaIntegerLiteral ValaIntegerLiteral;
 typedef struct _ValaIntegerLiteralClass ValaIntegerLiteralClass;
 typedef struct _ValaIntegerLiteralPrivate ValaIntegerLiteralPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -482,6 +483,16 @@ typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
 typedef struct _ValaSwitchLabel ValaSwitchLabel;
 typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
 
+#define VALA_TYPE_LOOP (vala_loop_get_type ())
+#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
+#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
+#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
+#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
+#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))
+
+typedef struct _ValaLoop ValaLoop;
+typedef struct _ValaLoopClass ValaLoopClass;
+
 #define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
 #define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
 #define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
@@ -853,16 +864,6 @@ typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;
 
-#define VALA_TYPE_SCOPE (vala_scope_get_type ())
-#define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
-#define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
-#define VALA_IS_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SCOPE))
-#define VALA_IS_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SCOPE))
-#define VALA_SCOPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SCOPE, ValaScopeClass))
-
-typedef struct _ValaScope ValaScope;
-typedef struct _ValaScopeClass ValaScopeClass;
-
 #define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
 #define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
 #define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
@@ -873,6 +874,26 @@ typedef struct _ValaScopeClass ValaScopeClass;
 typedef struct _ValaValueType ValaValueType;
 typedef struct _ValaValueTypeClass ValaValueTypeClass;
 
+#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
+#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
+#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+
+typedef struct _ValaStructValueType ValaStructValueType;
+typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+
+#define VALA_TYPE_SCOPE (vala_scope_get_type ())
+#define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
+#define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
+#define VALA_IS_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SCOPE))
+#define VALA_IS_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SCOPE))
+#define VALA_SCOPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SCOPE, ValaScopeClass))
+
+typedef struct _ValaScope ValaScope;
+typedef struct _ValaScopeClass ValaScopeClass;
+
 #define VALA_TYPE_INTEGER_TYPE (vala_integer_type_get_type ())
 #define VALA_INTEGER_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_INTEGER_TYPE, ValaIntegerType))
 #define VALA_INTEGER_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_INTEGER_TYPE, ValaIntegerTypeClass))
@@ -882,13 +903,8 @@ typedef struct _ValaValueTypeClass ValaValueTypeClass;
 
 typedef struct _ValaIntegerType ValaIntegerType;
 typedef struct _ValaIntegerTypeClass ValaIntegerTypeClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -909,9 +925,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -925,9 +938,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Base class for all literals in the source code.
- */
 struct _ValaLiteral {
 	ValaExpression parent_instance;
 	ValaLiteralPrivate * priv;
@@ -937,9 +947,6 @@ struct _ValaLiteralClass {
 	ValaExpressionClass parent_class;
 };
 
-/**
- * Represents an integer literal in the source code.
- */
 struct _ValaIntegerLiteral {
 	ValaLiteral parent_instance;
 	ValaIntegerLiteralPrivate * priv;
@@ -953,9 +960,6 @@ struct _ValaIntegerLiteralPrivate {
 	char* _value;
 };
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -999,6 +1003,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
 	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
 	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
+	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
@@ -1041,17 +1046,12 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Code visitor analyzing and checking code.
- */
 struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 	ValaSymbol* root_symbol;
-	ValaDataType* current_return_type;
-	ValaClass* current_class;
-	ValaStruct* current_struct;
 	ValaBlock* insert_block;
+	ValaDataType* void_type;
 	ValaDataType* bool_type;
 	ValaDataType* string_type;
 	ValaDataType* uchar_type;
@@ -1068,9 +1068,11 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
+	ValaStructValueType* gvalue_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
+	ValaDataType* gvaluearray_type;
 	ValaClass* gerror_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
@@ -1081,6 +1083,7 @@ struct _ValaSemanticAnalyzerClass {
 };
 
 
+static gpointer vala_integer_literal_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -1106,6 +1109,7 @@ GType vala_integer_literal_get_type (void);
 enum  {
 	VALA_INTEGER_LITERAL_DUMMY_PROPERTY
 };
+ValaLiteral* vala_literal_construct (GType object_type);
 void vala_integer_literal_set_value (ValaIntegerLiteral* self, const char* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -1116,7 +1120,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaIntegerLiteral* vala_integer_literal_new (const char* i, ValaSourceReference* source);
 ValaIntegerLiteral* vala_integer_literal_construct (GType object_type, const char* i, ValaSourceReference* source);
-ValaIntegerLiteral* vala_integer_literal_new (const char* i, ValaSourceReference* source);
 void vala_code_visitor_visit_integer_literal (ValaCodeVisitor* self, ValaIntegerLiteral* lit);
 void vala_code_visitor_visit_expression (ValaCodeVisitor* self, ValaExpression* expr);
 static void vala_integer_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -1166,6 +1169,7 @@ GType vala_if_statement_get_type (void);
 GType vala_switch_statement_get_type (void);
 GType vala_switch_section_get_type (void);
 GType vala_switch_label_get_type (void);
+GType vala_loop_get_type (void);
 GType vala_while_statement_get_type (void);
 GType vala_do_statement_get_type (void);
 GType vala_for_statement_get_type (void);
@@ -1203,6 +1207,8 @@ GType vala_typecheck_get_type (void);
 GType vala_conditional_expression_get_type (void);
 GType vala_lambda_expression_get_type (void);
 GType vala_assignment_get_type (void);
+GType vala_value_type_get_type (void);
+GType vala_struct_value_type_get_type (void);
 gpointer vala_scope_ref (gpointer instance);
 void vala_scope_unref (gpointer instance);
 GParamSpec* vala_param_spec_scope (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -1213,26 +1219,17 @@ ValaScope* vala_symbol_get_scope (ValaSymbol* self);
 ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name);
 ValaIntegerType* vala_integer_type_new (ValaStruct* type_symbol, const char* literal_value, const char* literal_type_name);
 ValaIntegerType* vala_integer_type_construct (GType object_type, ValaStruct* type_symbol, const char* literal_value, const char* literal_type_name);
-GType vala_value_type_get_type (void);
 GType vala_integer_type_get_type (void);
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_integer_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
-static gpointer vala_integer_literal_parent_class = NULL;
 static void vala_integer_literal_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new integer literal.
- *
- * @param i      literal value
- * @param source reference to source code
- * @return       newly created integer literal
- */
 ValaIntegerLiteral* vala_integer_literal_construct (GType object_type, const char* i, ValaSourceReference* source) {
 	ValaIntegerLiteral* self;
 	g_return_val_if_fail (i != NULL, NULL);
-	self = (ValaIntegerLiteral*) g_type_create_instance (object_type);
+	self = (ValaIntegerLiteral*) vala_literal_construct (object_type);
 	vala_integer_literal_set_value (self, i);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
@@ -1255,164 +1252,154 @@ static void vala_integer_literal_real_accept (ValaCodeNode* base, ValaCodeVisito
 
 static char* vala_integer_literal_real_to_string (ValaCodeNode* base) {
 	ValaIntegerLiteral * self;
-	const char* _tmp0_;
+	char* result;
 	self = (ValaIntegerLiteral*) base;
-	_tmp0_ = NULL;
-	return (_tmp0_ = self->priv->_value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = g_strdup (self->priv->_value);
+	return result;
 }
 
 
-/**
- * Returns the type name of the value this literal represents.
- *
- * @return the name of literal type
- */
 char* vala_integer_literal_get_type_name (ValaIntegerLiteral* self) {
-	const char* _tmp0_;
+	char* result;
 	char* number;
 	gint l;
 	gboolean u;
-	gboolean _tmp3_;
+	gboolean _tmp2_;
 	gint64 n;
-	gboolean _tmp5_;
+	gboolean _tmp4_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0_ = NULL;
-	number = (_tmp0_ = self->priv->_value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	number = g_strdup (self->priv->_value);
 	l = 0;
 	while (TRUE) {
-		gboolean _tmp1_;
-		char* _tmp2_;
-		_tmp1_ = FALSE;
+		gboolean _tmp0_;
+		char* _tmp1_;
+		_tmp0_ = FALSE;
 		if (g_str_has_suffix (number, "l")) {
-			_tmp1_ = TRUE;
+			_tmp0_ = TRUE;
 		} else {
-			_tmp1_ = g_str_has_suffix (number, "L");
+			_tmp0_ = g_str_has_suffix (number, "L");
 		}
-		if (!_tmp1_) {
+		if (!_tmp0_) {
 			break;
 		}
 		l++;
-		_tmp2_ = NULL;
-		number = (_tmp2_ = g_strndup (number, (gsize) (strlen (number) - 1)), number = (g_free (number), NULL), _tmp2_);
+		number = (_tmp1_ = g_strndup (number, strlen (number) - 1), _g_free0 (number), _tmp1_);
 	}
 	u = FALSE;
-	_tmp3_ = FALSE;
+	_tmp2_ = FALSE;
 	if (g_str_has_suffix (number, "u")) {
-		_tmp3_ = TRUE;
+		_tmp2_ = TRUE;
 	} else {
-		_tmp3_ = g_str_has_suffix (number, "U");
+		_tmp2_ = g_str_has_suffix (number, "U");
 	}
-	if (_tmp3_) {
-		char* _tmp4_;
+	if (_tmp2_) {
+		char* _tmp3_;
 		u = TRUE;
-		_tmp4_ = NULL;
-		number = (_tmp4_ = g_strndup (number, (gsize) (strlen (number) - 1)), number = (g_free (number), NULL), _tmp4_);
+		number = (_tmp3_ = g_strndup (number, strlen (number) - 1), _g_free0 (number), _tmp3_);
 	}
 	n = g_ascii_strtoll (number, NULL, 0);
-	_tmp5_ = FALSE;
+	_tmp4_ = FALSE;
 	if (!u) {
-		_tmp5_ = n > 0x7fffffff;
+		_tmp4_ = n > 0x7fffffff;
 	} else {
-		_tmp5_ = FALSE;
+		_tmp4_ = FALSE;
 	}
-	if (_tmp5_) {
-		/* value doesn't fit into signed 32-bit*/
+	if (_tmp4_) {
 		l = 2;
 	} else {
-		gboolean _tmp6_;
-		_tmp6_ = FALSE;
+		gboolean _tmp5_;
+		_tmp5_ = FALSE;
 		if (u) {
-			_tmp6_ = n > 0xffffffff;
+			_tmp5_ = n > 0xffffffff;
 		} else {
-			_tmp6_ = FALSE;
+			_tmp5_ = FALSE;
 		}
-		if (_tmp6_) {
-			/* value doesn't fit into unsigned 32-bit*/
+		if (_tmp5_) {
 			l = 2;
 		}
 	}
 	if (l == 0) {
 		if (u) {
-			char* _tmp7_;
-			_tmp7_ = NULL;
-			return (_tmp7_ = g_strdup ("uint"), number = (g_free (number), NULL), _tmp7_);
+			result = g_strdup ("uint");
+			_g_free0 (number);
+			return result;
 		} else {
-			char* _tmp8_;
-			_tmp8_ = NULL;
-			return (_tmp8_ = g_strdup ("int"), number = (g_free (number), NULL), _tmp8_);
+			result = g_strdup ("int");
+			_g_free0 (number);
+			return result;
 		}
 	} else {
 		if (l == 1) {
 			if (u) {
-				char* _tmp9_;
-				_tmp9_ = NULL;
-				return (_tmp9_ = g_strdup ("ulong"), number = (g_free (number), NULL), _tmp9_);
+				result = g_strdup ("ulong");
+				_g_free0 (number);
+				return result;
 			} else {
-				char* _tmp10_;
-				_tmp10_ = NULL;
-				return (_tmp10_ = g_strdup ("long"), number = (g_free (number), NULL), _tmp10_);
+				result = g_strdup ("long");
+				_g_free0 (number);
+				return result;
 			}
 		} else {
 			if (u) {
-				char* _tmp11_;
-				_tmp11_ = NULL;
-				return (_tmp11_ = g_strdup ("uint64"), number = (g_free (number), NULL), _tmp11_);
+				result = g_strdup ("uint64");
+				_g_free0 (number);
+				return result;
 			} else {
-				char* _tmp12_;
-				_tmp12_ = NULL;
-				return (_tmp12_ = g_strdup ("int64"), number = (g_free (number), NULL), _tmp12_);
+				result = g_strdup ("int64");
+				_g_free0 (number);
+				return result;
 			}
 		}
 	}
-	number = (g_free (number), NULL);
+	_g_free0 (number);
 }
 
 
 static gboolean vala_integer_literal_real_is_pure (ValaExpression* base) {
 	ValaIntegerLiteral * self;
+	gboolean result;
 	self = (ValaIntegerLiteral*) base;
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
 static gboolean vala_integer_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaIntegerLiteral * self;
-	ValaIntegerType* _tmp4_;
-	char* _tmp3_;
-	ValaStruct* _tmp2_;
-	char* _tmp1_;
+	gboolean result;
+	ValaIntegerType* _tmp3_;
+	char* _tmp2_;
+	ValaStruct* _tmp1_;
+	char* _tmp0_;
 	self = (ValaIntegerLiteral*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	_tmp4_ = NULL;
-	_tmp3_ = NULL;
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp4_ = vala_integer_type_new (_tmp2_ = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), _tmp1_ = vala_integer_literal_get_type_name (self))), self->priv->_value, _tmp3_ = vala_integer_literal_get_type_name (self))));
-	(_tmp4_ == NULL) ? NULL : (_tmp4_ = (vala_code_node_unref (_tmp4_), NULL));
-	_tmp3_ = (g_free (_tmp3_), NULL);
-	(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
-	_tmp1_ = (g_free (_tmp1_), NULL);
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp3_ = vala_integer_type_new (_tmp1_ = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), _tmp0_ = vala_integer_literal_get_type_name (self))), self->priv->_value, _tmp2_ = vala_integer_literal_get_type_name (self))));
+	_vala_code_node_unref0 (_tmp3_);
+	_g_free0 (_tmp2_);
+	_vala_code_node_unref0 (_tmp1_);
+	_g_free0 (_tmp0_);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 const char* vala_integer_literal_get_value (ValaIntegerLiteral* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_value;
+	result = self->priv->_value;
+	return result;
 }
 
 
 void vala_integer_literal_set_value (ValaIntegerLiteral* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_value = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_value = (g_free (self->priv->_value), NULL), _tmp2_);
+	self->priv->_value = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_value), _tmp0_);
 }
 
 
@@ -1435,7 +1422,7 @@ static void vala_integer_literal_instance_init (ValaIntegerLiteral * self) {
 static void vala_integer_literal_finalize (ValaCodeNode* obj) {
 	ValaIntegerLiteral * self;
 	self = VALA_INTEGER_LITERAL (obj);
-	self->priv->_value = (g_free (self->priv->_value), NULL);
+	_g_free0 (self->priv->_value);
 	VALA_CODE_NODE_CLASS (vala_integer_literal_parent_class)->finalize (obj);
 }
 
