@@ -150,6 +150,7 @@ typedef struct _ValaValueTypePrivate ValaValueTypePrivate;
 typedef struct _ValaIntegerType ValaIntegerType;
 typedef struct _ValaIntegerTypeClass ValaIntegerTypeClass;
 typedef struct _ValaIntegerTypePrivate ValaIntegerTypePrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_TYPESYMBOL (vala_typesymbol_get_type ())
 #define VALA_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))
@@ -180,6 +181,7 @@ typedef struct _ValaStructClass ValaStructClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_ENUM (vala_enum_get_type ())
 #define VALA_ENUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM, ValaEnum))
@@ -191,12 +193,6 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaEnum ValaEnum;
 typedef struct _ValaEnumClass ValaEnumClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -217,10 +213,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -250,9 +242,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * A value type, i.e. a struct or an enum type.
- */
 struct _ValaValueType {
 	ValaDataType parent_instance;
 	ValaValueTypePrivate * priv;
@@ -262,9 +251,6 @@ struct _ValaValueTypeClass {
 	ValaDataTypeClass parent_class;
 };
 
-/**
- * An integer type.
- */
 struct _ValaIntegerType {
 	ValaValueType parent_instance;
 	ValaIntegerTypePrivate * priv;
@@ -314,7 +300,6 @@ enum  {
 	VALA_INTEGER_TYPE_DUMMY_PROPERTY
 };
 GType vala_typesymbol_get_type (void);
-ValaValueType* vala_value_type_new (ValaTypeSymbol* type_symbol);
 ValaValueType* vala_value_type_construct (GType object_type, ValaTypeSymbol* type_symbol);
 GType vala_struct_get_type (void);
 ValaIntegerType* vala_integer_type_new (ValaStruct* type_symbol, const char* literal_value, const char* literal_type_name);
@@ -348,18 +333,12 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 ValaIntegerType* vala_integer_type_construct (GType object_type, ValaStruct* type_symbol, const char* literal_value, const char* literal_type_name) {
 	ValaIntegerType* self;
+	char* _tmp0_;
 	char* _tmp1_;
-	const char* _tmp0_;
-	char* _tmp3_;
-	const char* _tmp2_;
 	g_return_val_if_fail (type_symbol != NULL, NULL);
 	self = (ValaIntegerType*) vala_value_type_construct (object_type, (ValaTypeSymbol*) type_symbol);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->literal_value = (_tmp1_ = (_tmp0_ = literal_value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->literal_value = (g_free (self->priv->literal_value), NULL), _tmp1_);
-	_tmp3_ = NULL;
-	_tmp2_ = NULL;
-	self->priv->literal_type_name = (_tmp3_ = (_tmp2_ = literal_type_name, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), self->priv->literal_type_name = (g_free (self->priv->literal_type_name), NULL), _tmp3_);
+	self->priv->literal_value = (_tmp0_ = g_strdup (literal_value), _g_free0 (self->priv->literal_value), _tmp0_);
+	self->priv->literal_type_name = (_tmp1_ = g_strdup (literal_type_name), _g_free0 (self->priv->literal_type_name), _tmp1_);
 	return self;
 }
 
@@ -383,6 +362,11 @@ static ValaDataType* vala_integer_type_real_copy (ValaDataType* base) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_integer_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaIntegerType * self;
 	gboolean result;
@@ -396,64 +380,57 @@ static gboolean vala_integer_type_real_compatible (ValaDataType* base, ValaDataT
 		_tmp0_ = FALSE;
 	}
 	if (_tmp0_) {
-		ValaStruct* _tmp1_;
 		ValaStruct* target_st;
-		/* int literals are implicitly convertible to integer types
-		 of a lower rank if the value of the literal is within
-		 the range of the target type*/
-		_tmp1_ = NULL;
-		target_st = (_tmp1_ = VALA_STRUCT (vala_data_type_get_data_type (target_type)), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+		target_st = _vala_code_node_ref0 (VALA_STRUCT (vala_data_type_get_data_type (target_type)));
 		if (vala_struct_is_integer_type (target_st)) {
 			ValaAttribute* int_attr;
+			gboolean _tmp1_;
 			gboolean _tmp2_;
-			gboolean _tmp3_;
 			int_attr = vala_code_node_get_attribute ((ValaCodeNode*) target_st, "IntegerType");
+			_tmp1_ = FALSE;
 			_tmp2_ = FALSE;
-			_tmp3_ = FALSE;
 			if (int_attr != NULL) {
-				_tmp3_ = vala_attribute_has_argument (int_attr, "min");
-			} else {
-				_tmp3_ = FALSE;
-			}
-			if (_tmp3_) {
-				_tmp2_ = vala_attribute_has_argument (int_attr, "max");
+				_tmp2_ = vala_attribute_has_argument (int_attr, "min");
 			} else {
 				_tmp2_ = FALSE;
 			}
 			if (_tmp2_) {
+				_tmp1_ = vala_attribute_has_argument (int_attr, "max");
+			} else {
+				_tmp1_ = FALSE;
+			}
+			if (_tmp1_) {
 				gint val;
-				gboolean _tmp4_;
+				gboolean _tmp3_;
 				val = atoi (self->priv->literal_value);
-				_tmp4_ = FALSE;
+				_tmp3_ = FALSE;
 				if (val >= vala_attribute_get_integer (int_attr, "min")) {
-					_tmp4_ = val <= vala_attribute_get_integer (int_attr, "max");
+					_tmp3_ = val <= vala_attribute_get_integer (int_attr, "max");
 				} else {
-					_tmp4_ = FALSE;
+					_tmp3_ = FALSE;
 				}
-				result = _tmp4_;
-				(int_attr == NULL) ? NULL : (int_attr = (vala_code_node_unref (int_attr), NULL));
-				(target_st == NULL) ? NULL : (target_st = (vala_code_node_unref (target_st), NULL));
+				result = _tmp3_;
+				_vala_code_node_unref0 (int_attr);
+				_vala_code_node_unref0 (target_st);
 				return result;
 			} else {
-				/* assume to be compatible if the target type doesn't specify limits*/
 				result = TRUE;
-				(int_attr == NULL) ? NULL : (int_attr = (vala_code_node_unref (int_attr), NULL));
-				(target_st == NULL) ? NULL : (target_st = (vala_code_node_unref (target_st), NULL));
+				_vala_code_node_unref0 (int_attr);
+				_vala_code_node_unref0 (target_st);
 				return result;
 			}
-			(int_attr == NULL) ? NULL : (int_attr = (vala_code_node_unref (int_attr), NULL));
+			_vala_code_node_unref0 (int_attr);
 		}
-		(target_st == NULL) ? NULL : (target_st = (vala_code_node_unref (target_st), NULL));
+		_vala_code_node_unref0 (target_st);
 	} else {
-		gboolean _tmp5_;
-		_tmp5_ = FALSE;
+		gboolean _tmp4_;
+		_tmp4_ = FALSE;
 		if (VALA_IS_ENUM (vala_data_type_get_data_type (target_type))) {
-			_tmp5_ = _vala_strcmp0 (self->priv->literal_type_name, "int") == 0;
+			_tmp4_ = _vala_strcmp0 (self->priv->literal_type_name, "int") == 0;
 		} else {
-			_tmp5_ = FALSE;
+			_tmp4_ = FALSE;
 		}
-		if (_tmp5_) {
-			/* allow implicit conversion from 0 to enum and flags types*/
+		if (_tmp4_) {
 			if (atoi (self->priv->literal_value) == 0) {
 				result = TRUE;
 				return result;
@@ -482,8 +459,8 @@ static void vala_integer_type_instance_init (ValaIntegerType * self) {
 static void vala_integer_type_finalize (ValaCodeNode* obj) {
 	ValaIntegerType * self;
 	self = VALA_INTEGER_TYPE (obj);
-	self->priv->literal_value = (g_free (self->priv->literal_value), NULL);
-	self->priv->literal_type_name = (g_free (self->priv->literal_type_name), NULL);
+	_g_free0 (self->priv->literal_value);
+	_g_free0 (self->priv->literal_type_name);
 	VALA_CODE_NODE_CLASS (vala_integer_type_parent_class)->finalize (obj);
 }
 
