@@ -140,12 +140,6 @@ typedef struct _ValaInvalidType ValaInvalidType;
 typedef struct _ValaInvalidTypeClass ValaInvalidTypeClass;
 typedef struct _ValaInvalidTypePrivate ValaInvalidTypePrivate;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -166,10 +160,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -178,6 +168,7 @@ struct _ValaDataType {
 struct _ValaDataTypeClass {
 	ValaCodeNodeClass parent_class;
 	char* (*get_cname) (ValaDataType* self);
+	char* (*get_cdeclarator_suffix) (ValaDataType* self);
 	char* (*get_lower_case_cname) (ValaDataType* self, const char* infix);
 	char* (*to_qualified_string) (ValaDataType* self, ValaScope* scope);
 	ValaDataType* (*copy) (ValaDataType* self);
@@ -198,9 +189,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * An invalid reference to a data type.
- */
 struct _ValaInvalidType {
 	ValaDataType parent_instance;
 	ValaInvalidTypePrivate * priv;
@@ -211,6 +199,7 @@ struct _ValaInvalidTypeClass {
 };
 
 
+static gpointer vala_invalid_type_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -241,18 +230,17 @@ GType vala_invalid_type_get_type (void);
 enum  {
 	VALA_INVALID_TYPE_DUMMY_PROPERTY
 };
+ValaDataType* vala_data_type_construct (GType object_type);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 ValaInvalidType* vala_invalid_type_new (void);
 ValaInvalidType* vala_invalid_type_construct (GType object_type);
-ValaInvalidType* vala_invalid_type_new (void);
 static ValaDataType* vala_invalid_type_real_copy (ValaDataType* base);
-static gpointer vala_invalid_type_parent_class = NULL;
 
 
 
 ValaInvalidType* vala_invalid_type_construct (GType object_type) {
 	ValaInvalidType* self;
-	self = (ValaInvalidType*) g_type_create_instance (object_type);
+	self = (ValaInvalidType*) vala_data_type_construct (object_type);
 	vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 	return self;
 }
@@ -265,8 +253,10 @@ ValaInvalidType* vala_invalid_type_new (void) {
 
 static ValaDataType* vala_invalid_type_real_copy (ValaDataType* base) {
 	ValaInvalidType * self;
+	ValaDataType* result;
 	self = (ValaInvalidType*) base;
-	return (ValaDataType*) vala_invalid_type_new ();
+	result = (ValaDataType*) vala_invalid_type_new ();
+	return result;
 }
 
 
