@@ -21,25 +21,37 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <vala/valalockable.h>
+#include <glib.h>
+#include <glib-object.h>
+
+
+#define VALA_TYPE_LOCKABLE (vala_lockable_get_type ())
+#define VALA_LOCKABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOCKABLE, ValaLockable))
+#define VALA_IS_LOCKABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOCKABLE))
+#define VALA_LOCKABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), VALA_TYPE_LOCKABLE, ValaLockableIface))
+
+typedef struct _ValaLockable ValaLockable;
+typedef struct _ValaLockableIface ValaLockableIface;
+
+struct _ValaLockableIface {
+	GTypeInterface parent_iface;
+	gboolean (*get_lock_used) (ValaLockable* self);
+	void (*set_lock_used) (ValaLockable* self, gboolean used);
+};
 
 
 
+GType vala_lockable_get_type (void);
+gboolean vala_lockable_get_lock_used (ValaLockable* self);
+void vala_lockable_set_lock_used (ValaLockable* self, gboolean used);
 
 
 
-
-/**
- * Indicates a specific lockable object beeing actually locked somewhere.
- */
 gboolean vala_lockable_get_lock_used (ValaLockable* self) {
 	return VALA_LOCKABLE_GET_INTERFACE (self)->get_lock_used (self);
 }
 
 
-/**
- * Set this lockable object as beeing locked somewhere.
- */
 void vala_lockable_set_lock_used (ValaLockable* self, gboolean used) {
 	VALA_LOCKABLE_GET_INTERFACE (self)->set_lock_used (self, used);
 }
