@@ -136,6 +136,7 @@ typedef struct _ValaLoopPrivate ValaLoopPrivate;
 
 typedef struct _ValaBlock ValaBlock;
 typedef struct _ValaBlockClass ValaBlockClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -146,13 +147,8 @@ typedef struct _ValaBlockClass ValaBlockClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -173,16 +169,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents an endless loop.
- */
 struct _ValaLoop {
 	ValaCodeNode parent_instance;
 	ValaLoopPrivate * priv;
@@ -225,6 +215,7 @@ GType vala_block_get_type (void);
 enum  {
 	VALA_LOOP_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_loop_set_body (ValaLoop* self, ValaBlock* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -235,7 +226,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaLoop* vala_loop_new (ValaBlock* body, ValaSourceReference* source_reference);
 ValaLoop* vala_loop_construct (GType object_type, ValaBlock* body, ValaSourceReference* source_reference);
-ValaLoop* vala_loop_new (ValaBlock* body, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_loop (ValaCodeVisitor* self, ValaLoop* stmt);
 static void vala_loop_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaBlock* vala_loop_get_body (ValaLoop* self);
@@ -253,17 +243,10 @@ static void vala_loop_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new loop.
- *
- * @param body   loop body
- * @param source reference to source code
- * @return       newly created while statement
- */
 ValaLoop* vala_loop_construct (GType object_type, ValaBlock* body, ValaSourceReference* source_reference) {
 	ValaLoop* self;
 	g_return_val_if_fail (body != NULL, NULL);
-	self = (ValaLoop*) g_type_create_instance (object_type);
+	self = (ValaLoop*) vala_code_node_construct (object_type);
 	vala_loop_set_body (self, body);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
@@ -303,9 +286,8 @@ static gboolean vala_loop_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_code_node_check ((ValaCodeNode*) vala_loop_get_body (self), analyzer);
-	_tmp0_ = NULL;
 	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp0_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_loop_get_body (self)));
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL));
+	_gee_collection_object_unref0 (_tmp0_);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
 	return result;
 }
@@ -319,13 +301,15 @@ ValaBlock* vala_loop_get_body (ValaLoop* self) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_loop_set_body (ValaLoop* self, ValaBlock* value) {
-	ValaBlock* _tmp1_;
 	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_body = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp1_);
+	self->priv->_body = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_body), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_body, (ValaCodeNode*) self);
 }
 
@@ -353,7 +337,7 @@ static void vala_loop_instance_init (ValaLoop * self) {
 static void vala_loop_finalize (ValaCodeNode* obj) {
 	ValaLoop * self;
 	self = VALA_LOOP (obj);
-	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL));
+	_vala_code_node_unref0 (self->priv->_body);
 	VALA_CODE_NODE_CLASS (vala_loop_parent_class)->finalize (obj);
 }
 
