@@ -1,6 +1,6 @@
 /* valamemberinitializer.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -118,6 +118,8 @@ typedef struct _ValaAttributeClass ValaAttributeClass;
 typedef struct _ValaMemberInitializer ValaMemberInitializer;
 typedef struct _ValaMemberInitializerClass ValaMemberInitializerClass;
 typedef struct _ValaMemberInitializerPrivate ValaMemberInitializerPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -129,12 +131,6 @@ typedef struct _ValaMemberInitializerPrivate ValaMemberInitializerPrivate;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -155,10 +151,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a member initializer, i.e. an element of an object initializer, in
- * the source code.
- */
 struct _ValaMemberInitializer {
 	ValaCodeNode parent_instance;
 	ValaMemberInitializerPrivate * priv;
@@ -170,8 +162,8 @@ struct _ValaMemberInitializerClass {
 
 struct _ValaMemberInitializerPrivate {
 	char* _name;
-	ValaExpression* _initializer;
 	ValaSymbol* _symbol_reference;
+	ValaExpression* _initializer;
 };
 
 
@@ -200,6 +192,7 @@ GType vala_member_initializer_get_type (void);
 enum  {
 	VALA_MEMBER_INITIALIZER_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_member_initializer_set_initializer (ValaMemberInitializer* self, ValaExpression* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -211,32 +204,25 @@ void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReferenc
 void vala_member_initializer_set_name (ValaMemberInitializer* self, const char* value);
 ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpression* initializer, ValaSourceReference* source_reference);
 ValaMemberInitializer* vala_member_initializer_construct (GType object_type, const char* name, ValaExpression* initializer, ValaSourceReference* source_reference);
-ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpression* initializer, ValaSourceReference* source_reference);
 ValaExpression* vala_member_initializer_get_initializer (ValaMemberInitializer* self);
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 static gboolean vala_member_initializer_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
+static void vala_member_initializer_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 const char* vala_member_initializer_get_name (ValaMemberInitializer* self);
+void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 ValaSymbol* vala_member_initializer_get_symbol_reference (ValaMemberInitializer* self);
 void vala_member_initializer_set_symbol_reference (ValaMemberInitializer* self, ValaSymbol* value);
 static void vala_member_initializer_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new member initializer.
- *
- * @param name             member name
- * @param initializer      initializer expression
- * @param source_reference reference to source code
- * @return                 newly created member initializer
- */
 ValaMemberInitializer* vala_member_initializer_construct (GType object_type, const char* name, ValaExpression* initializer, ValaSourceReference* source_reference) {
 	ValaMemberInitializer* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (initializer != NULL, NULL);
-	self = (ValaMemberInitializer*) g_type_create_instance (object_type);
+	self = (ValaMemberInitializer*) vala_code_node_construct (object_type);
 	vala_member_initializer_set_initializer (self, initializer);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	vala_member_initializer_set_name (self, name);
@@ -253,7 +239,7 @@ static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVis
 	ValaMemberInitializer * self;
 	self = (ValaMemberInitializer*) base;
 	g_return_if_fail (visitor != NULL);
-	vala_code_node_accept ((ValaCodeNode*) self->priv->_initializer, visitor);
+	vala_code_node_accept ((ValaCodeNode*) vala_member_initializer_get_initializer (self), visitor);
 }
 
 
@@ -262,11 +248,22 @@ static gboolean vala_member_initializer_real_check (ValaCodeNode* base, ValaSema
 	gboolean result;
 	self = (ValaMemberInitializer*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
-	result = vala_code_node_check ((ValaCodeNode*) self->priv->_initializer, analyzer);
+	result = vala_code_node_check ((ValaCodeNode*) vala_member_initializer_get_initializer (self), analyzer);
 	return result;
 }
 
 
+static void vala_member_initializer_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
+	ValaMemberInitializer * self;
+	self = (ValaMemberInitializer*) base;
+	g_return_if_fail (old_node != NULL);
+	g_return_if_fail (new_node != NULL);
+	if (vala_member_initializer_get_initializer (self) == old_node) {
+		vala_member_initializer_set_initializer (self, new_node);
+	}
+}
+
+
 const char* vala_member_initializer_get_name (ValaMemberInitializer* self) {
 	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -276,12 +273,9 @@ const char* vala_member_initializer_get_name (ValaMemberInitializer* self) {
 
 
 void vala_member_initializer_set_name (ValaMemberInitializer* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -293,13 +287,16 @@ ValaExpression* vala_member_initializer_get_initializer (ValaMemberInitializer*
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_member_initializer_set_initializer (ValaMemberInitializer* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_initializer = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)), _tmp1_);
+	self->priv->_initializer = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_initializer), _tmp0_);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_initializer, (ValaCodeNode*) self);
 }
 
 
@@ -323,6 +320,7 @@ static void vala_member_initializer_class_init (ValaMemberInitializerClass * kla
 	g_type_class_add_private (klass, sizeof (ValaMemberInitializerPrivate));
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_member_initializer_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->check = vala_member_initializer_real_check;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_member_initializer_real_replace_expression;
 }
 
 
@@ -334,8 +332,8 @@ static void vala_member_initializer_instance_init (ValaMemberInitializer * self)
 static void vala_member_initializer_finalize (ValaCodeNode* obj) {
 	ValaMemberInitializer * self;
 	self = VALA_MEMBER_INITIALIZER (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL));
+	_g_free0 (self->priv->_name);
+	_vala_code_node_unref0 (self->priv->_initializer);
 	VALA_CODE_NODE_CLASS (vala_member_initializer_parent_class)->finalize (obj);
 }
 
