@@ -180,6 +180,9 @@ typedef struct _ValaObjectTypeSymbolClass ValaObjectTypeSymbolClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_CLASS (vala_class_get_type ())
 #define VALA_CLASS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CLASS, ValaClass))
@@ -211,12 +214,6 @@ typedef struct _ValaMemberClass ValaMemberClass;
 typedef struct _ValaMethod ValaMethod;
 typedef struct _ValaMethodClass ValaMethodClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -237,10 +234,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -270,9 +263,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * A reference type, i.e. a class, interface, or array type.
- */
 struct _ValaReferenceType {
 	ValaDataType parent_instance;
 	ValaReferenceTypePrivate * priv;
@@ -282,9 +272,6 @@ struct _ValaReferenceTypeClass {
 	ValaDataTypeClass parent_class;
 };
 
-/**
- * A class type.
- */
 struct _ValaObjectType {
 	ValaReferenceType parent_instance;
 	ValaObjectTypePrivate * priv;
@@ -334,6 +321,7 @@ GType vala_object_type_symbol_get_type (void);
 enum  {
 	VALA_OBJECT_TYPE_DUMMY_PROPERTY
 };
+ValaReferenceType* vala_reference_type_construct (GType object_type);
 void vala_object_type_set_type_symbol (ValaObjectType* self, ValaObjectTypeSymbol* value);
 void vala_data_type_set_data_type (ValaDataType* self, ValaTypeSymbol* value);
 ValaObjectType* vala_object_type_new (ValaObjectTypeSymbol* type_symbol);
@@ -381,7 +369,7 @@ static void vala_object_type_finalize (ValaCodeNode* obj);
 ValaObjectType* vala_object_type_construct (GType object_type, ValaObjectTypeSymbol* type_symbol) {
 	ValaObjectType* self;
 	g_return_val_if_fail (type_symbol != NULL, NULL);
-	self = (ValaObjectType*) g_type_create_instance (object_type);
+	self = (ValaObjectType*) vala_reference_type_construct (object_type);
 	vala_object_type_set_type_symbol (self, type_symbol);
 	vala_data_type_set_data_type ((ValaDataType*) self, (ValaTypeSymbol*) type_symbol);
 	return self;
@@ -408,9 +396,7 @@ static ValaDataType* vala_object_type_real_copy (ValaDataType* base) {
 		GeeList* _tmp0_;
 		GeeIterator* _tmp1_;
 		GeeIterator* _arg_it;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
+		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
 		while (TRUE) {
 			ValaDataType* arg;
 			ValaDataType* _tmp2_;
@@ -418,12 +404,11 @@ static ValaDataType* vala_object_type_real_copy (ValaDataType* base) {
 				break;
 			}
 			arg = (ValaDataType*) gee_iterator_get (_arg_it);
-			_tmp2_ = NULL;
 			vala_data_type_add_type_argument ((ValaDataType*) _result_, _tmp2_ = vala_data_type_copy (arg));
-			(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
-			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+			_vala_code_node_unref0 (_tmp2_);
+			_vala_code_node_unref0 (arg);
 		}
-		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
+		_gee_collection_object_unref0 (_arg_it);
 	}
 	result = (ValaDataType*) _result_;
 	return result;
@@ -436,48 +421,48 @@ static char* vala_object_type_real_get_cname (ValaDataType* base) {
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaObjectType*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = g_strdup_printf ("%s*", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_type_symbol, !vala_data_type_get_value_owned ((ValaDataType*) self))), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strdup_printf ("%s*", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_type_symbol, !vala_data_type_get_value_owned ((ValaDataType*) self))), _g_free0 (_tmp0_), _tmp1_);
 	return result;
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_object_type_real_stricter (ValaDataType* base, ValaDataType* target_type) {
 	ValaObjectType * self;
 	gboolean result;
-	ValaObjectType* _tmp1_;
 	ValaDataType* _tmp0_;
 	ValaObjectType* obj_target_type;
-	gboolean _tmp2_;
+	gboolean _tmp1_;
 	self = (ValaObjectType*) base;
 	g_return_val_if_fail (target_type != NULL, FALSE);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	obj_target_type = (_tmp1_ = (_tmp0_ = target_type, VALA_IS_OBJECT_TYPE (_tmp0_) ? ((ValaObjectType*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+	obj_target_type = _vala_code_node_ref0 ((_tmp0_ = target_type, VALA_IS_OBJECT_TYPE (_tmp0_) ? ((ValaObjectType*) _tmp0_) : NULL));
 	if (obj_target_type == NULL) {
 		result = FALSE;
-		(obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL));
+		_vala_code_node_unref0 (obj_target_type);
 		return result;
 	}
 	if (vala_data_type_get_value_owned ((ValaDataType*) self) != vala_data_type_get_value_owned (target_type)) {
 		result = FALSE;
-		(obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL));
+		_vala_code_node_unref0 (obj_target_type);
 		return result;
 	}
-	_tmp2_ = FALSE;
+	_tmp1_ = FALSE;
 	if (vala_data_type_get_nullable ((ValaDataType*) self)) {
-		_tmp2_ = !vala_data_type_get_nullable (target_type);
+		_tmp1_ = !vala_data_type_get_nullable (target_type);
 	} else {
-		_tmp2_ = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp2_) {
+	if (_tmp1_) {
 		result = FALSE;
-		(obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL));
+		_vala_code_node_unref0 (obj_target_type);
 		return result;
 	}
 	result = vala_typesymbol_is_subtype_of ((ValaTypeSymbol*) self->priv->_type_symbol, (ValaTypeSymbol*) obj_target_type->priv->_type_symbol);
-	(obj_target_type == NULL) ? NULL : (obj_target_type = (vala_code_node_unref (obj_target_type), NULL));
+	_vala_code_node_unref0 (obj_target_type);
 	return result;
 }
 
@@ -485,92 +470,81 @@ static gboolean vala_object_type_real_stricter (ValaDataType* base, ValaDataType
 static gboolean vala_object_type_real_is_invokable (ValaDataType* base) {
 	ValaObjectType * self;
 	gboolean result;
-	ValaClass* _tmp1_;
 	ValaObjectTypeSymbol* _tmp0_;
 	ValaClass* cl;
-	gboolean _tmp2_;
+	gboolean _tmp1_;
 	self = (ValaObjectType*) base;
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	cl = (_tmp1_ = (_tmp0_ = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0_) ? ((ValaClass*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-	_tmp2_ = FALSE;
+	cl = _vala_code_node_ref0 ((_tmp0_ = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0_) ? ((ValaClass*) _tmp0_) : NULL));
+	_tmp1_ = FALSE;
 	if (cl != NULL) {
-		_tmp2_ = vala_class_get_default_construction_method (cl) != NULL;
+		_tmp1_ = vala_class_get_default_construction_method (cl) != NULL;
 	} else {
-		_tmp2_ = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp2_) {
+	if (_tmp1_) {
 		result = TRUE;
-		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+		_vala_code_node_unref0 (cl);
 		return result;
 	} else {
 		result = FALSE;
-		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+		_vala_code_node_unref0 (cl);
 		return result;
 	}
-	(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+	_vala_code_node_unref0 (cl);
 }
 
 
 static ValaDataType* vala_object_type_real_get_return_type (ValaDataType* base) {
 	ValaObjectType * self;
 	ValaDataType* result;
-	ValaClass* _tmp1_;
 	ValaObjectTypeSymbol* _tmp0_;
 	ValaClass* cl;
-	gboolean _tmp2_;
+	gboolean _tmp1_;
 	self = (ValaObjectType*) base;
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	cl = (_tmp1_ = (_tmp0_ = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0_) ? ((ValaClass*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-	_tmp2_ = FALSE;
+	cl = _vala_code_node_ref0 ((_tmp0_ = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0_) ? ((ValaClass*) _tmp0_) : NULL));
+	_tmp1_ = FALSE;
 	if (cl != NULL) {
-		_tmp2_ = vala_class_get_default_construction_method (cl) != NULL;
+		_tmp1_ = vala_class_get_default_construction_method (cl) != NULL;
 	} else {
-		_tmp2_ = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp2_) {
-		ValaDataType* _tmp3_;
-		_tmp3_ = NULL;
-		result = (_tmp3_ = vala_method_get_return_type (vala_class_get_default_construction_method (cl)), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_));
-		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+	if (_tmp1_) {
+		result = _vala_code_node_ref0 (vala_method_get_return_type (vala_class_get_default_construction_method (cl)));
+		_vala_code_node_unref0 (cl);
 		return result;
 	} else {
 		result = NULL;
-		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+		_vala_code_node_unref0 (cl);
 		return result;
 	}
-	(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+	_vala_code_node_unref0 (cl);
 }
 
 
 static GeeList* vala_object_type_real_get_parameters (ValaDataType* base) {
 	ValaObjectType * self;
 	GeeList* result;
-	ValaClass* _tmp1_;
 	ValaObjectTypeSymbol* _tmp0_;
 	ValaClass* cl;
-	gboolean _tmp2_;
+	gboolean _tmp1_;
 	self = (ValaObjectType*) base;
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	cl = (_tmp1_ = (_tmp0_ = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0_) ? ((ValaClass*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-	_tmp2_ = FALSE;
+	cl = _vala_code_node_ref0 ((_tmp0_ = self->priv->_type_symbol, VALA_IS_CLASS (_tmp0_) ? ((ValaClass*) _tmp0_) : NULL));
+	_tmp1_ = FALSE;
 	if (cl != NULL) {
-		_tmp2_ = vala_class_get_default_construction_method (cl) != NULL;
+		_tmp1_ = vala_class_get_default_construction_method (cl) != NULL;
 	} else {
-		_tmp2_ = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp2_) {
+	if (_tmp1_) {
 		result = vala_method_get_parameters (vala_class_get_default_construction_method (cl));
-		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+		_vala_code_node_unref0 (cl);
 		return result;
 	} else {
 		result = NULL;
-		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+		_vala_code_node_unref0 (cl);
 		return result;
 	}
-	(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+	_vala_code_node_unref0 (cl);
 }
 
 
