@@ -66,6 +66,8 @@ typedef struct _ValaSymbolClass ValaSymbolClass;
 
 typedef struct _ValaLocalVariable ValaLocalVariable;
 typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 typedef struct _ValaParamSpecPhiFunction ValaParamSpecPhiFunction;
 
 struct _ValaPhiFunction {
@@ -125,9 +127,8 @@ ValaPhiFunction* vala_phi_function_construct (GType object_type, ValaLocalVariab
 	g_return_val_if_fail (variable != NULL, NULL);
 	self = (ValaPhiFunction*) g_type_create_instance (object_type);
 	vala_phi_function_set_original_variable (self, variable);
-	_tmp0_ = NULL;
 	vala_phi_function_set_operands (self, (GeeList*) (_tmp0_ = gee_array_list_new (VALA_TYPE_LOCAL_VARIABLE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal)));
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL));
+	_gee_collection_object_unref0 (_tmp0_);
 	{
 		gint i;
 		i = 0;
@@ -163,13 +164,15 @@ ValaLocalVariable* vala_phi_function_get_original_variable (ValaPhiFunction* sel
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static void vala_phi_function_set_original_variable (ValaPhiFunction* self, ValaLocalVariable* value) {
-	ValaLocalVariable* _tmp1_;
 	ValaLocalVariable* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_original_variable = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_original_variable == NULL) ? NULL : (self->priv->_original_variable = (vala_code_node_unref (self->priv->_original_variable), NULL)), _tmp1_);
+	self->priv->_original_variable = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_original_variable), _tmp0_);
 }
 
 
@@ -181,13 +184,15 @@ GeeList* vala_phi_function_get_operands (ValaPhiFunction* self) {
 }
 
 
+static gpointer _gee_collection_object_ref0 (gpointer self) {
+	return self ? gee_collection_object_ref (self) : NULL;
+}
+
+
 static void vala_phi_function_set_operands (ValaPhiFunction* self, GeeList* value) {
-	GeeList* _tmp1_;
 	GeeList* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_operands = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_operands == NULL) ? NULL : (self->priv->_operands = (gee_collection_object_unref (self->priv->_operands), NULL)), _tmp1_);
+	self->priv->_operands = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_operands), _tmp0_);
 }
 
 
@@ -300,8 +305,8 @@ static void vala_phi_function_instance_init (ValaPhiFunction * self) {
 static void vala_phi_function_finalize (ValaPhiFunction* obj) {
 	ValaPhiFunction * self;
 	self = VALA_PHI_FUNCTION (obj);
-	(self->priv->_original_variable == NULL) ? NULL : (self->priv->_original_variable = (vala_code_node_unref (self->priv->_original_variable), NULL));
-	(self->priv->_operands == NULL) ? NULL : (self->priv->_operands = (gee_collection_object_unref (self->priv->_operands), NULL));
+	_vala_code_node_unref0 (self->priv->_original_variable);
+	_gee_collection_object_unref0 (self->priv->_operands);
 }
 
 
