@@ -139,6 +139,7 @@ typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
 typedef struct _ValaPointerType ValaPointerType;
 typedef struct _ValaPointerTypeClass ValaPointerTypeClass;
 typedef struct _ValaPointerTypePrivate ValaPointerTypePrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -149,6 +150,7 @@ typedef struct _ValaPointerTypePrivate ValaPointerTypePrivate;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_TYPESYMBOL (vala_typesymbol_get_type ())
 #define VALA_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))
@@ -170,12 +172,6 @@ typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
 typedef struct _ValaTypeParameter ValaTypeParameter;
 typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -196,10 +192,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -229,9 +221,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * A pointer type.
- */
 struct _ValaPointerType {
 	ValaDataType parent_instance;
 	ValaPointerTypePrivate * priv;
@@ -278,6 +267,7 @@ GType vala_pointer_type_get_type (void);
 enum  {
 	VALA_POINTER_TYPE_DUMMY_PROPERTY
 };
+ValaDataType* vala_data_type_construct (GType object_type);
 void vala_pointer_type_set_base_type (ValaPointerType* self, ValaDataType* value);
 void vala_data_type_set_nullable (ValaDataType* self, gboolean value);
 gpointer vala_source_reference_ref (gpointer instance);
@@ -326,7 +316,7 @@ static void vala_pointer_type_finalize (ValaCodeNode* obj);
 ValaPointerType* vala_pointer_type_construct (GType object_type, ValaDataType* base_type, ValaSourceReference* source_reference) {
 	ValaPointerType* self;
 	g_return_val_if_fail (base_type != NULL, NULL);
-	self = (ValaPointerType*) g_type_create_instance (object_type);
+	self = (ValaPointerType*) vala_data_type_construct (object_type);
 	vala_pointer_type_set_base_type (self, base_type);
 	vala_data_type_set_nullable ((ValaDataType*) self, TRUE);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
@@ -345,9 +335,7 @@ static char* vala_pointer_type_real_to_qualified_string (ValaDataType* base, Val
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaPointerType*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = g_strconcat (_tmp0_ = vala_data_type_to_qualified_string (vala_pointer_type_get_base_type (self), scope), "*", NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strconcat (_tmp0_ = vala_data_type_to_qualified_string (vala_pointer_type_get_base_type (self), scope), "*", NULL), _g_free0 (_tmp0_), _tmp1_);
 	return result;
 }
 
@@ -369,9 +357,7 @@ static char* vala_pointer_type_real_get_cname (ValaDataType* base) {
 	} else {
 		char* _tmp1_;
 		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strconcat (_tmp1_ = vala_data_type_get_cname (vala_pointer_type_get_base_type (self)), "*", NULL), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp2_ = g_strconcat (_tmp1_ = vala_data_type_get_cname (vala_pointer_type_get_base_type (self)), "*", NULL), _g_free0 (_tmp1_), _tmp2_);
 		return result;
 	}
 }
@@ -383,9 +369,7 @@ static ValaDataType* vala_pointer_type_real_copy (ValaDataType* base) {
 	ValaDataType* _tmp0_;
 	ValaDataType* _tmp1_;
 	self = (ValaPointerType*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = (ValaDataType*) vala_pointer_type_new (_tmp0_ = vala_data_type_copy (vala_pointer_type_get_base_type (self)), NULL), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL)), _tmp1_);
+	result = (_tmp1_ = (ValaDataType*) vala_pointer_type_new (_tmp0_ = vala_data_type_copy (vala_pointer_type_get_base_type (self)), NULL), _vala_code_node_unref0 (_tmp0_), _tmp1_);
 	return result;
 }
 
@@ -404,9 +388,8 @@ static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataT
 		_tmp1_ = FALSE;
 		if (vala_data_type_get_data_type (target_type) != NULL) {
 			ValaAttribute* _tmp2_;
-			_tmp2_ = NULL;
 			_tmp1_ = (_tmp2_ = vala_code_node_get_attribute ((ValaCodeNode*) vala_data_type_get_data_type (target_type), "PointerType")) != NULL;
-			(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
+			_vala_code_node_unref0 (_tmp2_);
 		} else {
 			_tmp1_ = FALSE;
 		}
@@ -416,13 +399,11 @@ static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataT
 		result = TRUE;
 		return result;
 	}
-	/* temporarily ignore type parameters */
 	if (vala_data_type_get_type_parameter (target_type) != NULL) {
 		result = TRUE;
 		return result;
 	}
 	if (vala_data_type_is_reference_type_or_type_parameter (vala_pointer_type_get_base_type (self))) {
-		/* Object* is compatible with Object if Object is a reference type*/
 		result = vala_data_type_compatible (vala_pointer_type_get_base_type (self), target_type);
 		return result;
 	}
@@ -431,22 +412,25 @@ static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataT
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static ValaSymbol* vala_pointer_type_real_get_pointer_member (ValaDataType* base, const char* member_name) {
 	ValaPointerType * self;
 	ValaSymbol* result;
-	ValaSymbol* _tmp0_;
 	ValaSymbol* base_symbol;
 	self = (ValaPointerType*) base;
 	g_return_val_if_fail (member_name != NULL, NULL);
-	_tmp0_ = NULL;
-	base_symbol = (_tmp0_ = (ValaSymbol*) vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	base_symbol = _vala_code_node_ref0 ((ValaSymbol*) vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)));
 	if (base_symbol == NULL) {
 		result = NULL;
-		(base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL));
+		_vala_code_node_unref0 (base_symbol);
 		return result;
 	}
 	result = vala_semantic_analyzer_symbol_lookup_inherited (base_symbol, member_name);
-	(base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL));
+	_vala_code_node_unref0 (base_symbol);
 	return result;
 }
 
@@ -517,12 +501,9 @@ ValaDataType* vala_pointer_type_get_base_type (ValaPointerType* self) {
 
 
 void vala_pointer_type_set_base_type (ValaPointerType* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_base_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)), _tmp1_);
+	self->priv->_base_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_base_type), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_base_type, (ValaCodeNode*) self);
 }
 
@@ -553,7 +534,7 @@ static void vala_pointer_type_instance_init (ValaPointerType * self) {
 static void vala_pointer_type_finalize (ValaCodeNode* obj) {
 	ValaPointerType * self;
 	self = VALA_POINTER_TYPE (obj);
-	(self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL));
+	_vala_code_node_unref0 (self->priv->_base_type);
 	VALA_CODE_NODE_CLASS (vala_pointer_type_parent_class)->finalize (obj);
 }
 
