@@ -1,6 +1,6 @@
 /* valapostfixexpression.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -119,6 +119,7 @@ typedef struct _ValaExpressionPrivate ValaExpressionPrivate;
 typedef struct _ValaPostfixExpression ValaPostfixExpression;
 typedef struct _ValaPostfixExpressionClass ValaPostfixExpressionClass;
 typedef struct _ValaPostfixExpressionPrivate ValaPostfixExpressionPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -130,12 +131,47 @@ typedef struct _ValaPostfixExpressionPrivate ValaPostfixExpressionPrivate;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
+#define VALA_TYPE_MEMBER_ACCESS (vala_member_access_get_type ())
+#define VALA_MEMBER_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccess))
+#define VALA_MEMBER_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccessClass))
+#define VALA_IS_MEMBER_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_MEMBER_ACCESS))
+#define VALA_IS_MEMBER_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_MEMBER_ACCESS))
+#define VALA_MEMBER_ACCESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccessClass))
+
+typedef struct _ValaMemberAccess ValaMemberAccess;
+typedef struct _ValaMemberAccessClass ValaMemberAccessClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+
+#define VALA_TYPE_MEMBER (vala_member_get_type ())
+#define VALA_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_MEMBER, ValaMember))
+#define VALA_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_MEMBER, ValaMemberClass))
+#define VALA_IS_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_MEMBER))
+#define VALA_IS_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_MEMBER))
+#define VALA_MEMBER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_MEMBER, ValaMemberClass))
+
+typedef struct _ValaMember ValaMember;
+typedef struct _ValaMemberClass ValaMemberClass;
+
+#define VALA_TYPE_PROPERTY (vala_property_get_type ())
+#define VALA_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_PROPERTY, ValaProperty))
+#define VALA_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_PROPERTY, ValaPropertyClass))
+#define VALA_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_PROPERTY))
+#define VALA_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PROPERTY))
+#define VALA_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PROPERTY, ValaPropertyClass))
+
+typedef struct _ValaProperty ValaProperty;
+typedef struct _ValaPropertyClass ValaPropertyClass;
+
+#define VALA_TYPE_PROPERTY_ACCESSOR (vala_property_accessor_get_type ())
+#define VALA_PROPERTY_ACCESSOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessor))
+#define VALA_PROPERTY_ACCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorClass))
+#define VALA_IS_PROPERTY_ACCESSOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_PROPERTY_ACCESSOR))
+#define VALA_IS_PROPERTY_ACCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PROPERTY_ACCESSOR))
+#define VALA_PROPERTY_ACCESSOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorClass))
+
+typedef struct _ValaPropertyAccessor ValaPropertyAccessor;
+typedef struct _ValaPropertyAccessorClass ValaPropertyAccessorClass;
+
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -156,9 +192,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -172,9 +205,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Represents a postfix increment or decrement expression.
- */
 struct _ValaPostfixExpression {
 	ValaExpression parent_instance;
 	ValaPostfixExpressionPrivate * priv;
@@ -215,6 +245,7 @@ GType vala_postfix_expression_get_type (void);
 enum  {
 	VALA_POSTFIX_EXPRESSION_DUMMY_PROPERTY
 };
+ValaExpression* vala_expression_construct (GType object_type);
 void vala_postfix_expression_set_inner (ValaPostfixExpression* self, ValaExpression* value);
 void vala_postfix_expression_set_increment (ValaPostfixExpression* self, gboolean value);
 gpointer vala_source_reference_ref (gpointer instance);
@@ -236,7 +267,19 @@ gboolean vala_code_node_get_checked (ValaCodeNode* self);
 gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
+void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 ValaDataType* vala_expression_get_value_type (ValaExpression* self);
+void vala_report_error (ValaSourceReference* source, const char* message);
+ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
+GType vala_member_access_get_type (void);
+gboolean vala_member_access_get_prototype_access (ValaMemberAccess* self);
+ValaSymbol* vala_expression_get_symbol_reference (ValaExpression* self);
+char* vala_symbol_get_full_name (ValaSymbol* self);
+GType vala_member_get_type (void);
+GType vala_property_get_type (void);
+GType vala_property_accessor_get_type (void);
+ValaPropertyAccessor* vala_property_get_set_accessor (ValaProperty* self);
+gboolean vala_property_accessor_get_writable (ValaPropertyAccessor* self);
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_postfix_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 gboolean vala_postfix_expression_get_increment (ValaPostfixExpression* self);
@@ -244,19 +287,11 @@ static void vala_postfix_expression_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new postfix expression.
- *
- * @param inner  operand expression
- * @param inc    true for increment, false for decrement
- * @param source reference to source code
- * @return newly created postfix expression
- */
 ValaPostfixExpression* vala_postfix_expression_construct (GType object_type, ValaExpression* _inner, gboolean inc, ValaSourceReference* source) {
 	ValaPostfixExpression* self;
 	g_return_val_if_fail (_inner != NULL, NULL);
 	g_return_val_if_fail (source != NULL, NULL);
-	self = (ValaPostfixExpression*) g_type_create_instance (object_type);
+	self = (ValaPostfixExpression*) vala_expression_construct (object_type);
 	vala_postfix_expression_set_inner (self, _inner);
 	vala_postfix_expression_set_increment (self, inc);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
@@ -288,6 +323,11 @@ static gboolean vala_postfix_expression_real_is_pure (ValaExpression* base) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_postfix_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaPostfixExpression * self;
 	gboolean result;
@@ -298,7 +338,80 @@ static gboolean vala_postfix_expression_real_check (ValaCodeNode* base, ValaSema
 		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	vala_code_node_check ((ValaCodeNode*) self->priv->_inner, analyzer);
+	if (!vala_code_node_check ((ValaCodeNode*) self->priv->_inner, analyzer)) {
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		result = FALSE;
+		return result;
+	}
+	if (vala_expression_get_value_type (self->priv->_inner) == NULL) {
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "unsupported lvalue in postfix expression");
+		result = FALSE;
+		return result;
+	}
+	if (VALA_IS_MEMBER_ACCESS (self->priv->_inner)) {
+		ValaMemberAccess* ma;
+		gboolean _tmp2_;
+		ma = _vala_code_node_ref0 (VALA_MEMBER_ACCESS (self->priv->_inner));
+		if (vala_member_access_get_prototype_access (ma)) {
+			char* _tmp1_;
+			char* _tmp0_;
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp1_ = g_strdup_printf ("Access to instance member `%s' denied", _tmp0_ = vala_symbol_get_full_name (vala_expression_get_symbol_reference ((ValaExpression*) ma))));
+			_g_free0 (_tmp1_);
+			_g_free0 (_tmp0_);
+			result = FALSE;
+			_vala_code_node_unref0 (ma);
+			return result;
+		}
+		_tmp2_ = FALSE;
+		if (vala_code_node_get_error ((ValaCodeNode*) ma)) {
+			_tmp2_ = TRUE;
+		} else {
+			_tmp2_ = vala_expression_get_symbol_reference ((ValaExpression*) ma) == NULL;
+		}
+		if (_tmp2_) {
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			result = FALSE;
+			_vala_code_node_unref0 (ma);
+			return result;
+		}
+		_vala_code_node_unref0 (ma);
+	} else {
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "unsupported lvalue in postfix expression");
+		result = FALSE;
+		return result;
+	}
+	if (VALA_IS_MEMBER_ACCESS (self->priv->_inner)) {
+		ValaMemberAccess* ma;
+		ma = _vala_code_node_ref0 (VALA_MEMBER_ACCESS (self->priv->_inner));
+		if (VALA_IS_PROPERTY (vala_expression_get_symbol_reference ((ValaExpression*) ma))) {
+			ValaProperty* prop;
+			gboolean _tmp3_;
+			prop = _vala_code_node_ref0 (VALA_PROPERTY (vala_expression_get_symbol_reference ((ValaExpression*) ma)));
+			_tmp3_ = FALSE;
+			if (vala_property_get_set_accessor (prop) == NULL) {
+				_tmp3_ = TRUE;
+			} else {
+				_tmp3_ = !vala_property_accessor_get_writable (vala_property_get_set_accessor (prop));
+			}
+			if (_tmp3_) {
+				char* _tmp5_;
+				char* _tmp4_;
+				vala_code_node_set_error ((ValaCodeNode*) ma, TRUE);
+				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) ma), _tmp5_ = g_strdup_printf ("Property `%s' is read-only", _tmp4_ = vala_symbol_get_full_name ((ValaSymbol*) prop)));
+				_g_free0 (_tmp5_);
+				_g_free0 (_tmp4_);
+				result = FALSE;
+				_vala_code_node_unref0 (prop);
+				_vala_code_node_unref0 (ma);
+				return result;
+			}
+			_vala_code_node_unref0 (prop);
+		}
+		_vala_code_node_unref0 (ma);
+	}
 	vala_expression_set_value_type ((ValaExpression*) self, vala_expression_get_value_type (self->priv->_inner));
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
 	return result;
@@ -314,12 +427,9 @@ ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self)
 
 
 void vala_postfix_expression_set_inner (ValaPostfixExpression* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_inner = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp1_);
+	self->priv->_inner = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_inner), _tmp0_);
 }
 
 
@@ -355,7 +465,7 @@ static void vala_postfix_expression_instance_init (ValaPostfixExpression * self)
 static void vala_postfix_expression_finalize (ValaCodeNode* obj) {
 	ValaPostfixExpression * self;
 	self = VALA_POSTFIX_EXPRESSION (obj);
-	(self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL));
+	_vala_code_node_unref0 (self->priv->_inner);
 	VALA_CODE_NODE_CLASS (vala_postfix_expression_parent_class)->finalize (obj);
 }
 
