@@ -130,6 +130,7 @@ typedef struct _ValaLiteralPrivate ValaLiteralPrivate;
 typedef struct _ValaRealLiteral ValaRealLiteral;
 typedef struct _ValaRealLiteralClass ValaRealLiteralClass;
 typedef struct _ValaRealLiteralPrivate ValaRealLiteralPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -902,13 +903,8 @@ typedef struct _ValaScopeClass ValaScopeClass;
 
 typedef struct _ValaFloatingType ValaFloatingType;
 typedef struct _ValaFloatingTypeClass ValaFloatingTypeClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -929,9 +925,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -945,9 +938,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Base class for all literals in the source code.
- */
 struct _ValaLiteral {
 	ValaExpression parent_instance;
 	ValaLiteralPrivate * priv;
@@ -957,9 +947,6 @@ struct _ValaLiteralClass {
 	ValaExpressionClass parent_class;
 };
 
-/**
- * Represents a real literal in the source code.
- */
 struct _ValaRealLiteral {
 	ValaLiteral parent_instance;
 	ValaRealLiteralPrivate * priv;
@@ -973,9 +960,6 @@ struct _ValaRealLiteralPrivate {
 	char* _value;
 };
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -1062,17 +1046,12 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Code visitor analyzing and checking code.
- */
 struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 	ValaSymbol* root_symbol;
-	ValaDataType* current_return_type;
-	ValaClass* current_class;
-	ValaStruct* current_struct;
 	ValaBlock* insert_block;
+	ValaDataType* void_type;
 	ValaDataType* bool_type;
 	ValaDataType* string_type;
 	ValaDataType* uchar_type;
@@ -1130,6 +1109,7 @@ GType vala_real_literal_get_type (void);
 enum  {
 	VALA_REAL_LITERAL_DUMMY_PROPERTY
 };
+ValaLiteral* vala_literal_construct (GType object_type);
 void vala_real_literal_set_value (ValaRealLiteral* self, const char* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -1246,18 +1226,11 @@ static void vala_real_literal_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new real literal.
- *
- * @param r      literal value
- * @param source reference to source code
- * @return       newly created real literal
- */
 ValaRealLiteral* vala_real_literal_construct (GType object_type, const char* r, ValaSourceReference* source) {
 	ValaRealLiteral* self;
 	g_return_val_if_fail (r != NULL, NULL);
 	g_return_val_if_fail (source != NULL, NULL);
-	self = (ValaRealLiteral*) g_type_create_instance (object_type);
+	self = (ValaRealLiteral*) vala_literal_construct (object_type);
 	vala_real_literal_set_value (self, r);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
@@ -1278,11 +1251,6 @@ static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 }
 
 
-/**
- * Returns the type name of the value this literal represents.
- *
- * @return the name of literal type
- */
 char* vala_real_literal_get_type_name (ValaRealLiteral* self) {
 	char* result;
 	gboolean _tmp0_;
@@ -1314,10 +1282,8 @@ static gboolean vala_real_literal_real_is_pure (ValaExpression* base) {
 static char* vala_real_literal_real_to_string (ValaCodeNode* base) {
 	ValaRealLiteral * self;
 	char* result;
-	const char* _tmp0_;
 	self = (ValaRealLiteral*) base;
-	_tmp0_ = NULL;
-	result = (_tmp0_ = self->priv->_value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = g_strdup (self->priv->_value);
 	return result;
 }
 
@@ -1335,13 +1301,10 @@ static gboolean vala_real_literal_real_check (ValaCodeNode* base, ValaSemanticAn
 		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
 	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp2_ = vala_floating_type_new (_tmp1_ = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), _tmp0_ = vala_real_literal_get_type_name (self))))));
-	(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
-	(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL));
-	_tmp0_ = (g_free (_tmp0_), NULL);
+	_vala_code_node_unref0 (_tmp2_);
+	_vala_code_node_unref0 (_tmp1_);
+	_g_free0 (_tmp0_);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
 	return result;
 }
@@ -1356,12 +1319,9 @@ const char* vala_real_literal_get_value (ValaRealLiteral* self) {
 
 
 void vala_real_literal_set_value (ValaRealLiteral* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_value = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_value = (g_free (self->priv->_value), NULL), _tmp1_);
+	self->priv->_value = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_value), _tmp0_);
 }
 
 
@@ -1384,7 +1344,7 @@ static void vala_real_literal_instance_init (ValaRealLiteral * self) {
 static void vala_real_literal_finalize (ValaCodeNode* obj) {
 	ValaRealLiteral * self;
 	self = VALA_REAL_LITERAL (obj);
-	self->priv->_value = (g_free (self->priv->_value), NULL);
+	_g_free0 (self->priv->_value);
 	VALA_CODE_NODE_CLASS (vala_real_literal_parent_class)->finalize (obj);
 }
 
