@@ -58,6 +58,8 @@ typedef struct _ValaCodeNodeClass ValaCodeNodeClass;
 
 typedef struct _ValaSymbol ValaSymbol;
 typedef struct _ValaSymbolClass ValaSymbolClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -68,11 +70,9 @@ typedef struct _ValaSymbolClass ValaSymbolClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 typedef struct _ValaParamSpecScope ValaParamSpecScope;
 
-/**
- * Represents a part of the symbol tree.
- */
 struct _ValaScope {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -96,6 +96,7 @@ struct _ValaParamSpecScope {
 };
 
 
+static gpointer vala_scope_parent_class = NULL;
 
 gpointer vala_scope_ref (gpointer instance);
 void vala_scope_unref (gpointer instance);
@@ -117,7 +118,6 @@ enum  {
 void vala_scope_set_owner (ValaScope* self, ValaSymbol* value);
 ValaScope* vala_scope_new (ValaSymbol* owner);
 ValaScope* vala_scope_construct (GType object_type, ValaSymbol* owner);
-ValaScope* vala_scope_new (ValaSymbol* owner);
 ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 ValaSymbol* vala_scope_get_owner (ValaScope* self);
@@ -138,16 +138,10 @@ ValaScope* vala_scope_get_parent_scope (ValaScope* self);
 gboolean vala_scope_is_subscope_of (ValaScope* self, ValaScope* scope);
 GeeMap* vala_scope_get_symbol_table (ValaScope* self);
 void vala_scope_set_parent_scope (ValaScope* self, ValaScope* value);
-static gpointer vala_scope_parent_class = NULL;
 static void vala_scope_finalize (ValaScope* obj);
 
 
 
-/**
- * Creates a new scope.
- *
- * @return newly created scope
- */
 ValaScope* vala_scope_construct (GType object_type, ValaSymbol* owner) {
 	ValaScope* self;
 	self = (ValaScope*) g_type_create_instance (object_type);
@@ -161,34 +155,23 @@ ValaScope* vala_scope_new (ValaSymbol* owner) {
 }
 
 
-/**
- * Adds the specified symbol with the specified name to the symbol table
- * of this scope.
- *
- * @param name name for the specified symbol
- * @param sym  a symbol
- */
 void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (sym != NULL);
 	if (name != NULL) {
 		if (self->priv->symbol_table == NULL) {
 			GeeMap* _tmp0_;
-			_tmp0_ = NULL;
-			self->priv->symbol_table = (_tmp0_ = (GeeMap*) gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_str_hash, g_str_equal, g_direct_equal), (self->priv->symbol_table == NULL) ? NULL : (self->priv->symbol_table = (gee_collection_object_unref (self->priv->symbol_table), NULL)), _tmp0_);
+			self->priv->symbol_table = (_tmp0_ = (GeeMap*) gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_str_hash, g_str_equal, g_direct_equal), _gee_collection_object_unref0 (self->priv->symbol_table), _tmp0_);
 		} else {
 			ValaSymbol* _tmp1_;
 			gboolean _tmp2_;
-			_tmp1_ = NULL;
-			if ((_tmp2_ = (_tmp1_ = vala_scope_lookup (self, name)) != NULL, (_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL)), _tmp2_)) {
+			if ((_tmp2_ = (_tmp1_ = vala_scope_lookup (self, name)) != NULL, _vala_code_node_unref0 (_tmp1_), _tmp2_)) {
 				char* _tmp4_;
 				char* _tmp3_;
 				vala_code_node_set_error ((ValaCodeNode*) self->priv->_owner, TRUE);
-				_tmp4_ = NULL;
-				_tmp3_ = NULL;
 				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) sym), _tmp4_ = g_strdup_printf ("`%s' already contains a definition for `%s'", _tmp3_ = vala_symbol_get_full_name (self->priv->_owner), name));
-				_tmp4_ = (g_free (_tmp4_), NULL);
-				_tmp3_ = (g_free (_tmp3_), NULL);
+				_g_free0 (_tmp4_);
+				_g_free0 (_tmp3_);
 				return;
 			}
 		}
@@ -196,8 +179,7 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 	} else {
 		if (self->priv->anonymous_members == NULL) {
 			GeeList* _tmp5_;
-			_tmp5_ = NULL;
-			self->priv->anonymous_members = (_tmp5_ = (GeeList*) gee_array_list_new (VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal), (self->priv->anonymous_members == NULL) ? NULL : (self->priv->anonymous_members = (gee_collection_object_unref (self->priv->anonymous_members), NULL)), _tmp5_);
+			self->priv->anonymous_members = (_tmp5_ = (GeeList*) gee_array_list_new (VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal), _gee_collection_object_unref0 (self->priv->anonymous_members), _tmp5_);
 		}
 		gee_collection_add ((GeeCollection*) self->priv->anonymous_members, sym);
 	}
@@ -212,69 +194,65 @@ void vala_scope_remove (ValaScope* self, const char* name) {
 }
 
 
-/**
- * Returns the symbol stored in the symbol table with the specified
- * name.
- *
- * @param name name of the symbol to be returned
- * @return     found symbol or null
- */
 ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name) {
+	ValaSymbol* result;
 	ValaSymbol* sym;
-	gboolean _tmp1_;
+	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	if (self->priv->symbol_table == NULL) {
-		return NULL;
+		result = NULL;
+		return result;
 	}
 	sym = (ValaSymbol*) gee_map_get (self->priv->symbol_table, name);
-	_tmp1_ = FALSE;
+	_tmp0_ = FALSE;
 	if (sym != NULL) {
-		_tmp1_ = !vala_symbol_get_active (sym);
+		_tmp0_ = !vala_symbol_get_active (sym);
 	} else {
-		_tmp1_ = FALSE;
+		_tmp0_ = FALSE;
 	}
-	if (_tmp1_) {
-		ValaSymbol* _tmp2_;
-		_tmp2_ = NULL;
-		sym = (_tmp2_ = NULL, (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp2_);
+	if (_tmp0_) {
+		ValaSymbol* _tmp1_;
+		sym = (_tmp1_ = NULL, _vala_code_node_unref0 (sym), _tmp1_);
 	}
-	return sym;
+	result = sym;
+	return result;
 }
 
 
-/**
- * Returns whether the specified scope is an ancestor of this scope.
- *
- * @param scope a scope or null for the root scope
- * @return      true if this scope is a subscope of the specified
- *              scope, false otherwise
- */
 gboolean vala_scope_is_subscope_of (ValaScope* self, ValaScope* scope) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	if (scope == self) {
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
-	/* null scope is the root scope*/
 	if (scope == NULL) {
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
 	if (self->priv->_parent_scope != NULL) {
-		return vala_scope_is_subscope_of (self->priv->_parent_scope, scope);
+		result = vala_scope_is_subscope_of (self->priv->_parent_scope, scope);
+		return result;
 	}
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
 GeeMap* vala_scope_get_symbol_table (ValaScope* self) {
+	GeeMap* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeMap*) gee_read_only_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->symbol_table);
+	result = (GeeMap*) gee_read_only_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->symbol_table);
+	return result;
 }
 
 
 ValaSymbol* vala_scope_get_owner (ValaScope* self) {
+	ValaSymbol* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_owner;
+	result = self->priv->_owner;
+	return result;
 }
 
 
@@ -285,8 +263,10 @@ void vala_scope_set_owner (ValaScope* self, ValaSymbol* value) {
 
 
 ValaScope* vala_scope_get_parent_scope (ValaScope* self) {
+	ValaScope* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_parent_scope;
+	result = self->priv->_parent_scope;
+	return result;
 }
 
 
@@ -405,8 +385,8 @@ static void vala_scope_instance_init (ValaScope * self) {
 static void vala_scope_finalize (ValaScope* obj) {
 	ValaScope * self;
 	self = VALA_SCOPE (obj);
-	(self->priv->symbol_table == NULL) ? NULL : (self->priv->symbol_table = (gee_collection_object_unref (self->priv->symbol_table), NULL));
-	(self->priv->anonymous_members == NULL) ? NULL : (self->priv->anonymous_members = (gee_collection_object_unref (self->priv->anonymous_members), NULL));
+	_gee_collection_object_unref0 (self->priv->symbol_table);
+	_gee_collection_object_unref0 (self->priv->anonymous_members);
 }
 
 
