@@ -162,6 +162,19 @@ typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
 typedef struct _ValaMethod ValaMethod;
 typedef struct _ValaMethodClass ValaMethodClass;
 
+#define VALA_TYPE_BLOCK (vala_block_get_type ())
+#define VALA_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_BLOCK, ValaBlock))
+#define VALA_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_BLOCK, ValaBlockClass))
+#define VALA_IS_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_BLOCK))
+#define VALA_IS_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_BLOCK))
+#define VALA_BLOCK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_BLOCK, ValaBlockClass))
+
+typedef struct _ValaBlock ValaBlock;
+typedef struct _ValaBlockClass ValaBlockClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
+
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
 #define VALA_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
@@ -172,6 +185,16 @@ typedef struct _ValaMethodClass ValaMethodClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+
 #define VALA_TYPE_SCOPE (vala_scope_get_type ())
 #define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
 #define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
@@ -182,6 +205,16 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaScope ValaScope;
 typedef struct _ValaScopeClass ValaScopeClass;
 
+#define VALA_TYPE_MEMBER_ACCESS (vala_member_access_get_type ())
+#define VALA_MEMBER_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccess))
+#define VALA_MEMBER_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccessClass))
+#define VALA_IS_MEMBER_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_MEMBER_ACCESS))
+#define VALA_IS_MEMBER_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_MEMBER_ACCESS))
+#define VALA_MEMBER_ACCESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccessClass))
+
+typedef struct _ValaMemberAccess ValaMemberAccess;
+typedef struct _ValaMemberAccessClass ValaMemberAccessClass;
+
 #define VALA_TYPE_TYPESYMBOL (vala_typesymbol_get_type ())
 #define VALA_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))
 #define VALA_TYPESYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolClass))
@@ -203,13 +236,28 @@ typedef struct _ValaDelegate ValaDelegate;
 typedef struct _ValaDelegateClass ValaDelegateClass;
 
 #define VALA_TYPE_SYMBOL_ACCESSIBILITY (vala_symbol_accessibility_get_type ())
+#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
+
+#define VALA_TYPE_OBJECT_TYPE_SYMBOL (vala_object_type_symbol_get_type ())
+#define VALA_OBJECT_TYPE_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_OBJECT_TYPE_SYMBOL, ValaObjectTypeSymbol))
+#define VALA_OBJECT_TYPE_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_OBJECT_TYPE_SYMBOL, ValaObjectTypeSymbolClass))
+#define VALA_IS_OBJECT_TYPE_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_OBJECT_TYPE_SYMBOL))
+#define VALA_IS_OBJECT_TYPE_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_OBJECT_TYPE_SYMBOL))
+#define VALA_OBJECT_TYPE_SYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_OBJECT_TYPE_SYMBOL, ValaObjectTypeSymbolClass))
+
+typedef struct _ValaObjectTypeSymbol ValaObjectTypeSymbol;
+typedef struct _ValaObjectTypeSymbolClass ValaObjectTypeSymbolClass;
+
+#define VALA_TYPE_CLASS (vala_class_get_type ())
+#define VALA_CLASS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CLASS, ValaClass))
+#define VALA_CLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CLASS, ValaClassClass))
+#define VALA_IS_CLASS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CLASS))
+#define VALA_IS_CLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CLASS))
+#define VALA_CLASS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CLASS, ValaClassClass))
+
+typedef struct _ValaClass ValaClass;
+typedef struct _ValaClassClass ValaClassClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -230,9 +278,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -244,11 +289,10 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a general class member.
- */
 struct _ValaMember {
 	ValaSymbol parent_instance;
 	ValaMemberPrivate * priv;
@@ -258,18 +302,12 @@ struct _ValaMemberClass {
 	ValaSymbolClass parent_class;
 };
 
-/**
- * Represents a lockable object.
- */
 struct _ValaLockableIface {
 	GTypeInterface parent_iface;
 	gboolean (*get_lock_used) (ValaLockable* self);
 	void (*set_lock_used) (ValaLockable* self, gboolean used);
 };
 
-/**
- * Represents an object signal. Signals enable objects to provide notifications.
- */
 struct _ValaSignal {
 	ValaMember parent_instance;
 	ValaSignalPrivate * priv;
@@ -283,10 +321,11 @@ struct _ValaSignalPrivate {
 	gboolean _has_emitter;
 	gboolean _is_virtual;
 	GeeList* parameters;
-	ValaMethod* generated_method;
+	ValaMethod* _default_handler;
 	char* cname;
 	gboolean lock_used;
 	ValaDataType* _return_type;
+	ValaBlock* _body;
 };
 
 typedef enum  {
@@ -297,6 +336,8 @@ typedef enum  {
 } ValaSymbolAccessibility;
 
 
+static gpointer vala_signal_parent_class = NULL;
+static ValaLockableIface* vala_signal_vala_lockable_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -321,6 +362,7 @@ GType vala_lockable_get_type (void);
 GType vala_signal_get_type (void);
 GType vala_formal_parameter_get_type (void);
 GType vala_method_get_type (void);
+GType vala_block_get_type (void);
 #define VALA_SIGNAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SIGNAL, ValaSignalPrivate))
 enum  {
 	VALA_SIGNAL_DUMMY_PROPERTY
@@ -331,12 +373,16 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaMember* vala_member_new (const char* name, ValaSourceReference* source_reference);
-ValaMember* vala_member_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
+ValaMember* vala_member_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
 void vala_signal_set_return_type (ValaSignal* self, ValaDataType* value);
-ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaSignal* vala_signal_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
+ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
+ValaSignal* vala_signal_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
 void vala_formal_parameter_set_cparameter_position (ValaFormalParameter* self, double value);
 double vala_formal_parameter_get_cparameter_position (ValaFormalParameter* self);
 void vala_formal_parameter_set_carray_length_parameter_position (ValaFormalParameter* self, double value);
@@ -353,9 +399,10 @@ const char* vala_symbol_get_name (ValaSymbol* self);
 void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param);
 GeeList* vala_signal_get_parameters (ValaSignal* self);
 ValaDataType* vala_signal_get_return_type (ValaSignal* self);
-ValaDataType* vala_data_type_get_actual_type (ValaDataType* self, ValaDataType* derived_instance_type, ValaCodeNode* node_reference);
-ValaDelegate* vala_delegate_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaDelegate* vala_delegate_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
+GType vala_member_access_get_type (void);
+ValaDataType* vala_data_type_get_actual_type (ValaDataType* self, ValaDataType* derived_instance_type, ValaMemberAccess* method_access, ValaCodeNode* node_reference);
+ValaDelegate* vala_delegate_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
+ValaDelegate* vala_delegate_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
 GType vala_typesymbol_get_type (void);
 GType vala_delegate_get_type (void);
 void vala_delegate_set_has_target (ValaDelegate* self, gboolean value);
@@ -379,6 +426,7 @@ void vala_code_visitor_visit_member (ValaCodeVisitor* self, ValaMember* m);
 void vala_code_visitor_visit_signal (ValaCodeVisitor* self, ValaSignal* sig);
 static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
+ValaMethod* vala_signal_get_default_handler (ValaSignal* self);
 static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 const char* vala_attribute_get_name (ValaAttribute* self);
 void vala_signal_set_has_emitter (ValaSignal* self, gboolean value);
@@ -386,64 +434,58 @@ void vala_signal_process_attributes (ValaSignal* self);
 static gboolean vala_signal_real_get_lock_used (ValaLockable* base);
 static void vala_signal_real_set_lock_used (ValaLockable* base, gboolean used);
 static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
-gboolean vala_signal_get_is_virtual (ValaSignal* self);
-ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
-ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self);
-void vala_method_set_is_virtual (ValaMethod* self, gboolean value);
-void vala_method_set_vfunc_name (ValaMethod* self, const char* value);
-void vala_method_set_signal_reference (ValaMethod* self, ValaSignal* value);
-void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param);
-ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self);
-ValaMethod* vala_signal_get_method_handler (ValaSignal* self);
 gboolean vala_code_node_get_checked (ValaCodeNode* self);
 gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
+gboolean vala_signal_get_is_virtual (ValaSignal* self);
+ValaBlock* vala_signal_get_body (ValaSignal* self);
+void vala_report_error (ValaSourceReference* source, const char* message);
+ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
+ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
+ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
+static void vala_signal_set_default_handler (ValaSignal* self, ValaMethod* value);
+ValaScope* vala_symbol_get_owner (ValaSymbol* self);
+ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self);
+gboolean vala_symbol_get_external (ValaSymbol* self);
+void vala_symbol_set_external (ValaSymbol* self, gboolean value);
+void vala_method_set_is_virtual (ValaMethod* self, gboolean value);
+void vala_method_set_vfunc_name (ValaMethod* self, const char* value);
+void vala_method_set_signal_reference (ValaMethod* self, ValaSignal* value);
+void vala_method_set_body (ValaMethod* self, ValaBlock* value);
+void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param);
+ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self);
+GType vala_object_type_symbol_get_type (void);
+GType vala_class_get_type (void);
+void vala_class_add_hidden_method (ValaClass* self, ValaMethod* m);
 static gboolean vala_signal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
+void vala_signal_set_body (ValaSignal* self, ValaBlock* value);
 gboolean vala_signal_get_has_emitter (ValaSignal* self);
 void vala_signal_set_is_virtual (ValaSignal* self, gboolean value);
-static gpointer vala_signal_parent_class = NULL;
-static ValaLockableIface* vala_signal_vala_lockable_parent_iface = NULL;
 static void vala_signal_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-/**
- * Creates a new signal.
- *
- * @param name        signal name
- * @param return_type signal return type
- * @param source      reference to source code
- * @return            newly created signal
- */
-ValaSignal* vala_signal_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
+ValaSignal* vala_signal_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment) {
 	ValaSignal* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (return_type != NULL, NULL);
-	self = (ValaSignal*) vala_member_construct (object_type, name, source_reference);
+	self = (ValaSignal*) vala_member_construct (object_type, name, source_reference, comment);
 	vala_signal_set_return_type (self, return_type);
 	return self;
 }
 
 
-ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
-	return vala_signal_construct (VALA_TYPE_SIGNAL, name, return_type, source_reference);
+ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment) {
+	return vala_signal_construct (VALA_TYPE_SIGNAL, name, return_type, source_reference, comment);
 }
 
 
-/**
- * Appends parameter to signal handler.
- *
- * @param param a formal parameter
- */
 void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (param != NULL);
-	/* default C parameter position*/
 	vala_formal_parameter_set_cparameter_position (param, (double) (gee_collection_get_size ((GeeCollection*) self->priv->parameters) + 1));
 	vala_formal_parameter_set_carray_length_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
 	vala_formal_parameter_set_cdelegate_target_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
@@ -453,30 +495,26 @@ void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param) {
 
 
 GeeList* vala_signal_get_parameters (ValaSignal* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->parameters);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->parameters);
+	return result;
 }
 
 
-/**
- * Returns generated delegate to be used for signal handlers.
- *
- * @return delegate
- */
 ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_type, ValaCodeNode* node_reference) {
+	ValaDelegate* result;
 	ValaDataType* actual_return_type;
 	ValaDelegate* generated_delegate;
 	ValaDataType* sender_param_type;
-	ValaDelegate* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (sender_type != NULL, NULL);
 	g_return_val_if_fail (node_reference != NULL, NULL);
-	actual_return_type = vala_data_type_get_actual_type (vala_signal_get_return_type (self), sender_type, node_reference);
-	generated_delegate = vala_delegate_new (NULL, actual_return_type, NULL);
+	actual_return_type = vala_data_type_get_actual_type (vala_signal_get_return_type (self), sender_type, NULL, node_reference);
+	generated_delegate = vala_delegate_new (NULL, actual_return_type, NULL, NULL);
 	vala_delegate_set_has_target (generated_delegate, TRUE);
 	vala_symbol_set_access ((ValaSymbol*) generated_delegate, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 	vala_symbol_set_owner ((ValaSymbol*) generated_delegate, vala_symbol_get_scope ((ValaSymbol*) self));
-	/* sender parameter is never null and doesn't own its value*/
 	sender_param_type = vala_data_type_copy (sender_type);
 	vala_data_type_set_value_owned (sender_param_type, FALSE);
 	vala_data_type_set_nullable (sender_param_type, FALSE);
@@ -484,89 +522,81 @@ ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_t
 	{
 		GeeIterator* _param_it;
 		_param_it = gee_iterable_iterator ((GeeIterable*) self->priv->parameters);
-		while (gee_iterator_next (_param_it)) {
+		while (TRUE) {
 			ValaFormalParameter* param;
 			ValaFormalParameter* actual_param;
 			ValaDataType* _tmp0_;
+			if (!gee_iterator_next (_param_it)) {
+				break;
+			}
 			param = (ValaFormalParameter*) gee_iterator_get (_param_it);
 			actual_param = vala_formal_parameter_copy (param);
-			_tmp0_ = NULL;
-			vala_formal_parameter_set_parameter_type (actual_param, _tmp0_ = vala_data_type_get_actual_type (vala_formal_parameter_get_parameter_type (actual_param), sender_type, node_reference));
-			(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+			vala_formal_parameter_set_parameter_type (actual_param, _tmp0_ = vala_data_type_get_actual_type (vala_formal_parameter_get_parameter_type (actual_param), sender_type, NULL, node_reference));
+			_vala_code_node_unref0 (_tmp0_);
 			vala_delegate_add_parameter (generated_delegate, actual_param);
-			(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
-			(actual_param == NULL) ? NULL : (actual_param = (vala_code_node_unref (actual_param), NULL));
+			_vala_code_node_unref0 (param);
+			_vala_code_node_unref0 (actual_param);
 		}
-		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
+		_gee_collection_object_unref0 (_param_it);
 	}
 	vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), NULL, (ValaSymbol*) generated_delegate);
-	_tmp1_ = NULL;
-	return (_tmp1_ = generated_delegate, (actual_return_type == NULL) ? NULL : (actual_return_type = (vala_code_node_unref (actual_return_type), NULL)), (sender_param_type == NULL) ? NULL : (sender_param_type = (vala_code_node_unref (sender_param_type), NULL)), _tmp1_);
+	result = generated_delegate;
+	_vala_code_node_unref0 (actual_return_type);
+	_vala_code_node_unref0 (sender_param_type);
+	return result;
 }
 
 
-/**
- * Returns the name of this signal as it is used in C code.
- *
- * @return the name to be used in C code
- */
 char* vala_signal_get_cname (ValaSignal* self) {
-	const char* _tmp1_;
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->cname == NULL) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
-		self->priv->cname = (_tmp0_ = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
+		self->priv->cname = (_tmp0_ = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self)), _g_free0 (self->priv->cname), _tmp0_);
 	}
-	_tmp1_ = NULL;
-	return (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	result = g_strdup (self->priv->cname);
+	return result;
 }
 
 
 void vala_signal_set_cname (ValaSignal* self, const char* cname) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (cname != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->cname = (_tmp1_ = (_tmp0_ = cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1_);
+	self->priv->cname = (_tmp0_ = g_strdup (cname), _g_free0 (self->priv->cname), _tmp0_);
 }
 
 
-/**
- * Returns the string literal of this signal to be used in C code.
- *
- * @return string literal to be used in C code
- */
 ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self, const char* detail) {
+	ValaCCodeConstant* result;
 	GString* str;
 	char* i;
-	ValaCCodeConstant* _tmp2_;
 	g_return_val_if_fail (self != NULL, NULL);
 	str = g_string_new ("\"");
 	i = vala_signal_get_cname (self);
-	while (g_utf8_strlen (i, -1) > 0) {
+	while (TRUE) {
 		gunichar c;
-		char* _tmp1_;
-		const char* _tmp0_;
+		char* _tmp0_;
+		if (!(g_utf8_strlen (i, -1) > 0)) {
+			break;
+		}
 		c = g_utf8_get_char (i);
 		if (c == '_') {
 			g_string_append_c (str, '-');
 		} else {
 			g_string_append_unichar (str, c);
 		}
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		i = (_tmp1_ = (_tmp0_ = g_utf8_next_char (i), (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), i = (g_free (i), NULL), _tmp1_);
+		i = (_tmp0_ = g_strdup (g_utf8_next_char (i)), _g_free0 (i), _tmp0_);
 	}
 	if (detail != NULL) {
 		g_string_append (str, "::");
 		g_string_append (str, detail);
 	}
 	g_string_append_c (str, '"');
-	_tmp2_ = NULL;
-	return (_tmp2_ = vala_ccode_constant_new (str->str), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), i = (g_free (i), NULL), _tmp2_);
+	result = vala_ccode_constant_new (str->str);
+	_g_string_free0 (str);
+	_g_free0 (i);
+	return result;
 }
 
 
@@ -587,20 +617,28 @@ static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 	{
 		GeeIterator* _param_it;
 		_param_it = gee_iterable_iterator ((GeeIterable*) self->priv->parameters);
-		while (gee_iterator_next (_param_it)) {
+		while (TRUE) {
 			ValaFormalParameter* param;
+			if (!gee_iterator_next (_param_it)) {
+				break;
+			}
 			param = (ValaFormalParameter*) gee_iterator_get (_param_it);
 			vala_code_node_accept ((ValaCodeNode*) param, visitor);
-			(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
+			_vala_code_node_unref0 (param);
 		}
-		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
+		_gee_collection_object_unref0 (_param_it);
+	}
+	if (self->priv->_default_handler != NULL) {
+		vala_code_node_accept ((ValaCodeNode*) self->priv->_default_handler, visitor);
 	}
 }
 
 
-/**
- * Process all associated attributes.
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_signal_process_attributes (ValaSignal* self) {
 	g_return_if_fail (self != NULL);
 	{
@@ -608,15 +646,13 @@ void vala_signal_process_attributes (ValaSignal* self) {
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp0_;
 			ValaAttribute* a;
-			_tmp0_ = NULL;
-			a = (_tmp0_ = (ValaAttribute*) a_it->data, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+			a = _vala_code_node_ref0 ((ValaAttribute*) a_it->data);
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "HasEmitter") == 0) {
 					vala_signal_set_has_emitter (self, TRUE);
 				}
-				(a == NULL) ? NULL : (a = (vala_code_node_unref (a), NULL));
+				_vala_code_node_unref0 (a);
 			}
 		}
 	}
@@ -625,8 +661,10 @@ void vala_signal_process_attributes (ValaSignal* self) {
 
 static gboolean vala_signal_real_get_lock_used (ValaLockable* base) {
 	ValaSignal * self;
+	gboolean result;
 	self = (ValaSignal*) base;
-	return self->priv->lock_used;
+	result = self->priv->lock_used;
+	return result;
 }
 
 
@@ -648,42 +686,15 @@ static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old
 }
 
 
-ValaMethod* vala_signal_get_method_handler (ValaSignal* self) {
-	ValaMethod* _tmp1_;
-	g_return_val_if_fail (self != NULL, NULL);
-	g_assert (self->priv->_is_virtual);
-	if (self->priv->generated_method == NULL) {
-		ValaMethod* _tmp0_;
-		_tmp0_ = NULL;
-		self->priv->generated_method = (_tmp0_ = vala_method_new (vala_symbol_get_name ((ValaSymbol*) self), vala_signal_get_return_type (self), vala_code_node_get_source_reference ((ValaCodeNode*) self)), (self->priv->generated_method == NULL) ? NULL : (self->priv->generated_method = (vala_code_node_unref (self->priv->generated_method), NULL)), _tmp0_);
-		vala_symbol_set_access ((ValaSymbol*) self->priv->generated_method, vala_symbol_get_access ((ValaSymbol*) self));
-		vala_method_set_is_virtual (self->priv->generated_method, TRUE);
-		vala_method_set_vfunc_name (self->priv->generated_method, vala_symbol_get_name ((ValaSymbol*) self));
-		vala_method_set_signal_reference (self->priv->generated_method, self);
-		{
-			GeeIterator* _param_it;
-			_param_it = gee_iterable_iterator ((GeeIterable*) self->priv->parameters);
-			while (gee_iterator_next (_param_it)) {
-				ValaFormalParameter* param;
-				param = (ValaFormalParameter*) gee_iterator_get (_param_it);
-				vala_method_add_parameter (self->priv->generated_method, param);
-				(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
-			}
-			(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
-		}
-		vala_scope_add (vala_symbol_get_scope (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), NULL, (ValaSymbol*) self->priv->generated_method);
-	}
-	_tmp1_ = NULL;
-	return (_tmp1_ = self->priv->generated_method, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-}
-
-
 static gboolean vala_signal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaSignal * self;
+	gboolean result;
+	gboolean _tmp0_;
 	self = (ValaSignal*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_signal_process_attributes (self);
@@ -691,38 +702,102 @@ static gboolean vala_signal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer
 	{
 		GeeIterator* _param_it;
 		_param_it = gee_iterable_iterator ((GeeIterable*) self->priv->parameters);
-		while (gee_iterator_next (_param_it)) {
+		while (TRUE) {
 			ValaFormalParameter* param;
+			if (!gee_iterator_next (_param_it)) {
+				break;
+			}
 			param = (ValaFormalParameter*) gee_iterator_get (_param_it);
 			vala_code_node_check ((ValaCodeNode*) param, analyzer);
-			(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
+			_vala_code_node_unref0 (param);
 		}
-		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
+		_gee_collection_object_unref0 (_param_it);
 	}
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	_tmp0_ = FALSE;
+	if (!self->priv->_is_virtual) {
+		_tmp0_ = vala_signal_get_body (self) != NULL;
+	} else {
+		_tmp0_ = FALSE;
+	}
+	if (_tmp0_) {
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Only virtual signals can have a default signal handler body");
+	}
+	if (self->priv->_is_virtual) {
+		ValaMethod* _tmp1_;
+		ValaSymbol* _tmp2_;
+		ValaClass* cl;
+		vala_signal_set_default_handler (self, _tmp1_ = vala_method_new (vala_symbol_get_name ((ValaSymbol*) self), vala_signal_get_return_type (self), vala_code_node_get_source_reference ((ValaCodeNode*) self), NULL));
+		_vala_code_node_unref0 (_tmp1_);
+		vala_symbol_set_owner ((ValaSymbol*) self->priv->_default_handler, vala_symbol_get_owner ((ValaSymbol*) self));
+		vala_symbol_set_access ((ValaSymbol*) self->priv->_default_handler, vala_symbol_get_access ((ValaSymbol*) self));
+		vala_symbol_set_external ((ValaSymbol*) self->priv->_default_handler, vala_symbol_get_external ((ValaSymbol*) self));
+		vala_method_set_is_virtual (self->priv->_default_handler, TRUE);
+		vala_method_set_vfunc_name (self->priv->_default_handler, vala_symbol_get_name ((ValaSymbol*) self));
+		vala_method_set_signal_reference (self->priv->_default_handler, self);
+		vala_method_set_body (self->priv->_default_handler, vala_signal_get_body (self));
+		{
+			GeeIterator* _param_it;
+			_param_it = gee_iterable_iterator ((GeeIterable*) self->priv->parameters);
+			while (TRUE) {
+				ValaFormalParameter* param;
+				if (!gee_iterator_next (_param_it)) {
+					break;
+				}
+				param = (ValaFormalParameter*) gee_iterator_get (_param_it);
+				vala_method_add_parameter (self->priv->_default_handler, param);
+				_vala_code_node_unref0 (param);
+			}
+			_gee_collection_object_unref0 (_param_it);
+		}
+		cl = _vala_code_node_ref0 ((_tmp2_ = vala_symbol_get_parent_symbol ((ValaSymbol*) self), VALA_IS_CLASS (_tmp2_) ? ((ValaClass*) _tmp2_) : NULL));
+		vala_class_add_hidden_method (cl, self->priv->_default_handler);
+		vala_code_node_check ((ValaCodeNode*) self->priv->_default_handler, analyzer);
+		_vala_code_node_unref0 (cl);
+	}
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 ValaDataType* vala_signal_get_return_type (ValaSignal* self) {
+	ValaDataType* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_return_type;
+	result = self->priv->_return_type;
+	return result;
 }
 
 
 void vala_signal_set_return_type (ValaSignal* self, ValaDataType* value) {
-	ValaDataType* _tmp2_;
-	ValaDataType* _tmp1_;
+	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_return_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_return_type == NULL) ? NULL : (self->priv->_return_type = (vala_code_node_unref (self->priv->_return_type), NULL)), _tmp2_);
+	self->priv->_return_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_return_type), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_return_type, (ValaCodeNode*) self);
 }
 
 
+ValaBlock* vala_signal_get_body (ValaSignal* self) {
+	ValaBlock* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = self->priv->_body;
+	return result;
+}
+
+
+void vala_signal_set_body (ValaSignal* self, ValaBlock* value) {
+	ValaBlock* _tmp0_;
+	g_return_if_fail (self != NULL);
+	self->priv->_body = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_body), _tmp0_);
+	if (self->priv->_body != NULL) {
+		vala_symbol_set_owner ((ValaSymbol*) self->priv->_body, vala_symbol_get_scope ((ValaSymbol*) self));
+	}
+}
+
+
 gboolean vala_signal_get_has_emitter (ValaSignal* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_has_emitter;
+	result = self->priv->_has_emitter;
+	return result;
 }
 
 
@@ -733,8 +808,10 @@ void vala_signal_set_has_emitter (ValaSignal* self, gboolean value) {
 
 
 gboolean vala_signal_get_is_virtual (ValaSignal* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_is_virtual;
+	result = self->priv->_is_virtual;
+	return result;
 }
 
 
@@ -744,6 +821,21 @@ void vala_signal_set_is_virtual (ValaSignal* self, gboolean value) {
 }
 
 
+ValaMethod* vala_signal_get_default_handler (ValaSignal* self) {
+	ValaMethod* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = self->priv->_default_handler;
+	return result;
+}
+
+
+static void vala_signal_set_default_handler (ValaSignal* self, ValaMethod* value) {
+	ValaMethod* _tmp0_;
+	g_return_if_fail (self != NULL);
+	self->priv->_default_handler = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_default_handler), _tmp0_);
+}
+
+
 static void vala_signal_class_init (ValaSignalClass * klass) {
 	vala_signal_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->finalize = vala_signal_finalize;
@@ -772,10 +864,11 @@ static void vala_signal_instance_init (ValaSignal * self) {
 static void vala_signal_finalize (ValaCodeNode* obj) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (obj);
-	(self->priv->parameters == NULL) ? NULL : (self->priv->parameters = (gee_collection_object_unref (self->priv->parameters), NULL));
-	(self->priv->generated_method == NULL) ? NULL : (self->priv->generated_method = (vala_code_node_unref (self->priv->generated_method), NULL));
-	self->priv->cname = (g_free (self->priv->cname), NULL);
-	(self->priv->_return_type == NULL) ? NULL : (self->priv->_return_type = (vala_code_node_unref (self->priv->_return_type), NULL));
+	_gee_collection_object_unref0 (self->priv->parameters);
+	_vala_code_node_unref0 (self->priv->_default_handler);
+	_g_free0 (self->priv->cname);
+	_vala_code_node_unref0 (self->priv->_return_type);
+	_vala_code_node_unref0 (self->priv->_body);
 	VALA_CODE_NODE_CLASS (vala_signal_parent_class)->finalize (obj);
 }
 
