@@ -50,6 +50,16 @@ typedef struct _ValaSourceFilePrivate ValaSourceFilePrivate;
 typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+
 #define VALA_TYPE_CODE_NODE (vala_code_node_get_type ())
 #define VALA_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_NODE, ValaCodeNode))
 #define VALA_CODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
@@ -69,6 +79,9 @@ typedef struct _ValaCodeNodeClass ValaCodeNodeClass;
 
 typedef struct _ValaUsingDirective ValaUsingDirective;
 typedef struct _ValaUsingDirectiveClass ValaUsingDirectiveClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _g_mapped_file_free0(var) ((var == NULL) ? NULL : (var = (g_mapped_file_free (var), NULL)))
 
 #define VALA_TYPE_SYMBOL (vala_symbol_get_type ())
 #define VALA_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SYMBOL, ValaSymbol))
@@ -79,6 +92,7 @@ typedef struct _ValaUsingDirectiveClass ValaUsingDirectiveClass;
 
 typedef struct _ValaSymbol ValaSymbol;
 typedef struct _ValaSymbolClass ValaSymbolClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_UNRESOLVED_SYMBOL (vala_unresolved_symbol_get_type ())
 #define VALA_UNRESOLVED_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_UNRESOLVED_SYMBOL, ValaUnresolvedSymbol))
@@ -99,6 +113,7 @@ typedef struct _ValaUnresolvedSymbolClass ValaUnresolvedSymbolClass;
 
 typedef struct _ValaCodeVisitor ValaCodeVisitor;
 typedef struct _ValaCodeVisitorClass ValaCodeVisitorClass;
+#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -121,9 +136,6 @@ typedef struct _ValaSemanticAnalyzer ValaSemanticAnalyzer;
 typedef struct _ValaSemanticAnalyzerClass ValaSemanticAnalyzerClass;
 typedef struct _ValaParamSpecSourceFile ValaParamSpecSourceFile;
 
-/**
- * Represents a Vala source or VAPI package file.
- */
 struct _ValaSourceFile {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -137,9 +149,9 @@ struct _ValaSourceFileClass {
 
 struct _ValaSourceFilePrivate {
 	char* _filename;
-	char* _comment;
 	gboolean _external_package;
 	ValaCodeContext* _context;
+	GeeArrayList* comments;
 	GeeList* using_directives;
 	GeeList* nodes;
 	char* csource_filename;
@@ -154,6 +166,7 @@ struct _ValaParamSpecSourceFile {
 };
 
 
+static gpointer vala_source_file_parent_class = NULL;
 
 gpointer vala_source_file_ref (gpointer instance);
 void vala_source_file_unref (gpointer instance);
@@ -167,6 +180,12 @@ GParamSpec* vala_param_spec_code_context (const gchar* name, const gchar* nick,
 void vala_value_set_code_context (GValue* value, gpointer v_object);
 gpointer vala_value_get_code_context (const GValue* value);
 GType vala_code_context_get_type (void);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
 GParamSpec* vala_param_spec_code_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -184,7 +203,8 @@ void vala_source_file_set_context (ValaSourceFile* self, ValaCodeContext* value)
 void vala_source_file_set_content (ValaSourceFile* self, const char* value);
 ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* filename, gboolean pkg, const char* content);
 ValaSourceFile* vala_source_file_construct (GType object_type, ValaCodeContext* context, const char* filename, gboolean pkg, const char* content);
-ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* filename, gboolean pkg, const char* content);
+void vala_source_file_add_comment (ValaSourceFile* self, ValaComment* comment);
+GeeList* vala_source_file_get_comments (ValaSourceFile* self);
 GType vala_symbol_get_type (void);
 static gboolean vala_source_file_same_symbol (ValaSourceFile* self, ValaSymbol* sym1, ValaSymbol* sym2);
 ValaSymbol* vala_using_directive_get_namespace_symbol (ValaUsingDirective* self);
@@ -219,6 +239,7 @@ gboolean vala_code_context_get_ccode_only (ValaCodeContext* self);
 gboolean vala_code_context_get_save_csources (ValaCodeContext* self);
 char* vala_source_file_get_csource_filename (ValaSourceFile* self);
 const char* vala_code_context_get_header_filename (ValaCodeContext* self);
+const char* vala_code_context_get_includedir (ValaCodeContext* self);
 char* vala_source_file_get_cinclude_filename (ValaSourceFile* self);
 const char* vala_source_file_get_content (ValaSourceFile* self);
 static void vala_source_file_read_source_lines (ValaSourceFile* self, const char* cont);
@@ -236,10 +257,7 @@ gsize vala_source_file_get_mapped_length (ValaSourceFile* self);
 GType vala_semantic_analyzer_get_type (void);
 gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 gboolean vala_source_file_check (ValaSourceFile* self, ValaSemanticAnalyzer* analyzer);
-const char* vala_source_file_get_comment (ValaSourceFile* self);
-void vala_source_file_set_comment (ValaSourceFile* self, const char* value);
 gboolean vala_source_file_get_external_package (ValaSourceFile* self);
-static gpointer vala_source_file_parent_class = NULL;
 static void vala_source_file_finalize (ValaSourceFile* obj);
 static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -248,13 +266,6 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-/**
- * Creates a new source file.
- *
- * @param filename source file name
- * @param pkg      true if this is a VAPI package file
- * @return         newly created source file
- */
 ValaSourceFile* vala_source_file_construct (GType object_type, ValaCodeContext* context, const char* filename, gboolean pkg, const char* content) {
 	ValaSourceFile* self;
 	g_return_val_if_fail (context != NULL, NULL);
@@ -273,29 +284,41 @@ ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* file
 }
 
 
-/**
- * Adds a new using directive with the specified namespace.
- *
- * @param ns reference to namespace
- */
+void vala_source_file_add_comment (ValaSourceFile* self, ValaComment* comment) {
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (comment != NULL);
+	gee_collection_add ((GeeCollection*) self->priv->comments, comment);
+}
+
+
+GeeList* vala_source_file_get_comments (ValaSourceFile* self) {
+	GeeList* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_COMMENT, (GBoxedCopyFunc) vala_comment_ref, vala_comment_unref, (GeeList*) self->priv->comments);
+	return result;
+}
+
+
 void vala_source_file_add_using_directive (ValaSourceFile* self, ValaUsingDirective* ns) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (ns != NULL);
 	{
 		GeeIterator* _using_directive_it;
 		_using_directive_it = gee_iterable_iterator ((GeeIterable*) self->priv->using_directives);
-		while (gee_iterator_next (_using_directive_it)) {
+		while (TRUE) {
 			ValaUsingDirective* using_directive;
+			if (!gee_iterator_next (_using_directive_it)) {
+				break;
+			}
 			using_directive = (ValaUsingDirective*) gee_iterator_get (_using_directive_it);
 			if (vala_source_file_same_symbol (self, vala_using_directive_get_namespace_symbol (using_directive), vala_using_directive_get_namespace_symbol (ns))) {
-				/* ignore duplicates*/
-				(using_directive == NULL) ? NULL : (using_directive = (vala_code_node_unref (using_directive), NULL));
-				(_using_directive_it == NULL) ? NULL : (_using_directive_it = (gee_collection_object_unref (_using_directive_it), NULL));
+				_vala_code_node_unref0 (using_directive);
+				_gee_collection_object_unref0 (_using_directive_it);
 				return;
 			}
-			(using_directive == NULL) ? NULL : (using_directive = (vala_code_node_unref (using_directive), NULL));
+			_vala_code_node_unref0 (using_directive);
 		}
-		(_using_directive_it == NULL) ? NULL : (_using_directive_it = (gee_collection_object_unref (_using_directive_it), NULL));
+		_gee_collection_object_unref0 (_using_directive_it);
 	}
 	gee_collection_add ((GeeCollection*) self->priv->using_directives, ns);
 }
@@ -307,57 +330,54 @@ void vala_source_file_clear_using_directives (ValaSourceFile* self) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_source_file_same_symbol (ValaSourceFile* self, ValaSymbol* sym1, ValaSymbol* sym2) {
-	ValaUnresolvedSymbol* _tmp2_;
-	ValaSymbol* _tmp1_;
+	gboolean result;
+	ValaSymbol* _tmp0_;
 	ValaUnresolvedSymbol* unresolved_symbol1;
-	ValaUnresolvedSymbol* _tmp4_;
-	ValaSymbol* _tmp3_;
+	ValaSymbol* _tmp1_;
 	ValaUnresolvedSymbol* unresolved_symbol2;
-	gboolean _tmp5_;
-	gboolean _tmp7_;
+	gboolean _tmp2_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	if (sym1 == sym2) {
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	unresolved_symbol1 = (_tmp2_ = (_tmp1_ = sym1, VALA_IS_UNRESOLVED_SYMBOL (_tmp1_) ? ((ValaUnresolvedSymbol*) _tmp1_) : NULL), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
-	_tmp4_ = NULL;
-	_tmp3_ = NULL;
-	unresolved_symbol2 = (_tmp4_ = (_tmp3_ = sym2, VALA_IS_UNRESOLVED_SYMBOL (_tmp3_) ? ((ValaUnresolvedSymbol*) _tmp3_) : NULL), (_tmp4_ == NULL) ? NULL : vala_code_node_ref (_tmp4_));
-	_tmp5_ = FALSE;
+	unresolved_symbol1 = _vala_code_node_ref0 ((_tmp0_ = sym1, VALA_IS_UNRESOLVED_SYMBOL (_tmp0_) ? ((ValaUnresolvedSymbol*) _tmp0_) : NULL));
+	unresolved_symbol2 = _vala_code_node_ref0 ((_tmp1_ = sym2, VALA_IS_UNRESOLVED_SYMBOL (_tmp1_) ? ((ValaUnresolvedSymbol*) _tmp1_) : NULL));
+	_tmp2_ = FALSE;
 	if (unresolved_symbol1 != NULL) {
-		_tmp5_ = unresolved_symbol2 != NULL;
+		_tmp2_ = unresolved_symbol2 != NULL;
 	} else {
-		_tmp5_ = FALSE;
+		_tmp2_ = FALSE;
 	}
-	if (_tmp5_) {
+	if (_tmp2_) {
 		if (vala_source_file_same_symbol (self, (ValaSymbol*) vala_unresolved_symbol_get_inner (unresolved_symbol1), (ValaSymbol*) vala_unresolved_symbol_get_inner (unresolved_symbol2))) {
-			gboolean _tmp6_;
-			return (_tmp6_ = _vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) unresolved_symbol1), vala_symbol_get_name ((ValaSymbol*) unresolved_symbol2)) == 0, (unresolved_symbol1 == NULL) ? NULL : (unresolved_symbol1 = (vala_code_node_unref (unresolved_symbol1), NULL)), (unresolved_symbol2 == NULL) ? NULL : (unresolved_symbol2 = (vala_code_node_unref (unresolved_symbol2), NULL)), _tmp6_);
+			result = _vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) unresolved_symbol1), vala_symbol_get_name ((ValaSymbol*) unresolved_symbol2)) == 0;
+			_vala_code_node_unref0 (unresolved_symbol1);
+			_vala_code_node_unref0 (unresolved_symbol2);
+			return result;
 		}
 	}
-	return (_tmp7_ = FALSE, (unresolved_symbol1 == NULL) ? NULL : (unresolved_symbol1 = (vala_code_node_unref (unresolved_symbol1), NULL)), (unresolved_symbol2 == NULL) ? NULL : (unresolved_symbol2 = (vala_code_node_unref (unresolved_symbol2), NULL)), _tmp7_);
+	result = FALSE;
+	_vala_code_node_unref0 (unresolved_symbol1);
+	_vala_code_node_unref0 (unresolved_symbol2);
+	return result;
 }
 
 
-/**
- * Returns a copy of the list of using directives.
- *
- * @return using directive list
- */
 GeeList* vala_source_file_get_using_directives (ValaSourceFile* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_USING_DIRECTIVE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->using_directives);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_USING_DIRECTIVE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->using_directives);
+	return result;
 }
 
 
-/**
- * Adds the specified code node to this source file.
- *
- * @param node a code node
- */
 void vala_source_file_add_node (ValaSourceFile* self, ValaCodeNode* node) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (node != NULL);
@@ -372,14 +392,11 @@ void vala_source_file_remove_node (ValaSourceFile* self, ValaCodeNode* node) {
 }
 
 
-/**
- * Returns a copy of the list of code nodes.
- *
- * @return code node list
- */
 GeeList* vala_source_file_get_nodes (ValaSourceFile* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_CODE_NODE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->nodes);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_CODE_NODE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->nodes);
+	return result;
 }
 
 
@@ -396,29 +413,36 @@ void vala_source_file_accept_children (ValaSourceFile* self, ValaCodeVisitor* vi
 	{
 		GeeIterator* _ns_ref_it;
 		_ns_ref_it = gee_iterable_iterator ((GeeIterable*) self->priv->using_directives);
-		while (gee_iterator_next (_ns_ref_it)) {
+		while (TRUE) {
 			ValaUsingDirective* ns_ref;
+			if (!gee_iterator_next (_ns_ref_it)) {
+				break;
+			}
 			ns_ref = (ValaUsingDirective*) gee_iterator_get (_ns_ref_it);
 			vala_code_node_accept ((ValaCodeNode*) ns_ref, visitor);
-			(ns_ref == NULL) ? NULL : (ns_ref = (vala_code_node_unref (ns_ref), NULL));
+			_vala_code_node_unref0 (ns_ref);
 		}
-		(_ns_ref_it == NULL) ? NULL : (_ns_ref_it = (gee_collection_object_unref (_ns_ref_it), NULL));
+		_gee_collection_object_unref0 (_ns_ref_it);
 	}
 	{
 		GeeIterator* _node_it;
 		_node_it = gee_iterable_iterator ((GeeIterable*) self->priv->nodes);
-		while (gee_iterator_next (_node_it)) {
+		while (TRUE) {
 			ValaCodeNode* node;
+			if (!gee_iterator_next (_node_it)) {
+				break;
+			}
 			node = (ValaCodeNode*) gee_iterator_get (_node_it);
 			vala_code_node_accept (node, visitor);
-			(node == NULL) ? NULL : (node = (vala_code_node_unref (node), NULL));
+			_vala_code_node_unref0 (node);
 		}
-		(_node_it == NULL) ? NULL : (_node_it = (gee_collection_object_unref (_node_it), NULL));
+		_gee_collection_object_unref0 (_node_it);
 	}
 }
 
 
 static char* string_substring (const char* self, glong offset, glong len) {
+	char* result;
 	glong string_length;
 	const char* start;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -434,80 +458,80 @@ static char* string_substring (const char* self, glong offset, glong len) {
 	}
 	g_return_val_if_fail ((offset + len) <= string_length, NULL);
 	start = g_utf8_offset_to_pointer (self, offset);
-	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+	result = g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+	return result;
 }
 
 
 static char* vala_source_file_get_subdir (ValaSourceFile* self) {
+	char* result;
+	char* _tmp0_;
+	gboolean _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (vala_code_context_get_basedir (self->priv->_context) == NULL) {
-		return g_strdup ("");
+		result = g_strdup ("");
+		return result;
 	}
-	/* filename and basedir are already canonicalized*/
-	if (g_str_has_prefix (self->priv->_filename, vala_code_context_get_basedir (self->priv->_context))) {
+	if ((_tmp1_ = g_str_has_prefix (self->priv->_filename, _tmp0_ = g_strconcat (vala_code_context_get_basedir (self->priv->_context), "/", NULL)), _g_free0 (_tmp0_), _tmp1_)) {
 		char* basename;
 		char* subdir;
-		char* _tmp3_;
 		basename = g_path_get_basename (self->priv->_filename);
 		subdir = string_substring (self->priv->_filename, g_utf8_strlen (vala_code_context_get_basedir (self->priv->_context), -1), (g_utf8_strlen (self->priv->_filename, -1) - g_utf8_strlen (vala_code_context_get_basedir (self->priv->_context), -1)) - g_utf8_strlen (basename, -1));
-		while (g_utf8_get_char (g_utf8_offset_to_pointer (subdir, 0)) == '/') {
+		while (TRUE) {
 			char* _tmp2_;
-			const char* _tmp1_;
-			_tmp2_ = NULL;
-			_tmp1_ = NULL;
-			subdir = (_tmp2_ = (_tmp1_ = g_utf8_offset_to_pointer (subdir, (glong) 1), (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), subdir = (g_free (subdir), NULL), _tmp2_);
+			if (!(g_utf8_get_char (g_utf8_offset_to_pointer (subdir, 0)) == '/')) {
+				break;
+			}
+			subdir = (_tmp2_ = g_strdup (g_utf8_offset_to_pointer (subdir, (glong) 1)), _g_free0 (subdir), _tmp2_);
 		}
-		_tmp3_ = NULL;
-		return (_tmp3_ = subdir, basename = (g_free (basename), NULL), _tmp3_);
+		result = subdir;
+		_g_free0 (basename);
+		return result;
 	}
-	return g_strdup ("");
+	result = g_strdup ("");
+	return result;
 }
 
 
 static char* vala_source_file_get_destination_directory (ValaSourceFile* self) {
+	char* result;
+	char* _tmp0_;
 	char* _tmp1_;
-	char* _tmp2_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (vala_code_context_get_directory (self->priv->_context) == NULL) {
-		return vala_source_file_get_subdir (self);
+		result = vala_source_file_get_subdir (self);
+		return result;
 	}
-	_tmp1_ = NULL;
-	_tmp2_ = NULL;
-	return (_tmp2_ = g_strdup_printf ("%s/%s", vala_code_context_get_directory (self->priv->_context), _tmp1_ = vala_source_file_get_subdir (self)), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+	result = (_tmp1_ = g_strdup_printf ("%s/%s", vala_code_context_get_directory (self->priv->_context), _tmp0_ = vala_source_file_get_subdir (self)), _g_free0 (_tmp0_), _tmp1_);
+	return result;
 }
 
 
 static char* vala_source_file_get_basename (ValaSourceFile* self) {
+	char* result;
 	glong dot;
 	char* _tmp0_;
 	char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
-	dot = g_utf8_pointer_to_offset (self->priv->_filename, g_utf8_strrchr (self->priv->_filename, (glong) (-1), (gunichar) '.'));
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	return (_tmp1_ = g_path_get_basename (_tmp0_ = string_substring (self->priv->_filename, (glong) 0, dot)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	dot = g_utf8_pointer_to_offset (self->priv->_filename, g_utf8_strrchr (self->priv->_filename, (gssize) (-1), (gunichar) '.'));
+	result = (_tmp1_ = g_path_get_basename (_tmp0_ = string_substring (self->priv->_filename, (glong) 0, dot)), _g_free0 (_tmp0_), _tmp1_);
+	return result;
 }
 
 
 char* vala_source_file_get_relative_filename (ValaSourceFile* self) {
+	char* result;
 	char* _tmp1_;
 	char* _tmp0_;
 	char* _tmp2_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	_tmp2_ = NULL;
-	return (_tmp2_ = g_strconcat (_tmp0_ = vala_source_file_get_subdir (self), _tmp1_ = g_path_get_basename (self->priv->_filename), NULL), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp2_);
+	result = (_tmp2_ = g_strconcat (_tmp0_ = vala_source_file_get_subdir (self), _tmp1_ = g_path_get_basename (self->priv->_filename), NULL), _g_free0 (_tmp1_), _g_free0 (_tmp0_), _tmp2_);
+	return result;
 }
 
 
-/**
- * Returns the filename to use when generating C source files.
- *
- * @return generated C source filename
- */
 char* vala_source_file_get_csource_filename (ValaSourceFile* self) {
-	const char* _tmp7_;
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->csource_filename == NULL) {
 		gboolean _tmp0_;
@@ -521,68 +545,50 @@ char* vala_source_file_get_csource_filename (ValaSourceFile* self) {
 			char* _tmp3_;
 			char* _tmp2_;
 			char* _tmp1_;
-			_tmp3_ = NULL;
-			_tmp2_ = NULL;
-			_tmp1_ = NULL;
-			self->priv->csource_filename = (_tmp3_ = g_strdup_printf ("%s%s.c", _tmp1_ = vala_source_file_get_destination_directory (self), _tmp2_ = vala_source_file_get_basename (self)), self->priv->csource_filename = (g_free (self->priv->csource_filename), NULL), _tmp3_);
-			_tmp2_ = (g_free (_tmp2_), NULL);
-			_tmp1_ = (g_free (_tmp1_), NULL);
+			self->priv->csource_filename = (_tmp3_ = g_strdup_printf ("%s%s.c", _tmp1_ = vala_source_file_get_destination_directory (self), _tmp2_ = vala_source_file_get_basename (self)), _g_free0 (self->priv->csource_filename), _tmp3_);
+			_g_free0 (_tmp2_);
+			_g_free0 (_tmp1_);
 		} else {
 			char* _tmp6_;
 			char* _tmp5_;
 			char* _tmp4_;
-			/* temporary file*/
-			_tmp6_ = NULL;
-			_tmp5_ = NULL;
-			_tmp4_ = NULL;
-			self->priv->csource_filename = (_tmp6_ = g_strdup_printf ("%s%s.vala.c", _tmp4_ = vala_source_file_get_destination_directory (self), _tmp5_ = vala_source_file_get_basename (self)), self->priv->csource_filename = (g_free (self->priv->csource_filename), NULL), _tmp6_);
-			_tmp5_ = (g_free (_tmp5_), NULL);
-			_tmp4_ = (g_free (_tmp4_), NULL);
+			self->priv->csource_filename = (_tmp6_ = g_strdup_printf ("%s%s.vala.c", _tmp4_ = vala_source_file_get_destination_directory (self), _tmp5_ = vala_source_file_get_basename (self)), _g_free0 (self->priv->csource_filename), _tmp6_);
+			_g_free0 (_tmp5_);
+			_g_free0 (_tmp4_);
 		}
 	}
-	_tmp7_ = NULL;
-	return (_tmp7_ = self->priv->csource_filename, (_tmp7_ == NULL) ? NULL : g_strdup (_tmp7_));
+	result = g_strdup (self->priv->csource_filename);
+	return result;
 }
 
 
-/**
- * Returns the filename to use when including the generated C header
- * file.
- *
- * @return C header filename to include
- */
 char* vala_source_file_get_cinclude_filename (ValaSourceFile* self) {
-	const char* _tmp4_;
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->cinclude_filename == NULL) {
 		if (vala_code_context_get_header_filename (self->priv->_context) != NULL) {
 			char* _tmp0_;
-			_tmp0_ = NULL;
-			self->priv->cinclude_filename = (_tmp0_ = g_path_get_basename (vala_code_context_get_header_filename (self->priv->_context)), self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL), _tmp0_);
+			self->priv->cinclude_filename = (_tmp0_ = g_path_get_basename (vala_code_context_get_header_filename (self->priv->_context)), _g_free0 (self->priv->cinclude_filename), _tmp0_);
+			if (vala_code_context_get_includedir (self->priv->_context) != NULL) {
+				char* _tmp1_;
+				self->priv->cinclude_filename = (_tmp1_ = g_strdup_printf ("%s/%s", vala_code_context_get_includedir (self->priv->_context), self->priv->cinclude_filename), _g_free0 (self->priv->cinclude_filename), _tmp1_);
+			}
 		} else {
+			char* _tmp4_;
 			char* _tmp3_;
 			char* _tmp2_;
-			char* _tmp1_;
-			_tmp3_ = NULL;
-			_tmp2_ = NULL;
-			_tmp1_ = NULL;
-			self->priv->cinclude_filename = (_tmp3_ = g_strdup_printf ("%s%s.h", _tmp1_ = vala_source_file_get_subdir (self), _tmp2_ = vala_source_file_get_basename (self)), self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL), _tmp3_);
-			_tmp2_ = (g_free (_tmp2_), NULL);
-			_tmp1_ = (g_free (_tmp1_), NULL);
+			self->priv->cinclude_filename = (_tmp4_ = g_strdup_printf ("%s%s.h", _tmp2_ = vala_source_file_get_subdir (self), _tmp3_ = vala_source_file_get_basename (self)), _g_free0 (self->priv->cinclude_filename), _tmp4_);
+			_g_free0 (_tmp3_);
+			_g_free0 (_tmp2_);
 		}
 	}
-	_tmp4_ = NULL;
-	return (_tmp4_ = self->priv->cinclude_filename, (_tmp4_ == NULL) ? NULL : g_strdup (_tmp4_));
+	result = g_strdup (self->priv->cinclude_filename);
+	return result;
 }
 
 
-/**
- * Returns the requested line from this file, loading it if needed.
- *
- * @param lineno 1-based line number
- * @return       the specified source line
- */
 char* vala_source_file_get_source_line (ValaSourceFile* self, gint lineno) {
+	char* result;
 	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->source_array == NULL) {
@@ -599,15 +605,14 @@ char* vala_source_file_get_source_line (ValaSourceFile* self, gint lineno) {
 		_tmp0_ = lineno > gee_collection_get_size ((GeeCollection*) self->priv->source_array);
 	}
 	if (_tmp0_) {
-		return NULL;
+		result = NULL;
+		return result;
 	}
-	return (char*) gee_list_get ((GeeList*) self->priv->source_array, lineno - 1);
+	result = (char*) gee_list_get ((GeeList*) self->priv->source_array, lineno - 1);
+	return result;
 }
 
 
-/**
- * Parses the input file into ::source_array.
- */
 static void vala_source_file_read_source_file (ValaSourceFile* self) {
 	GError * _inner_error_;
 	char* cont;
@@ -618,10 +623,9 @@ static void vala_source_file_read_source_file (ValaSourceFile* self) {
 		char* _tmp2_;
 		gboolean _tmp1_;
 		char* _tmp0_;
-		_tmp2_ = NULL;
 		_tmp0_ = NULL;
 		_tmp1_ = g_file_get_contents (self->priv->_filename, &_tmp0_, NULL, &_inner_error_);
-		cont = (_tmp2_ = _tmp0_, cont = (g_free (cont), NULL), _tmp2_);
+		cont = (_tmp2_ = _tmp0_, _g_free0 (cont), _tmp2_);
 		_tmp1_;
 		if (_inner_error_ != NULL) {
 			if (_inner_error_->domain == G_FILE_ERROR) {
@@ -637,20 +641,20 @@ static void vala_source_file_read_source_file (ValaSourceFile* self) {
 		fe = _inner_error_;
 		_inner_error_ = NULL;
 		{
-			(fe == NULL) ? NULL : (fe = (g_error_free (fe), NULL));
-			cont = (g_free (cont), NULL);
+			_g_error_free0 (fe);
+			_g_free0 (cont);
 			return;
 		}
 	}
 	__finally6:
 	if (_inner_error_ != NULL) {
-		cont = (g_free (cont), NULL);
+		_g_free0 (cont);
 		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
 		g_clear_error (&_inner_error_);
 		return;
 	}
 	vala_source_file_read_source_lines (self, cont);
-	cont = (g_free (cont), NULL);
+	_g_free0 (cont);
 }
 
 
@@ -664,37 +668,49 @@ static void vala_source_file_read_source_lines (ValaSourceFile* self, const char
 	gint idx;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (cont != NULL);
-	_tmp0_ = NULL;
-	self->priv->source_array = (_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal), (self->priv->source_array == NULL) ? NULL : (self->priv->source_array = (gee_collection_object_unref (self->priv->source_array), NULL)), _tmp0_);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
+	self->priv->source_array = (_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal), _gee_collection_object_unref0 (self->priv->source_array), _tmp0_);
 	lines = (_tmp2_ = _tmp1_ = g_strsplit (cont, "\n", 0), lines_length1 = _vala_array_length (_tmp1_), lines_size = lines_length1, _tmp2_);
 	idx = 0;
-	for (idx = 0; lines[idx] != NULL; idx = idx + 1) {
-		gee_collection_add ((GeeCollection*) self->priv->source_array, lines[idx]);
+	{
+		gboolean _tmp3_;
+		idx = 0;
+		_tmp3_ = TRUE;
+		while (TRUE) {
+			if (!_tmp3_) {
+				idx = idx + 1;
+			}
+			_tmp3_ = FALSE;
+			if (!(lines[idx] != NULL)) {
+				break;
+			}
+			gee_collection_add ((GeeCollection*) self->priv->source_array, lines[idx]);
+		}
 	}
 	lines = (_vala_array_free (lines, lines_length1, (GDestroyNotify) g_free), NULL);
 }
 
 
 gchar* vala_source_file_get_mapped_contents (ValaSourceFile* self) {
+	gchar* result;
 	GError * _inner_error_;
 	g_return_val_if_fail (self != NULL, NULL);
 	_inner_error_ = NULL;
 	if (vala_source_file_get_content (self) != NULL) {
-		return vala_source_file_get_content (self);
+		result = vala_source_file_get_content (self);
+		return result;
 	}
 	if (self->priv->mapped_file == NULL) {
 		{
+			GMappedFile* _tmp0_;
 			GMappedFile* _tmp1_;
-			_tmp1_ = NULL;
-			self->priv->mapped_file = (_tmp1_ = g_mapped_file_new (self->priv->_filename, FALSE, &_inner_error_), (self->priv->mapped_file == NULL) ? NULL : (self->priv->mapped_file = (g_mapped_file_free (self->priv->mapped_file), NULL)), _tmp1_);
+			_tmp0_ = g_mapped_file_new (self->priv->_filename, FALSE, &_inner_error_);
 			if (_inner_error_ != NULL) {
 				if (_inner_error_->domain == G_FILE_ERROR) {
 					goto __catch7_g_file_error;
 				}
 				goto __finally7;
 			}
+			self->priv->mapped_file = (_tmp1_ = _tmp0_, _g_mapped_file_free0 (self->priv->mapped_file), _tmp1_);
 		}
 		goto __finally7;
 		__catch7_g_file_error:
@@ -704,11 +720,11 @@ gchar* vala_source_file_get_mapped_contents (ValaSourceFile* self) {
 			_inner_error_ = NULL;
 			{
 				char* _tmp2_;
-				gchar* _tmp3_;
-				_tmp2_ = NULL;
 				vala_report_error (NULL, _tmp2_ = g_strdup_printf ("Unable to map file `%s': %s", self->priv->_filename, e->message));
-				_tmp2_ = (g_free (_tmp2_), NULL);
-				return (_tmp3_ = NULL, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), _tmp3_);
+				_g_free0 (_tmp2_);
+				result = NULL;
+				_g_error_free0 (e);
+				return result;
 			}
 		}
 		__finally7:
@@ -718,78 +734,74 @@ gchar* vala_source_file_get_mapped_contents (ValaSourceFile* self) {
 			return NULL;
 		}
 	}
-	return g_mapped_file_get_contents (self->priv->mapped_file);
+	result = g_mapped_file_get_contents (self->priv->mapped_file);
+	return result;
 }
 
 
 static glong string_get_length (const char* self) {
+	glong result;
 	g_return_val_if_fail (self != NULL, 0L);
-	return g_utf8_strlen (self, -1);
+	result = g_utf8_strlen (self, -1);
+	return result;
 }
 
 
 gsize vala_source_file_get_mapped_length (ValaSourceFile* self) {
+	gsize result;
 	g_return_val_if_fail (self != NULL, 0UL);
 	if (vala_source_file_get_content (self) != NULL) {
-		return (gsize) string_get_length (vala_source_file_get_content (self));
+		result = (gsize) string_get_length (vala_source_file_get_content (self));
+		return result;
 	}
-	return (gsize) g_mapped_file_get_length (self->priv->mapped_file);
+	result = (gsize) g_mapped_file_get_length (self->priv->mapped_file);
+	return result;
 }
 
 
 gboolean vala_source_file_check (ValaSourceFile* self, ValaSemanticAnalyzer* analyzer) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	{
 		GeeIterator* _node_it;
 		_node_it = gee_iterable_iterator ((GeeIterable*) self->priv->nodes);
-		while (gee_iterator_next (_node_it)) {
+		while (TRUE) {
 			ValaCodeNode* node;
+			if (!gee_iterator_next (_node_it)) {
+				break;
+			}
 			node = (ValaCodeNode*) gee_iterator_get (_node_it);
 			vala_code_node_check (node, analyzer);
-			(node == NULL) ? NULL : (node = (vala_code_node_unref (node), NULL));
+			_vala_code_node_unref0 (node);
 		}
-		(_node_it == NULL) ? NULL : (_node_it = (gee_collection_object_unref (_node_it), NULL));
+		_gee_collection_object_unref0 (_node_it);
 	}
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
 const char* vala_source_file_get_filename (ValaSourceFile* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_filename;
+	result = self->priv->_filename;
+	return result;
 }
 
 
 void vala_source_file_set_filename (ValaSourceFile* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_filename = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2_);
-}
-
-
-const char* vala_source_file_get_comment (ValaSourceFile* self) {
-	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_comment;
-}
-
-
-void vala_source_file_set_comment (ValaSourceFile* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
-	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_comment = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp2_);
+	self->priv->_filename = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_filename), _tmp0_);
 }
 
 
 gboolean vala_source_file_get_external_package (ValaSourceFile* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_external_package;
+	result = self->priv->_external_package;
+	return result;
 }
 
 
@@ -800,8 +812,10 @@ void vala_source_file_set_external_package (ValaSourceFile* self, gboolean value
 
 
 ValaCodeContext* vala_source_file_get_context (ValaSourceFile* self) {
+	ValaCodeContext* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_context;
+	result = self->priv->_context;
+	return result;
 }
 
 
@@ -812,21 +826,19 @@ void vala_source_file_set_context (ValaSourceFile* self, ValaCodeContext* value)
 
 
 const char* vala_source_file_get_content (ValaSourceFile* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_content;
+	result = self->priv->_content;
+	return result;
 }
 
 
 void vala_source_file_set_content (ValaSourceFile* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
-	GeeArrayList* _tmp3_;
+	char* _tmp0_;
+	GeeArrayList* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_content = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_content = (g_free (self->priv->_content), NULL), _tmp2_);
-	_tmp3_ = NULL;
-	self->priv->source_array = (_tmp3_ = NULL, (self->priv->source_array == NULL) ? NULL : (self->priv->source_array = (gee_collection_object_unref (self->priv->source_array), NULL)), _tmp3_);
+	self->priv->_content = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_content), _tmp0_);
+	self->priv->source_array = (_tmp1_ = NULL, _gee_collection_object_unref0 (self->priv->source_array), _tmp1_);
 }
 
 
@@ -932,6 +944,7 @@ static void vala_source_file_class_init (ValaSourceFileClass * klass) {
 
 static void vala_source_file_instance_init (ValaSourceFile * self) {
 	self->priv = VALA_SOURCE_FILE_GET_PRIVATE (self);
+	self->priv->comments = gee_array_list_new (VALA_TYPE_COMMENT, (GBoxedCopyFunc) vala_comment_ref, vala_comment_unref, g_direct_equal);
 	self->priv->using_directives = (GeeList*) gee_array_list_new (VALA_TYPE_USING_DIRECTIVE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	self->priv->nodes = (GeeList*) gee_array_list_new (VALA_TYPE_CODE_NODE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	self->priv->csource_filename = NULL;
@@ -946,15 +959,15 @@ static void vala_source_file_instance_init (ValaSourceFile * self) {
 static void vala_source_file_finalize (ValaSourceFile* obj) {
 	ValaSourceFile * self;
 	self = VALA_SOURCE_FILE (obj);
-	self->priv->_filename = (g_free (self->priv->_filename), NULL);
-	self->priv->_comment = (g_free (self->priv->_comment), NULL);
-	(self->priv->using_directives == NULL) ? NULL : (self->priv->using_directives = (gee_collection_object_unref (self->priv->using_directives), NULL));
-	(self->priv->nodes == NULL) ? NULL : (self->priv->nodes = (gee_collection_object_unref (self->priv->nodes), NULL));
-	self->priv->csource_filename = (g_free (self->priv->csource_filename), NULL);
-	self->priv->cinclude_filename = (g_free (self->priv->cinclude_filename), NULL);
-	(self->priv->source_array == NULL) ? NULL : (self->priv->source_array = (gee_collection_object_unref (self->priv->source_array), NULL));
-	(self->priv->mapped_file == NULL) ? NULL : (self->priv->mapped_file = (g_mapped_file_free (self->priv->mapped_file), NULL));
-	self->priv->_content = (g_free (self->priv->_content), NULL);
+	_g_free0 (self->priv->_filename);
+	_gee_collection_object_unref0 (self->priv->comments);
+	_gee_collection_object_unref0 (self->priv->using_directives);
+	_gee_collection_object_unref0 (self->priv->nodes);
+	_g_free0 (self->priv->csource_filename);
+	_g_free0 (self->priv->cinclude_filename);
+	_gee_collection_object_unref0 (self->priv->source_array);
+	_g_mapped_file_free0 (self->priv->mapped_file);
+	_g_free0 (self->priv->_content);
 }
 
 
