@@ -130,6 +130,7 @@ typedef struct _ValaLiteralPrivate ValaLiteralPrivate;
 typedef struct _ValaStringLiteral ValaStringLiteral;
 typedef struct _ValaStringLiteralClass ValaStringLiteralClass;
 typedef struct _ValaStringLiteralPrivate ValaStringLiteralPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -882,13 +883,8 @@ typedef struct _ValaValueTypeClass ValaValueTypeClass;
 
 typedef struct _ValaStructValueType ValaStructValueType;
 typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -909,9 +905,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -925,9 +918,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Base class for all literals in the source code.
- */
 struct _ValaLiteral {
 	ValaExpression parent_instance;
 	ValaLiteralPrivate * priv;
@@ -937,9 +927,6 @@ struct _ValaLiteralClass {
 	ValaExpressionClass parent_class;
 };
 
-/**
- * Represents a string literal in the source code.
- */
 struct _ValaStringLiteral {
 	ValaLiteral parent_instance;
 	ValaStringLiteralPrivate * priv;
@@ -953,9 +940,6 @@ struct _ValaStringLiteralPrivate {
 	char* _value;
 };
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -1042,17 +1026,12 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Code visitor analyzing and checking code.
- */
 struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 	ValaSymbol* root_symbol;
-	ValaDataType* current_return_type;
-	ValaClass* current_class;
-	ValaStruct* current_struct;
 	ValaBlock* insert_block;
+	ValaDataType* void_type;
 	ValaDataType* bool_type;
 	ValaDataType* string_type;
 	ValaDataType* uchar_type;
@@ -1110,6 +1089,7 @@ GType vala_string_literal_get_type (void);
 enum  {
 	VALA_STRING_LITERAL_DUMMY_PROPERTY
 };
+ValaLiteral* vala_literal_construct (GType object_type);
 void vala_string_literal_set_value (ValaStringLiteral* self, const char* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -1217,17 +1197,10 @@ static void vala_string_literal_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new string literal.
- *
- * @param s      the literal value
- * @param source reference to source code
- * @return       newly created string literal
- */
 ValaStringLiteral* vala_string_literal_construct (GType object_type, const char* value, ValaSourceReference* source_reference) {
 	ValaStringLiteral* self;
 	g_return_val_if_fail (value != NULL, NULL);
-	self = (ValaStringLiteral*) g_type_create_instance (object_type);
+	self = (ValaStringLiteral*) vala_literal_construct (object_type);
 	vala_string_literal_set_value (self, value);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
@@ -1261,11 +1234,6 @@ static char* string_substring (const char* self, glong offset, glong len) {
 }
 
 
-/**
- * Evaluates the literal string value.
- *
- * @return the unescaped string
- */
 char* vala_string_literal_eval (ValaStringLiteral* self) {
 	char* result;
 	char* noquotes;
@@ -1274,11 +1242,9 @@ char* vala_string_literal_eval (ValaStringLiteral* self) {
 		result = NULL;
 		return result;
 	}
-	/* remove quotes */
 	noquotes = string_substring (self->priv->_value, (glong) 1, (glong) ((guint) (g_utf8_strlen (self->priv->_value, -1) - 2)));
-	/* unescape string */
 	result = g_strcompress (noquotes);
-	noquotes = (g_free (noquotes), NULL);
+	_g_free0 (noquotes);
 	return result;
 }
 
@@ -1313,10 +1279,8 @@ static gboolean vala_string_literal_real_is_non_null (ValaExpression* base) {
 static char* vala_string_literal_real_to_string (ValaCodeNode* base) {
 	ValaStringLiteral * self;
 	char* result;
-	const char* _tmp0_;
 	self = (ValaStringLiteral*) base;
-	_tmp0_ = NULL;
-	result = (_tmp0_ = self->priv->_value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = g_strdup (self->priv->_value);
 	return result;
 }
 
@@ -1332,9 +1296,8 @@ static gboolean vala_string_literal_real_check (ValaCodeNode* base, ValaSemantic
 		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	_tmp0_ = NULL;
 	vala_expression_set_value_type ((ValaExpression*) self, _tmp0_ = vala_data_type_copy (analyzer->string_type));
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+	_vala_code_node_unref0 (_tmp0_);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
 	return result;
 }
@@ -1349,12 +1312,9 @@ const char* vala_string_literal_get_value (ValaStringLiteral* self) {
 
 
 void vala_string_literal_set_value (ValaStringLiteral* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_value = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_value = (g_free (self->priv->_value), NULL), _tmp1_);
+	self->priv->_value = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_value), _tmp0_);
 }
 
 
@@ -1378,7 +1338,7 @@ static void vala_string_literal_instance_init (ValaStringLiteral * self) {
 static void vala_string_literal_finalize (ValaCodeNode* obj) {
 	ValaStringLiteral * self;
 	self = VALA_STRING_LITERAL (obj);
-	self->priv->_value = (g_free (self->priv->_value), NULL);
+	_g_free0 (self->priv->_value);
 	VALA_CODE_NODE_CLASS (vala_string_literal_parent_class)->finalize (obj);
 }
 
