@@ -146,6 +146,8 @@ typedef struct _ValaBlockClass ValaBlockClass;
 
 typedef struct _ValaSwitchSection ValaSwitchSection;
 typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -498,6 +500,16 @@ typedef struct _ValaIfStatementClass ValaIfStatementClass;
 typedef struct _ValaSwitchLabel ValaSwitchLabel;
 typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
 
+#define VALA_TYPE_LOOP (vala_loop_get_type ())
+#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
+#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
+#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
+#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
+#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))
+
+typedef struct _ValaLoop ValaLoop;
+typedef struct _ValaLoopClass ValaLoopClass;
+
 #define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
 #define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
 #define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
@@ -889,12 +901,16 @@ typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
+#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
+#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
+#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+
+typedef struct _ValaStructValueType ValaStructValueType;
+typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -915,16 +931,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a switch selection statement in the source code.
- */
 struct _ValaSwitchStatement {
 	ValaCodeNode parent_instance;
 	ValaSwitchStatementPrivate * priv;
@@ -939,9 +949,6 @@ struct _ValaSwitchStatementPrivate {
 	GeeList* sections;
 };
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -985,6 +992,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
 	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
 	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
+	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
@@ -1027,17 +1035,12 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Code visitor analyzing and checking code.
- */
 struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 	ValaSymbol* root_symbol;
-	ValaDataType* current_return_type;
-	ValaClass* current_class;
-	ValaStruct* current_struct;
 	ValaBlock* insert_block;
+	ValaDataType* void_type;
 	ValaDataType* bool_type;
 	ValaDataType* string_type;
 	ValaDataType* uchar_type;
@@ -1054,9 +1057,11 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
+	ValaStructValueType* gvalue_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
+	ValaDataType* gvaluearray_type;
 	ValaClass* gerror_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
@@ -1067,6 +1072,8 @@ struct _ValaSemanticAnalyzerClass {
 };
 
 
+static gpointer vala_switch_statement_parent_class = NULL;
+static ValaStatementIface* vala_switch_statement_vala_statement_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -1094,6 +1101,7 @@ GType vala_switch_section_get_type (void);
 enum  {
 	VALA_SWITCH_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -1104,7 +1112,6 @@ void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReferenc
 void vala_switch_statement_set_expression (ValaSwitchStatement* self, ValaExpression* value);
 ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expression, ValaSourceReference* source_reference);
 ValaSwitchStatement* vala_switch_statement_construct (GType object_type, ValaExpression* expression, ValaSourceReference* source_reference);
-ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expression, ValaSourceReference* source_reference);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 void vala_switch_statement_add_section (ValaSwitchStatement* self, ValaSwitchSection* section);
 GeeList* vala_switch_statement_get_sections (ValaSwitchStatement* self);
@@ -1161,6 +1168,7 @@ GType vala_initializer_list_get_type (void);
 GType vala_expression_statement_get_type (void);
 GType vala_if_statement_get_type (void);
 GType vala_switch_label_get_type (void);
+GType vala_loop_get_type (void);
 GType vala_while_statement_get_type (void);
 GType vala_do_statement_get_type (void);
 GType vala_for_statement_get_type (void);
@@ -1200,27 +1208,21 @@ GType vala_typecheck_get_type (void);
 GType vala_conditional_expression_get_type (void);
 GType vala_lambda_expression_get_type (void);
 GType vala_assignment_get_type (void);
+GType vala_struct_value_type_get_type (void);
 void vala_report_error (ValaSourceReference* source, const char* message);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
+ValaDataType* vala_data_type_copy (ValaDataType* self);
+void vala_expression_set_target_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_switch_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
-static gpointer vala_switch_statement_parent_class = NULL;
-static ValaStatementIface* vala_switch_statement_vala_statement_parent_iface = NULL;
 static void vala_switch_statement_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new switch statement.
- *
- * @param expression       switch expression
- * @param source_reference reference to source code
- * @return                 newly created switch statement
- */
 ValaSwitchStatement* vala_switch_statement_construct (GType object_type, ValaExpression* expression, ValaSourceReference* source_reference) {
 	ValaSwitchStatement* self;
 	g_return_val_if_fail (expression != NULL, NULL);
 	g_return_val_if_fail (source_reference != NULL, NULL);
-	self = (ValaSwitchStatement*) g_type_create_instance (object_type);
+	self = (ValaSwitchStatement*) vala_code_node_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	vala_switch_statement_set_expression (self, expression);
 	return self;
@@ -1232,11 +1234,6 @@ ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expression, Vala
 }
 
 
-/**
- * Appends the specified section to the list of switch sections.
- *
- * @param section a switch section
- */
 void vala_switch_statement_add_section (ValaSwitchStatement* self, ValaSwitchSection* section) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (section != NULL);
@@ -1245,14 +1242,11 @@ void vala_switch_statement_add_section (ValaSwitchStatement* self, ValaSwitchSec
 }
 
 
-/**
- * Returns a copy of the list of switch sections.
- *
- * @return section list
- */
 GeeList* vala_switch_statement_get_sections (ValaSwitchStatement* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_SWITCH_SECTION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->sections);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_SWITCH_SECTION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->sections);
+	return result;
 }
 
 
@@ -1273,13 +1267,16 @@ static void vala_switch_statement_real_accept_children (ValaCodeNode* base, Vala
 	{
 		GeeIterator* _section_it;
 		_section_it = gee_iterable_iterator ((GeeIterable*) self->priv->sections);
-		while (gee_iterator_next (_section_it)) {
+		while (TRUE) {
 			ValaSwitchSection* section;
+			if (!gee_iterator_next (_section_it)) {
+				break;
+			}
 			section = (ValaSwitchSection*) gee_iterator_get (_section_it);
 			vala_code_node_accept ((ValaCodeNode*) section, visitor);
-			(section == NULL) ? NULL : (section = (vala_code_node_unref (section), NULL));
+			_vala_code_node_unref0 (section);
 		}
-		(_section_it == NULL) ? NULL : (_section_it = (gee_collection_object_unref (_section_it), NULL));
+		_gee_collection_object_unref0 (_section_it);
 	}
 }
 
@@ -1297,63 +1294,78 @@ static void vala_switch_statement_real_replace_expression (ValaCodeNode* base, V
 
 static gboolean vala_switch_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaSwitchStatement * self;
-	gboolean _tmp2_;
-	gboolean _tmp3_;
+	gboolean result;
+	gboolean _tmp0_;
+	gboolean _tmp1_;
+	ValaDataType* _tmp2_;
 	self = (ValaSwitchStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (!vala_code_node_check ((ValaCodeNode*) vala_switch_statement_get_expression (self), analyzer)) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
-	_tmp2_ = FALSE;
-	_tmp3_ = FALSE;
+	_tmp0_ = FALSE;
+	_tmp1_ = FALSE;
 	if (!VALA_IS_INTEGER_TYPE (vala_expression_get_value_type (vala_switch_statement_get_expression (self)))) {
-		_tmp3_ = !VALA_IS_ENUM_VALUE_TYPE (vala_expression_get_value_type (vala_switch_statement_get_expression (self)));
+		_tmp1_ = !VALA_IS_ENUM_VALUE_TYPE (vala_expression_get_value_type (vala_switch_statement_get_expression (self)));
 	} else {
-		_tmp3_ = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp3_) {
-		_tmp2_ = !vala_data_type_compatible (vala_expression_get_value_type (vala_switch_statement_get_expression (self)), analyzer->string_type);
+	if (_tmp1_) {
+		_tmp0_ = !vala_data_type_compatible (vala_expression_get_value_type (vala_switch_statement_get_expression (self)), analyzer->string_type);
 	} else {
-		_tmp2_ = FALSE;
+		_tmp0_ = FALSE;
 	}
-	if (_tmp2_) {
+	if (_tmp0_) {
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_switch_statement_get_expression (self)), "Integer or string expression expected");
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
+	vala_expression_set_target_type (vala_switch_statement_get_expression (self), _tmp2_ = vala_data_type_copy (vala_expression_get_value_type (vala_switch_statement_get_expression (self))));
+	_vala_code_node_unref0 (_tmp2_);
 	{
 		GeeIterator* _section_it;
 		_section_it = gee_iterable_iterator ((GeeIterable*) self->priv->sections);
-		while (gee_iterator_next (_section_it)) {
+		while (TRUE) {
 			ValaSwitchSection* section;
+			if (!gee_iterator_next (_section_it)) {
+				break;
+			}
 			section = (ValaSwitchSection*) gee_iterator_get (_section_it);
 			vala_code_node_check ((ValaCodeNode*) section, analyzer);
-			(section == NULL) ? NULL : (section = (vala_code_node_unref (section), NULL));
+			_vala_code_node_unref0 (section);
 		}
-		(_section_it == NULL) ? NULL : (_section_it = (gee_collection_object_unref (_section_it), NULL));
+		_gee_collection_object_unref0 (_section_it);
 	}
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 ValaExpression* vala_switch_statement_get_expression (ValaSwitchStatement* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_expression;
+	result = self->priv->_expression;
+	return result;
+}
+
+
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
 }
 
 
 void vala_switch_statement_set_expression (ValaSwitchStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2_;
-	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp2_);
+	self->priv->_expression = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_expression), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_expression, (ValaCodeNode*) self);
 }
 
@@ -1383,8 +1395,8 @@ static void vala_switch_statement_instance_init (ValaSwitchStatement * self) {
 static void vala_switch_statement_finalize (ValaCodeNode* obj) {
 	ValaSwitchStatement * self;
 	self = VALA_SWITCH_STATEMENT (obj);
-	(self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL));
-	(self->priv->sections == NULL) ? NULL : (self->priv->sections = (gee_collection_object_unref (self->priv->sections), NULL));
+	_vala_code_node_unref0 (self->priv->_expression);
+	_gee_collection_object_unref0 (self->priv->sections);
 	VALA_CODE_NODE_CLASS (vala_switch_statement_parent_class)->finalize (obj);
 }
 
