@@ -126,6 +126,7 @@ typedef struct _ValaStatementIface ValaStatementIface;
 typedef struct _ValaThrowStatement ValaThrowStatement;
 typedef struct _ValaThrowStatementClass ValaThrowStatementClass;
 typedef struct _ValaThrowStatementPrivate ValaThrowStatementPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -186,13 +187,8 @@ typedef struct _ValaReferenceTypeClass ValaReferenceTypeClass;
 
 typedef struct _ValaErrorType ValaErrorType;
 typedef struct _ValaErrorTypeClass ValaErrorTypeClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -213,16 +209,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a throw statement in the source code.
- */
 struct _ValaThrowStatement {
 	ValaCodeNode parent_instance;
 	ValaThrowStatementPrivate * priv;
@@ -237,6 +227,8 @@ struct _ValaThrowStatementPrivate {
 };
 
 
+static gpointer vala_throw_statement_parent_class = NULL;
+static ValaStatementIface* vala_throw_statement_vala_statement_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -262,6 +254,7 @@ GType vala_throw_statement_get_type (void);
 enum  {
 	VALA_THROW_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -272,7 +265,6 @@ void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReferenc
 void vala_throw_statement_set_error_expression (ValaThrowStatement* self, ValaExpression* value);
 ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression, ValaSourceReference* source_reference);
 ValaThrowStatement* vala_throw_statement_construct (GType object_type, ValaExpression* error_expression, ValaSourceReference* source_reference);
-ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
 static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaExpression* vala_throw_statement_get_error_expression (ValaThrowStatement* self);
@@ -307,23 +299,14 @@ static void vala_throw_statement_real_get_defined_variables (ValaCodeNode* base,
 void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
 static void vala_throw_statement_real_get_used_variables (ValaCodeNode* base, GeeCollection* collection);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-static gpointer vala_throw_statement_parent_class = NULL;
-static ValaStatementIface* vala_throw_statement_vala_statement_parent_iface = NULL;
 static void vala_throw_statement_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new throw statement.
- *
- * @param error_expression the error expression
- * @param source_reference reference to source code
- * @return                 newly created throw statement
- */
 ValaThrowStatement* vala_throw_statement_construct (GType object_type, ValaExpression* error_expression, ValaSourceReference* source_reference) {
 	ValaThrowStatement* self;
 	g_return_val_if_fail (error_expression != NULL, NULL);
-	self = (ValaThrowStatement*) g_type_create_instance (object_type);
+	self = (ValaThrowStatement*) vala_code_node_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	vala_throw_statement_set_error_expression (self, error_expression);
 	return self;
@@ -367,45 +350,48 @@ static void vala_throw_statement_real_replace_expression (ValaCodeNode* base, Va
 
 static gboolean vala_throw_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaThrowStatement * self;
-	ValaErrorType* _tmp1;
+	gboolean result;
+	ValaErrorType* _tmp0_;
 	ValaDataType* error_type;
-	gboolean _tmp7;
 	self = (ValaThrowStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	_tmp1 = NULL;
-	vala_expression_set_target_type (vala_throw_statement_get_error_expression (self), (ValaDataType*) (_tmp1 = vala_error_type_new (NULL, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL));
+	vala_expression_set_target_type (vala_throw_statement_get_error_expression (self), (ValaDataType*) (_tmp0_ = vala_error_type_new (NULL, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	_vala_code_node_unref0 (_tmp0_);
 	vala_data_type_set_value_owned (vala_expression_get_target_type (vala_throw_statement_get_error_expression (self)), TRUE);
 	if (vala_throw_statement_get_error_expression (self) != NULL) {
 		if (!vala_code_node_check ((ValaCodeNode*) vala_throw_statement_get_error_expression (self), analyzer)) {
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			return FALSE;
+			result = FALSE;
+			return result;
 		}
 		if (vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)) == NULL) {
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_throw_statement_get_error_expression (self)), "invalid error expression");
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			return FALSE;
+			result = FALSE;
+			return result;
 		}
 		if (!VALA_IS_ERROR_TYPE (vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)))) {
-			char* _tmp5;
-			char* _tmp4;
-			_tmp5 = NULL;
-			_tmp4 = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_throw_statement_get_error_expression (self)), _tmp5 = g_strdup_printf ("`%s' is not an error type", _tmp4 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)))));
-			_tmp5 = (g_free (_tmp5), NULL);
-			_tmp4 = (g_free (_tmp4), NULL);
+			char* _tmp2_;
+			char* _tmp1_;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_throw_statement_get_error_expression (self)), _tmp2_ = g_strdup_printf ("`%s' is not an error type", _tmp1_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)))));
+			_g_free0 (_tmp2_);
+			_g_free0 (_tmp1_);
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			return FALSE;
+			result = FALSE;
+			return result;
 		}
 	}
 	error_type = vala_data_type_copy (vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)));
 	vala_code_node_set_source_reference ((ValaCodeNode*) error_type, vala_code_node_get_source_reference ((ValaCodeNode*) self));
 	vala_code_node_add_error_type ((ValaCodeNode*) self, error_type);
-	return (_tmp7 = !vala_code_node_get_error ((ValaCodeNode*) self), (error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL)), _tmp7);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	_vala_code_node_unref0 (error_type);
+	return result;
 }
 
 
@@ -426,18 +412,22 @@ static void vala_throw_statement_real_get_used_variables (ValaCodeNode* base, Ge
 
 
 ValaExpression* vala_throw_statement_get_error_expression (ValaThrowStatement* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_error_expression;
+	result = self->priv->_error_expression;
+	return result;
+}
+
+
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
 }
 
 
 void vala_throw_statement_set_error_expression (ValaThrowStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_error_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_error_expression == NULL) ? NULL : (self->priv->_error_expression = (vala_code_node_unref (self->priv->_error_expression), NULL)), _tmp2);
+	self->priv->_error_expression = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_error_expression), _tmp0_);
 	if (self->priv->_error_expression != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_error_expression, (ValaCodeNode*) self);
 	}
@@ -470,7 +460,7 @@ static void vala_throw_statement_instance_init (ValaThrowStatement * self) {
 static void vala_throw_statement_finalize (ValaCodeNode* obj) {
 	ValaThrowStatement * self;
 	self = VALA_THROW_STATEMENT (obj);
-	(self->priv->_error_expression == NULL) ? NULL : (self->priv->_error_expression = (vala_code_node_unref (self->priv->_error_expression), NULL));
+	_vala_code_node_unref0 (self->priv->_error_expression);
 	VALA_CODE_NODE_CLASS (vala_throw_statement_parent_class)->finalize (obj);
 }
 
