@@ -136,6 +136,7 @@ typedef struct _ValaWhileStatementPrivate ValaWhileStatementPrivate;
 
 typedef struct _ValaBlock ValaBlock;
 typedef struct _ValaBlockClass ValaBlockClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -209,12 +210,6 @@ typedef struct _ValaIfStatementClass ValaIfStatementClass;
 typedef struct _ValaLoop ValaLoop;
 typedef struct _ValaLoopClass ValaLoopClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -235,16 +230,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a while iteration statement in the source code.
- */
 struct _ValaWhileStatement {
 	ValaCodeNode parent_instance;
 	ValaWhileStatementPrivate * priv;
@@ -300,6 +289,7 @@ GType vala_block_get_type (void);
 enum  {
 	VALA_WHILE_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_while_statement_set_body (ValaWhileStatement* self, ValaBlock* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -349,19 +339,11 @@ static void vala_while_statement_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new while statement.
- *
- * @param cond   loop condition
- * @param body   loop body
- * @param source reference to source code
- * @return       newly created while statement
- */
 ValaWhileStatement* vala_while_statement_construct (GType object_type, ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference) {
 	ValaWhileStatement* self;
 	g_return_val_if_fail (condition != NULL, NULL);
 	g_return_val_if_fail (body != NULL, NULL);
-	self = (ValaWhileStatement*) g_type_create_instance (object_type);
+	self = (ValaWhileStatement*) vala_code_node_construct (object_type);
 	vala_while_statement_set_body (self, body);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	vala_while_statement_set_condition (self, condition);
@@ -392,25 +374,27 @@ static void vala_while_statement_real_accept_children (ValaCodeNode* base, ValaC
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_while_statement_always_true (ValaWhileStatement* self, ValaExpression* condition) {
 	gboolean result;
-	ValaBooleanLiteral* _tmp1_;
 	ValaExpression* _tmp0_;
 	ValaBooleanLiteral* literal;
-	gboolean _tmp2_;
+	gboolean _tmp1_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (condition != NULL, FALSE);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	literal = (_tmp1_ = (_tmp0_ = condition, VALA_IS_BOOLEAN_LITERAL (_tmp0_) ? ((ValaBooleanLiteral*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-	_tmp2_ = FALSE;
+	literal = _vala_code_node_ref0 ((_tmp0_ = condition, VALA_IS_BOOLEAN_LITERAL (_tmp0_) ? ((ValaBooleanLiteral*) _tmp0_) : NULL));
+	_tmp1_ = FALSE;
 	if (literal != NULL) {
-		_tmp2_ = vala_boolean_literal_get_value (literal);
+		_tmp1_ = vala_boolean_literal_get_value (literal);
 	} else {
-		_tmp2_ = FALSE;
+		_tmp1_ = FALSE;
 	}
-	result = _tmp2_;
-	(literal == NULL) ? NULL : (literal = (vala_code_node_unref (literal), NULL));
+	result = _tmp1_;
+	_vala_code_node_unref0 (literal);
 	return result;
 }
 
@@ -419,12 +403,9 @@ static gboolean vala_while_statement_real_check (ValaCodeNode* base, ValaSemanti
 	ValaWhileStatement * self;
 	gboolean result;
 	ValaLoop* loop;
-	ValaBlock* _tmp1_;
 	ValaBlock* parent_block;
 	self = (ValaWhileStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
-	/* convert to simple loop
-	 do not generate if block if condition is always true*/
 	if (!vala_while_statement_always_true (self, vala_while_statement_get_condition (self))) {
 		ValaUnaryExpression* if_condition;
 		ValaBlock* true_block;
@@ -432,22 +413,20 @@ static gboolean vala_while_statement_real_check (ValaCodeNode* base, ValaSemanti
 		ValaIfStatement* if_stmt;
 		if_condition = vala_unary_expression_new (VALA_UNARY_OPERATOR_LOGICAL_NEGATION, vala_while_statement_get_condition (self), vala_code_node_get_source_reference ((ValaCodeNode*) vala_while_statement_get_condition (self)));
 		true_block = vala_block_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_while_statement_get_condition (self)));
-		_tmp0_ = NULL;
 		vala_block_add_statement (true_block, (ValaStatement*) (_tmp0_ = vala_break_statement_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_while_statement_get_condition (self)))));
-		(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+		_vala_code_node_unref0 (_tmp0_);
 		if_stmt = vala_if_statement_new ((ValaExpression*) if_condition, true_block, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) vala_while_statement_get_condition (self)));
 		vala_block_insert_statement (vala_while_statement_get_body (self), 0, (ValaStatement*) if_stmt);
-		(if_condition == NULL) ? NULL : (if_condition = (vala_code_node_unref (if_condition), NULL));
-		(true_block == NULL) ? NULL : (true_block = (vala_code_node_unref (true_block), NULL));
-		(if_stmt == NULL) ? NULL : (if_stmt = (vala_code_node_unref (if_stmt), NULL));
+		_vala_code_node_unref0 (if_condition);
+		_vala_code_node_unref0 (true_block);
+		_vala_code_node_unref0 (if_stmt);
 	}
 	loop = vala_loop_new (vala_while_statement_get_body (self), vala_code_node_get_source_reference ((ValaCodeNode*) self));
-	_tmp1_ = NULL;
-	parent_block = (_tmp1_ = VALA_BLOCK (vala_code_node_get_parent_node ((ValaCodeNode*) self)), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+	parent_block = _vala_code_node_ref0 (VALA_BLOCK (vala_code_node_get_parent_node ((ValaCodeNode*) self)));
 	vala_block_replace_statement (parent_block, (ValaStatement*) self, (ValaStatement*) loop);
 	result = vala_code_node_check ((ValaCodeNode*) loop, analyzer);
-	(loop == NULL) ? NULL : (loop = (vala_code_node_unref (loop), NULL));
-	(parent_block == NULL) ? NULL : (parent_block = (vala_code_node_unref (parent_block), NULL));
+	_vala_code_node_unref0 (loop);
+	_vala_code_node_unref0 (parent_block);
 	return result;
 }
 
@@ -461,12 +440,9 @@ ValaExpression* vala_while_statement_get_condition (ValaWhileStatement* self) {
 
 
 void vala_while_statement_set_condition (ValaWhileStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_condition = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp1_);
+	self->priv->_condition = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_condition), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_condition, (ValaCodeNode*) self);
 }
 
@@ -480,12 +456,9 @@ ValaBlock* vala_while_statement_get_body (ValaWhileStatement* self) {
 
 
 void vala_while_statement_set_body (ValaWhileStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp1_;
 	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_body = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp1_);
+	self->priv->_body = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_body), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_body, (ValaCodeNode*) self);
 }
 
@@ -513,8 +486,8 @@ static void vala_while_statement_instance_init (ValaWhileStatement * self) {
 static void vala_while_statement_finalize (ValaCodeNode* obj) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (obj);
-	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL));
-	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL));
+	_vala_code_node_unref0 (self->priv->_condition);
+	_vala_code_node_unref0 (self->priv->_body);
 	VALA_CODE_NODE_CLASS (vala_while_statement_parent_class)->finalize (obj);
 }
 
