@@ -126,6 +126,7 @@ typedef struct _ValaStatementIface ValaStatementIface;
 typedef struct _ValaYieldStatement ValaYieldStatement;
 typedef struct _ValaYieldStatementClass ValaYieldStatementClass;
 typedef struct _ValaYieldStatementPrivate ValaYieldStatementPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -137,12 +138,6 @@ typedef struct _ValaYieldStatementPrivate ValaYieldStatementPrivate;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -163,16 +158,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a yield statement in the source code.
- */
 struct _ValaYieldStatement {
 	ValaCodeNode parent_instance;
 	ValaYieldStatementPrivate * priv;
@@ -214,6 +203,7 @@ GType vala_yield_statement_get_type (void);
 enum  {
 	VALA_YIELD_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_yield_statement_set_yield_expression (ValaYieldStatement* self, ValaExpression* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -224,7 +214,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaYieldStatement* vala_yield_statement_new (ValaExpression* yield_expression, ValaSourceReference* source_reference);
 ValaYieldStatement* vala_yield_statement_construct (GType object_type, ValaExpression* yield_expression, ValaSourceReference* source_reference);
-ValaYieldStatement* vala_yield_statement_new (ValaExpression* yield_expression, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_yield_statement (ValaCodeVisitor* self, ValaYieldStatement* y);
 static void vala_yield_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaExpression* vala_yield_statement_get_yield_expression (ValaYieldStatement* self);
@@ -241,16 +230,9 @@ static void vala_yield_statement_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new yield statement.
- *
- * @param yield_expression the yield expression
- * @param source_reference reference to source code
- * @return                 newly created yield statement
- */
 ValaYieldStatement* vala_yield_statement_construct (GType object_type, ValaExpression* yield_expression, ValaSourceReference* source_reference) {
 	ValaYieldStatement* self;
-	self = (ValaYieldStatement*) g_type_create_instance (object_type);
+	self = (ValaYieldStatement*) vala_code_node_construct (object_type);
 	vala_yield_statement_set_yield_expression (self, yield_expression);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
@@ -314,13 +296,15 @@ ValaExpression* vala_yield_statement_get_yield_expression (ValaYieldStatement* s
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_yield_statement_set_yield_expression (ValaYieldStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_yield_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_yield_expression == NULL) ? NULL : (self->priv->_yield_expression = (vala_code_node_unref (self->priv->_yield_expression), NULL)), _tmp1_);
+	self->priv->_yield_expression = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_yield_expression), _tmp0_);
 	if (self->priv->_yield_expression != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_yield_expression, (ValaCodeNode*) self);
 	}
@@ -351,7 +335,7 @@ static void vala_yield_statement_instance_init (ValaYieldStatement * self) {
 static void vala_yield_statement_finalize (ValaCodeNode* obj) {
 	ValaYieldStatement * self;
 	self = VALA_YIELD_STATEMENT (obj);
-	(self->priv->_yield_expression == NULL) ? NULL : (self->priv->_yield_expression = (vala_code_node_unref (self->priv->_yield_expression), NULL));
+	_vala_code_node_unref0 (self->priv->_yield_expression);
 	VALA_CODE_NODE_CLASS (vala_yield_statement_parent_class)->finalize (obj);
 }
 
