@@ -23,9 +23,9 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <vala.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdio.h>
 #include <glib/gstdio.h>
 #include <gee.h>
 #include <config.h>
@@ -41,6 +41,11 @@
 typedef struct _ValaVAPIGen ValaVAPIGen;
 typedef struct _ValaVAPIGenClass ValaVAPIGenClass;
 typedef struct _ValaVAPIGenPrivate ValaVAPIGenPrivate;
+#define _vala_code_context_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_context_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_source_file_unref0(var) ((var == NULL) ? NULL : (var = (vala_source_file_unref (var), NULL)))
+#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
+#define _vala_code_visitor_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_visitor_unref (var), NULL)))
 
 #define VALA_TYPE_GIR_PARSER (vala_gir_parser_get_type ())
 #define VALA_GIR_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_GIR_PARSER, ValaGirParser))
@@ -61,6 +66,9 @@ typedef struct _ValaGirParserClass ValaGirParserClass;
 
 typedef struct _ValaGIdlParser ValaGIdlParser;
 typedef struct _ValaGIdlParserClass ValaGIdlParserClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _g_option_context_free0(var) ((var == NULL) ? NULL : (var = (g_option_context_free (var), NULL)))
+#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
 
 struct _ValaVAPIGen {
 	GObject parent_instance;
@@ -76,12 +84,6 @@ struct _ValaVAPIGenPrivate {
 };
 
 
-
-GType vala_vapi_gen_get_type (void);
-#define VALA_VAPI_GEN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_VAPI_GEN, ValaVAPIGenPrivate))
-enum  {
-	VALA_VAPI_GEN_DUMMY_PROPERTY
-};
 static char* vala_vapi_gen_directory;
 static char* vala_vapi_gen_directory = NULL;
 static gboolean vala_vapi_gen_version;
@@ -98,6 +100,13 @@ static char** vala_vapi_gen_packages;
 static char** vala_vapi_gen_packages = NULL;
 static char* vala_vapi_gen_metadata_filename;
 static char* vala_vapi_gen_metadata_filename = NULL;
+static gpointer vala_vapi_gen_parent_class = NULL;
+
+GType vala_vapi_gen_get_type (void);
+#define VALA_VAPI_GEN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_VAPI_GEN, ValaVAPIGenPrivate))
+enum  {
+	VALA_VAPI_GEN_DUMMY_PROPERTY
+};
 static gint vala_vapi_gen_quit (ValaVAPIGen* self);
 static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg);
 static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1);
@@ -115,108 +124,203 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self);
 ValaVAPIGen* vala_vapi_gen_new (void);
 ValaVAPIGen* vala_vapi_gen_construct (GType object_type);
 static gint vala_vapi_gen_main (char** args, int args_length1);
-ValaVAPIGen* vala_vapi_gen_new (void);
-static gpointer vala_vapi_gen_parent_class = NULL;
 static void vala_vapi_gen_finalize (GObject* obj);
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static gint _vala_array_length (gpointer array);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", (gchar) 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", (gchar) 0, 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"metadata", (gchar) 0, 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_metadata_filename, "Metadata filename", "FILE"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", (gchar) 0, 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", (gchar) 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
 
 
 static gint vala_vapi_gen_quit (ValaVAPIGen* self) {
+	gint result;
 	g_return_val_if_fail (self != NULL, 0);
 	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) == 0) {
 		if (!vala_vapi_gen_quiet_mode) {
 			fprintf (stdout, "Generation succeeded - %d warning(s)\n", vala_report_get_warnings (vala_code_context_get_report (self->priv->context)));
 		}
-		return 0;
+		result = 0;
+		return result;
 	} else {
 		if (!vala_vapi_gen_quiet_mode) {
 			fprintf (stdout, "Generation failed: %d error(s), %d warning(s)\n", vala_report_get_errors (vala_code_context_get_report (self->priv->context)), vala_report_get_warnings (vala_code_context_get_report (self->priv->context)));
 		}
-		return 1;
+		result = 1;
+		return result;
 	}
 }
 
 
+static char* string_strip (const char* self) {
+	char* result;
+	char* _result_;
+	g_return_val_if_fail (self != NULL, NULL);
+	_result_ = g_strdup (self);
+	g_strstrip (_result_);
+	result = _result_;
+	return result;
+}
+
+
 static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
+	gboolean result;
+	GError * _inner_error_;
 	char* package_path;
-	ValaSourceFile* _tmp2;
-	gboolean _tmp3;
+	ValaSourceFile* _tmp0_;
+	char* _tmp2_;
+	char* _tmp1_;
+	char* _tmp3_;
+	char* deps_filename;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (pkg != NULL, FALSE);
+	_inner_error_ = NULL;
 	if (vala_code_context_has_package (self->priv->context, pkg)) {
-		/* ignore multiple occurences of the same package*/
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
 	package_path = vala_code_context_get_package_path (self->priv->context, pkg, vala_vapi_gen_vapi_directories, _vala_array_length (vala_vapi_gen_vapi_directories));
 	if (package_path == NULL) {
-		gboolean _tmp1;
-		return (_tmp1 = FALSE, package_path = (g_free (package_path), NULL), _tmp1);
+		result = FALSE;
+		_g_free0 (package_path);
+		return result;
 	}
 	vala_code_context_add_package (self->priv->context, pkg);
-	_tmp2 = NULL;
-	vala_code_context_add_source_file (self->priv->context, _tmp2 = vala_source_file_new (self->priv->context, package_path, TRUE, NULL));
-	(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_source_file_unref (_tmp2), NULL));
-	return (_tmp3 = TRUE, package_path = (g_free (package_path), NULL), _tmp3);
+	vala_code_context_add_source_file (self->priv->context, _tmp0_ = vala_source_file_new (self->priv->context, package_path, TRUE, NULL));
+	_vala_source_file_unref0 (_tmp0_);
+	deps_filename = (_tmp3_ = g_build_filename (_tmp1_ = g_path_get_dirname (package_path), _tmp2_ = g_strdup_printf ("%s.deps", pkg), NULL), _g_free0 (_tmp2_), _g_free0 (_tmp1_), _tmp3_);
+	if (g_file_test (deps_filename, G_FILE_TEST_EXISTS)) {
+		{
+			char* deps_content;
+			gulong deps_len;
+			char* _tmp6_;
+			gboolean _tmp5_;
+			char* _tmp4_;
+			deps_content = NULL;
+			deps_len = 0UL;
+			_tmp4_ = NULL;
+			_tmp5_ = g_file_get_contents (deps_filename, &_tmp4_, &deps_len, &_inner_error_);
+			deps_content = (_tmp6_ = _tmp4_, _g_free0 (deps_content), _tmp6_);
+			_tmp5_;
+			if (_inner_error_ != NULL) {
+				_g_free0 (deps_content);
+				if (_inner_error_->domain == G_FILE_ERROR) {
+					goto __catch4_g_file_error;
+				}
+				goto __finally4;
+			}
+			{
+				char** _tmp7_;
+				char** dep_collection;
+				int dep_collection_length1;
+				int dep_it;
+				dep_collection = _tmp7_ = g_strsplit (deps_content, "\n", 0);
+				dep_collection_length1 = _vala_array_length (_tmp7_);
+				for (dep_it = 0; dep_it < _vala_array_length (_tmp7_); dep_it = dep_it + 1) {
+					char* dep;
+					dep = g_strdup (dep_collection[dep_it]);
+					{
+						char* _tmp8_;
+						dep = (_tmp8_ = string_strip (dep), _g_free0 (dep), _tmp8_);
+						if (_vala_strcmp0 (dep, "") != 0) {
+							if (!vala_vapi_gen_add_package (self, dep)) {
+								char* _tmp9_;
+								vala_report_error (NULL, _tmp9_ = g_strdup_printf ("%s, dependency of %s, not found in specified Vala API directories", dep, pkg));
+								_g_free0 (_tmp9_);
+							}
+						}
+						_g_free0 (dep);
+					}
+				}
+				dep_collection = (_vala_array_free (dep_collection, dep_collection_length1, (GDestroyNotify) g_free), NULL);
+			}
+			_g_free0 (deps_content);
+		}
+		goto __finally4;
+		__catch4_g_file_error:
+		{
+			GError * e;
+			e = _inner_error_;
+			_inner_error_ = NULL;
+			{
+				char* _tmp10_;
+				vala_report_error (NULL, _tmp10_ = g_strdup_printf ("Unable to read dependency file: %s", e->message));
+				_g_free0 (_tmp10_);
+				_g_error_free0 (e);
+			}
+		}
+		__finally4:
+		if (_inner_error_ != NULL) {
+			_g_free0 (package_path);
+			_g_free0 (deps_filename);
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+			g_clear_error (&_inner_error_);
+			return FALSE;
+		}
+	}
+	result = TRUE;
+	_g_free0 (package_path);
+	_g_free0 (deps_filename);
+	return result;
 }
 
 
 static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1) {
-	GError * inner_error;
+	char** result;
+	GError * _inner_error_;
 	g_return_val_if_fail (depsfile != NULL, NULL);
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	{
 		char* contents;
-		char* _tmp2;
-		gboolean _tmp1;
-		char* _tmp0;
-		char** _tmp3;
-		char** _tmp4;
-		char** _tmp5;
+		char* _tmp2_;
+		gboolean _tmp1_;
+		char* _tmp0_;
+		char** _tmp4_;
+		char* _tmp3_;
+		char** _tmp5_;
+		char** _tmp6_;
 		contents = NULL;
-		_tmp2 = NULL;
-		_tmp0 = NULL;
-		_tmp1 = g_file_get_contents (depsfile, &_tmp0, NULL, &inner_error);
-		contents = (_tmp2 = _tmp0, contents = (g_free (contents), NULL), _tmp2);
-		_tmp1;
-		if (inner_error != NULL) {
-			contents = (g_free (contents), NULL);
-			if (inner_error->domain == G_FILE_ERROR) {
-				goto __catch4_g_file_error;
+		_tmp0_ = NULL;
+		_tmp1_ = g_file_get_contents (depsfile, &_tmp0_, NULL, &_inner_error_);
+		contents = (_tmp2_ = _tmp0_, _g_free0 (contents), _tmp2_);
+		_tmp1_;
+		if (_inner_error_ != NULL) {
+			_g_free0 (contents);
+			if (_inner_error_->domain == G_FILE_ERROR) {
+				goto __catch5_g_file_error;
 			}
-			goto __finally4;
+			goto __finally5;
 		}
-		_tmp3 = NULL;
-		_tmp4 = NULL;
-		_tmp5 = NULL;
-		return (_tmp5 = (_tmp4 = _tmp3 = g_strsplit (g_strstrip (contents), "\n", 0), *result_length1 = _vala_array_length (_tmp3), _tmp4), contents = (g_free (contents), NULL), _tmp5);
+		result = (_tmp6_ = (_tmp5_ = _tmp4_ = g_strsplit (_tmp3_ = string_strip (contents), "\n", 0), _g_free0 (_tmp3_), _tmp5_), *result_length1 = _vala_array_length (_tmp4_), _tmp6_);
+		_g_free0 (contents);
+		return result;
+		_g_free0 (contents);
 	}
-	goto __finally4;
-	__catch4_g_file_error:
+	goto __finally5;
+	__catch5_g_file_error:
 	{
 		GError * e;
-		e = inner_error;
-		inner_error = NULL;
+		e = _inner_error_;
+		_inner_error_ = NULL;
 		{
-			gpointer _tmp6;
-			char** _tmp7;
-			/* deps files are optional*/
-			_tmp7 = NULL;
-			return (_tmp7 = (_tmp6 = NULL, *result_length1 = 0, _tmp6), (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), _tmp7);
+			gpointer _tmp7_;
+			result = (_tmp7_ = NULL, *result_length1 = 0, _tmp7_);
+			_g_error_free0 (e);
+			return result;
+			_g_error_free0 (e);
 		}
 	}
-	__finally4:
-	if (inner_error != NULL) {
-		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-		g_clear_error (&inner_error);
+	__finally5:
+	if (_inner_error_ != NULL) {
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+		g_clear_error (&_inner_error_);
 		return NULL;
 	}
 }
 
 
 static char* string_substring (const char* self, glong offset, glong len) {
+	char* result;
 	glong string_length;
 	const char* start;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -232,32 +336,31 @@ static char* string_substring (const char* self, glong offset, glong len) {
 	}
 	g_return_val_if_fail ((offset + len) <= string_length, NULL);
 	start = g_utf8_offset_to_pointer (self, offset);
-	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+	result = g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+	return result;
 }
 
 
 static gint vala_vapi_gen_run (ValaVAPIGen* self) {
-	ValaCodeContext* _tmp0;
-	char** _tmp15;
+	gint result;
+	ValaCodeContext* _tmp0_;
+	char** _tmp13_;
 	ValaParser* parser;
 	ValaGirParser* girparser;
 	ValaGIdlParser* gidlparser;
 	ValaSymbolResolver* resolver;
 	ValaSemanticAnalyzer* analyzer;
-	gboolean _tmp22;
-	gint _tmp29;
+	gboolean _tmp14_;
 	g_return_val_if_fail (self != NULL, 0);
-	_tmp0 = NULL;
-	self->priv->context = (_tmp0 = vala_code_context_new (), (self->priv->context == NULL) ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL)), _tmp0);
+	self->priv->context = (_tmp0_ = vala_code_context_new (), _vala_code_context_unref0 (self->priv->context), _tmp0_);
+	vala_code_context_set_profile (self->priv->context, VALA_PROFILE_GOBJECT);
 	vala_code_context_push (self->priv->context);
-	/* default package */
 	if (!vala_vapi_gen_add_package (self, "glib-2.0")) {
 		vala_report_error (NULL, "glib-2.0 not found in specified Vala API directories");
 	}
 	if (!vala_vapi_gen_add_package (self, "gobject-2.0")) {
 		vala_report_error (NULL, "gobject-2.0 not found in specified Vala API directories");
 	}
-	/* load packages from .deps file */
 	{
 		char** source_collection;
 		int source_collection_length1;
@@ -265,33 +368,28 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		source_collection = vala_vapi_gen_sources;
 		source_collection_length1 = _vala_array_length (vala_vapi_gen_sources);
 		for (source_it = 0; source_it < _vala_array_length (vala_vapi_gen_sources); source_it = source_it + 1) {
-			const char* _tmp7;
 			char* source;
-			_tmp7 = NULL;
-			source = (_tmp7 = source_collection[source_it], (_tmp7 == NULL) ? NULL : g_strdup (_tmp7));
+			source = g_strdup (source_collection[source_it]);
 			{
-				char* _tmp1;
-				char* _tmp2;
+				char* _tmp1_;
+				char* _tmp2_;
 				char* depsfile;
-				char** _tmp4;
+				char** _tmp4_;
 				gint deps_size;
 				gint deps_length1;
-				gint _tmp3;
+				gint _tmp3_;
 				char** deps;
 				if (!g_str_has_suffix (source, ".gi")) {
-					source = (g_free (source), NULL);
+					_g_free0 (source);
 					continue;
 				}
-				_tmp1 = NULL;
-				_tmp2 = NULL;
-				depsfile = (_tmp2 = g_strconcat (_tmp1 = string_substring (source, (glong) 0, g_utf8_strlen (source, -1) - g_utf8_strlen ("gi", -1)), "deps", NULL), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+				depsfile = (_tmp2_ = g_strconcat (_tmp1_ = string_substring (source, (glong) 0, g_utf8_strlen (source, -1) - g_utf8_strlen ("gi", -1)), "deps", NULL), _g_free0 (_tmp1_), _tmp2_);
 				if (!g_file_test (depsfile, G_FILE_TEST_EXISTS)) {
-					source = (g_free (source), NULL);
-					depsfile = (g_free (depsfile), NULL);
+					_g_free0 (source);
+					_g_free0 (depsfile);
 					continue;
 				}
-				_tmp4 = NULL;
-				deps = (_tmp4 = vala_vapi_gen_get_packages_from_depsfile (depsfile, &_tmp3), deps_length1 = _tmp3, deps_size = deps_length1, _tmp4);
+				deps = (_tmp4_ = vala_vapi_gen_get_packages_from_depsfile (depsfile, &_tmp3_), deps_length1 = _tmp3_, deps_size = deps_length1, _tmp4_);
 				{
 					char** dep_collection;
 					int dep_collection_length1;
@@ -299,29 +397,59 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 					dep_collection = deps;
 					dep_collection_length1 = deps_length1;
 					for (dep_it = 0; dep_it < deps_length1; dep_it = dep_it + 1) {
-						const char* _tmp6;
 						char* dep;
-						_tmp6 = NULL;
-						dep = (_tmp6 = dep_collection[dep_it], (_tmp6 == NULL) ? NULL : g_strdup (_tmp6));
+						dep = g_strdup (dep_collection[dep_it]);
 						{
 							if (!vala_vapi_gen_add_package (self, dep)) {
-								char* _tmp5;
-								_tmp5 = NULL;
-								vala_report_error (NULL, _tmp5 = g_strdup_printf ("%s not found in specified Vala API directories", dep));
-								_tmp5 = (g_free (_tmp5), NULL);
+								char* _tmp5_;
+								vala_report_error (NULL, _tmp5_ = g_strdup_printf ("%s not found in specified Vala API directories", dep));
+								_g_free0 (_tmp5_);
 							}
-							dep = (g_free (dep), NULL);
+							_g_free0 (dep);
 						}
 					}
 				}
-				source = (g_free (source), NULL);
-				depsfile = (g_free (depsfile), NULL);
+				_g_free0 (source);
+				_g_free0 (depsfile);
 				deps = (_vala_array_free (deps, deps_length1, (GDestroyNotify) g_free), NULL);
 			}
 		}
 	}
+	if (vala_vapi_gen_library != NULL) {
+		char* depsfile;
+		depsfile = g_strconcat (vala_vapi_gen_library, ".deps", NULL);
+		if (g_file_test (depsfile, G_FILE_TEST_EXISTS)) {
+			char** _tmp7_;
+			gint deps_size;
+			gint deps_length1;
+			gint _tmp6_;
+			char** deps;
+			deps = (_tmp7_ = vala_vapi_gen_get_packages_from_depsfile (depsfile, &_tmp6_), deps_length1 = _tmp6_, deps_size = deps_length1, _tmp7_);
+			{
+				char** dep_collection;
+				int dep_collection_length1;
+				int dep_it;
+				dep_collection = deps;
+				dep_collection_length1 = deps_length1;
+				for (dep_it = 0; dep_it < deps_length1; dep_it = dep_it + 1) {
+					char* dep;
+					dep = g_strdup (dep_collection[dep_it]);
+					{
+						if (!vala_vapi_gen_add_package (self, dep)) {
+							char* _tmp8_;
+							vala_report_error (NULL, _tmp8_ = g_strdup_printf ("%s not found in specified Vala API directories", dep));
+							_g_free0 (_tmp8_);
+						}
+						_g_free0 (dep);
+					}
+				}
+			}
+			deps = (_vala_array_free (deps, deps_length1, (GDestroyNotify) g_free), NULL);
+		}
+		_g_free0 (depsfile);
+	}
 	if (vala_vapi_gen_packages != NULL) {
-		char** _tmp10;
+		char** _tmp10_;
 		{
 			char** package_collection;
 			int package_collection_length1;
@@ -329,26 +457,23 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 			package_collection = vala_vapi_gen_packages;
 			package_collection_length1 = _vala_array_length (vala_vapi_gen_packages);
 			for (package_it = 0; package_it < _vala_array_length (vala_vapi_gen_packages); package_it = package_it + 1) {
-				const char* _tmp9;
 				char* package;
-				_tmp9 = NULL;
-				package = (_tmp9 = package_collection[package_it], (_tmp9 == NULL) ? NULL : g_strdup (_tmp9));
+				package = g_strdup (package_collection[package_it]);
 				{
 					if (!vala_vapi_gen_add_package (self, package)) {
-						char* _tmp8;
-						_tmp8 = NULL;
-						vala_report_error (NULL, _tmp8 = g_strdup_printf ("%s not found in specified Vala API directories", package));
-						_tmp8 = (g_free (_tmp8), NULL);
+						char* _tmp9_;
+						vala_report_error (NULL, _tmp9_ = g_strdup_printf ("%s not found in specified Vala API directories", package));
+						_g_free0 (_tmp9_);
 					}
-					package = (g_free (package), NULL);
+					_g_free0 (package);
 				}
 			}
 		}
-		_tmp10 = NULL;
-		vala_vapi_gen_packages = (_tmp10 = NULL, vala_vapi_gen_packages = (_vala_array_free (vala_vapi_gen_packages, _vala_array_length (vala_vapi_gen_packages), (GDestroyNotify) g_free), NULL), _tmp10);
+		vala_vapi_gen_packages = (_tmp10_ = NULL, vala_vapi_gen_packages = (_vala_array_free (vala_vapi_gen_packages, _vala_array_length (vala_vapi_gen_packages), (GDestroyNotify) g_free), NULL), _tmp10_);
 	}
 	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
-		return vala_vapi_gen_quit (self);
+		result = vala_vapi_gen_quit (self);
+		return result;
 	}
 	{
 		char** source_collection;
@@ -357,36 +482,33 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		source_collection = vala_vapi_gen_sources;
 		source_collection_length1 = _vala_array_length (vala_vapi_gen_sources);
 		for (source_it = 0; source_it < _vala_array_length (vala_vapi_gen_sources); source_it = source_it + 1) {
-			const char* _tmp14;
 			char* source;
-			_tmp14 = NULL;
-			source = (_tmp14 = source_collection[source_it], (_tmp14 == NULL) ? NULL : g_strdup (_tmp14));
+			source = g_strdup (source_collection[source_it]);
 			{
 				if (g_file_test (source, G_FILE_TEST_EXISTS)) {
-					ValaSourceFile* _tmp12;
-					_tmp12 = NULL;
-					vala_code_context_add_source_file (self->priv->context, _tmp12 = vala_source_file_new (self->priv->context, source, TRUE, NULL));
-					(_tmp12 == NULL) ? NULL : (_tmp12 = (vala_source_file_unref (_tmp12), NULL));
+					ValaSourceFile* _tmp11_;
+					vala_code_context_add_source_file (self->priv->context, _tmp11_ = vala_source_file_new (self->priv->context, source, TRUE, NULL));
+					_vala_source_file_unref0 (_tmp11_);
 				} else {
-					char* _tmp13;
-					_tmp13 = NULL;
-					vala_report_error (NULL, _tmp13 = g_strdup_printf ("%s not found", source));
-					_tmp13 = (g_free (_tmp13), NULL);
+					char* _tmp12_;
+					vala_report_error (NULL, _tmp12_ = g_strdup_printf ("%s not found", source));
+					_g_free0 (_tmp12_);
 				}
-				source = (g_free (source), NULL);
+				_g_free0 (source);
 			}
 		}
 	}
-	_tmp15 = NULL;
-	vala_vapi_gen_sources = (_tmp15 = NULL, vala_vapi_gen_sources = (_vala_array_free (vala_vapi_gen_sources, _vala_array_length (vala_vapi_gen_sources), (GDestroyNotify) g_free), NULL), _tmp15);
+	vala_vapi_gen_sources = (_tmp13_ = NULL, vala_vapi_gen_sources = (_vala_array_free (vala_vapi_gen_sources, _vala_array_length (vala_vapi_gen_sources), (GDestroyNotify) g_free), NULL), _tmp13_);
 	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
-		return vala_vapi_gen_quit (self);
+		result = vala_vapi_gen_quit (self);
+		return result;
 	}
 	parser = vala_parser_new ();
 	vala_parser_parse (parser, self->priv->context);
 	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
-		gint _tmp17;
-		return (_tmp17 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), _tmp17);
+		result = vala_vapi_gen_quit (self);
+		_vala_code_visitor_unref0 (parser);
+		return result;
 	}
 	girparser = vala_gir_parser_new ();
 	if (vala_vapi_gen_metadata_filename != NULL) {
@@ -394,126 +516,143 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	}
 	vala_gir_parser_parse (girparser, self->priv->context);
 	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
-		gint _tmp18;
-		return (_tmp18 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), _tmp18);
+		result = vala_vapi_gen_quit (self);
+		_vala_code_visitor_unref0 (parser);
+		_vala_code_visitor_unref0 (girparser);
+		return result;
 	}
 	gidlparser = vala_gidl_parser_new ();
 	vala_gidl_parser_parse (gidlparser, self->priv->context);
 	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
-		gint _tmp19;
-		return (_tmp19 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), _tmp19);
+		result = vala_vapi_gen_quit (self);
+		_vala_code_visitor_unref0 (parser);
+		_vala_code_visitor_unref0 (girparser);
+		_vala_code_visitor_unref0 (gidlparser);
+		return result;
 	}
 	resolver = vala_symbol_resolver_new ();
 	vala_symbol_resolver_resolve (resolver, self->priv->context);
 	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
-		gint _tmp20;
-		return (_tmp20 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), _tmp20);
+		result = vala_vapi_gen_quit (self);
+		_vala_code_visitor_unref0 (parser);
+		_vala_code_visitor_unref0 (girparser);
+		_vala_code_visitor_unref0 (gidlparser);
+		_vala_code_visitor_unref0 (resolver);
+		return result;
 	}
 	analyzer = vala_semantic_analyzer_new ();
 	vala_semantic_analyzer_analyze (analyzer, self->priv->context);
 	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
-		gint _tmp21;
-		return (_tmp21 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), (analyzer == NULL) ? NULL : (analyzer = (vala_code_visitor_unref (analyzer), NULL)), _tmp21);
+		result = vala_vapi_gen_quit (self);
+		_vala_code_visitor_unref0 (parser);
+		_vala_code_visitor_unref0 (girparser);
+		_vala_code_visitor_unref0 (gidlparser);
+		_vala_code_visitor_unref0 (resolver);
+		_vala_code_visitor_unref0 (analyzer);
+		return result;
 	}
-	_tmp22 = FALSE;
+	_tmp14_ = FALSE;
 	if (vala_vapi_gen_library == NULL) {
-		_tmp22 = vala_gir_parser_get_package_name (girparser) != NULL;
+		_tmp14_ = vala_gir_parser_get_package_name (girparser) != NULL;
 	} else {
-		_tmp22 = FALSE;
+		_tmp14_ = FALSE;
 	}
-	if (_tmp22) {
-		char* _tmp24;
-		const char* _tmp23;
-		_tmp24 = NULL;
-		_tmp23 = NULL;
-		vala_vapi_gen_library = (_tmp24 = (_tmp23 = vala_gir_parser_get_package_name (girparser), (_tmp23 == NULL) ? NULL : g_strdup (_tmp23)), vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL), _tmp24);
+	if (_tmp14_) {
+		char* _tmp15_;
+		vala_vapi_gen_library = (_tmp15_ = g_strdup (vala_gir_parser_get_package_name (girparser)), _g_free0 (vala_vapi_gen_library), _tmp15_);
 	}
 	if (vala_vapi_gen_library != NULL) {
 		ValaCodeWriter* interface_writer;
-		char* _tmp27;
-		char* _tmp28;
-		/* interface writer ignores external packages*/
+		char* _tmp18_;
+		char* _tmp19_;
 		{
-			GeeList* _tmp25;
-			GeeIterator* _tmp26;
+			GeeList* _tmp16_;
+			GeeIterator* _tmp17_;
 			GeeIterator* _file_it;
-			/* interface writer ignores external packages*/
-			_tmp25 = NULL;
-			_tmp26 = NULL;
-			_file_it = (_tmp26 = gee_iterable_iterator ((GeeIterable*) (_tmp25 = vala_code_context_get_source_files (self->priv->context))), (_tmp25 == NULL) ? NULL : (_tmp25 = (gee_collection_object_unref (_tmp25), NULL)), _tmp26);
-			/* interface writer ignores external packages*/
-			while (gee_iterator_next (_file_it)) {
+			_file_it = (_tmp17_ = gee_iterable_iterator ((GeeIterable*) (_tmp16_ = vala_code_context_get_source_files (self->priv->context))), _gee_collection_object_unref0 (_tmp16_), _tmp17_);
+			while (TRUE) {
 				ValaSourceFile* file;
-				/* interface writer ignores external packages*/
+				if (!gee_iterator_next (_file_it)) {
+					break;
+				}
 				file = (ValaSourceFile*) gee_iterator_get (_file_it);
 				if (!g_str_has_suffix (vala_source_file_get_filename (file), ".vapi")) {
 					vala_source_file_set_external_package (file, FALSE);
 				}
-				(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
+				_vala_source_file_unref0 (file);
 			}
-			(_file_it == NULL) ? NULL : (_file_it = (gee_collection_object_unref (_file_it), NULL));
+			_gee_collection_object_unref0 (_file_it);
 		}
-		interface_writer = vala_code_writer_new (FALSE);
-		_tmp27 = NULL;
-		vala_code_writer_write_file (interface_writer, self->priv->context, _tmp27 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library));
-		_tmp27 = (g_free (_tmp27), NULL);
-		_tmp28 = NULL;
-		vala_vapi_gen_library = (_tmp28 = NULL, vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL), _tmp28);
-		(interface_writer == NULL) ? NULL : (interface_writer = (vala_code_visitor_unref (interface_writer), NULL));
+		interface_writer = vala_code_writer_new (FALSE, FALSE);
+		vala_code_writer_write_file (interface_writer, self->priv->context, _tmp18_ = g_strdup_printf ("%s.vapi", vala_vapi_gen_library));
+		_g_free0 (_tmp18_);
+		vala_vapi_gen_library = (_tmp19_ = NULL, _g_free0 (vala_vapi_gen_library), _tmp19_);
+		_vala_code_visitor_unref0 (interface_writer);
 	}
-	return (_tmp29 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), (analyzer == NULL) ? NULL : (analyzer = (vala_code_visitor_unref (analyzer), NULL)), _tmp29);
+	result = vala_vapi_gen_quit (self);
+	_vala_code_visitor_unref0 (parser);
+	_vala_code_visitor_unref0 (girparser);
+	_vala_code_visitor_unref0 (gidlparser);
+	_vala_code_visitor_unref0 (resolver);
+	_vala_code_visitor_unref0 (analyzer);
+	return result;
 }
 
 
 static gint vala_vapi_gen_main (char** args, int args_length1) {
-	GError * inner_error;
+	gint result;
+	GError * _inner_error_;
 	ValaVAPIGen* vapigen;
-	gint _tmp3;
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	{
 		GOptionContext* opt_context;
 		opt_context = g_option_context_new ("- Vala API Generator");
 		g_option_context_set_help_enabled (opt_context, TRUE);
 		g_option_context_add_main_entries (opt_context, VALA_VAPI_GEN_options, NULL);
-		g_option_context_parse (opt_context, &args_length1, &args, &inner_error);
-		if (inner_error != NULL) {
-			(opt_context == NULL) ? NULL : (opt_context = (g_option_context_free (opt_context), NULL));
-			if (inner_error->domain == G_OPTION_ERROR) {
-				goto __catch5_g_option_error;
+		g_option_context_parse (opt_context, &args_length1, &args, &_inner_error_);
+		if (_inner_error_ != NULL) {
+			_g_option_context_free0 (opt_context);
+			if (_inner_error_->domain == G_OPTION_ERROR) {
+				goto __catch6_g_option_error;
 			}
-			goto __finally5;
+			goto __finally6;
 		}
-		(opt_context == NULL) ? NULL : (opt_context = (g_option_context_free (opt_context), NULL));
+		_g_option_context_free0 (opt_context);
 	}
-	goto __finally5;
-	__catch5_g_option_error:
+	goto __finally6;
+	__catch6_g_option_error:
 	{
 		GError * e;
-		e = inner_error;
-		inner_error = NULL;
+		e = _inner_error_;
+		_inner_error_ = NULL;
 		{
-			gint _tmp0;
 			fprintf (stdout, "%s\n", e->message);
 			fprintf (stdout, "Run '%s --help' to see a full list of available command line options.\n", args[0]);
-			return (_tmp0 = 1, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), _tmp0);
+			result = 1;
+			_g_error_free0 (e);
+			return result;
 		}
 	}
-	__finally5:
-	if (inner_error != NULL) {
-		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-		g_clear_error (&inner_error);
+	__finally6:
+	if (_inner_error_ != NULL) {
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+		g_clear_error (&_inner_error_);
 		return 0;
 	}
 	if (vala_vapi_gen_version) {
 		fprintf (stdout, "Vala API Generator %s\n", PACKAGE_VERSION);
-		return 0;
+		result = 0;
+		return result;
 	}
 	if (vala_vapi_gen_sources == NULL) {
 		fprintf (stderr, "No source file specified.\n");
-		return 1;
+		result = 1;
+		return result;
 	}
 	vapigen = vala_vapi_gen_new ();
-	return (_tmp3 = vala_vapi_gen_run (vapigen), (vapigen == NULL) ? NULL : (vapigen = (g_object_unref (vapigen), NULL)), _tmp3);
+	result = vala_vapi_gen_run (vapigen);
+	_g_object_unref0 (vapigen);
+	return result;
 }
 
 
@@ -525,7 +664,7 @@ int main (int argc, char ** argv) {
 
 ValaVAPIGen* vala_vapi_gen_construct (GType object_type) {
 	ValaVAPIGen * self;
-	self = g_object_newv (object_type, 0, NULL);
+	self = (ValaVAPIGen*) g_object_new (object_type, NULL);
 	return self;
 }
 
@@ -550,7 +689,7 @@ static void vala_vapi_gen_instance_init (ValaVAPIGen * self) {
 static void vala_vapi_gen_finalize (GObject* obj) {
 	ValaVAPIGen * self;
 	self = VALA_VAPI_GEN (obj);
-	(self->priv->context == NULL) ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL));
+	_vala_code_context_unref0 (self->priv->context);
 	G_OBJECT_CLASS (vala_vapi_gen_parent_class)->finalize (obj);
 }
 
@@ -565,7 +704,7 @@ GType vala_vapi_gen_get_type (void) {
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
 		for (i = 0; i < array_length; i = i + 1) {
@@ -574,6 +713,11 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 			}
 		}
 	}
+}
+
+
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	_vala_array_destroy (array, array_length, destroy_func);
 	g_free (array);
 }
 
@@ -590,5 +734,16 @@ static gint _vala_array_length (gpointer array) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return str1 != str2;
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
